<?php
/*
Plugin Name: Portfolio Post Type
Plugin URI: http://www.megathe.me
Description: Enables a portfolio post type and taxonomies.
Version: 1.0
Author: MegaTheme
Author URI: http://www.megathe.me
*/

/**
 * Registering a post type called "Portfolios".
 */
function mega_create_portfolio_type() {
	register_post_type( 'portfolio',
		array(
			'labels' => array(
				'name' => __( 'Portfolio', 'mega' ),
				'singular_name' => __( 'Portfolio', 'mega' ),
				'add_new' => _x( 'Add New', 'portfolio', 'mega' ),
				'add_new_item' => __( 'Add New Portfolio', 'mega' ),
				'edit_item' => __( 'Edit Portfolio', 'mega' ),
				'new_item' => __( 'New Portfolio', 'mega' ),
				'all_items' => __( 'All Portfolios', 'mega' ),
				'view_item' => __( 'View Portfolio', 'mega' ),
				'search_items' => __( 'Search Portfolio', 'mega' ),
				'not_found' =>  __( 'No portfolios found', 'mega' ),
				'not_found_in_trash' => __( 'No portfolios found in Trash', 'mega' )
			),
			'publicly_queryable' => true,
			'show_ui' => true, 
			'show_in_menu' => true,
			'show_in_nav_menus' => true,
			'query_var' => true,
			'rewrite' => array( 'slug' => 'portfolio', 'with_front' => false ),
			'capability_type' => 'post',
			'has_archive' => false,
			'public' => true,
			'hierarchical' => false,
			'menu_position' => 5,
			'exclude_from_search' => false,
			'supports' => array( 'title', 'editor', 'thumbnail', 'excerpt', 'revisions' ),
			'menu_icon' => 'dashicons-portfolio'
		)
	);
}
add_action( 'init', 'mega_create_portfolio_type' );

/**
* Displays the portfolio icon in the glance view for version 3.8 and up.
*/
function mega_add_icons() {

	if ( version_compare( $GLOBALS['wp_version'], '3.8', '>=' ) ) {
		?>
		<style>
			#menu-posts-portfolio .menu-icon-post div.wp-menu-image:before {
				content: "\f322" !important;
			}
		</style>
	<?php }
}
add_action( 'admin_head', 'mega_add_icons' );

// Create taxonomy, categories for the post type "Portfolios"
function mega_create_portfolio_taxonomies() {
	$labels = array(
		'name' => __( 'Categories', 'mega' ),
		'singular_name' => __( 'Category', 'mega' ),
		'all_items' => __( 'All', 'mega' ),
	); 
	register_taxonomy( 'portfolio-category', array( 'portfolio' ), array(
		'hierarchical' => true,
		'labels' => $labels,
		'show_ui' => true,
		'show_tagcloud' => false,
		'show_in_nav_menus' => false,
		'show_admin_column' => true,
		'query_var' => true
	) );
}
add_action( 'init', 'mega_create_portfolio_taxonomies' );

// Add filter to ensure the text Portfolio, or portfolio, is displayed when user updates a portfolio 
function mega_portfolio_updated_messages( $messages ) {
  global $post, $post_ID;

  $messages['portfolio'] = array(
    0 => '', // Unused. Messages start at index 1.
    1 => sprintf( __( 'Portfolio updated. <a href="%s">View portfolio</a>', 'mega' ), esc_url( get_permalink( $post_ID ) ) ),
    2 => __( 'Custom field updated.', 'mega' ),
    3 => __( 'Custom field deleted.', 'mega' ),
    4 => __( 'Portfolio updated.', 'mega' ),
    /* translators: %s: date and time of the revision */
    5 => isset( $_GET['revision'] ) ? sprintf( __( 'Portfolio restored to revision from %s', 'mega' ), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
    6 => sprintf( __( 'Portfolio published. <a href="%s">View portfolio</a>', 'mega' ), esc_url( get_permalink( $post_ID ) ) ),
    7 => __( 'Portfolio saved.', 'mega' ),
    8 => sprintf( __( 'Portfolio submitted. <a target="_blank" href="%s">Preview portfolio</a>', 'mega' ), esc_url( add_query_arg( 'preview', 'true', get_permalink( $post_ID ) ) ) ),
    9 => sprintf( __( 'Portfolio scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview portfolio</a>', 'mega' ),
      // translators: Publish box date format, see http://php.net/date
      date_i18n( __( 'M j, Y @ G:i', 'mega' ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
    10 => sprintf( __( 'Portfolio draft updated. <a target="_blank" href="%s">Preview portfolio</a>', 'mega' ), esc_url( add_query_arg( 'preview', 'true', get_permalink( $post_ID ) ) ) ),
  );

  return $messages;
}
add_filter( 'post_updated_messages', 'mega_portfolio_updated_messages' );

// Display contextual help for portfolio
function mega_portfolio_add_help_text( $contextual_help ) {
  // Get the current screen object
  $current_screen = get_current_screen();
  if ( 'portfolio' == $current_screen->id ) {
    $customize_display = '<p>' . __( 'The title field and the big Portfolio Editing Area are fixed in place, but you can reposition all the other boxes using drag and drop, and can minimize or expand them by clicking the title bar of each box. Use the Screen Options tab to unhide more boxes (Slug) or to choose a 1- or 2-column layout for this screen.', 'mega' ) . '</p>';

	$current_screen->add_help_tab( array(
		'id'      => 'customize-display',
		'title'   => __( 'Customizing This Display', 'mega' ),
		'content' => $customize_display,
	) );

	$title_and_editor  = '<p>' . __( '<strong>Title</strong> - Enter a title for your portfolio. After you enter a title, you&#8217;ll see the permalink below, which you can edit.', 'mega' ) . '</p>';
	$title_and_editor .= '<p>' . __( '<strong>Portfolio editor</strong> - Enter the text for your portfolio. There are two modes of editing: Visual and HTML. Choose the mode by clicking on the appropriate tab. Visual mode gives you a WYSIWYG editor. Click the last icon in the row to get a second row of controls. The HTML mode allows you to enter raw HTML along with your portfolio text. You can insert media files by clicking the icons above the portfolio editor and following the directions. You can go to the distraction-free writing screen via the Fullscreen icon in Visual mode (second to last in the top row) or the Fullscreen button in HTML mode (last in the row). Once there, you can make buttons visible by hovering over the top area. Exit Fullscreen back to the regular portfolio editor.', 'mega' ) . '</p>';

	$current_screen->add_help_tab( array(
		'id'      => 'title-portfolio-editor',
		'title'   => __( 'Title and Portfolio Editor', 'mega' ),
		'content' => $title_and_editor,
	) );

	$publish_box = '<p>' . __( '<strong>Publish</strong> - You can set the terms of publishing your portfolio in the Publish box. For Status, Visibility, and Publish (immediately), click on the Edit link to reveal more options. Visibility includes options for password-protecting a portfolio or making it stay at the top of your blog indefinitely (sticky). Publish (immediately) allows you to set a future or past date and time, so you can schedule a portfolio to be published in the future or backdate a portfolio.', 'mega' ) . '</p>';

	if ( current_theme_supports( 'post-thumbnails' ) && post_type_supports( 'post', 'thumbnail' ) ) {
		$publish_box .= '<p>' . __( '<strong>Featured Image</strong> - This allows you to associate an image with your portfolio without inserting it. This is usually useful only if your theme makes use of the featured image as a portfolio thumbnail on the home page, a custom header, etc.', 'mega' ) . '</p>';
	}

	$current_screen->add_help_tab( array(
		'id'      => 'publish-box',
		'title'   => __( 'Publish Box', 'mega' ),
		'content' => $publish_box,
	) );

	$current_screen->set_help_sidebar(
			'<p>' . sprintf( __( 'You can also create portfolio with the <a href="%s">Press This bookmarklet</a>.' ), 'mega' ) . '</p>' .
			'<p><strong>' . __( 'For more information:', 'mega' ) . '</strong></p>' .
			'<p>' . __( '<a href="http://codex.wordpress.org/Posts_Add_New_Screen" target="_blank">Documentation on Writing and Editing Posts</a>', 'mega' ) . '</p>' .
			'<p>' . __( '<a href="http://wordpress.org/support/" target="_blank">Support Forums</a>', 'mega' ) . '</p>'
	);
  }
  return $contextual_help;
}
add_action( 'admin_head', 'mega_portfolio_add_help_text' );

// Enable portfolio in Nav Menus by default
function mega_display_portfolio_post_type_nav_box() {

    $hidden_nav_boxes = get_user_option( 'metaboxhidden_nav-menus' );

    $post_type = 'portfolio'; // Can also be a taxonomy slug
    $post_type_nav_box = 'add-post-type-'. $post_type;

    if ( is_array( $hidden_nav_boxes ) && in_array( $post_type_nav_box, $hidden_nav_boxes ) ) {
        foreach ( $hidden_nav_boxes as $i => $nav_box ) {
            if ( $nav_box == $post_type_nav_box ) {
                unset( $hidden_nav_boxes[$i] );
			}
        }
        update_user_option( get_current_user_id(), 'metaboxhidden_nav-menus', $hidden_nav_boxes );
    }
}
add_action( 'admin_init', 'mega_display_portfolio_post_type_nav_box' );

// Moving the portfolio menu above the Posts menu using menu_position
function mega_edit_admin_menu() {
    global $menu;
    $menu[7] = $menu[5]; // Copy 'Posts' to a new menu location
    unset( $menu[5] ); // Unset Posts (from original position)
    ksort( $menu ); // Sort the menu
}
add_action( 'admin_head', 'mega_edit_admin_menu' );

/**
 * Using a Custom Walker Function for wp_list_categories for portfolio.
 */
class Mega_Walker_Portfolio_Category extends Walker_Category {
   function start_el( &$output, $category, $depth = 0, $args = array(), $id = 0 ) {
      extract( $args );
      $cat_name = esc_attr( $category->name );
      $cat_name = apply_filters( 'mega_list_cats', $cat_name, $category );
	  $link = '<a href="#" data-filter=".'. esc_attr( $category->slug ) .'" ';
      if ( ! ( $use_desc_for_title == 0 || empty($category->description) ) )
         $link .= 'title="' . esc_attr( strip_tags( apply_filters( 'mega_category_description', $category->description, $category ) ) ) . '"';
      $link .= '>';
      $link .= $cat_name;
      $link .= '</a>';
      if ( ( ! empty( $feed_image ) ) || ( ! empty( $feed ) ) ) {
         $link .= ' ';
         if ( empty( $feed_image ) )
            $link .= '(';
         $link .= '<a href="' . esc_url( get_category_feed_link( $category->term_id, $feed_type ) ) . '"';
         if ( empty( $feed ) )
            $alt = ' alt="' . sprintf( esc_html__( 'Feed for all posts filed under %s', 'mega' ), $cat_name ) . '"';
         else {
            $title = ' title="' . esc_attr( $feed ) . '"';
            $alt = ' alt="' . esc_attr( $feed ) . '"';
            $name = $feed;
            $link .= $title;
         }
         $link .= '>';
         if ( empty( $feed_image ) )
            $link .= $name;
         else
            $link .= "<img src='$feed_image'$alt$title" . ' />';
         $link .= '</a>';
         if ( empty( $feed_image ) )
            $link .= ')';
      }
      if ( isset( $show_count ) && $show_count )
         $link .= ' (' . intval( $category->count ) . ')';
      if ( isset( $show_date ) && $show_date ) {
         $link .= ' ' . gmdate( 'Y-m-d', $category->last_update_timestamp );
      }
      if ( isset( $current_category ) && $current_category )
         $_current_category = get_category( $current_category );
      if ( 'list' == $args['style'] ) {
          $output .= '<li class="segment-'. rand( 2, 99 ).'"';
          $class = 'cat-item cat-item-'. $category->term_id;
          if ( isset( $current_category ) && $current_category && ( $category->term_id == $current_category ) )
             $class .=  ' current-cat';
          elseif ( isset( $_current_category ) && $_current_category && ( $category->term_id == $_current_category->parent ) )
             $class .=  ' current-cat-parent';
          $output .=  '';
          $output .= ">$link\n";
       } else {
          $output .= "\t$link<br />\n";
       }
   }
}

/**
 * Adds custom taxonomies to the post class.
 */
if ( ! function_exists( 'mega_custom_taxonomy_post_class' ) ) {
	function mega_custom_taxonomy_post_class( $classes, $class, $ID ) {

			if ( ( 'portfolio' == get_post_type() ) ) {
				$taxonomy = 'portfolio-category';
			}
			
			if ( ! empty( $taxonomy ) ) {
				$terms = get_the_terms( (int) $ID, $taxonomy );
					if ( ! empty( $terms ) ) {
						foreach ( (array) $terms as $order => $term ) {
							if ( ! in_array( $term->slug, $classes ) ) {
								$classes[] = $term->slug;
							}
						}
					}
			}
            return $classes;
        }
    }
add_filter( 'post_class', 'mega_custom_taxonomy_post_class', 10, 3 );

// Disable canonical redirect for portfolio custom post type to get pagination work on homepage
function mega_disable_redirect_canonical( $redirect_url ) {
    if ( is_front_page() && post_type_exists( 'portfolio' ) ) {
		$redirect_url = false;
	}
    return $redirect_url;
}
add_filter( 'redirect_canonical', 'mega_disable_redirect_canonical' );

// Add New Column
function mega_columns_head( $defaults ) {
    $defaults['featured_image'] = __( 'Featured Image', 'mega' );
	$new = array();
    $featured_image = $defaults['featured_image']; // save the featured_image column
    unset( $defaults['featured_image'] ); // remove it from the columns list

    foreach( $defaults as $key => $value ) {
        if ( $key == 'taxonomy-portfolio-category' ) { // when we find the taxonomy-portfolio-category column
           $new['featured_image'] = $featured_image; // put the featured_image column before it
        }    
        $new[$key]=$value;
    }  

    return $new;
}
add_filter( 'manage_portfolio_posts_columns', 'mega_columns_head' );
 
// Show the Featured Image
function mega_columns_content( $column_name, $post_ID ) {
    if ( $column_name == 'featured_image' ) {
        $post_thumbnail_id = get_post_thumbnail_id( $post_ID );
		if ( $post_thumbnail_id ) {
			$post_thumbnail_img = wp_get_attachment_image_src( $post_thumbnail_id, 'thumbnail' );
			echo '<img width="' . $post_thumbnail_img[1] . '" height="' . $post_thumbnail_img[2] . '" src="' . $post_thumbnail_img[0] . '" alt="" loading="lazy" />';
		} else {
			echo '<span aria-hidden="true">—</span>';
			echo '<span class="screen-reader-text">No categories</span>';
		}
    }
}
add_action( 'manage_portfolio_posts_custom_column', 'mega_columns_content', 10, 2 );

// Featured Image Column
function mega_print_portfolio_posts_custom_column_style() {
		
		$portfolio_posts_custom_column_css = "
	
		/* Portfolio Featured Image Column */
		.column-featured_image {
			width: 10%;
		}
		.column-featured_image img {
			max-width: 40px;
			height: auto;
		}";
		
		wp_add_inline_style( 'list-tables', $portfolio_posts_custom_column_css );
}
add_action( 'admin_enqueue_scripts', 'mega_print_portfolio_posts_custom_column_style' );

// Portfolio Settings Meta Box
if ( ! function_exists( 'mega_portfolio_settings_add_meta_box' ) ) {
	function mega_portfolio_settings_add_meta_box(){
		add_meta_box( 'mega_portfolio_settings', esc_html__( 'Portfolio Settings', 'mega' ), 'mega_portfolio_settings_meta_box', 'portfolio', 'side', 'low' );
	}
}
add_action( 'add_meta_boxes', 'mega_portfolio_settings_add_meta_box' );

if ( ! function_exists( 'mega_backend_scripts_portfolio_settings_meta_box' ) ) {
	function mega_backend_scripts_portfolio_settings_meta_box( $hook ) {
		if ( in_array( $hook, array( 'post.php', 'post-new.php' ) ) ) {
			$screen = get_current_screen();
			
			if ( is_object( $screen ) && 'portfolio' == $screen->post_type ) {
				wp_enqueue_style( 'wp-color-picker');
				wp_enqueue_script( 'wp-color-picker');
			}
		}
	}
}
add_action( 'admin_enqueue_scripts', 'mega_backend_scripts_portfolio_settings_meta_box');

if ( ! function_exists( 'mega_portfolio_settings_meta_box' ) ) {
	function mega_portfolio_settings_meta_box( $post ) {
		$custom = get_post_custom( $post->ID );
		$background_color = ( isset( $custom['background_color'][0] ) ) ? $custom['background_color'][0] : '';
		$text_color = ( isset( $custom['text_color'][0] ) ) ? $custom['text_color'][0] : '';
		$custom_url = ( isset( $custom['custom_url'][0] ) ) ? $custom['custom_url'][0] : '';
		wp_nonce_field( 'mega_portfolio_settings_meta_box', 'mega_portfolio_settings_meta_box_nonce' );
		?>
		<script>
		jQuery(document).ready(function($){
		    $('.color_field').each(function(){
        		$(this).wpColorPicker();
			});
		});
		</script>
		<style>
			.mt-meta-box-title { 
				margin-bottom: 6px;
			}
		</style>
		<div class="pagebox">
			<p class="mt-meta-box-title"><?php esc_attr_e( 'Background color', 'mega' ); ?></p>
		    <input class="color_field color-picker-hex wp-color-picker" type="text" maxlength="7" name="background_color" value="<?php esc_attr_e( $background_color ); ?>"/>
			
			<p class="mt-meta-box-title"><?php esc_attr_e( 'Text color', 'mega' ); ?></p>
		    <input class="color_field color-picker-hex wp-color-picker" type="text" maxlength="7" name="text_color" value="<?php esc_attr_e( $text_color ); ?>"/>
			
			<p class="mt-meta-box-title"><?php esc_attr_e( 'Custom URL', 'mega' ); ?></p>
		    <input type="text" name="custom_url" value="<?php esc_attr_e( $custom_url ); ?>"/>
		</div>
		<?php
	}
}

if ( ! function_exists( 'mega_save_portfolio_settings_meta_box' ) ) {
	function mega_save_portfolio_settings_meta_box( $post_id ) {
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}
		if( ! current_user_can( 'edit_pages' ) ) {
			return;
		}
		if ( ! isset( $_POST['background_color'] ) || ! wp_verify_nonce( $_POST['mega_portfolio_settings_meta_box_nonce'], 'mega_portfolio_settings_meta_box' ) ) {
			return;
		}
		if ( ! isset( $_POST['text_color'] ) || ! wp_verify_nonce( $_POST['mega_portfolio_settings_meta_box_nonce'], 'mega_portfolio_settings_meta_box' ) ) {
			return;
		}
		if ( ! isset( $_POST['custom_url'] ) || ! wp_verify_nonce( $_POST['mega_portfolio_settings_meta_box_nonce'], 'mega_portfolio_settings_meta_box' ) ) {
			return;
		}
		$background_color = ( isset( $_POST['background_color'] ) && $_POST['background_color'] != '' ) ? $_POST['background_color'] : '';
		$text_color = ( isset( $_POST['text_color'] ) && $_POST['text_color'] != '' ) ? $_POST['text_color'] : '';
		$custom_url = ( isset( $_POST['custom_url'] ) && $_POST['custom_url'] != '' ) ? $_POST['custom_url'] : '';
		update_post_meta( $post_id, 'background_color', $background_color );
		update_post_meta( $post_id, 'text_color', $text_color );
		update_post_meta( $post_id, 'custom_url', $custom_url );
	}
}
add_action( 'save_post', 'mega_save_portfolio_settings_meta_box' );

// Portfolio Gallery Meta Box
if ( ! function_exists( 'mega_portfolio_gallery_add_meta_box' ) ) {
	function mega_portfolio_gallery_add_meta_box(){
		add_meta_box( 'mega_portfolio_gallery', esc_html__( 'Portfolio Gallery', 'mega' ), 'mega_portfolio_gallery_meta_box', 'portfolio', 'side', 'low' );
	}
}
add_action( 'add_meta_boxes', 'mega_portfolio_gallery_add_meta_box' );

if ( ! function_exists( 'mega_portfolio_gallery_meta_box' ) ) {
	function mega_portfolio_gallery_meta_box( $post ) {
		$custom = get_post_custom( $post->ID );
		$portfolio_image_gallery = ( isset( $custom['portfolio_image_gallery'][0] ) ) ? $custom['portfolio_image_gallery'][0] : '';
		wp_nonce_field( 'mega_portfolio_gallery_meta_box', 'mega_portfolio_gallery_meta_box_nonce' );
		?>
		<script>
		jQuery(document).ready(function($){
		    // Portfolio gallery file uploads.
			var portfolio_gallery_frame;
			var $image_gallery_ids = $( '#portfolio_image_gallery' );
			var $portfolio_images    = $( '#portfolio_images_container' ).find( 'ul.portfolio_images' );

			$( '.add_portfolio_images' ).on( 'click', 'a', function( event ) {
				var $el = $( this );

				event.preventDefault();

				// If the media frame already exists, reopen it.
				if ( portfolio_gallery_frame ) {
					portfolio_gallery_frame.open();
					return;
				}

				// Create the media frame.
				portfolio_gallery_frame = wp.media.frames.portfolio_gallery = wp.media({
					// Set the title of the modal.
					title: $el.data( 'choose' ),
					button: {
						text: $el.data( 'update' )
					},
					states: [
						new wp.media.controller.Library({
							title: $el.data( 'choose' ),
							filterable: 'all',
							multiple: true
						})
					]
				});

				// When an image is selected, run a callback.
				portfolio_gallery_frame.on( 'select', function() {
					var selection = portfolio_gallery_frame.state().get( 'selection' );
					var attachment_ids = $image_gallery_ids.val();

					selection.map( function( attachment ) {
						attachment = attachment.toJSON();

						if ( attachment.id ) {
							attachment_ids   = attachment_ids ? attachment_ids + ',' + attachment.id : attachment.id;
							var attachment_image = attachment.sizes && attachment.sizes.thumbnail ? attachment.sizes.thumbnail.url : attachment.url;

							$portfolio_images.append(
								'<li class="image" data-attachment_id="' + attachment.id + '"><img src="' + attachment_image +
								'" /><ul class="actions"><li><a href="#" class="delete" title="' + $el.data('delete') + '">' +
								$el.data('text') + '</a></li></ul></li>'
							);
						}
					});

					$image_gallery_ids.val( attachment_ids );
				});

				// Finally, open the modal.
				portfolio_gallery_frame.open();
			});
			
			// Image ordering.
			$portfolio_images.sortable({
				items: 'li.image',
				cursor: 'move',
				scrollSensitivity: 40,
				forcePlaceholderSize: true,
				forceHelperSize: false,
				helper: 'clone',
				opacity: 0.65,
				placeholder: 'mega-metabox-sortable-placeholder',
				start: function( event, ui ) {
					ui.item.css( 'background-color', '#f6f6f6' );
				},
				stop: function( event, ui ) {
					ui.item.removeAttr( 'style' );
				},
				update: function() {
					var attachment_ids = '';

					$( '#portfolio_images_container' ).find( 'ul li.image' ).css( 'cursor', 'default' ).each( function() {
						var attachment_id = $( this ).attr( 'data-attachment_id' );
						attachment_ids = attachment_ids + attachment_id + ',';
					});

					$image_gallery_ids.val( attachment_ids );
				}
			});
			
			// Remove images.
			$( '#portfolio_images_container' ).on( 'click', 'a.delete', function() {
				$( this ).closest( 'li.image' ).remove();

				var attachment_ids = '';

				$( '#portfolio_images_container' ).find( 'ul li.image' ).css( 'cursor', 'default' ).each( function() {
					var attachment_id = $( this ).attr( 'data-attachment_id' );
					attachment_ids = attachment_ids + attachment_id + ',';
				});

				$image_gallery_ids.val( attachment_ids );

				// Remove any lingering tooltips.
				$( '#tiptip_holder' ).removeAttr( 'style' );
				$( '#tiptip_arrow' ).removeAttr( 'style' );

				return false;
			});
		});
		</script>
		<style>
		.add_portfolio_images {}
		#portfolio_images_container {}
		#portfolio_images_container ul {
			margin: 0;
			padding: 0;
		}
		#portfolio_images_container ul::after,
		#portfolio_images_container ul::before {
			content: ' ';
			display: table;
		}
		#portfolio_images_container ul::after {
			clear: both;
		}
		#portfolio_images_container ul li.add,
		#portfolio_images_container ul li.image,
		#portfolio_images_container ul li.mega-metabox-sortable-placeholder {
			width: 80px;
			float: left;
			cursor: move;
			border: 1px solid #d5d5d5;
			margin: 4px 4px 0 0;
			background: #f7f7f7;
			border-radius: 2px;
			position: relative;
			box-sizing: border-box;
		}
		#portfolio_images_container ul li.add img,
		#portfolio_images_container ul li.image img,
		#portfolio_images_container ul li.mega-metabox-sortable-placeholder img {
			width: 100%;
			height: auto;
			display: block;
		}
		#portfolio_images_container ul li.mega-metabox-sortable-placeholder {
			border: 3px dashed #ddd;
			position: relative;
		}
		#portfolio_images_container ul li.mega-metabox-sortable-placeholder::after {
			font-family: Dashicons;
			speak: none;
			font-weight: 400;
			font-variant: normal;
			text-transform: none;
			line-height: 1;
			-webkit-font-smoothing: antialiased;
			margin: 0;
			text-indent: 0;
			position: absolute;
			top: 0;
			left: 0;
			width: 100%;
			height: 100%;
			text-align: center;
			content: "\f161";
			font-size: 2.618em;
			line-height: 72px;
			color: #ddd;
		}
		#portfolio_images_container ul ul.actions {
			position: absolute;
			top: -8px;
			right: -8px;
			padding: 2px;
			display: none;
		}
		@media (max-width: 768px) {
			#portfolio_images_container ul ul.actions {
				display:block;
			}
		}
		#portfolio_images_container ul ul.actions li {
			float: right;
			margin: 0 0 0 2px;
		}
		#portfolio_images_container ul ul.actions li a {
			width: 1em;
			height: 1em;
			margin: 0;
			height: 0;
			display: block;
			overflow: hidden;
		}
		#portfolio_images_container ul ul.actions li a.tips {
			cursor: pointer;
		}
		#portfolio_images_container ul ul.actions li a.delete {
			display: block;
			text-indent: -9999px;
			position: relative;
			height: 1em;
			width: 1em;
			font-size: 1.4em;
		}
		#portfolio_images_container ul ul.actions li a.delete::before {
			font-family: Dashicons;
			speak: none;
			font-weight: 400;
			font-variant: normal;
			text-transform: none;
			line-height: 1;
			-webkit-font-smoothing: antialiased;
			margin: 0;
			text-indent: 0;
			position: absolute;
			top: 0;
			left: 0;
			width: 100%;
			height: 100%;
			text-align: center;
			content: "\f153";
			color: #999;
			background: #fff;
			border-radius: 50%;
			height: 1em;
			width: 1em;
			line-height: 1em;
		}
		#portfolio_images_container ul ul.actions li a.delete:hover::before {
			color: #a00;
		}
		#portfolio_images_container ul li:hover ul.actions {
			display: block;
		}
		</style>
		<div class="pagebox">
			<div id="portfolio_images_container">
				<ul class="portfolio_images">
					<?php
					
					$attachments = get_post_meta( get_the_ID(), 'portfolio_image_gallery', true );
					$attachments = explode( ',', $attachments );
					$update_meta = false;
					$updated_gallery_ids = array();

					if ( ! empty( $attachments ) ) {
						foreach ( $attachments as $attachment_id ) {
							$attachment = wp_get_attachment_image( $attachment_id, 'thumbnail' );

							// if attachment is empty skip.
							if ( empty( $attachment ) ) {
								$update_meta = true;
								continue;
							}
							?>
							<li class="image" data-attachment_id="<?php echo esc_attr( $attachment_id ); ?>">
								<?php echo $attachment; ?>
								<ul class="actions">
									<li><a href="#" class="delete tips" data-tip="<?php esc_attr_e( 'Delete image', 'mega' ); ?>"><?php esc_html_e( 'Delete', 'mega' ); ?></a></li>
								</ul>
							</li>
							<?php

							// rebuild ids to be saved.
							$updated_gallery_ids[] = $attachment_id;
						}

					}
					?>
				</ul>
				
				<input type="hidden" id="portfolio_image_gallery" name="portfolio_image_gallery" value="<?php echo esc_attr( implode( ',', $updated_gallery_ids ) ); ?>" />
			</div>
			
			<p class="add_portfolio_images">
				<a href="#" data-choose="<?php esc_attr_e( 'Add images to portfolio gallery', 'mega' ); ?>" data-update="<?php esc_attr_e( 'Add to gallery', 'mega' ); ?>" data-delete="<?php esc_attr_e( 'Delete image', 'mega' ); ?>" data-text="<?php esc_attr_e( 'Delete', 'mega' ); ?>"><?php esc_html_e( 'Add portfolio gallery images', 'mega' ); ?></a>
			</p>
		</div>
		<?php
	}
}

if ( ! function_exists( 'mega_save_portfolio_gallery_meta_box' ) ) {
	function mega_save_portfolio_gallery_meta_box( $post_id ) {
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}
		if( ! current_user_can( 'edit_pages' ) ) {
			return;
		}
		if ( ! isset( $_POST['portfolio_image_gallery'] ) || ! wp_verify_nonce( $_POST['mega_portfolio_gallery_meta_box_nonce'], 'mega_portfolio_gallery_meta_box' ) ) {
			return;
		}
		$portfolio_image_gallery = ( isset( $_POST['portfolio_image_gallery'] ) && $_POST['portfolio_image_gallery'] != '' ) ? $_POST['portfolio_image_gallery'] : '';
		update_post_meta( $post_id, 'portfolio_image_gallery', $portfolio_image_gallery );
	}
}
add_action( 'save_post', 'mega_save_portfolio_gallery_meta_box' );
