<?php
/**
 * The Header.
 *
 * @package WordPress
 * @subpackage Skylab
 * @since Skylab 1.0
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>" />
<meta name="viewport" content="width=device-width, initial-scale=1" />

<meta http-equiv="X-UA-Compatible" content="IE=Edge">

<link rel="profile" href="https://gmpg.org/xfn/11" />
	
<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php wp_body_open(); ?>

	<?php $header_behavior = get_theme_mod( 'header_behavior', 'normal' ); ?>
	<?php $center_logo_and_menu = get_theme_mod( 'center_logo_and_menu' ); ?>
	<?php $header_position = get_theme_mod( 'header_position', 'top' ); ?>
	<?php $top_bar = get_theme_mod( 'top_bar' ); ?>
	<?php $top_bar_behavior = get_theme_mod( 'top_bar_behavior', 'normal' ); ?>
	
	<?php $page_transition_effect = get_theme_mod( 'page_transition_effect', 'fade' ); ?>
	<?php if ( $page_transition_effect == 'up_down' || $page_transition_effect == 'left_right' ) { ?>
		<div class="page-transition-overlay"></div>
	<?php } ?>

	<div id="page" class="hfeed">
	
	<?php // Search ?>
	<?php $search_position = get_theme_mod( 'search_position', 'none' ); ?>
	<?php if ( $search_position == 'header' || $search_position == 'top_bar' ) { ?>
		<div class="search-wrapper">
			<div class="search-wrapper-helper">
				<button class="close-button"><svg viewBox="0 0 40 40"><path d="M4.3,35.7L35.7,4.3"></path><path d="M4.3,4.3l31.4,31.4"></path></svg></button>
				<div class="search-form-wrapper">
					<?php get_search_form(); // Search form ?>
				</div>
			</div>
		</div>
	<?php } ?>

	<?php // Top Bar ?>
	<?php if ( ! empty( $top_bar ) ) { ?>
		<?php get_template_part( 'top-bar' ); ?>
	<?php } ?>

	<?php if ( $header_position == 'left' || $header_position == 'right' ) { ?>
	<div id="header-main-wrapper">
	<?php } ?>
	<div id="header-wrapper" class="header-wrapper main-header <?php if ( $header_behavior == 'fixed' && empty( $top_bar ) || $header_behavior == 'fixed' && ! empty( $top_bar ) && $top_bar_behavior != 'normal' && $top_bar_behavior != 'fixed_on_scroll' && empty( $center_logo_and_menu ) ) { ?>fixed<?php } ?>">
		
		<?php // Mobile Menu ?>
		<?php if ( has_nav_menu( 'primary' ) || has_nav_menu( 'secondary' ) || has_nav_menu( 'sliding' ) || has_nav_menu( 'top_bar' ) ) { ?>
			<?php $mobile_menu_align = get_theme_mod( 'mobile_menu_align', 'left' ); ?>
			<div class="mobile-menu-wrapper clearfix align-<?php echo esc_attr( $mobile_menu_align ); ?>">
				<div class="mobile-menu-wrapper-helper">
					<button class="close-button"><svg viewBox="0 0 40 40"><path d="M4.3,35.7L35.7,4.3"></path><path d="M4.3,4.3l31.4,31.4"></path></svg></button>
					<div class="access-mobile-menu-wrapper clearfix">
							<?php // Primary Menu ?>
							<?php if ( has_nav_menu( 'primary' ) ) { ?>
								<?php wp_nav_menu( array(
									'theme_location' => 'primary',
									'menu_class' => 'nav-menu-mobile',
									'container_class' => 'nav-menu nav-menu-mobile-wrapper nav-menu-primary-header',
									'before' => '',
									'after' => '',
									'link_before' => '<span>',
									'link_after' => '</span>' )
								); ?>
							<?php } ?>
							
							<?php // Secondary Menu ?>
							<?php if ( has_nav_menu( 'secondary' ) ) { ?>
								<?php wp_nav_menu( array(
									'theme_location' => 'secondary',
									'menu_class' => 'nav-menu-mobile',
									'container_class' => 'nav-menu nav-menu-mobile-wrapper nav-menu-secondary-header',
									'before' => '',
									'after' => '',
									'link_before' => '<span>',
									'link_after' => '</span>' )
								); ?>
							<?php } ?>
							
							<?php // Sliding Menu ?>
							<?php if ( has_nav_menu( 'sliding' ) ) { ?>
								<?php wp_nav_menu( array(
									'theme_location' => 'sliding',
									'menu_class' => 'nav-menu-mobile',
									'container_class' => 'nav-menu nav-menu-mobile-wrapper nav-menu-sliding',
									'before' => '',
									'after' => '',
									'link_before' => '<span>',
									'link_after' => '</span>' )
								); ?>
							<?php } ?>
							
							<?php if ( ! empty( $top_bar ) ) { ?>
							<?php // Top Bar Menu ?>
							<?php if ( has_nav_menu( 'top_bar' ) ) { ?>
								<?php wp_nav_menu( array(
									'theme_location' => 'top_bar',
									'menu_class' => 'nav-menu-mobile',
									'container_class' => 'nav-menu nav-menu-mobile-wrapper nav-menu-top-bar',
									'before' => '',
									'after' => '',
									'link_before' => '<span>',
									'link_after' => '</span>' )
								); ?>
							<?php } ?>
							<?php } ?>
							
							<?php $top_bar_info = get_theme_mod( 'top_bar_info' ); ?>
							<?php $header_info = get_theme_mod( 'header_info' ); ?>
							<?php $social_links_position = get_theme_mod( 'social_links_position', 'none' ); ?>
							<?php if ( $social_links_position == 'header' || $social_links_position == 'top_bar' && ! empty( $top_bar ) || $search_position == 'header' || $search_position == 'top_bar' && ! empty( $top_bar ) || ! empty( $top_bar_info ) || has_nav_menu( 'top_bar' ) || ! empty( $header_info ) ) { ?>
							<div class="mobile-elements-wrapper">
							<?php } ?>
							
							<?php // Social Links ?>
							<?php if ( $social_links_position == 'header' || $social_links_position == 'top_bar' ) { ?>
								<?php $social_links_style = get_theme_mod( 'social_links_style', 1 ); ?>
								<div class="social-links-wrapper-mobile social-links-style-<?php echo esc_attr( $social_links_style ); ?>">
									<?php get_template_part( 'social-links' ); ?>
								</div>
							<?php } ?>
							
							<?php // Search ?>
							<?php if ( $search_position == 'header' || $search_position == 'top_bar' ) { ?>	
								<div class="search-header-wrapper">
									<span class="search-header-icon"><svg viewBox="0 0 512 512"><path d="M225.474,0C101.151,0,0,101.151,0,225.474c0,124.33,101.151,225.474,225.474,225.474 c124.33,0,225.474-101.144,225.474-225.474C450.948,101.151,349.804,0,225.474,0z M225.474,409.323 c-101.373,0-183.848-82.475-183.848-183.848S124.101,41.626,225.474,41.626s183.848,82.475,183.848,183.848 S326.847,409.323,225.474,409.323z"></path><path d="M505.902,476.472L386.574,357.144c-8.131-8.131-21.299-8.131-29.43,0c-8.131,8.124-8.131,21.306,0,29.43l119.328,119.328 c4.065,4.065,9.387,6.098,14.715,6.098c5.321,0,10.649-2.033,14.715-6.098C514.033,497.778,514.033,484.596,505.902,476.472z"></path></svg></span>
								</div>
							<?php } ?>
							
							<?php if ( ! empty( $top_bar ) ) { ?>
							<?php // Top Bar Info 2 ?>
							<?php $top_bar_info_2 = get_theme_mod( 'top_bar_info_2' ); ?>
							<?php if ( ! empty( $top_bar_info_2 ) ) { ?>
								<div class="info-top-bar info-top-bar-2">
									<?php if ( function_exists( 'icl_t' ) ) { ?>
										<?php echo icl_t( 'Customizer', 'top_bar_info_2', $top_bar_info_2 ); ?>
									<?php } else { ?>
										<?php echo do_shortcode( $top_bar_info_2 ); ?>
									<?php } ?>
								</div>
							<?php } ?>
							
							<?php // Top Bar Info ?>
							<?php if ( ! empty( $top_bar_info ) ) { ?>
								<div class="info-top-bar">
									<?php if ( function_exists( 'icl_t' ) ) { ?>
										<?php echo icl_t( 'Customizer', 'top_bar_info', $top_bar_info ); ?>
									<?php } else { ?>
										<?php echo do_shortcode( $top_bar_info ); ?>
									<?php } ?>
								</div>
							<?php } ?>
							<?php } ?>
							
							<?php // Header Info ?>
							<?php $header_info = get_theme_mod( 'header_info' ); ?>
							<?php if ( ! empty( $header_info ) ) { ?>
								<div class="info-header">
									<?php if ( function_exists( 'icl_t' ) ) { ?>
										<?php echo icl_t( 'Customizer', 'header_info', $header_info ); ?>
									<?php } else { ?>
										<?php echo do_shortcode( $header_info ); ?>
									<?php } ?>
								</div>
							<?php } ?>
							
							<?php if ( $social_links_position == 'header' || $social_links_position == 'top_bar' && ! empty( $top_bar ) || $search_position == 'header' || $search_position == 'top_bar' && ! empty( $top_bar ) || ! empty( $top_bar_info ) || has_nav_menu( 'top_bar' ) || ! empty( $header_info ) ) { ?>
							</div><!-- .mobile-elements-wrapper -->
							<?php } ?>
					</div>
				</div>
			</div>
		<?php } ?>
		
		<div id="header" class="header">
			<?php // Sliding Menu ?>
			<?php if ( has_nav_menu( 'sliding' ) ) { ?>
			
				<?php $sliding_menu_align = get_theme_mod( 'sliding_menu_align', 'right' ); ?>
				<?php $full_width_sliding_menu = get_theme_mod( 'full_width_sliding_menu' ); ?>
				<?php if ( ! empty( $full_width_sliding_menu ) ) { ?>
					<?php $center_and_enable_full_width_for_secondary_menu_class = 'center-and-full-width-enabled' ; ?>
				<?php } else { ?>
					<?php $center_and_enable_full_width_for_secondary_menu_class = 'center-and-full-width-disabled' ; ?>
				<?php } ?>
				
				<div id="sliding-menu-wrapper" class="clearfix align-<?php echo esc_attr( $sliding_menu_align ); ?> <?php echo esc_attr( $center_and_enable_full_width_for_secondary_menu_class ); ?>">
					<div class="sliding-menu-wrapper-helper">
						<button class="close-button"><svg viewBox="0 0 40 40"><path d="M4.3,35.7L35.7,4.3"></path><path d="M4.3,4.3l31.4,31.4"></path></svg></button>
						<div id="access-sliding-menu-wrapper" class="clearfix">		 
							<nav id="access-sliding-menu" class="clearfix">
								<?php wp_nav_menu( array(
									'theme_location' => 'sliding',
									'menu_class' => 'nav-menu sliding-menu',
									'container_class' => 'nav-menu nav-menu-sliding',
									'before' => '',
									'after' => '',
									'link_before' => '<span>',
									'link_after' => '</span>' )
								); ?>
							</nav>
							
							<?php if ( is_active_sidebar( 'sidebar-10' ) ) { ?>
								<div class="sliding-menu-area-one widget-area clearfix">
									<div class="clearfix">
										<?php dynamic_sidebar( 'sidebar-10' ); ?>
									</div>
								</div>
							<?php } ?>
						</div>
					</div>
				</div>
			<?php } ?>
			
			<header id="branding" class="clearfix <?php if ( $header_behavior == 'fixed' && in_array( $header_position, array( "top", "bottom" ) ) ) { ?>compensate-for-scrollbar<?php } ?>">
				<div class="branding-helper">
			
					<?php if ( empty( $center_logo_and_menu ) ) { ?>
						<nav id="access" class="clearfix">
					<?php } ?>
					
							<?php // Mobile Area Button ?>
							<?php if ( has_nav_menu( 'primary' ) || has_nav_menu( 'secondary' ) || has_nav_menu( 'sliding' ) || has_nav_menu( 'top_bar' ) ) { ?>
								<?php $mobile_menu_align = get_theme_mod( 'mobile_menu_align', 'left' ); ?>
								<button class="mobile-menu-dropdown-wrapper clearfix align-<?php echo esc_attr( $mobile_menu_align ); ?>">
									<div>
										<span class="mobile-menu-dropdown clearfix">
											<span class="menu-line"></span>
											<span class="menu-line"></span>
										</span>
									</div>
								</button>
							<?php } ?>
							
							<?php // Sliding Menu Button ?>
							<?php if ( has_nav_menu( 'sliding' ) ) { ?>
								<?php if ( $sliding_menu_align == 'left' ) { ?>
									<div id="sliding-menu-dropdown-wrapper" class="clearfix">
										<span id="sliding-menu-dropdown" class="clearfix">
											<span class="menu-line"></span>
										</span>
									</div>
								<?php } ?>
							<?php } ?>
							
							<?php // Display Logo and Site Title Together ?>
							<?php $display_logo_and_site_title_together = get_theme_mod( 'display_logo_and_site_title_together' ); ?>
							<?php if ( ! empty( $display_logo_and_site_title_together ) && has_custom_logo() ) { ?>
									<?php $custom_logo_id = get_theme_mod( 'custom_logo' ); ?>
									<?php $custom_logo_src = wp_get_attachment_image_src( $custom_logo_id, 'large' ); ?>
									<?php $custom_logo_title = get_the_title( $custom_logo_id ); ?>
									<?php
									// Check logo file type
									$custom_logo_type =  get_post_mime_type( $custom_logo_id );
									$custom_logo_mime_type = explode( '/', $custom_logo_type );
									if ( ! isset( $custom_logo_mime_type['1'] ) ) {
									   $custom_logo_mime_type['1'] = null;
									}
									$custom_logo_type = $custom_logo_mime_type['1'];
									?>
									<div id="site-title" class="clearfix logo-and-site-title-together">
										<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" id="custom-logo">
											<?php // Transparent Header Logo ?>
											<?php $custom_logo_transparent_header = get_theme_mod( 'custom_logo_transparent_header' ); ?>
											<?php if ( ! empty( $custom_logo_transparent_header ) ) { ?>
												<?php $custom_logo_transparent_header_id = attachment_url_to_postid( $custom_logo_transparent_header ); ?>
												<?php $custom_logo_transparent_header_src = wp_get_attachment_image_src( $custom_logo_transparent_header_id, 'large' ); ?>
												<?php
												// Check transparent header logo file type
												$custom_logo_transparent_header_type =  get_post_mime_type( $custom_logo_transparent_header_id );
												$custom_logo_transparent_header_mime_type = explode( '/', $custom_logo_transparent_header_type );
												if ( ! isset( $custom_logo_transparent_header_mime_type['1'] ) ) {
												   $custom_logo_transparent_header_mime_type['1'] = null;
												}
												$custom_logo_transparent_header_type = $custom_logo_transparent_header_mime_type['1'];
												?>
												<div class="logo-for-transparent-header-wrapper">
												<?php if ( $custom_logo_transparent_header_type == 'svg+xml' ) { ?>
													<img class="logo-for-transparent-header logo-svg style-svg" src="<?php echo esc_url( $custom_logo_transparent_header_src[0] ); ?>" alt="<?php echo esc_attr( $custom_logo_title ); ?>" />
												<?php } else { ?>
													<img class="logo-for-transparent-header" src="<?php echo esc_url( $custom_logo_transparent_header_src[0] ); ?>" width="<?php echo esc_attr( $custom_logo_transparent_header_src[1] ); ?>" height="<?php echo esc_attr( $custom_logo_transparent_header_src[2] ); ?>" alt="<?php echo esc_attr( $custom_logo_title ); ?>" />
												<?php } ?>
												</div>
											<?php } ?>
											
											<div class="logo-default-wrapper">
											<?php if ( $custom_logo_type == 'svg+xml' ) { ?>
												<img class="logo-default logo-svg style-svg" src="<?php echo esc_url( $custom_logo_src[0] ); ?>" alt="<?php echo esc_attr( $custom_logo_title ); ?>" />
											<?php } else { ?>
												<img class="logo-default" src="<?php echo esc_url( $custom_logo_src[0] ); ?>" width="<?php echo esc_attr( $custom_logo_src[1] ); ?>" height="<?php echo esc_attr( $custom_logo_src[2] ); ?>" alt="<?php echo esc_attr( $custom_logo_title ); ?>" />
											<?php } ?>
											</div>
											
											<div class="site-title-description-wrapper">
												<?php // Site Title ?>
												<span class="site-title"><?php bloginfo( 'name' ); ?></span>
												
												<?php // Title Tagline ?>
												<?php $display_tagline = get_theme_mod( 'display_tagline' ); ?>
												<?php if ( ! empty( $display_tagline ) ) { ?>
													<?php $description = get_bloginfo( 'description', 'display' ); ?>
													<span class="site-description"><?php echo esc_html( $description ); ?></span>
												<?php } ?>
											</div>
										</a>
									</div>
								
							<?php } else { ?>
						
								<?php if ( has_custom_logo() ) { ?>
									<?php $custom_logo_id = get_theme_mod( 'custom_logo' ); ?>
									<?php $custom_logo_src = wp_get_attachment_image_src( $custom_logo_id, 'large' ); ?>
									<?php $custom_logo_title = get_the_title( $custom_logo_id ); ?>
									<?php
									// Check logo file type
									$custom_logo_type =  get_post_mime_type( $custom_logo_id );
									$custom_logo_mime_type = explode( '/', $custom_logo_type );
									if ( ! isset( $custom_logo_mime_type['1'] ) ) {
									   $custom_logo_mime_type['1'] = null;
									}
									$custom_logo_type = $custom_logo_mime_type['1'];
									?>
									<div id="site-title" class="clearfix">
										<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" id="custom-logo">
											
											<?php // Transparent Header Logo ?>
											<?php $custom_logo_transparent_header = get_theme_mod( 'custom_logo_transparent_header' ); ?>
											<?php if ( ! empty( $custom_logo_transparent_header ) ) { ?>
												<?php $custom_logo_transparent_header_id = attachment_url_to_postid( $custom_logo_transparent_header ); ?>
												<?php $custom_logo_transparent_header_src = wp_get_attachment_image_src( $custom_logo_transparent_header_id, 'large' ); ?>
												<?php
												// Check transparent header logo file type
												$custom_logo_transparent_header_type =  get_post_mime_type( $custom_logo_transparent_header_id );
												$custom_logo_transparent_header_mime_type = explode( '/', $custom_logo_transparent_header_type );
												if ( ! isset( $custom_logo_transparent_header_mime_type['1'] ) ) {
												   $custom_logo_transparent_header_mime_type['1'] = null;
												}
												$custom_logo_transparent_header_type = $custom_logo_transparent_header_mime_type['1'];
												?>
												<div class="logo-for-transparent-header-wrapper">
												<?php if ( $custom_logo_transparent_header_type == 'svg+xml' ) { ?>
													<img class="logo-for-transparent-header logo-svg style-svg" src="<?php echo esc_url( $custom_logo_transparent_header_src[0] ); ?>" alt="<?php echo esc_attr( $custom_logo_title ); ?>" />
												<?php } else { ?>
													<img class="logo-for-transparent-header" src="<?php echo esc_url( $custom_logo_transparent_header_src[0] ); ?>" width="<?php echo esc_attr( $custom_logo_transparent_header_src[1] ); ?>" height="<?php echo esc_attr( $custom_logo_transparent_header_src[2] ); ?>" alt="<?php echo esc_attr( $custom_logo_title ); ?>" />
												<?php } ?>
												</div>
											<?php } ?>
											
											<div class="logo-default-wrapper">
											<?php if ( $custom_logo_type == 'svg+xml' ) { ?>
												<img class="logo-default logo-svg style-svg" src="<?php echo esc_url( $custom_logo_src[0] ); ?>" alt="<?php echo esc_attr( $custom_logo_title ); ?>" />
											<?php } else { ?>
												<img class="logo-default" src="<?php echo esc_url( $custom_logo_src[0] ); ?>" width="<?php echo esc_attr( $custom_logo_src[1] ); ?>" height="<?php echo esc_attr( $custom_logo_src[2] ); ?>" alt="<?php echo esc_attr( $custom_logo_title ); ?>" />
											<?php } ?>
											</div>
											
											<?php // Title Tagline ?>
											<?php $display_tagline = get_theme_mod( 'display_tagline' ); ?>
											<?php if ( ! empty( $display_tagline ) ) { ?>
												<?php $description = get_bloginfo( 'description', 'display' ); ?>
												<span class="site-description"><?php echo esc_html( $description ); ?></span>
											<?php } ?>
										</a>
									</div>
									
								<?php } else { ?>
								
									<?php // Title Tagline Position ?>
									<?php $display_tagline_below_site_title = get_theme_mod( 'display_tagline_below_site_title' ); ?>
									<div id="site-title" class="clearfix">
										<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" <?php if ( ! empty( $display_tagline_below_site_title ) ) { ?>class="site-description-below"<?php } ?>>
											
											<div class="site-title-description-wrapper">
												<?php // Site Title ?>
												<span class="site-title"><?php bloginfo( 'name' ); ?></span>
												
												<?php // Title Tagline ?>
												<?php $display_tagline = get_theme_mod( 'display_tagline' ); ?>
												<?php if ( ! empty( $display_tagline ) ) { ?>
													<?php $description = get_bloginfo( 'description', 'display' ); ?>
													<span class="site-description"><?php  echo esc_html( $description ); ?></span>
												<?php } ?>
											</div>
										</a>
									</div>
								<?php } ?>
							
							<?php } ?>
							
							<?php // WPML ?>
							<?php if ( function_exists( 'icl_object_id' ) ) { ?>
								<?php $wpml_language_switcher_position = get_theme_mod( 'wpml_language_switcher_position', 'none' ); ?>
								<?php if ( $wpml_language_switcher_position == 'header' ) { ?>
									<div class="lang-sel-wrapper">
										<?php $languages = icl_get_languages( 'skip_missing=1' ); ?>
										<?php foreach( $languages as $l ) { ?>
											<?php if ( $l['active'] ) { ?>
												<?php $active_language_class = 'class="active"'; ?>
											<?php } else { ?>
												<?php $active_language_class = ''; ?>
											<?php } ?>
											<?php $langs[] = '<a href="'. esc_url( $l['url'] ) .'" '. $active_language_class .'>'. esc_html( $l['language_code'] ) .'</a>'; ?>
										<?php } ?>
										<?php echo join( '<span>/</span> ', $langs ); ?>
									</div>
								<?php } ?>
							<?php } ?>
							
							<?php if ( $header_position !== 'left' && $header_position !== 'right' ) { ?>
							
								<?php // Header Info ?>
								<?php $header_info = get_theme_mod( 'header_info' ); ?>
								<?php if ( ! empty( $header_info ) ) { ?>
									<div class="info-header">
										<?php if ( function_exists( 'icl_t' ) ) { ?>
											<?php echo icl_t( 'Customizer', 'header_info', $header_info ); ?>
										<?php } else { ?>
											<?php echo do_shortcode( $header_info ); ?>
										<?php } ?>
									</div>
								<?php } ?>
							
								<?php // WooCommerce ?>
								<?php if ( class_exists( 'woocommerce' ) ) { ?>
									<?php $woocommerce_cart_position = get_theme_mod( 'woocommerce_cart_position', 'header' ); ?>
									<?php $woocommerce_my_account_position = get_theme_mod( 'woocommerce_my_account_position', 'header' ); ?>
									<?php $woocommerce_wishlist_position = get_theme_mod( 'woocommerce_wishlist_position', 'header' ); ?>
									<?php if ( $woocommerce_cart_position == 'header' || $woocommerce_my_account_position == 'header' || $woocommerce_wishlist_position == 'header' && class_exists( 'YITH_WCWL' ) ) { ?>
										<?php $cart_icon_style = get_theme_mod( 'cart_icon_style', 1 ); ?>
										<?php $my_account_icon_style = get_theme_mod( 'my_account_icon_style', 1 ); ?>
										<div class="woocommerce-links-wrapper cart-icon-style-<?php echo esc_attr( $cart_icon_style ); ?> my-account-icon-style-<?php echo esc_attr( $my_account_icon_style ); ?>">
											<div class="woocommerce-links">
										
												<?php // YITH WooCommerce Wishlist ?>
												<?php if ( class_exists( 'YITH_WCWL' ) ) { ?>
													<?php if ( $woocommerce_wishlist_position == 'header' ) { ?>
														<div class="yith-wishlist-wrapper transition">
															<a href="<?php echo esc_url( get_permalink( get_option( 'yith_wcwl_wishlist_page_id' ) ) ); ?>" class="yith-wishlist-icon"><span><i></i></span></a>
														</div>
													<?php } ?>
												<?php } ?>
												
												<?php // WooCommerce My Account ?>
												<?php if ( $woocommerce_my_account_position == 'header' ) { ?>
													<div class="woocommerce-my-account-wrapper transition">
														<a href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ); ?>" class="woocommerce-my-account"><span><i><svg viewBox="0 0 512 512"><path d="M256,288.389c-153.837,0-238.56,72.776-238.56,204.925c0,10.321,8.365,18.686,18.686,18.686h439.747 c10.321,0,18.686-8.365,18.686-18.686C494.56,361.172,409.837,288.389,256,288.389z M55.492,474.628 c7.35-98.806,74.713-148.866,200.508-148.866s193.159,50.06,200.515,148.866H55.492z"></path><path d="M256,0c-70.665,0-123.951,54.358-123.951,126.437c0,74.19,55.604,134.54,123.951,134.54s123.951-60.35,123.951-134.534 C379.951,54.358,326.665,0,256,0z M256,223.611c-47.743,0-86.579-43.589-86.579-97.168c0-51.611,36.413-89.071,86.579-89.071 c49.363,0,86.579,38.288,86.579,89.071C342.579,180.022,303.743,223.611,256,223.611z"></path></svg></i></span></a>
														
														<div class="woocommerce-links-helper">
															<em></em>
															<?php if ( is_user_logged_in() ) { ?>
																<ul>
																	<li><a class="logout" href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_logout_page_id' ) ) ); ?>"><span><?php esc_html_e( 'Logout', 'skylab' ); ?></span></a></li>
																	<li><a class="account" href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ); ?>"><span><?php esc_html_e( 'My Account', 'skylab' ); ?></span></a></li>
																</ul>
															<?php } else { ?>
																<ul>
																	<li><a class="account" href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ); ?>"><span><?php esc_html_e( 'Login', 'skylab' ); ?></span></a></li>
																</ul>
															<?php } ?>
														</div>
													</div>
												<?php } ?>
												
												<?php // WooCommerce Cart ?>
												<?php if ( $woocommerce_cart_position == 'header' ) { ?>
													<div class="woocommerce-mini-cart-wrapper">
														<?php if ( ! WC()->cart->get_cart_contents_count() ) { ?>
															<a class="woocommerce-mini-cart" href="<?php echo esc_url( wc_get_cart_url() ); ?>"><span><i><svg viewBox="0 0 512 512"><path d="M467.952,427.383l-25.3-245.673c-1.045-10.187-9.627-17.93-19.867-17.93h-332.9c-10.213,0-18.789,7.717-19.861,17.877 L44.044,427.45c-2.144,21.452,5.007,43.011,19.614,59.156C78.266,502.739,98.986,512,120.511,512h271.653 c21.425,0,41.952-9.075,56.293-24.914C462.999,471.06,470.103,449.328,467.952,427.383z M418.876,460.261 c-6.898,7.603-16.385,11.791-26.712,11.791H120.518c-10.26,0-20.187-4.468-27.238-12.257c-7.051-7.79-10.506-18.13-9.494-28.257 l24.075-227.803h296.9l23.449,227.657C429.276,442.198,425.953,452.451,418.876,460.261z"></path><path d="M259.663,0c-63.144,0-114.518,51.373-114.518,114.518v69.243h39.948v-69.243c0-41.12,33.45-74.57,74.57-74.57 c41.12,0,74.576,33.45,74.576,74.57v69.243h39.941v-69.243C374.181,51.373,322.808,0,259.663,0z"></path></svg></i></span></a>
														<?php } else { ?>
															<a class="woocommerce-mini-cart" href="<?php echo esc_url( wc_get_cart_url() ); ?>"><span><i><svg viewBox="0 0 512 512"><path d="M467.952,427.383l-25.3-245.673c-1.045-10.187-9.627-17.93-19.867-17.93h-332.9c-10.213,0-18.789,7.717-19.861,17.877 L44.044,427.45c-2.144,21.452,5.007,43.011,19.614,59.156C78.266,502.739,98.986,512,120.511,512h271.653 c21.425,0,41.952-9.075,56.293-24.914C462.999,471.06,470.103,449.328,467.952,427.383z M418.876,460.261 c-6.898,7.603-16.385,11.791-26.712,11.791H120.518c-10.26,0-20.187-4.468-27.238-12.257c-7.051-7.79-10.506-18.13-9.494-28.257 l24.075-227.803h296.9l23.449,227.657C429.276,442.198,425.953,452.451,418.876,460.261z"></path><path d="M259.663,0c-63.144,0-114.518,51.373-114.518,114.518v69.243h39.948v-69.243c0-41.12,33.45-74.57,74.57-74.57 c41.12,0,74.576,33.45,74.576,74.57v69.243h39.941v-69.243C374.181,51.373,322.808,0,259.663,0z"></path></svg></i> <span class="cart-contents-count"><?php echo WC()->cart->get_cart_contents_count(); ?></span></span></a>
															<div class="product-list-cart">
																<em></em>
																<ul>
																<?php foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) { ?>
																	<?php $_product = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key ); ?>
																	<li>
																		<a href="<?php echo esc_url( get_permalink( $_product->get_id() ) ); ?>">
																			<?php echo get_the_post_thumbnail( $_product->get_id(), 'shop_thumbnail' ); ?>
																			<span class="product"><?php echo trim( $_product->get_name() ); ?></span>
																			<span class="product-quantity-price-wrapper"><?php echo trim( $cart_item['quantity'] ); ?> x <?php echo WC()->cart->get_product_subtotal( $cart_item['data'], $cart_item['quantity'] ); ?></span>
																		</a>
																	</li>
																<?php } ?>
																</ul>
																<div class="woocommerce-mini-cart-checkout">
																	<div class="woocommerce-mini-cart-total-wrapper">
																		<span class="woocommerce-mini-cart-total-text"><?php esc_html_e( 'Total', 'skylab' ); ?></span><span class="woocommerce-mini-cart-total-number"><?php echo WC()->cart->get_cart_total(); ?></span>
																	</div>
																	<a class="button alt to-checkout" href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_checkout_page_id' ) ) ); ?>"><span><?php esc_html_e( 'To checkout', 'skylab' ); ?></span></a>
																	<a class="button to-cart" href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_cart_page_id' ) ) ); ?>"><span><?php esc_html_e( 'View cart', 'skylab' ); ?></span></a>
																</div>
															</div>
														<?php } ?>
													</div>
												<?php } ?>
								
											</div><!-- .woocommerce-links -->
										</div><!-- .woocommerce-links-wrapper -->
									<?php } ?>
								<?php } // End if ( class_exists( 'woocommerce' ) ) ?>
							
								<?php // Search ?>
								<?php $search_position = get_theme_mod( 'search_position', 'none' ); ?>
								<?php if ( $search_position == 'header' || $search_position == 'top_bar' ) { ?>	
									<div class="search-header-wrapper">
										<span class="search-header-icon"><svg viewBox="0 0 512 512"><path d="M225.474,0C101.151,0,0,101.151,0,225.474c0,124.33,101.151,225.474,225.474,225.474 c124.33,0,225.474-101.144,225.474-225.474C450.948,101.151,349.804,0,225.474,0z M225.474,409.323 c-101.373,0-183.848-82.475-183.848-183.848S124.101,41.626,225.474,41.626s183.848,82.475,183.848,183.848 S326.847,409.323,225.474,409.323z"></path><path d="M505.902,476.472L386.574,357.144c-8.131-8.131-21.299-8.131-29.43,0c-8.131,8.124-8.131,21.306,0,29.43l119.328,119.328 c4.065,4.065,9.387,6.098,14.715,6.098c5.321,0,10.649-2.033,14.715-6.098C514.033,497.778,514.033,484.596,505.902,476.472z"></path></svg></span>
									</div>
								<?php } ?>
							
								<?php // Sliding Menu Button ?>
								<?php if ( has_nav_menu( 'sliding' ) ) { ?>
									<?php if ( $sliding_menu_align == 'right' ) { ?>
										<div id="sliding-menu-dropdown-wrapper" class="clearfix">
											<span id="sliding-menu-dropdown" class="clearfix">
												<span class="menu-line"></span>
											</span>
										</div>
									<?php } ?>
								<?php } ?>
							
								<?php // Social Links ?>
								<?php $social_links_position = get_theme_mod( 'social_links_position', 'none' ); ?>
								<?php if ( $social_links_position == 'header' ) { ?>
									<?php $social_links_style = get_theme_mod( 'social_links_style', 1 ); ?>
									<div class="social-links-wrapper social-links-style-<?php echo esc_attr( $social_links_style ); ?>">
										<?php get_template_part( 'social-links' ); ?>
									</div>
								<?php } ?>
							
							<?php } ?>
							
							<?php if ( empty( $center_logo_and_menu ) ) { ?>
									
									<?php // Primary Menu ?>
									<?php if ( has_nav_menu( 'primary' ) ) { ?>
									<div class="menu-wrapper menu-wrapper-primary">
										<div class="nav-menu-primary-header-wrapper">
											<?php if ( $header_position == 'left' || $header_position == 'right' ) { ?>
												<?php wp_nav_menu( array(
													'theme_location' => 'primary',
													'menu_class' => 'dropdown',
													'container_class' => 'nav-menu nav-menu-primary-header',
													'before' => '',
													'after' => '',
													'link_before' => '<span>',
													'link_after' => '</span>' )
												); ?>
											<?php } else { ?>
												<?php wp_nav_menu( array(
													'theme_location' => 'primary',
													'menu_class' => 'dropdown',
													'container_class' => 'nav-menu nav-menu-primary-header',
													'link_before' => '<span>',
													'link_after' => '</span>' )
												); ?>
											<?php } ?>
										</div>
									</div>
									<?php } ?>
									
									<?php // Secondary Menu ?>
									<?php if ( has_nav_menu( 'secondary' ) ) { ?>
									<div class="menu-wrapper menu-wrapper-secondary">
										<div class="nav-menu-secondary-header-wrapper">
											<?php wp_nav_menu( array(
												'theme_location' => 'secondary',
												'menu_class' => 'dropdown',
												'container_class' => 'nav-menu nav-menu-secondary-header',
												'link_before' => '<span>',
												'link_after' => '</span>' )
											); ?>
										</div>
									</div>
									<?php } ?>
								
							<?php } ?>
							
							<?php // Social links and header info in left or right header ?>
							<?php if ( $header_position == 'left' || $header_position == 'right' ) { ?>
							
								<?php // WooCommerce ?>
								<?php if ( class_exists( 'woocommerce' ) ) { ?>
									<?php $woocommerce_cart_position = get_theme_mod( 'woocommerce_cart_position', 'header' ); ?>
									<?php $woocommerce_my_account_position = get_theme_mod( 'woocommerce_my_account_position', 'header' ); ?>
									<?php $woocommerce_wishlist_position = get_theme_mod( 'woocommerce_wishlist_position', 'header' ); ?>
									<?php if ( $woocommerce_cart_position == 'header' || $woocommerce_my_account_position == 'header' || $woocommerce_wishlist_position == 'header' && class_exists( 'YITH_WCWL' ) ) { ?>
										<?php $cart_icon_style = get_theme_mod( 'cart_icon_style', 1 ); ?>
										<?php $my_account_icon_style = get_theme_mod( 'my_account_icon_style', 1 ); ?>
										<div class="woocommerce-links-wrapper cart-icon-style-<?php echo esc_attr( $cart_icon_style ); ?> my-account-icon-style-<?php echo esc_attr( $my_account_icon_style ); ?>">
											<div class="woocommerce-links">
										
												<?php // YITH WooCommerce Wishlist ?>
												<?php if ( class_exists( 'YITH_WCWL' ) ) { ?>
													<?php if ( $woocommerce_wishlist_position == 'header' ) { ?>
														<div class="yith-wishlist-wrapper transition">
															<a href="<?php echo esc_url( get_permalink( get_option( 'yith_wcwl_wishlist_page_id' ) ) ); ?>" class="yith-wishlist-icon"><span><i></i></span></a>
														</div>
													<?php } ?>
												<?php } ?>
												
												<?php // WooCommerce My Account ?>
												<?php if ( $woocommerce_my_account_position == 'header' ) { ?>
													<div class="woocommerce-my-account-wrapper transition">
														<a href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ); ?>" class="woocommerce-my-account"><span><i></i></span></a>
														
														<div class="woocommerce-links-helper">
															<em></em>
															<?php if ( is_user_logged_in() ) { ?>
																<ul>
																	<li><a class="logout" href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_logout_page_id' ) ) ); ?>"><span><?php esc_html_e( 'Logout', 'skylab' ); ?></span></a></li>
																	<li><a class="account" href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ); ?>"><span><?php esc_html_e( 'My Account', 'skylab' ); ?></span></a></li>
																</ul>
															<?php } else { ?>
																<ul>
																	<li><a class="account" href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ); ?>"><span><?php esc_html_e( 'Login', 'skylab' ); ?></span></a></li>
																</ul>
															<?php } ?>
														</div>
													</div>
												<?php } ?>
												
												<?php // WooCommerce Cart ?>
												<?php if ( $woocommerce_cart_position == 'header' ) { ?>
													<div class="woocommerce-mini-cart-wrapper">
														<?php if ( ! WC()->cart->get_cart_contents_count() ) { ?>
															<a class="woocommerce-mini-cart" href="<?php echo esc_url( wc_get_cart_url() ); ?>"><span><i><svg viewBox="0 0 512 512"><path d="M467.952,427.383l-25.3-245.673c-1.045-10.187-9.627-17.93-19.867-17.93h-332.9c-10.213,0-18.789,7.717-19.861,17.877 L44.044,427.45c-2.144,21.452,5.007,43.011,19.614,59.156C78.266,502.739,98.986,512,120.511,512h271.653 c21.425,0,41.952-9.075,56.293-24.914C462.999,471.06,470.103,449.328,467.952,427.383z M418.876,460.261 c-6.898,7.603-16.385,11.791-26.712,11.791H120.518c-10.26,0-20.187-4.468-27.238-12.257c-7.051-7.79-10.506-18.13-9.494-28.257 l24.075-227.803h296.9l23.449,227.657C429.276,442.198,425.953,452.451,418.876,460.261z"></path><path d="M259.663,0c-63.144,0-114.518,51.373-114.518,114.518v69.243h39.948v-69.243c0-41.12,33.45-74.57,74.57-74.57 c41.12,0,74.576,33.45,74.576,74.57v69.243h39.941v-69.243C374.181,51.373,322.808,0,259.663,0z"></path></svg></i></span></a>
														<?php } else { ?>
															<a class="woocommerce-mini-cart" href="<?php echo esc_url( wc_get_cart_url() ); ?>"><span><i><svg viewBox="0 0 512 512"><path d="M467.952,427.383l-25.3-245.673c-1.045-10.187-9.627-17.93-19.867-17.93h-332.9c-10.213,0-18.789,7.717-19.861,17.877 L44.044,427.45c-2.144,21.452,5.007,43.011,19.614,59.156C78.266,502.739,98.986,512,120.511,512h271.653 c21.425,0,41.952-9.075,56.293-24.914C462.999,471.06,470.103,449.328,467.952,427.383z M418.876,460.261 c-6.898,7.603-16.385,11.791-26.712,11.791H120.518c-10.26,0-20.187-4.468-27.238-12.257c-7.051-7.79-10.506-18.13-9.494-28.257 l24.075-227.803h296.9l23.449,227.657C429.276,442.198,425.953,452.451,418.876,460.261z"></path><path d="M259.663,0c-63.144,0-114.518,51.373-114.518,114.518v69.243h39.948v-69.243c0-41.12,33.45-74.57,74.57-74.57 c41.12,0,74.576,33.45,74.576,74.57v69.243h39.941v-69.243C374.181,51.373,322.808,0,259.663,0z"></path></svg></i> <span class="cart-contents-count"><?php echo WC()->cart->get_cart_contents_count(); ?></span></span></a>
															<div class="product-list-cart">
																<em></em>
																<ul>
																<?php foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) { ?>
																	<?php $_product = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key ); ?>
																	<li>
																		<a href="<?php echo esc_url( get_permalink( $_product->get_id() ) ); ?>">
																			<?php echo get_the_post_thumbnail( $_product->get_id(), 'shop_thumbnail' ); ?>
																			<span class="product"><?php echo trim( $_product->get_name() ); ?></span>
																			<span class="product-quantity-price-wrapper"><?php echo trim( $cart_item['quantity'] ); ?> x <?php echo WC()->cart->get_product_subtotal( $cart_item['data'], $cart_item['quantity'] ); ?></span>
																		</a>
																	</li>
																<?php } ?>
																</ul>
																<div class="woocommerce-mini-cart-checkout">
																	<div class="woocommerce-mini-cart-total-wrapper">
																		<span class="woocommerce-mini-cart-total-text"><?php esc_html_e( 'Total', 'skylab' ); ?></span><span class="woocommerce-mini-cart-total-number"><?php echo WC()->cart->get_cart_total(); ?></span>
																	</div>
																	<a class="button alt to-checkout" href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_checkout_page_id' ) ) ); ?>"><span><?php esc_html_e( 'To checkout', 'skylab' ); ?></span></a>
																	<a class="button to-cart" href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_cart_page_id' ) ) ); ?>"><span><?php esc_html_e( 'View cart', 'skylab' ); ?></span></a>
																</div>
															</div>
														<?php } ?>
													</div>
												<?php } ?>
								
											</div><!-- .woocommerce-links -->
										</div><!-- .woocommerce-links-wrapper -->
									<?php } ?>
								<?php } // End if ( class_exists( 'woocommerce' ) ) ?>
							
								<?php $search_position = get_theme_mod( 'search_position', 'none' ); ?>
								<?php $header_info = get_theme_mod( 'header_info' ); ?>
								<?php $social_links_position = get_theme_mod( 'social_links_position', 'none' ); ?>
								<?php if ( $search_position == 'header' || $search_position == 'top_bar' || ! empty( $header_info ) || $social_links_position == 'header' ) { ?>
								<div class="header-elements-wrapper">
								
									<?php // Social Links ?>
									<?php if ( $social_links_position == 'header' ) { ?>
										<?php $social_links_style = get_theme_mod( 'social_links_style', 1 ); ?>
										<div class="social-links-wrapper social-links-style-<?php echo esc_attr( $social_links_style ); ?>">
											<?php get_template_part( 'social-links' ); ?>
										</div>
									<?php } ?>
									
									<?php // Search ?>
									<?php if ( $search_position == 'header' || $search_position == 'top_bar' ) { ?>	
										<div class="search-header-wrapper">
											<span class="search-header-icon"><svg viewBox="0 0 512 512"><path d="M225.474,0C101.151,0,0,101.151,0,225.474c0,124.33,101.151,225.474,225.474,225.474 c124.33,0,225.474-101.144,225.474-225.474C450.948,101.151,349.804,0,225.474,0z M225.474,409.323 c-101.373,0-183.848-82.475-183.848-183.848S124.101,41.626,225.474,41.626s183.848,82.475,183.848,183.848 S326.847,409.323,225.474,409.323z"></path><path d="M505.902,476.472L386.574,357.144c-8.131-8.131-21.299-8.131-29.43,0c-8.131,8.124-8.131,21.306,0,29.43l119.328,119.328 c4.065,4.065,9.387,6.098,14.715,6.098c5.321,0,10.649-2.033,14.715-6.098C514.033,497.778,514.033,484.596,505.902,476.472z"></path></svg></span>
										</div>
									<?php } ?>
								
									<?php // Header Info ?>
									<?php if ( ! empty( $header_info ) ) { ?>
										<div class="info-header">
											<?php if ( function_exists( 'icl_t' ) ) { ?>
												<?php echo icl_t( 'Customizer', 'header_info', $header_info ); ?>
											<?php } else { ?>
												<?php echo do_shortcode( $header_info ); ?>
											<?php } ?>
										</div>
									<?php } ?>
								
								</div>
								<?php } ?>
							
							<?php } ?>
						
					<?php if ( empty( $center_logo_and_menu ) ) { ?>
						</nav><!-- #access -->
					<?php } ?>
						
				</div><!-- .branding-helper -->
			</header><!-- #branding -->
			
			<?php // Center Logo and Menu ?>
			<?php if ( ! empty( $center_logo_and_menu ) ) { ?>
				<nav id="access-wrapper">
					<div id="nav-menu-wrapper">
						<nav id="access" class="clearfix">
							<?php if ( has_nav_menu( 'primary' ) ) { ?>
								<div class="nav-menu-primary-header-wrapper">
									<?php wp_nav_menu( array(
										'theme_location' => 'primary',
										'menu_class' => 'dropdown',
										'container_class' => 'nav-menu nav-menu-primary-header',
										'link_before' => '<span>',
										'link_after' => '</span>' )
									); ?>
								</div>
							<?php } ?>
						</nav>
					</div>
				</nav>
			<?php } ?>
			
		</div><!-- #header -->
	</div><!-- #header-wrapper -->
