jQuery( document ).ready(function($) {
	"use strict";

	/**
	 * Sortable Repeater Custom Control
	 *
	 * @author Anthony Hortin <http://maddisondesigns.com>
	 * @license http://www.gnu.org/licenses/gpl-2.0.html
	 * @link https://github.com/maddisondesigns
	 */

	// Update the values for all our input fields and initialise the sortable repeater
	$('.sortable_repeater_control').each(function() {
		// If there is an existing customizer value, populate our rows
		var defaultValuesArray = $(this).find('.customize-control-sortable-repeater').val().split(',');
		var numRepeaterItems = defaultValuesArray.length;

		if(numRepeaterItems > 0) {
			// Add the first item to our existing input field
			$(this).find('.repeater-input').val(defaultValuesArray[0]);
			// Create a new row for each new value
			if(numRepeaterItems > 1) {
				var i;
				for (i = 1; i < numRepeaterItems; ++i) {
					skyrocketAppendRow($(this), defaultValuesArray[i]);
				}
			}
		}
	});

	// Make our Repeater fields sortable
	$(this).find('.sortable_repeater.sortable').sortable({
		update: function(event, ui) {
			skyrocketGetAllInputs($(this).parent());
		}
	});

	// Remove item starting from it's parent element
	$('.sortable_repeater.sortable').on('click', '.customize-control-sortable-repeater-delete', function(event) {
		event.preventDefault();
		var numItems = $(this).parent().parent().find('.repeater').length;

		if(numItems > 1) {
			$(this).parent().slideUp('fast', function() {
				var parentContainer = $(this).parent().parent();
				$(this).remove();
				skyrocketGetAllInputs(parentContainer);
			})
		}
		else {
			$(this).parent().find('.repeater-input').val('');
			skyrocketGetAllInputs($(this).parent().parent().parent());
		}
	});

	// Add new item
	$('.customize-control-sortable-repeater-add').click(function(event) {
		event.preventDefault();
		skyrocketAppendRow($(this).parent());
		skyrocketGetAllInputs($(this).parent());
	});

	// Refresh our hidden field if any fields change
	$('.sortable_repeater.sortable').change(function() {
		skyrocketGetAllInputs($(this).parent());
	})

	// Add https:// to the start of the URL if it doesn't have it
	$('.sortable_repeater.sortable').on('blur', '.repeater-input', function() {
		var url = $(this);
		var val = url.val();
		if(val && !val.match(/^.+:\/\/.*/) && !val.match(/^.+:.*/)) {
			// Important! Make sure to trigger change event so Customizer knows it has to save the field
			url.val('https://' + val).trigger('change');
		}
	});

	// Append a new row to our list of elements
	function skyrocketAppendRow($element, defaultValue = '') {
		var newRow = '<div class="repeater" style="display:none"><input type="text" value="' + defaultValue + '" class="repeater-input" placeholder="https://" /><span class="dashicons dashicons-sort"></span><a class="customize-control-sortable-repeater-delete" href="#"><span class="dashicons dashicons-no-alt"></span></a></div>';

		$element.find('.sortable').append(newRow);
		$element.find('.sortable').find('.repeater:last').slideDown('slow', function(){
			$(this).find('input').focus();
		});
	}

	// Get the values from the repeater input fields and add to our hidden field
	function skyrocketGetAllInputs($element) {
		var inputValues = $element.find('.repeater-input').map(function() {
			return $(this).val() || null;
		}).toArray();
		// Add all the values from our repeater fields to the hidden field (which is the one that actually gets saved)
		$element.find('.customize-control-sortable-repeater').val(inputValues);
		// Important! Make sure to trigger change event so Customizer knows it has to save the field
		$element.find('.customize-control-sortable-repeater').trigger('change');
	}
	
	/**
	 * Font Uploader Custom Control
	 */
	 
	// Update the values for all our input fields and initialise the sortable repeater
	$('.font-control-container-wrapper-helper').each(function() {
		// If there is an existing customizer value, populate our rows
		var defaultValuesArray = $(this).find('.font-input').val().split(/,(?=[^\]]*(?:\[|$))(?=[^}]*(?:{|$))/);
		var numRepeaterItems = defaultValuesArray.length;

		if(numRepeaterItems > 0) {
			// Add the first item to our existing input field
			$(this).find('.font-control-container').find('.font-data-input').val(defaultValuesArray[0]);
			if (defaultValuesArray[0]) {
				defaultValuesArray[0] = JSON.parse(defaultValuesArray[0]);
				$(this).find('.font-control-container').find('.font-name').val(defaultValuesArray[0]['name']);
				$(this).find('.font-control-container').find('.font-weight').val(defaultValuesArray[0]['weight']);
				$(this).find('.font-control-container').find('.font-style').val(defaultValuesArray[0]['style']);
			}
			// Create a new row for each new value
			if(numRepeaterItems > 1) {
				var i;
				for (i = 1; i < numRepeaterItems; ++i) {
					megaAppendRow($(this), defaultValuesArray[i]);
				}
			}
		}
	});
	
	
	// Get the values from the repeater input fields and add to our hidden field
	function megaGetAllInputs($element) {
		var inputValues = $element.find('.font-control-container').find('.font-data-input').map(function() {
			return $(this).val() || null;
		}).toArray();
		
		// Add all the values from our repeater fields to the hidden field (which is the one that actually gets saved)
		$element.find('.font-input').val(inputValues);
		// Important! Make sure to trigger change event so Customizer knows it has to save the field
		$element.find('.font-input').trigger('change');
	}
	
	// Append a new row to our list of elements
	function megaAppendRow($element, defaultValue = '') {
		var $newRow = $element.find('.font-control-container:last').clone(true);
		$newRow.find('.font-src-list').empty();
		$newRow.find('.font-data-input').val(defaultValue);
		if (defaultValue !== "") {
			defaultValue = JSON.parse(defaultValue);
			$newRow.find('.font-name').val(defaultValue['name']);
			$newRow.find('.font-weight').val(defaultValue['weight']);
			$newRow.find('.font-style').val(defaultValue['style']);
		}
		
		$element.find('.font-control-container-wrapper').append($newRow);
		$element.find('.font-control-container:last').slideDown();
	}
	
	// Remove item starting from it's parent element
	$('.font-control-container').on('click', '.button-link-delete', function(event) {
		event.preventDefault();
		var numItems = $(this).parent().parent().find('.font-control-container').length;

		if(numItems > 1) {
			$(this).parent().slideUp('fast', function() {
				var parentContainer = $(this).parent().parent();
				$(this).remove();
				megaGetAllInputs(parentContainer);
			})
		} else {
			$(this).parent().find('.font-src-list').empty();
			$(this).parent().find('.font-data-input').val('');
			megaGetAllInputs($(this).parent().parent().parent());
		}
	});
	
	// Add new item
	$('.font-control-container-add').on('click', function(event) {
		event.preventDefault();
		var $el = $(this);
		megaAppendRow($el.closest('.font-control-container-wrapper-helper'));
	});
	
	$('.font-control-container').each(function() {
		var selectedFont;
		var begin_attachment_string = $(this).find('.font-data-input').val();
		if (begin_attachment_string) {
			begin_attachment_string = JSON.parse(begin_attachment_string);
			if (begin_attachment_string['src']) {
				var begin_attachment_array = begin_attachment_string['src'].split(",");
				for(var i = 0; i < begin_attachment_array.length; i++){
					if(begin_attachment_array[i] != ""){
						$(this).find('.font-src-list').append( "<li class='font-src'>" + begin_attachment_array[i] + "</li>" );
					}
				}
			}
		}
		
		// Media library
		$(this).find('.choose-from-library-link').unbind('click').on('click', function( event ) {
			var frame;
			var $el = $(this);

			event.preventDefault();

			if ( frame ) {
				frame.open();
				return;
			}
			
			// Create the media frame.
			frame = wp.media.frames.customFont = wp.media({
				// Set the title of the modal.
				title: $el.data('choose'),
				
				// Tell the modal to show only fonts.
				library: {
					type: 'font'
				},

				// Customize the submit button.
				button: {
					// Set the text of the button.
					text: $el.data('choose')
				},
				
				multiple: true
			});

			frame.on('select', function() {
				var selection = frame.state().get('selection');
				var attachments = [];
				selection.map( function( attachment ) {
					attachment = attachment.toJSON();
					$el.closest('.font-control-container').find('.font-src-list').append( "<li class='font-src'>" + attachment.url + "</li" );
					attachments.push(attachment.url);
				 });
				 var attachment_string = $el.closest('.font-control-container').find('.font-data-input').val();
				 if (attachment_string['src']) {
					 attachment_string = JSON.parse(attachment_string);
					 attachment_string = attachment_string['src'] + "," + attachments.join() + ",";
				 } else {
					 attachment_string = attachments.join() + ",";
				 }
				 // Remove the first comma
				 attachment_string = attachment_string.replace(/^,/, '');
				 // Remove the last comma and any whitespace
				 attachment_string = attachment_string.replace(/,\s*$/, "");
				 selectedFont = {
					src: attachment_string,
					name: $el.closest('.font-control-container').find('.font-name').val(),
					weight: $el.closest('.font-control-container').find('.font-weight').val(),
					style: $el.closest('.font-control-container').find('.font-style').val()
				 };
				 $el.closest('.font-control-container').find('.font-data-input').val(JSON.stringify(selectedFont)).trigger('change');
				 megaGetAllInputs($el.closest('.font-control-container-wrapper-helper'));
			 });
			 
			 frame.open();
		 });
		 
		 // Get the values from the font input fields and add to our hidden field
		 function megaGetOptions($element) {
			var attachment_string = $element.closest('.font-control-container').find('.font-data-input').val();
			if (attachment_string) {
				attachment_string = JSON.parse(attachment_string);
			}
			selectedFont = {
				src: attachment_string['src'],
				name: $element.closest('.font-control-container').find('.font-name').val(),
				weight: $element.closest('.font-control-container').find('.font-weight').val(),
				style: $element.closest('.font-control-container').find('.font-style').val()
			};
			$element.closest('.font-control-container').find('.font-data-input').val(JSON.stringify(selectedFont)).trigger('change');
			megaGetAllInputs($element.closest('.font-control-container-wrapper-helper'));
		 }
		 
		 // Font name
		 $(this).find('.font-name').on('blur', function() {
			 var $el = $(this);
			 megaGetOptions($el);
			 megaGetAllInputs($el);
		 });
		 
		 // Font weight
		 $(this).find('.font-weight').on('change', function() {
			 var $el = $(this);
			 megaGetOptions($el);
			 megaGetAllInputs($el);
		 });
		 
		 // Font style
		 $(this).find('.font-style').on('change', function() {
			 var $el = $(this);
			 megaGetOptions($el);
			 megaGetAllInputs($el);
		 });

		// Delete font src
		$(this).find('.font-src-list').on('click', function() {
			var $el = $(this);
			$(event.target).closest('li').remove();
			 
			var fontSrc = this.querySelectorAll('.font-src');
			var attachment_string = [];

			fontSrc.forEach(function(element) {
				attachment_string.push(element.textContent);
			});
			 
			attachment_string = attachment_string.toString();
			 
			selectedFont = {
				src: attachment_string,
				name: $el.closest('.font-control-container').find('.font-name').val(),
				weight: $el.closest('.font-control-container').find('.font-weight').val(),
				style: $el.closest('.font-control-container').find('.font-style').val()
			};
			 
			$el.closest('.font-control-container').find('.font-data-input').val(JSON.stringify(selectedFont)).trigger('change');
			megaGetAllInputs($el.closest('.font-control-container-wrapper-helper'));
		});
	 });

});
