"use strict";
document.addEventListener('DOMContentLoaded', function(event) {
  var containerWrapper = document.getElementsByClassName("mt-posts-container-wrapper");
  for (let i = 0; i < containerWrapper.length; i++) {
    if (containerWrapper[i].classList.contains("layout-justified") || containerWrapper[i].classList.contains("layout-cellsbyrow")) {
      Isotope.Item.prototype._create = function() {
        // assign id, used for original-order sorting
        this.id = this.layout.itemGUID++;
        // transition objects
        this._transn = {
          ingProperties: {},
          clean: {},
          onEnd: {}
        };
        this.sortData = {};
      };

      Isotope.Item.prototype.layoutPosition = function() {
        this.emitEvent("layout", [this]);
      };

      Isotope.prototype.arrange = function(opts) {
        // set any options pass
        this.option( opts );
        this._getIsInstant();
        // flag for initalized
        this._isLayoutInited = true;
      };

      // layout mode that does not position items
      Isotope.LayoutMode.create("none");
    }
  
    // Start up isotope with default settings
    if (containerWrapper[i].classList.contains("lazyload-enabled")) {
      startIsotope(containerWrapper[i]);
    } else {
     imagesLoaded(containerWrapper[i], function(instance) {
	   startIsotope(containerWrapper[i])
     });
    }
  
  }
  
  function startIsotope(el) {
    var container = el.querySelector(".mt-posts-container"),
      isotopeItems = el.getElementsByClassName("isotope-item");

    var gutter;
    if (!el.classList.contains("margin-0px")) {
      gutter = ".gutter-sizer";
    } else {
      gutter = 0;
    }
    
    var layoutMode;
    if (el.classList.contains("layout-justified") || el.classList.contains("layout-cellsbyrow")) {
      layoutMode = "none";
    } else if (el.classList.contains("layout-fitrows")) {
      layoutMode = "fitRows";
    } else {
      layoutMode = "masonry";
    }
    
    if (el.classList.contains("layout-fitrows")) {
      var iso = new Isotope(container, {
        layoutMode: "fitRows",
        itemSelector: ".isotope-item",
        fitRows: {
          gutter: gutter
        },
        percentPosition: true,
		stagger: 0,
		transitionDuration: 0,
		hiddenStyle: {
		  opacity: 0,
		  transform: "translate(0px, 40px)"
		},
		visibleStyle: {
		  opacity: 1,
		  transform: "translate(0px, 0px)"
		},
      });
    } else {
      var iso = new Isotope(container, {
        itemSelector: ".isotope-item",
        layoutMode: layoutMode,
        masonry: {
          columnWidth: ".grid-sizer",
          gutter: gutter
        },
        percentPosition: true,
		stagger: 0,
		transitionDuration: 0,
		hiddenStyle: {
		  opacity: 0,
		  transform: "translate(0px, 40px)"
		},
		visibleStyle: {
		  opacity: 1,
		  transform: "translate(0px, 0px)"
		},
      });
    }
    
    // Overlay background color palette from an image
    if (el.classList.contains("overlay-background-color-palette-enabled")) {
      var overlayBackgroundColorOpacity = 1;
      overlayBackgroundColorOpacity = el.getAttribute("data-overlay-bg-color-opacity");
	  for (let j = 0; j < isotopeItems.length; j++) {
        isotopeItems[j].querySelector(".attachment").addEventListener('lazyloaded', function() {
          // color-thief
          var colorThief = new ColorThief(),
            dominantColor = colorThief.getPalette(this, 2),
            colorOverlay = "rgba(" + dominantColor[0][0] + "," + dominantColor[0][1] + "," + dominantColor[0][2] + "," + overlayBackgroundColorOpacity + ")";

          this.parentElement.querySelector(".overlay").style.setProperty("background", colorOverlay);
              
          // Color contrast
          var brightness = Math.round(((parseInt(dominantColor[0][0]) * 299) + (parseInt(dominantColor[0][1]) * 587) + (parseInt(dominantColor[0][2]) * 114)) / 1000);
          
          if (brightness < 125) {
            this.closest(".post-thumbnail-wrapper-1").classList.add("background--dark");
            var entryMeta = this.parentElement.querySelectorAll("h2, .entry-excerpt, .entry-category");
			for (let k = 0; k < entryMeta.length; k++) {
              entryMeta[k].style.setProperty("color", "#fff");
            }
          } else {
            this.closest(".post-thumbnail-wrapper-1").classList.add("background--light");
          }
        });
      }
    }
    
    // Loader
    if (el.classList.contains("lazyload-disabled")) {
      var loader = el.querySelector(".loader-lg");
      Object.assign(loader.style, {"opacity": "0", "visibility": "hidden"});
      if (el.classList.contains("mt-animate_when_almost_visible-disabled")) {
        Object.assign(el.style, {"opacity": "1", "visibility": "inherit"});
		for (let j = 0; j < isotopeItems.length; j++) {
          Object.assign(isotopeItems[j].style, {"opacity": "1"});
        }
      }
    }
    
    if (el.classList.contains("mt-animate_when_almost_visible-disabled")) {
      iso.once("layoutComplete", function(laidOutItems) {
        Object.assign(container.style, {"opacity": "1", "visibility": "inherit"});
		for (let j = 0; j < isotopeItems.length; j++) {
          Object.assign(isotopeItems[j].style, {"opacity": "1"});
        }
      });
      iso.layout();
    }
    
    // Animate the posts when they enter into the browsers viewport
    if (el.classList.contains("mt-animate_when_almost_visible-enabled")) {
      iso.once("layoutComplete", function(laidOutItems) {
        if (el.classList.contains("mt-animate_when_almost_visible-delayed-enabled")) {
          if (el.classList.contains("fadeinup")) {
            for (let j = 0; j < isotopeItems.length; j++) {
              isotopeItems[j].style.setProperty("transform", "translate(0px, 40px)");
            }
          }
          
          var itemQueue = [],
            delay = 125,
            queueTimer;
          
          if (el.classList.contains("fadeinup")) {
            var animation = {
              transition: "opacity ease .35s, transform ease .35s",
              opacity: "1",
              transform: "translate(0px, 0px)"
            };
            var offset = "105%";
          } else {
            var animation = {
              transition: "opacity ease .35s",
              opacity: "1"
            };
            var offset = "95%";
          }
            
          function processItemQueue() {
            if (queueTimer) return // We're already processing the queue
            queueTimer = window.setInterval(function() {
              if (itemQueue.length) {
                Object.assign(itemQueue.shift().style, animation);
                processItemQueue();
              } else {
                window.clearInterval(queueTimer);
                queueTimer = null;
              }
            }, delay)
          }

         for (let j = 0; j < isotopeItems.length; j++) {
            var waypoints = new Waypoint({
              element: isotopeItems[j],
              handler: function(direction) {
                Object.assign(container.style, {"opacity": "1", "visibility": "inherit"});
                itemQueue.push(this.element);
                processItemQueue();
                this.destroy();
              },
              offset: offset,
            });
          }
        } else {
          var waypoint = new Waypoint({
            element: container,
            handler: function(direction) {
              Object.assign(container.style, {"opacity": "1", "visibility": "inherit"});
              if (this.element.parentElement.classList.contains("fadeinup")) {
                for (let j = 0; j < isotopeItems.length; j++) {
                  isotopeItems[j].style.setProperty("transform", "translate(0px, 40px)");
                  var delay = j * 125;
                  (function(j) {
                    setTimeout(function() {
                      Object.assign(isotopeItems[j].style, {"transition": "opacity ease .35s, transform ease .35s", "opacity": "1", "transform": "translate(0px, 0px)"});
                    }, delay);
                  })(j);
                }
              } else {
                for (let j = 0; j < isotopeItems.length; j++) {
                  var delay = j * 125;
                  (function(j) {
                    setTimeout(function() {
                      Object.assign(isotopeItems[j].style, {"transition": "opacity ease .35s", "opacity": "1"});
                    }, delay);
                   })(j);
                 }
               }
               this.destroy();
            },
            offset: "85%",
          });
          
        }
      });
      iso.layout();
    }
	
	// Filter items when filter link is clicked
    var containerWrapper = container.parentElement,
	  filterButtons = containerWrapper.querySelectorAll(".filters a");
    for (let j = 0; j < filterButtons.length; j++) {
	  filterButtons[j].addEventListener("click", function(e) {
        containerWrapper.classList.remove("mt-animate_when_almost_visible-enabled");
         
		var filterValue = e.target.getAttribute("data-filter");
		iso.arrange({
          filter: filterValue
        });
      
        setTimeout(function() {
          //reLayout();
          // Update skrollr
          if (typeof skrollr != "undefined") {
            var parallaxInner = document.querySelector(".vc_parallax-inner");
            if (parallaxInner) {
              setTimeout(function() {
                vcParallaxSkroll.refresh();
              }, 1000 );
            }
          }
        
          // Update waypoints
          if (typeof Waypoint != "undefined") {
            setTimeout(function() {
              Waypoint.refreshAll();
            }, 1000 );
          }
        }, 350);
		
	    // Set selected menu items
        // don't proceed if already selected
        if (this.classList.contains("selected")) {
          e.preventDefault();
        }
		var optionSet = this.closest(".option-set"),
		  optionLinks = optionSet.querySelector(".selected");
        optionLinks.classList.remove("selected");
        this.classList.add("selected");
      
        e.preventDefault();
      });
    }
  }
});