"use strict";

var isotopeItem = document.getElementsByClassName("isotope-item");
for (let i = 0; i < isotopeItem.length; i++) {
  isotopeItem[i].style.setProperty("opacity", "0");
}
	
var body = document.body,
  page = document.getElementById("page"),
  headerWrapper = document.getElementById("header-wrapper");

// Radio buttons and checkboxes
var radios = document.querySelectorAll("input[type=radio]");
for (let i = 0; i < radios.length; i++) {
  radios[i].classList.add("input-radio-custom");
  radios[i].nextElementSibling.insertAdjacentHTML("afterBegin", "<span class='radio-custom'></span>");
}
var checkboxes = document.querySelectorAll("input[type=checkbox]");
for (let i = 0; i < checkboxes.length; i++) {
  checkboxes[i].classList.add("input-checkbox-custom");
  var next = checkboxes[i].nextElementSibling,
    textNode = next.childNodes[0].nodeValue;
  if (textNode !== null) {
    var span = document.createElement("span");
    textNode = document.createTextNode(textNode);
    span.appendChild(textNode);
    next.replaceChild(span, next.childNodes[0]);
  }
  next.insertAdjacentHTML("afterBegin", "<span class='checkbox-custom'><svg class='checkbox-checkmark' viewBox='0 0 24 24'><path class='checkbox-checkmark-path' fill='none' d='M1.73,12.91 8.1,19.28 22.79,4.59'></path></svg></span>");
}

// Page init
body.classList.remove("hidden");

// Page init browser back button
window.addEventListener("pageshow", function(event) {
  if (event.persisted || window.performance && window.performance.navigation.type == 2) {
    body.classList.remove('hidden');
  }
}, false);

// Mobile menu button
var mobileMenuButton = headerWrapper.querySelector(".mobile-menu-dropdown-wrapper");
mobileMenuButton.addEventListener("click", function() {
  body.classList.add("show-responsive-nav");
});

// Mobile menu close button
var mobileMenuCloseButton = headerWrapper.querySelector(".close-button");
mobileMenuCloseButton.addEventListener("click", function() {
  body.classList.remove("show-responsive-nav");
});

// Returns a function, that, as long as it continues to be invoked, will not
// be triggered. The function will be called after it stops being called for
// N milliseconds. If `immediate` is passed, trigger the function on the
// leading edge, instead of the trailing.
function debounce(func, wait, immediate) {
  var timeout;
  return function() {
    var context = this, args = arguments;
    var later = function() {
      timeout = null;
      if (!immediate) func.apply(context, args);
    };
    var callNow = immediate && !timeout;
    clearTimeout(timeout);
    timeout = setTimeout(later, wait);
    if (callNow) func.apply(context, args);
  };
};

document.addEventListener("DOMContentLoaded", function(event) {
  // Waypoints
  var animated = document.getElementsByClassName("wpb_animate_when_almost_visible");
  for (let i = 0; i < animated.length; i++) {
    var waypoint = new Waypoint({
      element: animated[i],
      handler: function(direction) {
        this.element.classList.add("wpb_start_animation", "animated");
        this.destroy();
      },
      offset: "85%"
    });
  }

  // Update Waypoints
  if (typeof imagesLoaded != "undefined") {
    imagesLoaded(body, function() {
      if (typeof Waypoint != "undefined") {
        Waypoint.refreshAll();
      }
    });
  }

  if (typeof Waypoint != "undefined") {
    Waypoint.refreshAll();
    
    var waypointResize = debounce(function() {
      setTimeout(function() {
        Waypoint.refreshAll();
      }, 1500);
    }, 250);

    window.addEventListener("resize", waypointResize);
  }
});

// Scroll to
function scrollToEl(Y, duration, easingFunction) {
  var start = Date.now(),
    elem = document.documentElement,
    from = elem.scrollTop;

  if (from === Y) {
    return; /* Prevent scrolling to the Y point if already there */
  }

  function scroll(timestamp) {
    var currentTime = Date.now(),
      time = Math.min(1, ((currentTime - start) / duration)),
      easedT = easingFunction(time);

    elem.scrollTop = (easedT * (Y - from)) + from;

    if (time < 1) requestAnimationFrame(scroll);
  }

  requestAnimationFrame(scroll);
}

/*
 * Easing Functions - inspired from http://gizma.com/easing/
 * only considering the t value for the range [0, 1] => [0, 1]
 */
var easing = {
  // Acceleration until halfway, then deceleration
  easeInOutQuart: function (t) { return t<.5 ? 8*t*t*t*t : 1-8*(--t)*t*t*t },
}

// Delegate all clicks on "a" tag (links)
var a = document.getElementsByTagName("a");
for (let i = 0; i < a.length; i++) {
  a[i].addEventListener("click", function(e) {
    // Prevent a link to reload current page
    
    // Home
    if (body.classList.contains("home")) {
      if (this.getAttribute("rel") === "home") {
        e.preventDefault();
        return;
      }
    }
    
    // Menu
    if (this.getAttribute("aria-current") === "page") {
      e.preventDefault();
      return;
    }
    
    const classNames = ["add_to_wishlist", "slick-thumbnail", "fresco", "remove", "ajax_add_to_cart", "fancybox-item", "play-button", "esgbox"]
    if (classNames.some(className => this.classList.contains(className))) {
      return;
    }

    // Get the href attribute
    var url = this.getAttribute("href"),
      urlTarget = this.getAttribute("target");

    // Verify if the new url exists or is a hash
    if (!url || url === "javascript:void(null);" || url.indexOf("#") > -1 || urlTarget === "_blank" || url.indexOf("mailto:") > -1 || url.indexOf("tel:") > -1) {
      return;
    }
    
    body.classList.add("hidden");
    
    setTimeout(function() {
      // when the animation is complete, set the new location
      location = url;
    }, 250)

    // Prevent the default browser behavior
    e.preventDefault();
  });
}