"use strict";
document.addEventListener('DOMContentLoaded', function(event) {
  // Wrap in IIFE so that it can be called again later as bodhisvgsInlineSupport();
  var bodhisvgsInlineSupport;
  (bodhisvgsInlineSupport = function() {
    // If force inline SVG option is active then add class
    if (ForceInlineSVGActive === "true") {
      // Find all SVG inside img and add class if it hasn't got it
      var img = document.querySelectorAll("img");
      for (let i = 0; i < img.length; i++) {
        // Check if the SRC attribute is present at all
        var src = img[i].getAttribute("src");
        if (src) {
          // Pick only those with the extension we want
          if (src.match(/\.(svg)/)) {
            // Add our class name
			if (!img[i].classList.contains(cssTarget.ForceInlineSVG)) {
			  img[i].classList.add(cssTarget.ForceInlineSVG);
            }
          }
        }
      }
    }

    // Check to see if user set alternate class
    if ( ForceInlineSVGActive === "true" ) {
      if (cssTarget.Bodhi !== "img.") {
        var target = cssTarget.Bodhi;
      } else {
        var target = "img.style-svg";
      }
    } else {
      if (cssTarget !== "img.") {
        var target = cssTarget;
      } else {
        var target = "img.style-svg";
      }
    }
    
    var targetEl = document.querySelectorAll(target);
    for (let i = 0; i < targetEl.length; i++) {
      var imgID = targetEl[i].getAttribute("id");
      var imgClass = targetEl[i].getAttribute("class");
      var imgURL = targetEl[i].getAttribute("src");

      if (!imgURL.endsWith("svg")) {
        return;
      }
      
      fetch(imgURL)  
        .then(response => response.text())
        .then(str => new window.DOMParser().parseFromString(str, "text/xml"))
        .then(function(data) {
        // Get the SVG tag, ignore the rest
        var svg = data.querySelector("svg");

        var svgID = svg.getAttribute("id");

        // Add replaced image's ID to the new SVG if necessary
        if (typeof imgID === "undefined") {
            if (typeof svgID === "undefined") {
            imgID = "svg-replaced-" + i;
            svg.setAttribute("id", imgID);
          } else {
            imgID = svgID;
          }
        } else {
          svg.setAttribute("id", imgID);
        }

        // Add replaced image's classes to the new SVG
        if (typeof imgClass !== "undefined") {
            svg.setAttribute("class", imgClass + " replaced-svg svg-replaced-" + i);
        }

        // Remove any invalid XML tags as per http://validator.w3.org
        svg.removeAttribute("xmlns:a");

        // Replace image with new SVG
        var imgParent = targetEl[i].parentElement;
        imgParent.replaceChild(svg, targetEl[i]);

        var event = new Event("svg.loaded", {"detail": {
          id: imgID
        }});
        document.dispatchEvent(event);
        }).catch(function(error) {  
        console.log('Request failed', error);  
      });
    }
  })(); // Execute immediately
});