<?php
/**
 * Skylab functions and definitions
 *
 * @package WordPress
 * @subpackage Skylab
 * @since Skylab 1.0
 */

update_option( 'mega_theme_verify', true );
update_option( 'envato_purchase_code_4740718', 'activated' );

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 1170;
	
/**
 * Tell WordPress to run mega_setup() when the 'after_setup_theme' hook is run.
 */
add_action( 'after_setup_theme', 'mega_setup' );

/**
 * Sets up theme defaults and registers support for various WordPress features.
 */
if ( ! function_exists( 'mega_setup' ) ) {
	function mega_setup() {

		load_theme_textdomain( 'skylab', get_template_directory() . '/languages' );

		// This theme styles the visual editor with editor-style.css to match the theme style.
		add_editor_style();

		// Add default posts and comments RSS feed links to <head>.
		add_theme_support( 'automatic-feed-links' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menu( 'primary', esc_html__( 'Primary Menu', 'skylab' ) );
		register_nav_menu( 'secondary', esc_html__( 'Secondary Menu', 'skylab' ) );
		register_nav_menu( 'sliding', esc_html__( 'Sliding Menu', 'skylab' ) );
		register_nav_menu( 'top_bar', esc_html__( 'Top Bar Menu', 'skylab' ) );

		// This theme uses Featured Images (also known as post thumbnails) for per-post/per-page and custom backgrounds
		add_theme_support( 'post-thumbnails' );
		
		// Title
		add_theme_support( 'title-tag' );
		
		// Add theme support for Custom Logo.
		add_theme_support(
			'custom-logo',
			array(
				'height'      => '',
				'width'       => '',
				'flex-height' => true,
				'flex-width'  => true,
			)
		);
		
		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );
		
		// Add support for responsive embeds.
		add_theme_support( 'responsive-embeds' );
		
		// Restoring the classic Widgets Editor
		remove_theme_support( 'widgets-block-editor' );
		
		// Declare WooCommerce support
		add_theme_support( 'woocommerce' );
		
		if ( class_exists( 'woocommerce' ) ) {
		
			// Ensure cart contents update when products are added to the cart via AJAX
			function mega_woocommerce_header_add_to_cart_fragment( $fragments ) {
				global $woocommerce;
				
				ob_start();
				
				?>

				<div class="woocommerce-mini-cart-wrapper">
					<?php if ( ! $woocommerce->cart->cart_contents_count ) { ?>
						<a class="woocommerce-mini-cart" href="<?php echo esc_url( wc_get_cart_url() ); ?>"><span><i><svg viewBox="0 0 512 512"><path d="M467.952,427.383l-25.3-245.673c-1.045-10.187-9.627-17.93-19.867-17.93h-332.9c-10.213,0-18.789,7.717-19.861,17.877 L44.044,427.45c-2.144,21.452,5.007,43.011,19.614,59.156C78.266,502.739,98.986,512,120.511,512h271.653 c21.425,0,41.952-9.075,56.293-24.914C462.999,471.06,470.103,449.328,467.952,427.383z M418.876,460.261 c-6.898,7.603-16.385,11.791-26.712,11.791H120.518c-10.26,0-20.187-4.468-27.238-12.257c-7.051-7.79-10.506-18.13-9.494-28.257 l24.075-227.803h296.9l23.449,227.657C429.276,442.198,425.953,452.451,418.876,460.261z"></path><path d="M259.663,0c-63.144,0-114.518,51.373-114.518,114.518v69.243h39.948v-69.243c0-41.12,33.45-74.57,74.57-74.57 c41.12,0,74.576,33.45,74.576,74.57v69.243h39.941v-69.243C374.181,51.373,322.808,0,259.663,0z"></path></svg></i></span></a>
					<?php } else { ?>
						<a class="woocommerce-mini-cart" href="<?php echo esc_url( wc_get_cart_url() ); ?>"><span><i><svg viewBox="0 0 512 512"><path d="M467.952,427.383l-25.3-245.673c-1.045-10.187-9.627-17.93-19.867-17.93h-332.9c-10.213,0-18.789,7.717-19.861,17.877 L44.044,427.45c-2.144,21.452,5.007,43.011,19.614,59.156C78.266,502.739,98.986,512,120.511,512h271.653 c21.425,0,41.952-9.075,56.293-24.914C462.999,471.06,470.103,449.328,467.952,427.383z M418.876,460.261 c-6.898,7.603-16.385,11.791-26.712,11.791H120.518c-10.26,0-20.187-4.468-27.238-12.257c-7.051-7.79-10.506-18.13-9.494-28.257 l24.075-227.803h296.9l23.449,227.657C429.276,442.198,425.953,452.451,418.876,460.261z"></path><path d="M259.663,0c-63.144,0-114.518,51.373-114.518,114.518v69.243h39.948v-69.243c0-41.12,33.45-74.57,74.57-74.57 c41.12,0,74.576,33.45,74.576,74.57v69.243h39.941v-69.243C374.181,51.373,322.808,0,259.663,0z"></path></svg></i> <span class="cart-contents-count"><?php echo trim( $woocommerce->cart->cart_contents_count ); ?></span></span></a>
						<div class="product-list-cart">
							<em></em>
							<ul>
							<?php foreach( $woocommerce->cart->cart_contents as $cart_item ) { ?>
								<li>
									<a href="<?php echo esc_url( get_permalink( $cart_item['product_id'] ) ); ?>" class="cart-product-link">
										<div><div class="cart-thumbnail-wrapper"><?php echo get_the_post_thumbnail( $cart_item['product_id'], 'shop_thumbnail' ); ?></div></div>
										<span class="product"><?php echo trim( $cart_item['data']->post->post_title ); ?></span>
									</a>
									<?php echo trim( $cart_item['quantity'] ); ?> x <?php echo trim( $woocommerce->cart->get_product_subtotal( $cart_item['data'], $cart_item['quantity'] ) ); ?>
								</li>
							<?php } ?>
							</ul>
							<div class="woocommerce-mini-cart-checkout">
								<div class="woocommerce-mini-cart-total-wrapper">
									<span class="woocommerce-mini-cart-total-text"><?php esc_html_e( 'Total', 'skylab' ); ?></span><span class="woocommerce-mini-cart-total-number"><?php echo trim( $woocommerce->cart->get_cart_total() ); ?></span>
								</div>
								<a class="button alt to-checkout" href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_checkout_page_id' ) ) ); ?>"><span><?php esc_html_e( 'To checkout', 'skylab' ); ?></span></a>
								<a class="button to-cart" href="<?php echo esc_url( get_permalink( get_option( 'woocommerce_cart_page_id' ) ) ); ?>"><span><?php esc_html_e( 'View cart', 'skylab' ); ?></span></a>
							</div>
						</div>
					<?php } ?>
				</div>
				<?php
				
				$fragments['#page .woocommerce-mini-cart-wrapper'] = ob_get_clean();
				
				return $fragments;
				
			}
			add_filter( 'add_to_cart_fragments', 'mega_woocommerce_header_add_to_cart_fragment' );
			
			// AJAX add to cart button on single product page
			add_action( 'wp_ajax_woocommerce_add_to_cart_single_product_mega', 'mega_add_to_cart_single_product_callback' );
			add_action( 'wp_ajax_nopriv_woocommerce_add_to_cart_single_product_mega', 'mega_add_to_cart_single_product_callback' );
			
			function mega_add_to_cart_single_product_callback() {
				
				ob_start();
				
				$product_id = apply_filters( 'woocommerce_add_to_cart_product_id', absint( $_POST['product_id'] ) );
				$quantity = empty( $_POST['quantity'] ) ? 1 : apply_filters( 'woocommerce_stock_amount', $_POST['quantity'] );
				$passed_validation = apply_filters( 'woocommerce_add_to_cart_validation', true, $product_id, $quantity );
			
				if ( $passed_validation && WC()->cart->add_to_cart( $product_id, $quantity ) ) {
					do_action( 'woocommerce_ajax_added_to_cart', $product_id );
					if ( get_option( 'woocommerce_cart_redirect_after_add' ) == 'yes' ) {
						wc_add_to_cart_message( $product_id );
					}
			
					// Return fragments
					WC_AJAX::get_refreshed_fragments();
				} else {
					$this->json_headers();
			
					// If there was an error adding to the cart, redirect to the product page to show any errors
					$data = array(
						'error' => true,
						'product_url' => apply_filters( 'woocommerce_cart_redirect_after_error', get_permalink( $product_id ), $product_id )
					);
					echo json_encode( $data );
				}
				die();
			}
			
			// Hook in functions to display the wrappers theme requires
			remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
			remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );
			
			add_action( 'woocommerce_before_main_content', 'mega_wrapper_start', 10 );
			add_action( 'woocommerce_after_main_content', 'mega_theme_wrapper_end', 10 );

			function mega_wrapper_start() {
				echo '<div id="primary">';
			}

			function mega_theme_wrapper_end() {
				echo '</div>';
			}
			
			// Change number of products that are displayed per page (shop page)
			function mega_loop_shop_per_page( $cols ) {
				// $cols contains the current number of products per page based on the value stored on Options -> Reading
				// Return the number of products you wanna show per page.
				$cols = 12;
				return $cols;
			}
			add_filter( 'loop_shop_per_page', 'mega_loop_shop_per_page', 20 );
			
			if ( ! function_exists( 'mega_loop_columns' ) ) {
				function mega_loop_columns() {
					$shop_columns = get_theme_mod( 'shop_columns', 3 );
					return $shop_columns;
				}
			}
			add_filter( 'loop_shop_columns', 'mega_loop_columns' );
			
			// Cross-Sells Columns
			function mega_cross_sells_columns( $columns ) {
				return 2;
			}
			add_filter( 'woocommerce_cross_sells_columns', 'mega_cross_sells_columns' );
			
			// Cross-Sells Number
			function mega_cartCrossSellTotal( $total ) {
				$total = '2';
				return $total;
			}
			add_filter( 'woocommerce_cross_sells_total', 'mega_cartCrossSellTotal' );
			
			// WooCommerce Sale Text
			function mega_woocommerce_sale_flash( $html ) {
				return str_replace( esc_html__( 'Sale!', 'skylab' ), esc_html__( 'Sale', 'skylab' ), $html );
			}
			add_filter( 'woocommerce_sale_flash', 'mega_woocommerce_sale_flash' );
			
			// WooCommerce redefine woocommerce_output_related_products()
			function mega_related_products_args( $args ) {
				$related_products_slider_on_single_product_page = get_theme_mod( 'related_products_slider_on_single_product_page' );
				if ( ! empty( $related_products_slider_on_single_product_page ) ) {
					$number = 9;
				} else {
					$number = 4;
				}
				  
				$args['posts_per_page'] = $number; // 4 related products
				$args['columns'] = 4; // arranged in 2 columns
				return $args;
			}
			add_filter( 'woocommerce_output_related_products_args', 'mega_related_products_args' );
			
			// Change YITH add to cart button text on wishlist page
			if ( class_exists( 'YITH_WCWL' ) ) {
				function mega_yith_wcwl_add_to_cart_label() {
					return '<span><span>'. esc_html__( 'Add to cart', 'skylab' ) .'</span></span><i></i>';
				}
				add_filter( 'yith_wcwl_add_to_cart_label', 'mega_yith_wcwl_add_to_cart_label' );
			}
			
			// Removing this html option completelly
			function mega_filter_dropdown_option_html( $html, $args ) {
				$show_option_none_text = $args['show_option_none'] ? $args['show_option_none'] : __( 'Choose an option', 'skylab' );
				$show_option_none_html = '<option value="">' . esc_html( $show_option_none_text ) . '</option>';

				$html = str_replace( $show_option_none_html, '', $html );

				return $html;
			}
			add_filter( 'woocommerce_dropdown_variation_attribute_options_html', 'mega_filter_dropdown_option_html', 12, 2 );
		
		} // End if ( class_exists( 'woocommerce' ) )
		
		// WPML for Customizer
		if ( function_exists( 'icl_register_string' ) ) {
			$top_bar_info = get_theme_mod( 'top_bar_info' );
			icl_register_string( 'Customizer', 'top_bar_info', $top_bar_info );
			$footer_info = get_theme_mod( 'footer_info' );
			icl_register_string( 'Customizer', 'footer_info', $footer_info );
		}
		
	}
} // mega_setup

// Customizer
function mega_customize_register( $wp_customize ) {
	
	/**
	 * Alpha Color Picker Customizer Control
	 *
	 * This control adds a second slider for opacity to the stock WordPress color picker,
	 * and it includes logic to seamlessly convert between RGBa and Hex color values as
	 * opacity is added to or removed from a color.
	 *
	 */
	class Mega_Customize_Alpha_Color_Control extends WP_Customize_Control {

		/**
		 * Official control name.
		 */
		public $type = 'alpha-color';

		/**
		 * Add support for palettes to be passed in.
		 *
		 * Supported palette values are true, false, or an array of RGBa and Hex colors.
		 */
		public $palette;

		/**
		 * Add support for showing the opacity value on the slider handle.
		 */
		public $show_opacity;

		/**
		 * Enqueue scripts and styles.
		 *
		 * Ideally these would get registered and given proper paths before this control object
		 * gets initialized, then we could simply enqueue them here, but for completeness as a
		 * stand alone class we'll register and enqueue them here.
		 */
		public function enqueue() {
			wp_enqueue_script(
				'mega-alpha-color-picker',
				get_template_directory_uri() . '/inc/alpha-color-picker/alpha-color-picker.js',
				array( 'jquery', 'wp-color-picker' ),
				'1.0.0',
				true
			);
			wp_enqueue_style(
				'mega-alpha-color-picker',
				get_template_directory_uri() . '/inc/alpha-color-picker/alpha-color-picker.css',
				array( 'wp-color-picker' ),
				'1.0.0'
			);
		}

		/**
		 * Render the control.
		 */
		public function render_content() {

			// Process the palette
			if ( is_array( $this->palette ) ) {
				$palette = implode( '|', $this->palette );
			} else {
				// Default to true.
				$palette = ( false === $this->palette || 'false' === $this->palette ) ? 'false' : 'true';
			}

			// Support passing show_opacity as string or boolean. Default to true.
			$show_opacity = ( false === $this->show_opacity || 'false' === $this->show_opacity ) ? 'false' : 'true';

			// Begin the output. ?>
			<?php // Output the label and description if they were passed in.
			if ( isset( $this->label ) && '' !== $this->label ) {
				echo '<span class="customize-control-title">' . sanitize_text_field( $this->label ) . '</span>';
			}
			if ( isset( $this->description ) && '' !== $this->description ) {
				echo '<span class="description customize-control-description">' . sanitize_text_field( $this->description ) . '</span>';
			} ?>
			<div class="customize-control-content">
				<label>
					<span class="screen-reader-text"><?php echo isset( $this->label ) && '' !== $this->label ? $this->label : "Alpha Color Picker"; ?></span>
					<input class="alpha-color-control" type="text" data-show-opacity="<?php echo esc_attr( $show_opacity ); ?>" data-palette="<?php echo esc_attr( $palette ); ?>" data-default-color="<?php echo esc_attr( $this->settings['default']->default ); ?>" <?php $this->link(); ?>  />
				</label>
			</div>
			<?php
		}
	}
	
	/**
	 * Sortable Repeater Custom Control
	 *
	 * @author Anthony Hortin <http://maddisondesigns.com>
	 * @license http://www.gnu.org/licenses/gpl-2.0.html
	 * @link https://github.com/maddisondesigns
	 */
	class Mega_Sortable_Repeater_Custom_Control extends WP_Customize_Control {
		/**
		 * The type of control being rendered
		 */
		public $type = 'sortable_repeater';
		/**
		 * Button labels
		 */
		public $button_labels = array();
		/**
		 * Constructor
		 */
		public function __construct( $manager, $id, $args = array(), $options = array() ) {
			parent::__construct( $manager, $id, $args );
			// Merge the passed button labels with our default labels
			$this->button_labels = wp_parse_args( $this->button_labels,
				array(
					'add' => __( 'Add', 'skylab' ),
				)
			);
		}
		/**
		 * Enqueue our scripts and styles
		 */
		public function enqueue() {
			wp_enqueue_script( 'mega-customizer', get_template_directory_uri() . '/inc/customizer.js', array( 'jquery', 'jquery-ui-core' ), '1.0', true );
			wp_enqueue_style( 'mega-customizer', get_template_directory_uri() . '/inc/customizer.css', array(), '1.0', 'all' );
		}
		/**
		 * Render the control in the customizer
		 */
		public function render_content() {
		?>
		  <div class="sortable_repeater_control">
				<?php if( !empty( $this->label ) ) { ?>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<?php } ?>
				<?php if( !empty( $this->description ) ) { ?>
					<span class="customize-control-description"><?php echo esc_html( $this->description ); ?></span>
				<?php } ?>
				<input type="hidden" id="<?php echo esc_attr( $this->id ); ?>" name="<?php echo esc_attr( $this->id ); ?>" value="<?php echo esc_attr( $this->value() ); ?>" class="customize-control-sortable-repeater" <?php $this->link(); ?> />
				<div class="sortable_repeater sortable">
					<div class="repeater">
						<input type="text" value="" class="repeater-input" placeholder="https://" /><span class="dashicons dashicons-sort"></span><a class="customize-control-sortable-repeater-delete" href="#"><span class="dashicons dashicons-no-alt"></span></a>
					</div>
				</div>
				<button class="button customize-control-sortable-repeater-add" type="button"><?php echo esc_html( $this->button_labels['add'] ); ?></button>
			</div>
		<?php
		}
	}
	
	class WP_Customize_Font_Control extends WP_Customize_Control {
		public function enqueue() {
			wp_enqueue_style( 'mega-customizer', get_template_directory_uri().'/inc/customizer.css ');
			wp_enqueue_script( 'mega-customizer', get_template_directory_uri().'/inc/customizer.js', array( 'jquery' ), rand(), true );
		}

		public function render_content() { ?>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			  
			<div class="font-control-container-wrapper-helper">
				<div class="font-control-container-wrapper">
					<div class="font-control-container">
						<div class="font-control">
							<div class="attachment-media-view attachment-media-view-font">
								<div class="fonts-wrapper">
									<ul class="font-src-list"></ul>
								</div>
								<button type="button" class="choose-from-library-link upload-button button-add-media" data-choose="<?php esc_attr_e( 'Select font', 'skylab' ); ?>"><?php echo esc_html__( 'Select font', 'skylab' ); ?></button>
								<div class="actions"></div>
							</div>
						</div>
						
						<div class="font-control">
							<span class="description customize-control-description"><?php echo esc_html( __( 'Enter font name', 'skylab' ) ); ?></span>
							<input type="text" value="" class="font-name" />
						</div>
						
						<div class="font-control">
							<span class="description customize-control-description"><?php echo esc_html( __( 'Select font weight', 'skylab' ) ); ?></span>
							<select class="font-weight">
								<option value="100"><?php echo esc_html( __( 'Thin 100', 'skylab' ) ); ?></option>
								<option value="200"><?php echo esc_html( __( 'Extra Light 200', 'skylab' ) ); ?></option>
								<option value="300"><?php echo esc_html( __( 'Light 300', 'skylab' ) ); ?></option>
								<option value="400" selected="selected"><?php echo esc_html( __( 'Regular 400', 'skylab' ) ); ?></option>
								<option value="500"><?php echo esc_html( __( 'Medium 500', 'skylab' ) ); ?></option>
								<option value="600"><?php echo esc_html( __( 'Semi Bold 600', 'skylab' ) ); ?></option>
								<option value="700"><?php echo esc_html( __( 'Bold 700', 'skylab' ) ); ?></option>
								<option value="800"><?php echo esc_html( __( 'Extra Bold 800', 'skylab' ) ); ?></option>
								<option value="900"><?php echo esc_html( __( 'Black 900', 'skylab' ) ); ?></option>
							</select>
						</div>
						
						<div class="font-control">
							<span class="description customize-control-description"><?php echo esc_html( __( 'Select font style', 'skylab' ) ); ?></span>
							<select class="font-style">
								<option value="normal" selected="selected"><?php echo esc_html( __( 'Normal', 'skylab' ) ); ?></option>
								<option value="italic"><?php echo esc_html( __( 'Italic', 'skylab' ) ); ?></option>
							</select>
						</div>

						<input type="hidden" class="font-data-input" value="" class="wp-editor-area">
						<button type="button" class="button-link button-link-delete"><?php echo esc_html( __( 'Remove font', 'skylab' ) ); ?></button>
					</div>
				</div>
				<button class="button font-control-container-add" type="button"><?php echo esc_html( __( 'Add font', 'skylab' ) ); ?></button>
				<input type="hidden" id="<?php echo esc_attr( $this->id ); ?>" name="<?php echo esc_attr( $this->id ); ?>" value="<?php echo esc_attr( $this->value() ); ?>" class="font-input wp-editor-area" <?php $this->link(); ?>>
			</div>
		  <?php
		}
	}
	
	// Add postMessage support
	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title',
				'render_callback' => 'mega_customize_partial_blogname',
			)
		);
	}
	
	// Site Identity Section
	$wp_customize->get_section( 'title_tagline' )->priority = 10;
	
	// Transparent Header Logo
	$wp_customize->add_setting( 'custom_logo_transparent_header', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'custom_logo_transparent_header', array(
		'label' => __( 'Transparent Header Logo', 'skylab' ),
		'section' => 'title_tagline',
		'priority' => 9,
	) ) );
	
	// Logo Height
    $wp_customize->add_setting( 'logo_height', array(
		'default' => 32,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'logo_height',
	   array(
		  'label' => __( 'Logo Height', 'skylab' ),
		  'description' => __( 'Choose a value for logo height in pixels. Default value is 32.', 'skylab' ),
		  'section' => 'title_tagline',
		  'priority' => 9,
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 22,
			 'max' => 99,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Display Tagline
	$wp_customize->add_setting( 'display_tagline', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'display_tagline', array(
		'label' => __( 'Display Tagline', 'skylab' ),
		'section' => 'title_tagline',
		'type' => 'checkbox',
	) );
	
	// Display Tagline Below Site Title
	$wp_customize->add_setting( 'display_tagline_below_site_title', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'display_tagline_below_site_title', array(
		'label' => __( 'Display Tagline Below Site Title', 'skylab' ),
		'section' => 'title_tagline',
		'type' => 'checkbox',
	) );
	
	// Tagline Margin
	$wp_customize->add_setting( 'tagline_margin', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'tagline_margin', array(
		'label' => __( 'Tagline Margin', 'skylab' ),
		'section' => 'title_tagline',
		'type' => 'checkbox',
	) );
	
	// Display Logo and Site Title Together
	$wp_customize->add_setting( 'display_logo_and_site_title_together', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'display_logo_and_site_title_together', array(
		'label' => __( 'Display Logo and Site Title Together', 'skylab' ),
		'section' => 'title_tagline',
		'type' => 'checkbox',
	) );
	
	// Site Icon Dark
	$wp_customize->add_setting( 'site_icon_dark', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Site_Icon_Control( $wp_customize, 'site_icon_dark',
		array(
			'label' => __( 'Site Icon Dark', 'skylab' ),
			'section'     => 'title_tagline',
			'priority'    => 60,
			'height'      => 512,
			'width'       => 512,
		)
	) );
	
	// General Section
	$wp_customize->add_section( 'general' , array(
		'title' => __( 'General', 'skylab' ),
		'priority' => 10,
	) );
	
	// Page Load Progress Indicator
	$wp_customize->add_setting( 'page_load_progress_indicator', array(
		'default' => 'progress_bar',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'page_load_progress_indicator', array(
		'label' => __( 'Page Load Progress Indicator', 'skylab' ),
		'section' => 'general',
		'type' => 'select',
		'choices' => array(
			'disabled' => __( 'Disabled', 'skylab' ),
			'progress_bar' => __( 'Progress Bar', 'skylab' ),
		),
	) );
	
	// Disable Right Click on Images
	$wp_customize->add_setting( 'disable_right_click_on_images', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'disable_right_click_on_images', array(
		'label' => __( 'Disable Right Click on Images', 'skylab' ),
		'section' => 'general',
		'type' => 'checkbox',
	) );
	
	// Search Position
    $wp_customize->add_setting( 'search_position', array(
		'default' => 'none',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'search_position',
	   array(
		  'label' => __( 'Search Position', 'skylab' ),
		  'section' => 'general',
		  'type' => 'select',
		  'choices' => array(
			 'none' => __( 'None', 'skylab' ),
			 'header' => __( 'Header', 'skylab' ),
			 'top_bar' => __( 'Top Bar', 'skylab' ),
		  ),
	   )
	);
	
	// Search Align
    $wp_customize->add_setting( 'search_align', array(
		'default' => 'right',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'search_align',
	   array(
		  'label' => __( 'Search Align', 'skylab' ),
		  'section' => 'general',
		  'type' => 'select',
		  'choices' => array(
			 'right' => __( 'Right', 'skylab' ),
			 'left' => __( 'Left', 'skylab' ),
		  ),
	   )
	);
	
	// Primary/Secondary/Top Bar Menu Items Transition Hover
	$wp_customize->add_setting( 'primary_secondary_top_bar_menu_items_transition_hover', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'primary_secondary_top_bar_menu_items_transition_hover', array(
		'label' => __( 'Primary/Secondary/Top Bar Menu Items Transition Hover', 'skylab' ),
		'section' => 'general',
		'type' => 'checkbox',
	) );
	
	// WPML Language Switcher Position
	if ( function_exists( 'icl_object_id' ) ) {
		$wp_customize->add_setting( 'wpml_language_switcher_position', array(
			'default' => 'none',
			'transport' => 'refresh',
			'sanitize_callback' => 'esc_attr',
		) );
		$wp_customize->add_control( 'wpml_language_switcher_position',
		   array(
			  'label' => __( 'WPML Language Switcher Position', 'skylab' ),
			  'section' => 'general',
			  'type' => 'select',
			  'choices' => array(
				 'none' => __( 'None', 'skylab' ),
				 'header' => __( 'Header', 'skylab' ),
				 'top_bar' => __( 'Top Bar', 'skylab' ),
			  ),
		   )
		);
	}
	
	// Single Post Navigation
	$wp_customize->add_setting( 'single_post_navigation', array(
		'default' => false,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'single_post_navigation', array(
		'label' => __( 'Single Post Navigation', 'skylab' ),
		'section' => 'general',
		'type' => 'checkbox',
	) );
	
	// Single Portfolio Navigation
	$wp_customize->add_setting( 'single_portfolio_navigation', array(
		'default' => false,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'single_portfolio_navigation', array(
		'label' => __( 'Single Portfolio Navigation', 'skylab' ),
		'section' => 'general',
		'type' => 'checkbox',
	) );
	
	// Single Navigation Style
	$wp_customize->add_setting( 'single_navigation_style', array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'single_navigation_style',
	   array(
		  'label' => __( 'Single Navigation Style', 'skylab' ),
		  'description' => __( 'Prev/next post style.', 'skylab' ),
		  'section' => 'general',
		  'type' => 'select',
		  'choices' => array(
			 1 => 1,
			 2 => 2,
		  ),
	   )
	);
	
	// Single Navigation Images
	$wp_customize->add_setting( 'single_navigation_images', array(
		'default' => false,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'single_navigation_images', array(
		'label' => __( 'Single Navigation Images', 'skylab' ),
		'section' => 'general',
		'type' => 'checkbox',
	) );
	
	// Full Width Single Navigation
	$wp_customize->add_setting( 'full_width_single_navigation', array(
		'default' => false,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'full_width_single_navigation', array(
		'label' => __( 'Full Width Single Navigation', 'skylab' ),
		'section' => 'general',
		'type' => 'checkbox',
	) );
	
	// Buttons Style
	$wp_customize->add_setting( 'buttons_style', array(
		'default' => 'modern',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'buttons_style',
	   array(
		  'label' => __( 'Buttons Style', 'skylab' ),
		  'section' => 'general',
		  'type' => 'select',
		  'choices' => array(
			 'modern' => __( 'Modern', 'skylab' ),
			 'outline' => __( 'Outline', 'skylab' ),
		  ),
	   )
	);
	
	// Buttons Shape
	$wp_customize->add_setting( 'buttons_shape', array(
		'default' => 'square',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'buttons_shape',
	   array(
		  'label' => __( 'Buttons Shape', 'skylab' ),
		  'section' => 'general',
		  'type' => 'select',
		  'choices' => array(
			 'square' => __( 'Square', 'skylab' ),
			 'rounded' => __( 'Rounded', 'skylab' ),
			 'round' => __( 'Round', 'skylab' ),
			 'superround' => __( 'Super Round', 'skylab' ),
		  ),
	   )
	);
	
	// General Arrows Buttons Style
	$wp_customize->add_setting( 'general_arrows_buttons_style', array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'general_arrows_buttons_style',
	   array(
		  'label' => __( 'General Arrows Buttons Style', 'skylab' ),
		  'description' => __( 'To top, prev/next post buttons style.', 'skylab' ),
		  'section' => 'general',
		  'type' => 'select',
		  'choices' => array(
			 1 => __( 'Minimal', 'skylab' ),
			 2 => __( 'Square', 'skylab' ),
			 3 => __( 'Round', 'skylab' ),
		  ),
	   )
	);
	
	// Input Style
	$wp_customize->add_setting( 'input_style', array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'input_style',
	   array(
		  'label' => __( 'Input Style', 'skylab' ),
		  'description' => __( 'Input style.', 'skylab' ),
		  'section' => 'general',
		  'type' => 'select',
		  'choices' => array(
			 1 => 1,
			 2 => 2,
		  ),
	   )
	);
	
	// Links Hover Opacity Effect
	$wp_customize->add_setting( 'links_hover_opacity_effect', array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'links_hover_opacity_effect', array(
		'label' => __( 'Links Hover Opacity Effect', 'skylab' ),
		'section' => 'general',
		'type' => 'checkbox',
	) );
	
	// Links Click Opacity Effect
	$wp_customize->add_setting( 'links_click_opacity_effect', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'links_click_opacity_effect', array(
		'label' => __( 'Links Click Opacity Effect', 'skylab' ),
		'section' => 'general',
		'type' => 'checkbox',
	) );
	
	// Links Click Color Effect
	$wp_customize->add_setting( 'links_click_color_effect', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'links_click_color_effect', array(
		'label' => __( 'Links Click Color Effect', 'skylab' ),
		'section' => 'general',
		'type' => 'checkbox',
	) );
	
	// Header Section
	$wp_customize->add_section( 'header' , array(
		'title' => __( 'Header', 'skylab' ),
		'priority' => 10,
	) );
	
	// Header Behavior
    $wp_customize->add_setting( 'header_behavior', array(
		'default' => 'normal',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'header_behavior',
	   array(
		  'label' => __( 'Header Behavior', 'skylab' ),
		  'section' => 'header',
		  'type' => 'select',
		  'choices' => array(
			 'normal' => __( 'Normal', 'skylab' ),
			 'fixed' => __( 'Fixed', 'skylab' ),
			 'fixed_on_scroll' => __( 'Fixed on Scroll', 'skylab' ),
		  ),
	   )
	);
	
	// Header Height Reduction on Scrolling
	$wp_customize->add_setting( 'header_height_reduction_on_scrolling', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'header_height_reduction_on_scrolling', array(
		'label' => __( 'Header Height Reduction on Scrolling', 'skylab' ),
		'description' => __( 'Note: fixed or fixed on scroll header behavior must be enabled.', 'skylab' ),
		'section' => 'header',
		'type' => 'checkbox',
	) );
	
	// Header Height (Width)
    $wp_customize->add_setting( 'header_height_width', array(
		'default' => 64,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'header_height_width',
	   array(
		  'label' => __( 'Header Height (Width)', 'skylab' ),
		  'description' => __( 'Choose a value for header height (width) in pixels. Note: to adjust header width "Left" or "Right" value for "Header Position" option must be enabled.', 'skylab' ),
		  'section' => 'header',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 35,
			 'max' => 310,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Header Height on Scrolling
    $wp_customize->add_setting( 'header_height_on_scrolling', array(
		'default' => 54,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'header_height_on_scrolling',
	   array(
		  'label' => __( 'Header Height on Scrolling', 'skylab' ),
		  'description' => __( 'Choose a value for header height on scrolling in pixels. Note: "Header Height Reduction on Scrolling" option must be enabled.', 'skylab' ),
		  'section' => 'header',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 35,
			 'max' => 180,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Full Width Header
	$wp_customize->add_setting( 'full_width_header', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'full_width_header', array(
		'label' => __( 'Full Width Header', 'skylab' ),
		'section' => 'header',
		'type' => 'checkbox',
	) );
	
	// Header Position
    $wp_customize->add_setting( 'header_position', array(
		'default' => 'top',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'header_position',
	   array(
		  'label' => __( 'Header Position', 'skylab' ),
		  'section' => 'header',
		  'type' => 'select',
		  'choices' => array(
			 'top' => __( 'Top', 'skylab' ),
			 'left' => __( 'Left', 'skylab' ),
			 'bottom' => __( 'Bottom', 'skylab' ),
			 'right' => __( 'Right', 'skylab' ),
		  ),
	   )
	);
	
	// Center Content Horizontally for Left/Right Header
	$wp_customize->add_setting( 'center_content_horizontally_for_left_right_header', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'center_content_horizontally_for_left_right_header', array(
		'label' => __( 'Center Content Horizontally for Left/Right Header', 'skylab' ),
		'description' => __( 'Note: "Left" or "Right" value for "Header Position" option must be enabled.', 'skylab' ),
		'section' => 'header',
		'type' => 'checkbox',
	) );
	
	// Header Info
	$wp_customize->add_setting( 'header_info', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'mega_sanitize_textarea_field',
	) );
	$wp_customize->add_control( 'header_info', array(
		'label' => __( 'Header Info', 'skylab' ),
		'description' => __( 'Enter the info you would like to display in header of your site.', 'skylab' ),
		'section' => 'header',
		'type' => 'textarea',
	) );
	
	// Header Top Border
	$wp_customize->add_setting( 'header_top_border', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'header_top_border', array(
		'label' => __( 'Header Top Border', 'skylab' ),
		'section' => 'header',
		'type' => 'checkbox',
	) );
	
	// Header Bottom Border
	$wp_customize->add_setting( 'header_bottom_border', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'header_bottom_border', array(
		'label' => __( 'Header Bottom Border', 'skylab' ),
		'section' => 'header',
		'type' => 'checkbox',
	) );
	
	// Primary Menu Align
    $wp_customize->add_setting( 'menu_align', array(
		'default' => 'right',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_align',
	   array(
		  'label' => __( 'Primary Menu Align', 'skylab' ),
		  'section' => 'header',
		  'type' => 'select',
		  'choices' => array(
			 'right' => __( 'Right', 'skylab' ),
			 'center' => __( 'Center', 'skylab' ),
			 'left' => __( 'Left', 'skylab' ),
		  ),
	   )
	);
	
	// Secondary Menu Align
    $wp_customize->add_setting( 'secondary_menu_align', array(
		'default' => 'right',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'secondary_menu_align',
	   array(
		  'label' => __( 'Secondary Menu Align', 'skylab' ),
		  'section' => 'header',
		  'type' => 'select',
		  'choices' => array(
			 'right' => __( 'Right', 'skylab' ),
			 'left' => __( 'Left', 'skylab' ),
		  ),
	   )
	);
	
	// Mobile Menu Align
    $wp_customize->add_setting( 'mobile_menu_align', array(
		'default' => 'left',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'mobile_menu_align',
	   array(
		  'label' => __( 'Mobile Menu Align', 'skylab' ),
		  'section' => 'header',
		  'type' => 'select',
		  'choices' => array(
			 'left' => __( 'Left', 'skylab' ),
			 'right' => __( 'Right', 'skylab' ),
		  ),
	   )
	);
	
	// Logo Align
    $wp_customize->add_setting( 'logo_align', array(
		'default' => 'left',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'logo_align',
	   array(
		  'label' => __( 'Logo Align', 'skylab' ),
		  'section' => 'header',
		  'type' => 'select',
		  'choices' => array(
			 'left' => __( 'Left', 'skylab' ),
			 'center' => __( 'Center', 'skylab' ),
			 'right' => __( 'Right', 'skylab' ),
		  ),
	   )
	);
	
	// Sliding Menu Align
    $wp_customize->add_setting( 'sliding_menu_align', array(
		'default' => 'right',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'sliding_menu_align',
	   array(
		  'label' => __( 'Sliding Menu Align', 'skylab' ),
		  'section' => 'header',
		  'type' => 'select',
		  'choices' => array(
			 'right' => __( 'Right', 'skylab' ),
			 'left' => __( 'Left', 'skylab' ),
		  ),
	   )
	);
	
	// Full Width Sliding Menu
	$wp_customize->add_setting( 'full_width_sliding_menu', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'full_width_sliding_menu', array(
		'label' => __( 'Full Width Sliding Menu', 'skylab' ),
		'section' => 'header',
		'type' => 'checkbox',
	) );
	
	// Center Logo and Menu
	$wp_customize->add_setting( 'center_logo_and_menu', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'center_logo_and_menu', array(
		'label' => __( 'Center Logo and Menu', 'skylab' ),
		'section' => 'header',
		'type' => 'checkbox',
	) );
	
	// Menu Opacity on Hover
	$wp_customize->add_setting( 'menu_opacity_hover', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_opacity_hover', array(
		'label' => __( 'Menu Opacity on Hover', 'skylab' ),
		'section' => 'header',
		'type' => 'checkbox',
	) );
	
	// Mix Blend Mode
	$wp_customize->add_setting( 'header_mix_blend_mode', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'header_mix_blend_mode', array(
		'label' => __( 'Mix Blend Mode', 'skylab' ),
		'section' => 'header',
		'type' => 'checkbox',
	) );
	
	// Justify Content
	$wp_customize->add_setting( 'header_justify_content', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'header_justify_content', array(
		'label' => __( 'Justify Content', 'skylab' ),
		'section' => 'header',
		'type' => 'checkbox',
	) );
	
	// Top Bar Section
	$wp_customize->add_section( 'top_bar' , array(
		'title' => __( 'Top Bar', 'skylab' ),
		'priority' => 10,
	) );
	
	// Top Bar
	$wp_customize->add_setting( 'top_bar', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'top_bar', array(
		'label' => __( 'Top Bar', 'skylab' ),
		'section' => 'top_bar',
		'type' => 'checkbox',
	) );
	
	// Top Bar Behavior
    $wp_customize->add_setting( 'top_bar_behavior', array(
		'default' => 'normal',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'top_bar_behavior',
	   array(
		  'label' => __( 'Top Bar Behavior', 'skylab' ),
		  'section' => 'top_bar',
		  'type' => 'select',
		  'choices' => array(
			 'normal' => __( 'Normal', 'skylab' ),
			 'fixed' => __( 'Fixed', 'skylab' ),
			 'fixed_on_scroll' => __( 'Fixed on Scroll', 'skylab' ),
		  ),
	   )
	);
	
	// Top Bar Height Reduction on Scrolling
	$wp_customize->add_setting( 'top_bar_height_reduction_on_scrolling', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'top_bar_height_reduction_on_scrolling', array(
		'description' => __( 'Note: fixed or fixed on scroll top bar behavior must be enabled.', 'skylab' ),
		'label' => __( 'Top Bar Height Reduction on Scrolling', 'skylab' ),
		'section' => 'top_bar',
		'type' => 'checkbox',
	) );
	
	// Top Bar Height
    $wp_customize->add_setting( 'top_bar_height', array(
		'default' => 40,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'top_bar_height',
	   array(
		  'label' => __( 'Top Bar Height', 'skylab' ),
		  'description' => __( 'Choose a value for top bar height in pixels.', 'skylab' ),
		  'section' => 'top_bar',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 30,
			 'max' => 110,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Top Bar Height on Scrolling
    $wp_customize->add_setting( 'top_bar_height_on_scrolling', array(
		'default' => 30,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'top_bar_height_on_scrolling',
	   array(
		  'label' => __( 'Top Bar Height on Scrolling', 'skylab' ),
		  'description' => __( 'Choose a value for top bar height on scrolling in pixels. Note: "Top Bar Height Reduction on Scrolling" option must be enabled.', 'skylab' ),
		  'section' => 'top_bar',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 30,
			 'max' => 50,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Sanitize textarea field
	function mega_sanitize_textarea_field( $content ) {
		return trim( $content );
	}
	
	// Top Bar Info
	$wp_customize->add_setting( 'top_bar_info', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'mega_sanitize_textarea_field',
	) );
	$wp_customize->add_control( 'top_bar_info', array(
		'label' => __( 'Top Bar Info', 'skylab' ),
		'description' => __( 'Enter the info you would like to display in top bar of your site.', 'skylab' ),
		'section' => 'top_bar',
		'type' => 'textarea',
	) );
	
	// Top Bar Info 2
	$wp_customize->add_setting( 'top_bar_info_2', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'mega_sanitize_textarea_field',
	) );
	$wp_customize->add_control( 'top_bar_info_2', array(
		'label' => __( 'Top Bar Info 2', 'skylab' ),
		'description' => __( 'Enter the info you would like to display in top bar of your site.', 'skylab' ),
		'section' => 'top_bar',
		'type' => 'textarea',
	) );
	
	// Top Bar Bottom Border
	$wp_customize->add_setting( 'top_bar_bottom_border', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'top_bar_bottom_border', array(
		'label' => __( 'Top Bar Bottom Border', 'skylab' ),
		'section' => 'top_bar',
		'type' => 'checkbox',
	) );
	
	// Top Bar Menu Align
    $wp_customize->add_setting( 'top_bar_menu_align', array(
		'default' => 'right',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'top_bar_menu_align',
	   array(
		  'label' => __( 'Top Bar Menu Align', 'skylab' ),
		  'section' => 'top_bar',
		  'type' => 'select',
		  'choices' => array(
			 'right' => __( 'Right', 'skylab' ),
			 'center' => __( 'Center', 'skylab' ),
			 'left' => __( 'Left', 'skylab' ),
		  ),
	   )
	);
	
	// Footer Section
	$wp_customize->add_section( 'footer' , array(
		'title' => __( 'Footer', 'skylab' ),
		'priority' => 10,
	) );
	
	// Back to Top Button
	$wp_customize->add_setting( 'back_to_top_button', array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'back_to_top_button', array(
		'label' => __( 'Back to Top Button', 'skylab' ),
		'section' => 'footer',
		'type' => 'checkbox',
	) );
	
	// Back to Top Button Mix Blend Mode
	$wp_customize->add_setting( 'back_to_top_button_mix_blend_mode', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'back_to_top_button_mix_blend_mode', array(
		'label' => __( 'Back to Top Button Mix Blend Mode', 'skylab' ),
		'section' => 'footer',
		'type' => 'checkbox',
	) );
	
	// Full Width Footer
	$wp_customize->add_setting( 'full_width_footer', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'full_width_footer', array(
		'label' => __( 'Full Width Footer', 'skylab' ),
		'section' => 'footer',
		'type' => 'checkbox',
	) );
	
	// Footer Bottom Area Top Padding
    $wp_customize->add_setting( 'footer_bottom_area_top_padding', array(
		'default' => 40,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'footer_bottom_area_top_padding',
	   array(
		  'label' => __( 'Footer Bottom Area Top Padding', 'skylab' ),
		  'description' => __( 'Choose a value for footer bottom area top padding in pixels. Default value is 50.', 'skylab' ),
		  'section' => 'footer',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 0,
			 'max' => 150,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Footer Bottom Area Bottom Padding
    $wp_customize->add_setting( 'footer_bottom_area_bottom_padding', array(
		'default' => 40,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'footer_bottom_area_bottom_padding',
	   array(
		  'label' => __( 'Footer Bottom Area Bottom Padding', 'skylab' ),
		  'description' => __( 'Choose a value for footer bottom area bottom padding in pixels. Default value is 50.', 'skylab' ),
		  'section' => 'footer',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 15,
			 'max' => 150,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Footer Top Border
	$wp_customize->add_setting( 'footer_top_border', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'footer_top_border', array(
		'label' => __( 'Footer Top Border', 'skylab' ),
		'section' => 'footer',
		'type' => 'checkbox',
	) );
	
	// Footer Bottom Area Top Border
	$wp_customize->add_setting( 'footer_bottom_area_top_border', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'footer_bottom_area_top_border', array(
		'label' => __( 'Footer Bottom Area Top Border', 'skylab' ),
		'section' => 'footer',
		'type' => 'checkbox',
	) );
	
	// Footer Parallax
	$wp_customize->add_setting( 'footer_parallax', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'footer_parallax', array(
		'label' => __( 'Footer Parallax', 'skylab' ),
		'section' => 'footer',
		'type' => 'checkbox',
	) );
	
	// Social Links Section
	$wp_customize->add_section( 'social_links' , array(
		'title' => __( 'Social Links', 'skylab' ),
		'priority' => 10,
	) );
	
	// Social Links Position
    $wp_customize->add_setting( 'social_links_position', array(
		'default' => 'none',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'social_links_position',
	   array(
		  'label' => __( 'Social Links Position', 'skylab' ),
		  'section' => 'social_links',
		  'type' => 'select',
		  'choices' => array(
			 'none' => __( 'None', 'skylab' ),
			 'header' => __( 'Header', 'skylab' ),
			 'top_bar' => __( 'Top Bar', 'skylab' ),
		  ),
	   )
	);
	
	// Social Links Align
    $wp_customize->add_setting( 'social_links_align', array(
		'default' => 'right',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'social_links_align',
	   array(
		  'label' => __( 'Social Links Align', 'skylab' ),
		  'section' => 'social_links',
		  'type' => 'select',
		  'choices' => array(
			 'right' => __( 'Right', 'skylab' ),
			 'left' => __( 'Left', 'skylab' ),
		  ),
	   )
	);
	
	// Social Links Style
    $wp_customize->add_setting( 'social_links_style', array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'social_links_style',
	   array(
		  'label' => __( 'Social Links Style', 'skylab' ),
		  'section' => 'social_links',
		  'type' => 'select',
		  'choices' => array(
			 1 => 1,
			 2 => 2,
			 3 => 3,
		  ),
	   )
	);
	
	// Social Links Opacity on Hover
	$wp_customize->add_setting( 'social_links_opacity_hover', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'social_links_opacity_hover', array(
		'label' => __( 'Social Links Opacity on Hover', 'skylab' ),
		'section' => 'social_links',
		'type' => 'checkbox',
	) );
	
	// Add Sortable Repeater Setting and Custom Control for Social Media URLs
	$wp_customize->add_setting( 'social_links',
		array(
			'default' => '',
			'transport' => 'refresh',
			'sanitize_callback' => 'esc_attr'
		)
	);
	$wp_customize->add_control( new Mega_Sortable_Repeater_Custom_Control( $wp_customize, 'social_links',
		array(
			'label' => __( 'Social Links', 'skylab' ),
			'description' => esc_html__( 'Add a social links. Drag and drop each field to reorder them.', 'skylab' ),
			'section' => 'social_links',
			'button_labels' => array(
				'add' => __( 'Add Link', 'skylab' ),
			)
		)
	) );
	
	// Typography Panel
	$wp_customize->add_panel( 'typography', array(
		'title' => __( 'Typography', 'skylab' ),
		'priority' => 11,
	) );
	
	// General Typography Section
	$wp_customize->add_section( 'general_typography' , array(
		'title' => __( 'General', 'skylab' ),
		'priority' => 10,
		'panel' => 'typography',
	) );
	
	// Primary Typography Google Font URL
    $wp_customize->add_setting( 'primary_typography_google_font_url', array(
		'default' => '',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'primary_typography_google_font_url',
	   array(
		  'label' => __( 'Primary Google Font URL', 'skylab' ),
		  'description' => __( 'Example: https://fonts.googleapis.com/css?family=Lato:400,400i,700,700i&display=swap', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'text',
	   )
	);
	
	// Primary Typography Font
	$wp_customize->add_setting( 'primary_typography_font', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Font_Control( $wp_customize, 'primary_typography_font', array(
		'label' => __( 'Primary Font', 'skylab' ),
		'section' => 'general_typography',
	) ) );
	
	// Secondary Typography Google Font URL
    $wp_customize->add_setting( 'secondary_typography_google_font_url', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'secondary_typography_google_font_url',
	   array(
		  'label' => __( 'Secondary Google Font URL', 'skylab' ),
		  'description' => __( 'Example: https://fonts.googleapis.com/css?family=Lato:400,400i,700,700i&display=swap', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'text',
	   )
	);
	
	// Secondary Typography Font
	$wp_customize->add_setting( 'secondary_typography_font', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Font_Control( $wp_customize, 'secondary_typography_font', array(
		'label' => __( 'Secondary Font', 'skylab' ),
		'section' => 'general_typography',
	) ) );
	
	// Additional Typography Google Font URL
    $wp_customize->add_setting( 'additional_typography_google_font_url', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'additional_typography_google_font_url',
	   array(
		  'label' => __( 'Additional Google Font URL', 'skylab' ),
		  'description' => __( 'Example: https://fonts.googleapis.com/css?family=Lato:400,400i,700,700i&display=swap', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'text',
	   )
	);
	
	// Additional Typography Font
	$wp_customize->add_setting( 'additional_typography_font', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Font_Control( $wp_customize, 'additional_typography_font', array(
		'label' => __( 'Additional Font', 'skylab' ),
		'section' => 'general_typography',
	) ) );
	
	// Body Font Size
    $wp_customize->add_setting( 'body_font_size', array(
		'default' => 16,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'body_font_size',
	   array(
		  'label' => __( 'Body Font Size', 'skylab' ),
		  'description' => __( 'Choose a value for body font size in pixels. Default value is 16.', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 10,
			 'max' => 22,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Body Font Weight
    $wp_customize->add_setting( 'body_font_weight', array(
		'default' => 400,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'body_font_weight',
	   array(
		  'label' => __( 'Body Font Weight', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'select',
		  'choices' => array(
			 100 => __( 'Thin 100', 'skylab' ),
			 200 => __( 'Extra Light 200', 'skylab' ),
			 300 => __( 'Light 300', 'skylab' ),
			 400 => __( 'Regular 400', 'skylab' ),
			 500 => __( 'Medium 500', 'skylab' ),
			 600 => __( 'Semi Bold 600', 'skylab' ),
			 700 => __( 'Bold 700', 'skylab' ),
			 800 => __( 'Extra Bold 800', 'skylab' ),
			 900 => __( 'Black 900', 'skylab' ),
		  ),
	   )
	);
	
	// Bold Font Weight
    $wp_customize->add_setting( 'bold_font_weight', array(
		'default' => 700,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'bold_font_weight',
	   array(
		  'label' => __( 'Bold Font Weight', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'select',
		  'choices' => array(
			 100 => __( 'Thin 100', 'skylab' ),
			 200 => __( 'Extra Light 200', 'skylab' ),
			 300 => __( 'Light 300', 'skylab' ),
			 400 => __( 'Regular 400', 'skylab' ),
			 500 => __( 'Medium 500', 'skylab' ),
			 600 => __( 'Semi Bold 600', 'skylab' ),
			 700 => __( 'Bold 700', 'skylab' ),
			 800 => __( 'Extra Bold 800', 'skylab' ),
			 900 => __( 'Black 900', 'skylab' ),
		  ),
	   )
	);
	
	// Heading Font Weight
    $wp_customize->add_setting( 'heading_font_weight', array(
		'default' => 700,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'heading_font_weight',
	   array(
		  'label' => __( 'Heading Font Weight', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'select',
		  'choices' => array(
			 100 => __( 'Thin 100', 'skylab' ),
			 200 => __( 'Extra Light 200', 'skylab' ),
			 300 => __( 'Light 300', 'skylab' ),
			 400 => __( 'Regular 400', 'skylab' ),
			 500 => __( 'Medium 500', 'skylab' ),
			 600 => __( 'Semi Bold 600', 'skylab' ),
			 700 => __( 'Bold 700', 'skylab' ),
			 800 => __( 'Extra Bold 800', 'skylab' ),
			 900 => __( 'Black 900', 'skylab' ),
		  ),
	   )
	);
	
	// Links Text Decoration
    $wp_customize->add_setting( 'links_text_decoration', array(
		'default' => 'underline',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'links_text_decoration',
	   array(
		  'label' => __( 'Links Text Decoration', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'select',
		  'choices' => array(
			 'underline' => __( 'Underline', 'skylab' ),
			 'none' => __( 'None', 'skylab' ),
		  ),
	   )
	);
	
	// Links Text Decoration Weight
    $wp_customize->add_setting( 'links_text_decoration_weight', array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'links_text_decoration_weight',
	   array(
		  'label' => __( 'Links Text Decoration Weight', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'select',
		  'choices' => array(
			 1 => __( 'Normal', 'skylab' ),
			 2 => __( 'Bold', 'skylab' ),
		  ),
	   )
	);
	
	// Links Font Style
    $wp_customize->add_setting( 'links_font_style', array(
		'default' => 'normal',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'links_font_style',
	   array(
		  'label' => __( 'Links Font Style', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'select',
		  'choices' => array(
			 'normal' => __( 'Normal', 'skylab' ),
			 'italic' => __( 'Italic', 'skylab' ),
		  ),
	   )
	);
	
	// Buttons Font
    $wp_customize->add_setting( 'buttons_font', array(
		'default' => 'primary',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'buttons_font',
	   array(
		  'label' => __( 'Buttons Font', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'select',
		  'choices' => array(
			 'primary' => __( 'Primary', 'skylab' ),
			 'secondary' => __( 'Secondary', 'skylab' ),
		  ),
	   )
	);
	
	// Buttons Font Size
    $wp_customize->add_setting( 'buttons_font_size', array(
		'default' => 10,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'buttons_font_size',
	   array(
		  'label' => __( 'Buttons Font Size', 'skylab' ),
		  'description' => __( 'Choose a value for buttons font size in pixels. Default value is 10.', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 8,
			 'max' => 32,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Buttons Text Transform
    $wp_customize->add_setting( 'buttons_text_transform', array(
		'default' => 'uppercase',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'buttons_text_transform',
	   array(
		  'label' => __( 'Buttons Text Transform', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'select',
		  'choices' => array(
			 'none' => __( 'None', 'skylab' ),
			 'uppercase' => __( 'Uppercase', 'skylab' ),
			 'lowercase' =>  __( 'Lowercase', 'skylab' ),
		  ),
	   )
	);
	
	// Buttons Font Weight
    $wp_customize->add_setting( 'buttons_font_weight', array(
		'default' => 400,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'buttons_font_weight',
	   array(
		  'label' => __( 'Buttons Font Weight', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'select',
		  'choices' => array(
			 100 => __( 'Thin 100', 'skylab' ),
			 200 => __( 'Extra Light 200', 'skylab' ),
			 300 => __( 'Light 300', 'skylab' ),
			 400 => __( 'Regular 400', 'skylab' ),
			 500 => __( 'Medium 500', 'skylab' ),
			 600 => __( 'Semi Bold 600', 'skylab' ),
			 700 => __( 'Bold 700', 'skylab' ),
			 800 => __( 'Extra Bold 800', 'skylab' ),
			 900 => __( 'Black 900', 'skylab' ),
		  ),
	   )
	);
	
	// Buttons Letter Spacing
    $wp_customize->add_setting( 'buttons_letter_spacing', array(
		'default' => 2,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'buttons_letter_spacing',
	   array(
		  'label' => __( 'Buttons Letter Spacing', 'skylab' ),
		  'description' => __( 'Choose a value for buttons letter spacing in pixels. Default value is 2.', 'skylab' ),
		  'section' => 'general_typography',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 0,
			 'max' => 20,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Site Title Typography Section
	$wp_customize->add_section( 'site_title_typography' , array(
		'title' => __( 'Site Title', 'skylab' ),
		'priority' => 10,
		'panel' => 'typography',
	) );
	
	// Site Title Font
    $wp_customize->add_setting( 'site_title_font', array(
		'default' => 'secondary',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'site_title_font',
	   array(
		  'label' => __( 'Site Title Font', 'skylab' ),
		  'section' => 'site_title_typography',
		  'type' => 'select',
		  'choices' => array(
			 'primary' => __( 'Primary', 'skylab' ),
			 'secondary' => __( 'Secondary', 'skylab' ),
			 'additional' => __( 'Additional', 'skylab' ),
		  ),
	   )
	);
	
	// Site Title Font Size
    $wp_customize->add_setting( 'site_title_font_size', array(
		'default' => 24,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'site_title_font_size',
	   array(
		  'label' => __( 'Site Title Font Size', 'skylab' ),
		  'description' => __( 'Enter a value for site title font size in pixels or depending of screen width in rem: 24 or 1rem. Default value is 24.', 'skylab' ),
		  'section' => 'site_title_typography',
		  'type' => 'text',
	   )
	);
	
	// Site Title Font Size for Header Height on Scrolling
    $wp_customize->add_setting( 'site_title_font_size_for_header_height_on_scrolling', array(
		'default' => 24,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'site_title_font_size_for_header_height_on_scrolling',
	   array(
		  'label' => __( 'Site Title Font Size for Header Height on Scrolling', 'skylab' ),
		  'description' => __( 'Enter a value for site title font size for header height on scrolling in pixels or depending of screen width in rem: 24 or 1rem. Default value is 24.', 'skylab' ),
		  'section' => 'site_title_typography',
		  'type' => 'text',
	   )
	);
	
	// Site Title Text Transform
    $wp_customize->add_setting( 'site_title_text_transform', array(
		'default' => 'none',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'site_title_text_transform',
	   array(
		  'label' => __( 'Site Title Text Transform', 'skylab' ),
		  'section' => 'site_title_typography',
		  'type' => 'select',
		  'choices' => array(
			 'none' => __( 'None', 'skylab' ),
			 'uppercase' => __( 'Uppercase', 'skylab' ),
			 'lowercase' =>  __( 'Lowercase', 'skylab' ),
		  ),
	   )
	);
	
	// Site Title Font Weight
    $wp_customize->add_setting( 'site_title_font_weight', array(
		'default' => 700,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'site_title_font_weight',
	   array(
		  'label' => __( 'Site Title Font Weight', 'skylab' ),
		  'section' => 'site_title_typography',
		  'type' => 'select',
		  'choices' => array(
			 100 => __( 'Thin 100', 'skylab' ),
			 200 => __( 'Extra Light 200', 'skylab' ),
			 300 => __( 'Light 300', 'skylab' ),
			 400 => __( 'Regular 400', 'skylab' ),
			 500 => __( 'Medium 500', 'skylab' ),
			 600 => __( 'Semi Bold 600', 'skylab' ),
			 700 => __( 'Bold 700', 'skylab' ),
			 800 => __( 'Extra Bold 800', 'skylab' ),
			 900 => __( 'Black 900', 'skylab' ),
		  ),
	   )
	);
	
	// Site Title Letter Spacing
    $wp_customize->add_setting( 'site_title_letter_spacing', array(
		'default' => 0,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'site_title_letter_spacing',
	   array(
		  'label' => __( 'Site Title Letter Spacing', 'skylab' ),
		  'description' => __( 'Enter a value for site title letter spacing in pixels or in em: 2 or 2em. Default value is 0.', 'skylab' ),
		  'section' => 'site_title_typography',
		  'type' => 'text',
	   )
	);
	
	// Site Title Font Style
    $wp_customize->add_setting( 'site_title_font_style', array(
		'default' => 'normal',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'site_title_font_style',
	   array(
		  'label' => __( 'Site Title Font Style', 'skylab' ),
		  'section' => 'site_title_typography',
		  'type' => 'select',
		  'choices' => array(
			 'normal' => __( 'Normal', 'skylab' ),
			 'italic' => __( 'Italic', 'skylab' ),
		  ),
	   )
	);
	
	// Tagline Typography Section
	$wp_customize->add_section( 'tagline_typography' , array(
		'title' => __( 'Tagline', 'skylab' ),
		'priority' => 10,
		'panel' => 'typography',
	) );
	
	// Tagline Font
    $wp_customize->add_setting( 'site_tagline_font', array(
		'default' => 'secondary',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'site_tagline_font',
	   array(
		  'label' => __( 'Tagline Font', 'skylab' ),
		  'section' => 'tagline_typography',
		  'type' => 'select',
		  'choices' => array(
			 'primary' => __( 'Primary', 'skylab' ),
			 'secondary' => __( 'Secondary', 'skylab' ),
		  ),
	   )
	);
	
	// Tagline Font Size
    $wp_customize->add_setting( 'tagline_font_size', array(
		'default' => 24,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'tagline_font_size',
	   array(
		  'label' => __( 'Tagline Font Size', 'skylab' ),
		  'description' => __( 'Enter a value for tagline font size in pixels or depending of screen width in rem: 24 or 1rem. Default value is 24.', 'skylab' ),
		  'section' => 'tagline_typography',
		  'type' => 'text',
	   )
	);
	
	// Tagline Font Size for Header Height on Scrolling
    $wp_customize->add_setting( 'tagline_font_size_for_header_height_on_scrolling', array(
		'default' => 24,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'tagline_font_size_for_header_height_on_scrolling',
	   array(
		  'label' => __( 'Tagline Font Size for Header Height on Scrolling', 'skylab' ),
		  'description' => __( 'Enter a value for tagline font size for header height on scrolling in pixels or depending of screen width in rem: 24 or 1rem. Default value is 24.', 'skylab' ),
		  'section' => 'tagline_typography',
		  'type' => 'text',
	   )
	);
	
	// Tagline Text Transform
    $wp_customize->add_setting( 'tagline_text_transform', array(
		'default' => 'none',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'tagline_text_transform',
	   array(
		  'label' => __( 'Tagline Text Transform', 'skylab' ),
		  'section' => 'tagline_typography',
		  'type' => 'select',
		  'choices' => array(
			 'none' => __( 'None', 'skylab' ),
			 'uppercase' => __( 'Uppercase', 'skylab' ),
			 'lowercase' =>  __( 'Lowercase', 'skylab' ),
		  ),
	   )
	);
	
	// Tagline Font Weight
    $wp_customize->add_setting( 'tagline_font_weight', array(
		'default' => 700,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'tagline_font_weight',
	   array(
		  'label' => __( 'Tagline Font Weight', 'skylab' ),
		  'section' => 'tagline_typography',
		  'type' => 'select',
		  'choices' => array(
			 100 => __( 'Thin 100', 'skylab' ),
			 200 => __( 'Extra Light 200', 'skylab' ),
			 300 => __( 'Light 300', 'skylab' ),
			 400 => __( 'Regular 400', 'skylab' ),
			 500 => __( 'Medium 500', 'skylab' ),
			 600 => __( 'Semi Bold 600', 'skylab' ),
			 700 => __( 'Bold 700', 'skylab' ),
			 800 => __( 'Extra Bold 800', 'skylab' ),
			 900 => __( 'Black 900', 'skylab' ),
		  ),
	   )
	);
	
	// Tagline Letter Spacing
    $wp_customize->add_setting( 'tagline_letter_spacing', array(
		'default' => 0,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'tagline_letter_spacing',
	   array(
		  'label' => __( 'Tagline Letter Spacing', 'skylab' ),
		  'description' => __( 'Choose a value for tagline letter spacing in pixels. Default value is 0.', 'skylab' ),
		  'section' => 'tagline_typography',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 0,
			 'max' => 20,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Tagline Font Style
    $wp_customize->add_setting( 'tagline_font_style', array(
		'default' => 'normal',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'tagline_font_style',
	   array(
		  'label' => __( 'Tagline Font Style', 'skylab' ),
		  'section' => 'tagline_typography',
		  'type' => 'select',
		  'choices' => array(
			 'normal' => __( 'Normal', 'skylab' ),
			 'italic' => __( 'Italic', 'skylab' ),
		  ),
	   )
	);
	
	// Primary Menu Typography Section
	$wp_customize->add_section( 'menu_typography' , array(
		'title' => __( 'Primary Menu', 'skylab' ),
		'priority' => 10,
		'panel' => 'typography',
	) );
	
	// Primary Menu Font
    $wp_customize->add_setting( 'menu_font', array(
		'default' => 'primary',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_font',
	   array(
		  'label' => __( 'Primary Menu Font', 'skylab' ),
		  'section' => 'menu_typography',
		  'type' => 'select',
		  'choices' => array(
			 'primary' => __( 'Primary', 'skylab' ),
			 'secondary' => __( 'Secondary', 'skylab' ),
		  ),
	   )
	);
	
	// Primary Menu Font Size
    $wp_customize->add_setting( 'menu_font_size', array(
		'default' => 16,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_font_size',
	   array(
		  'label' => __( 'Primary Menu Font Size', 'skylab' ),
		  'description' => __( 'Enter a value for menu font size in pixels or depending of screen width in rem: 16 or 1rem. Default value is 16.', 'skylab' ),
		  'section' => 'menu_typography',
		  'type' => 'text',
	   )
	);
	
	// Primary Menu Text Transform
    $wp_customize->add_setting( 'menu_text_transform', array(
		'default' => 'none',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_text_transform',
	   array(
		  'label' => __( 'Primary Menu Text Transform', 'skylab' ),
		  'section' => 'menu_typography',
		  'type' => 'select',
		  'choices' => array(
			 'none' => __( 'None', 'skylab' ),
			 'uppercase' => __( 'Uppercase', 'skylab' ),
			 'lowercase' =>  __( 'Lowercase', 'skylab' ),
		  ),
	   )
	);
	
	// Primary Menu Font Weight
    $wp_customize->add_setting( 'menu_font_weight', array(
		'default' => 400,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_font_weight',
	   array(
		  'label' => __( 'Primary Menu Font Weight', 'skylab' ),
		  'section' => 'menu_typography',
		  'type' => 'select',
		  'choices' => array(
			 100 => __( 'Thin 100', 'skylab' ),
			 200 => __( 'Extra Light 200', 'skylab' ),
			 300 => __( 'Light 300', 'skylab' ),
			 400 => __( 'Regular 400', 'skylab' ),
			 500 => __( 'Medium 500', 'skylab' ),
			 600 => __( 'Semi Bold 600', 'skylab' ),
			 700 => __( 'Bold 700', 'skylab' ),
			 800 => __( 'Extra Bold 800', 'skylab' ),
			 900 => __( 'Black 900', 'skylab' ),
		  ),
	   )
	);
	
	// Primary Menu Letter Spacing
    $wp_customize->add_setting( 'menu_letter_spacing', array(
		'default' => 0,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_letter_spacing',
	   array(
		  'label' => __( 'Primary Menu Letter Spacing', 'skylab' ),
		  'description' => __( 'Choose a value for menu letter spacing in pixels. Default value is 0.', 'skylab' ),
		  'section' => 'menu_typography',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 0,
			 'max' => 20,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Primary Menu Font Style
    $wp_customize->add_setting( 'menu_font_style', array(
		'default' => 'normal',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_font_style',
	   array(
		  'label' => __( 'Primary Menu Font Style', 'skylab' ),
		  'section' => 'menu_typography',
		  'type' => 'select',
		  'choices' => array(
			 'normal' => __( 'Normal', 'skylab' ),
			 'italic' => __( 'Italic', 'skylab' ),
		  ),
	   )
	);
	
	// Primary Menu Text Decoration - Hover/Active
    $wp_customize->add_setting( 'menu_text_decoration_hover', array(
		'default' => 'underline',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_text_decoration_hover',
	   array(
		  'label' => __( 'Primary Menu Text Decoration - Hover/Active', 'skylab' ),
		  'section' => 'menu_typography',
		  'type' => 'select',
		  'choices' => array(
			 'underline' => __( 'Underline', 'skylab' ),
			 'overline' => __( 'Overline', 'skylab' ),
			 'line_through' => __( 'Line-through', 'skylab' ),
			 'underline_overline' => __( 'Underline overline', 'skylab' ),
			 'none' => __( 'None', 'skylab' ),
		  ),
	   )
	);
	
	// Secondary Menu Typography Section
	$wp_customize->add_section( 'menu_secondary_typography' , array(
		'title' => __( 'Secondary Menu', 'skylab' ),
		'priority' => 10,
		'panel' => 'typography',
	) );
	
	// Secondary Menu Font
    $wp_customize->add_setting( 'menu_secondary_font', array(
		'default' => 'primary',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_secondary_font',
	   array(
		  'label' => __( 'Secondary Menu Font', 'skylab' ),
		  'section' => 'menu_secondary_typography',
		  'type' => 'select',
		  'choices' => array(
			 'primary' => __( 'Primary', 'skylab' ),
			 'secondary' => __( 'Secondary', 'skylab' ),
		  ),
	   )
	);
	
	// Secondary Menu Font Size
    $wp_customize->add_setting( 'menu_secondary_font_size', array(
		'default' => 16,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_secondary_font_size',
	   array(
		  'label' => __( 'Secondary Menu Font Size', 'skylab' ),
		  'description' => __( 'Enter a value for menu_secondary font size in pixels or depending of screen width in rem: 16 or 1rem. Default value is 16.', 'skylab' ),
		  'section' => 'menu_secondary_typography',
		  'type' => 'text',
	   )
	);
	
	// Secondary Menu Text Transform
    $wp_customize->add_setting( 'menu_secondary_text_transform', array(
		'default' => 'none',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_secondary_text_transform',
	   array(
		  'label' => __( 'Secondary Menu Text Transform', 'skylab' ),
		  'section' => 'menu_secondary_typography',
		  'type' => 'select',
		  'choices' => array(
			 'none' => __( 'None', 'skylab' ),
			 'uppercase' => __( 'Uppercase', 'skylab' ),
			 'lowercase' =>  __( 'Lowercase', 'skylab' ),
		  ),
	   )
	);
	
	// Secondary Menu Font Weight
    $wp_customize->add_setting( 'menu_secondary_font_weight', array(
		'default' => 400,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_secondary_font_weight',
	   array(
		  'label' => __( 'Secondary Menu Font Weight', 'skylab' ),
		  'section' => 'menu_secondary_typography',
		  'type' => 'select',
		  'choices' => array(
			 100 => __( 'Thin 100', 'skylab' ),
			 200 => __( 'Extra Light 200', 'skylab' ),
			 300 => __( 'Light 300', 'skylab' ),
			 400 => __( 'Regular 400', 'skylab' ),
			 500 => __( 'Medium 500', 'skylab' ),
			 600 => __( 'Semi Bold 600', 'skylab' ),
			 700 => __( 'Bold 700', 'skylab' ),
			 800 => __( 'Extra Bold 800', 'skylab' ),
			 900 => __( 'Black 900', 'skylab' ),
		  ),
	   )
	);
	
	// Secondary Menu Letter Spacing
    $wp_customize->add_setting( 'menu_secondary_letter_spacing', array(
		'default' => 0,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_secondary_letter_spacing',
	   array(
		  'label' => __( 'Secondary Menu Letter Spacing', 'skylab' ),
		  'description' => __( 'Choose a value for menu_secondary letter spacing in pixels. Default value is 0.', 'skylab' ),
		  'section' => 'menu_secondary_typography',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 0,
			 'max' => 20,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Secondary Menu Font Style
    $wp_customize->add_setting( 'menu_secondary_font_style', array(
		'default' => 'normal',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_secondary_font_style',
	   array(
		  'label' => __( 'Secondary Menu Font Style', 'skylab' ),
		  'section' => 'menu_secondary_typography',
		  'type' => 'select',
		  'choices' => array(
			 'normal' => __( 'Normal', 'skylab' ),
			 'italic' => __( 'Italic', 'skylab' ),
		  ),
	   )
	);
	
	// Secondary Menu Text Decoration - Hover/Active
    $wp_customize->add_setting( 'menu_secondary_text_decoration_hover', array(
		'default' => 'underline',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_secondary_text_decoration_hover',
	   array(
		  'label' => __( 'Secondary Menu Text Decoration - Hover/Active', 'skylab' ),
		  'section' => 'menu_secondary_typography',
		  'type' => 'select',
		  'choices' => array(
			 'underline' => __( 'Underline', 'skylab' ),
			 'none' => __( 'None', 'skylab' ),
		  ),
	   )
	);
	
	// Sliding Menu Typography Section
	$wp_customize->add_section( 'menu_sliding_typography' , array(
		'title' => __( 'Sliding Menu', 'skylab' ),
		'priority' => 10,
		'panel' => 'typography',
	) );
	
	// Sliding Menu Font
    $wp_customize->add_setting( 'menu_sliding_font', array(
		'default' => 'primary',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_sliding_font',
	   array(
		  'label' => __( 'Sliding Menu Font', 'skylab' ),
		  'section' => 'menu_sliding_typography',
		  'type' => 'select',
		  'choices' => array(
			 'primary' => __( 'Primary', 'skylab' ),
			 'secondary' => __( 'Secondary', 'skylab' ),
		  ),
	   )
	);
	
	// Sliding Menu Font Size
    $wp_customize->add_setting( 'menu_sliding_font_size', array(
		'default' => 16,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_sliding_font_size',
	   array(
		  'label' => __( 'Sliding Menu Font Size', 'skylab' ),
		  'description' => __( 'Enter a value for menu sliding font size in pixels or depending of screen width in rem: 16 or 1rem. Default value is 16.', 'skylab' ),
		  'section' => 'menu_sliding_typography',
		  'type' => 'text',
	   )
	);
	
	// Sliding Menu Text Transform
    $wp_customize->add_setting( 'menu_sliding_text_transform', array(
		'default' => 'none',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_sliding_text_transform',
	   array(
		  'label' => __( 'Sliding Menu Text Transform', 'skylab' ),
		  'section' => 'menu_sliding_typography',
		  'type' => 'select',
		  'choices' => array(
			 'none' => __( 'None', 'skylab' ),
			 'uppercase' => __( 'Uppercase', 'skylab' ),
			 'lowercase' =>  __( 'Lowercase', 'skylab' ),
		  ),
	   )
	);
	
	// Sliding Menu Font Weight
    $wp_customize->add_setting( 'menu_sliding_font_weight', array(
		'default' => 400,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_sliding_font_weight',
	   array(
		  'label' => __( 'Sliding Menu Font Weight', 'skylab' ),
		  'section' => 'menu_sliding_typography',
		  'type' => 'select',
		  'choices' => array(
			 100 => __( 'Thin 100', 'skylab' ),
			 200 => __( 'Extra Light 200', 'skylab' ),
			 300 => __( 'Light 300', 'skylab' ),
			 400 => __( 'Regular 400', 'skylab' ),
			 500 => __( 'Medium 500', 'skylab' ),
			 600 => __( 'Semi Bold 600', 'skylab' ),
			 700 => __( 'Bold 700', 'skylab' ),
			 800 => __( 'Extra Bold 800', 'skylab' ),
			 900 => __( 'Black 900', 'skylab' ),
		  ),
	   )
	);
	
	// Sliding Menu Letter Spacing
    $wp_customize->add_setting( 'menu_sliding_letter_spacing', array(
		'default' => 0,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_sliding_letter_spacing',
	   array(
		  'label' => __( 'Sliding Menu Letter Spacing', 'skylab' ),
		  'description' => __( 'Choose a value for menu_sliding letter spacing in pixels. Default value is 0.', 'skylab' ),
		  'section' => 'menu_sliding_typography',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 0,
			 'max' => 20,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Sliding Menu Font Style
    $wp_customize->add_setting( 'menu_sliding_font_style', array(
		'default' => 'normal',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_sliding_font_style',
	   array(
		  'label' => __( 'Sliding Menu Font Style', 'skylab' ),
		  'section' => 'menu_sliding_typography',
		  'type' => 'select',
		  'choices' => array(
			 'normal' => __( 'Normal', 'skylab' ),
			 'italic' => __( 'Italic', 'skylab' ),
		  ),
	   )
	);
	
	// Sliding Menu Text Decoration - Hover/Active
    $wp_customize->add_setting( 'menu_sliding_text_decoration_hover', array(
		'default' => 'underline',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_sliding_text_decoration_hover',
	   array(
		  'label' => __( 'Sliding Menu Text Decoration - Hover/Active', 'skylab' ),
		  'section' => 'menu_sliding_typography',
		  'type' => 'select',
		  'choices' => array(
			 'underline' => __( 'Underline', 'skylab' ),
			 'none' => __( 'None', 'skylab' ),
		  ),
	   )
	);
	
	// Top Bar Menu Typography Section
	$wp_customize->add_section( 'menu_top_bar_typography' , array(
		'title' => __( 'Top Bar Menu', 'skylab' ),
		'priority' => 10,
		'panel' => 'typography',
	) );
	
	// Top Bar Menu Font
    $wp_customize->add_setting( 'menu_top_bar_font', array(
		'default' => 'primary',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_top_bar_font',
	   array(
		  'label' => __( 'Top Bar Menu Font', 'skylab' ),
		  'section' => 'menu_top_bar_typography',
		  'type' => 'select',
		  'choices' => array(
			 'primary' => __( 'Primary', 'skylab' ),
			 'secondary' => __( 'Secondary', 'skylab' ),
		  ),
	   )
	);
	
	// Top Bar Menu Font Size
    $wp_customize->add_setting( 'menu_top_bar_font_size', array(
		'default' => 16,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_top_bar_font_size',
	   array(
		  'label' => __( 'Top Bar Menu Font Size', 'skylab' ),
		  'description' => __( 'Choose a value for menu_top_bar font size in pixels. Default value is 16.', 'skylab' ),
		  'section' => 'menu_top_bar_typography',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 10,
			 'max' => 36,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Top Bar Menu Text Transform
    $wp_customize->add_setting( 'menu_top_bar_text_transform', array(
		'default' => 'none',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_top_bar_text_transform',
	   array(
		  'label' => __( 'Top Bar Menu Text Transform', 'skylab' ),
		  'section' => 'menu_top_bar_typography',
		  'type' => 'select',
		  'choices' => array(
			 'none' => __( 'None', 'skylab' ),
			 'uppercase' => __( 'Uppercase', 'skylab' ),
			 'lowercase' =>  __( 'Lowercase', 'skylab' ),
		  ),
	   )
	);
	
	// Top Bar Menu Font Weight
    $wp_customize->add_setting( 'menu_top_bar_font_weight', array(
		'default' => 400,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_top_bar_font_weight',
	   array(
		  'label' => __( 'Top Bar Menu Font Weight', 'skylab' ),
		  'section' => 'menu_top_bar_typography',
		  'type' => 'select',
		  'choices' => array(
			 100 => __( 'Thin 100', 'skylab' ),
			 200 => __( 'Extra Light 200', 'skylab' ),
			 300 => __( 'Light 300', 'skylab' ),
			 400 => __( 'Regular 400', 'skylab' ),
			 500 => __( 'Medium 500', 'skylab' ),
			 600 => __( 'Semi Bold 600', 'skylab' ),
			 700 => __( 'Bold 700', 'skylab' ),
			 800 => __( 'Extra Bold 800', 'skylab' ),
			 900 => __( 'Black 900', 'skylab' ),
		  ),
	   )
	);
	
	// Top Bar Menu Letter Spacing
    $wp_customize->add_setting( 'menu_top_bar_letter_spacing', array(
		'default' => 0,
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_top_bar_letter_spacing',
	   array(
		  'label' => __( 'Top Bar Menu Letter Spacing', 'skylab' ),
		  'description' => __( 'Choose a value for menu_top_bar letter spacing in pixels. Default value is 0.', 'skylab' ),
		  'section' => 'menu_top_bar_typography',
		  'type' => 'number',
		  'input_attrs' => array(
			 'min' => 0,
			 'max' => 20,
			 'style' => 'width: 65px',
		  ),
	   )
	);
	
	// Top Bar Menu Font Style
    $wp_customize->add_setting( 'menu_top_bar_font_style', array(
		'default' => 'normal',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_top_bar_font_style',
	   array(
		  'label' => __( 'Top Bar Menu Font Style', 'skylab' ),
		  'section' => 'menu_top_bar_typography',
		  'type' => 'select',
		  'choices' => array(
			 'normal' => __( 'Normal', 'skylab' ),
			 'italic' => __( 'Italic', 'skylab' ),
		  ),
	   )
	);
	
	// Top Bar Menu Text Decoration - Hover/Active
    $wp_customize->add_setting( 'menu_top_bar_text_decoration_hover', array(
		'default' => 'underline',
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'menu_top_bar_text_decoration_hover',
	   array(
		  'label' => __( 'Top Bar Menu Text Decoration - Hover/Active', 'skylab' ),
		  'section' => 'menu_top_bar_typography',
		  'type' => 'select',
		  'choices' => array(
			 'underline' => __( 'Underline', 'skylab' ),
			 'none' => __( 'None', 'skylab' ),
		  ),
	   )
	);
	
	// Colors Panel
	$wp_customize->add_panel( 'colors', array(
		'title' => __( 'Colors', 'skylab' ),
		'priority' => 11,
	) );
	
	// General Colors Section
	$wp_customize->add_section( 'general_colors' , array(
		'title' => __( 'General', 'skylab' ),
		'priority' => 10,
		'panel' => 'colors',
	) );
	
	// Accent Color
    $wp_customize->add_setting( 'accent_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'accent_color', array(
		'label' => __( 'Accent Color', 'skylab' ),
		'description' => __( 'Choose an accent color for your site. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Body Color
    $wp_customize->add_setting( 'body_color', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'body_color', array(
		'label' => __( 'Body Color', 'skylab' ),
		'description' => __( 'Choose a body color for your site. Default value is #ffffff.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Primary Color
    $wp_customize->add_setting( 'primary_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_color', array(
		'label' => __( 'Primary Color', 'skylab' ),
		'description' => __( 'Choose a primary color for your site. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Secondary Color
    $wp_customize->add_setting( 'secondary_color', array(
		'default' => '#999999',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_color', array(
		'label' => __( 'Secondary Color', 'skylab' ),
		'description' => __( 'Choose a secondary color for your site. Default value is #999999.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Third Color
    $wp_customize->add_setting( 'third_color', array(
		'default' => '#f2f2f2',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'third_color', array(
		'label' => __( 'Third Color', 'skylab' ),
		'description' => __( 'Choose a third color for your site. Default value is #f2f2f2.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Borders Color
    $wp_customize->add_setting( 'borders_color', array(
		'default' => '#e6e6e6',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'borders_color', array(
		'label' => __( 'Borders Color', 'skylab' ),
		'description' => __( 'Choose a borders color for your site. Default value is #e6e6e6.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Links Color
    $wp_customize->add_setting( 'links_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'links_color', array(
		'label' => __( 'Links Color', 'skylab' ),
		'description' => __( 'Choose a links color for your site. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Links Color - Hover
    $wp_customize->add_setting( 'links_color_hover', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'links_color_hover', array(
		'label' => __( 'Links Color - Hover', 'skylab' ),
		'description' => __( 'Choose a links color - hover for your site. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Links Color - Active
    $wp_customize->add_setting( 'links_color_active', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'links_color_active', array(
		'label' => __( 'Links Color - Active', 'skylab' ),
		'description' => __( 'Choose a links color - active for your site. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Enable Links Color on Underline Only
	$wp_customize->add_setting( 'enable_links_color_on_underline_only', array(
		'transport' => 'refresh',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( 'enable_links_color_on_underline_only', array(
		'label' => __( 'Enable Links Color on Underline Only', 'skylab' ),
		'section' => 'general_colors',
		'type' => 'checkbox',
	) );
	
	// Page Load Progress Bar Color
    $wp_customize->add_setting( 'page_load_progress_bar_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'page_load_progress_bar_color', array(
		'label' => __( 'Page Load Progress Bar Color', 'skylab' ),
		'description' => __( 'Choose a page load progress bar color for your site. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Page Load Progress Indicator Color
    $wp_customize->add_setting( 'page_load_progress_indicator_color', array(
		'default' => '#999999',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'page_load_progress_indicator_color', array(
		'label' => __( 'Page Load Progress Indicator Color', 'skylab' ),
		'description' => __( 'Choose a page load progress indicator color for your site. Default value is #999999.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Page Load Overlay Background Color
    $wp_customize->add_setting( 'page_load_overlay_background_color', array(
		'default' => '#f2f2f2',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'page_load_overlay_background_color', array(
		'label' => __( 'Page Load Overlay Background Color', 'skylab' ),
		'description' => __( 'Choose a page load overlay background color for your site. Default value is #f2f2f2.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Buttons Background Color
    $wp_customize->add_setting( 'buttons_background_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'buttons_background_color', array(
		'label' => __( 'Buttons Background Color', 'skylab' ),
		'description' => __( 'Choose a value for buttons background color. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Buttons Background Color - Hover
    $wp_customize->add_setting( 'buttons_background_color_hover', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'buttons_background_color_hover', array(
		'label' => __( 'Buttons Background Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for buttons background color - hover. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Buttons Background Color - Active
    $wp_customize->add_setting( 'buttons_background_color_active', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'buttons_background_color_active', array(
		'label' => __( 'Buttons Background Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for buttons background color - active. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Buttons Text Color
    $wp_customize->add_setting( 'buttons_text_color', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'buttons_text_color', array(
		'label' => __( 'Buttons Text Color', 'skylab' ),
		'description' => __( 'Choose a value for buttons text color. Default value is #ffffff.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Buttons Text Color - Hover
    $wp_customize->add_setting( 'buttons_text_color_hover', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'buttons_text_color_hover', array(
		'label' => __( 'Buttons Text Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for buttons text color - hover. Default value is #ffffff.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Buttons Text Color - Active
    $wp_customize->add_setting( 'buttons_text_color_active', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'buttons_text_color_active', array(
		'label' => __( 'Buttons Text Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for buttons text color - active. Default value is #ffffff.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Inputs Placeholders Color
    $wp_customize->add_setting( 'inputs_placeholders_color', array(
		'default' => '#999999',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'inputs_placeholders_color', array(
		'label' => __( 'Inputs Placeholders Color', 'skylab' ),
		'description' => __( 'Choose a value for inputs placeholders color. Default value is #999999.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Inputs Borders Color
    $wp_customize->add_setting( 'inputs_borders_color', array(
		'default' => '#e6e6e6',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new Mega_Customize_Alpha_Color_Control( $wp_customize, 'inputs_borders_color', array(
		'label' => __( 'Inputs Borders Color', 'skylab' ),
		'description' => __( 'Choose a value for inputs borders color. Default value is #e6e6e6.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Inputs Borders Color - Hover
    $wp_customize->add_setting( 'inputs_borders_color_hover', array(
		'default' => '#999999',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new Mega_Customize_Alpha_Color_Control( $wp_customize, 'inputs_borders_color_hover', array(
		'label' => __( 'Inputs Borders Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for inputs borders color - hover. Default value is #999999.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Inputs Borders Color - Focus
    $wp_customize->add_setting( 'inputs_borders_color_focus', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new Mega_Customize_Alpha_Color_Control( $wp_customize, 'inputs_borders_color_focus', array(
		'label' => __( 'Inputs Borders Color - Focus', 'skylab' ),
		'description' => __( 'Choose a value for inputs borders color - focus. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// General Arrows Icons Color
    $wp_customize->add_setting( 'general_arrows_icons_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'general_arrows_icons_color', array(
		'label' => __( 'General Arrows Icons Color', 'skylab' ),
		'description' => __( 'Choose a value for general arrows icons color. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// General Arrows Icons Color - Hover
    $wp_customize->add_setting( 'general_arrows_icons_color_hover', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'general_arrows_icons_color_hover', array(
		'label' => __( 'General Arrows Icons Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for general arrows icons color - hover. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// General Arrows Icons Color - Active
    $wp_customize->add_setting( 'general_arrows_icons_color_active', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'general_arrows_icons_color_active', array(
		'label' => __( 'General Arrows Icons Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for general arrows icons color - active. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// General Arrows Background Color
    $wp_customize->add_setting( 'general_arrows_background_color', array(
		'default' => '#f2f2f2',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new Mega_Customize_Alpha_Color_Control( $wp_customize, 'general_arrows_background_color', array(
		'label' => __( 'General Arrows Background Color', 'skylab' ),
		'description' => __( 'Choose a value for general arrows background color. Default value is #f2f2f2.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// General Arrows Background Color - Hover
    $wp_customize->add_setting( 'general_arrows_background_color_hover', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new Mega_Customize_Alpha_Color_Control( $wp_customize, 'general_arrows_background_color_hover', array(
		'label' => __( 'General Arrows Background Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for general arrows background color - hover. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// General Arrows Background Color - Active
    $wp_customize->add_setting( 'general_arrows_background_color_active', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new Mega_Customize_Alpha_Color_Control( $wp_customize, 'general_arrows_background_color_active', array(
		'label' => __( 'General Arrows Background Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for general arrows background color - active. Default value is #000000.', 'skylab' ),
		'section' => 'general_colors',
	) ) );
	
	// Header Colors Section
	$wp_customize->add_section( 'header_colors' , array(
		'title' => __( 'Header', 'skylab' ),
		'priority' => 10,
		'panel' => 'colors',
	) );
	
	// Header Background Color
    $wp_customize->add_setting( 'header_background_color', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_background_color', array(
		'label' => __( 'Header Background Color', 'skylab' ),
		'description' => __( 'Choose a value for header background color. Default value is #ffffff.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Site Title Color
    $wp_customize->add_setting( 'site_title_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'site_title_color', array(
		'label' => __( 'Site Title Color', 'skylab' ),
		'description' => __( 'Choose a value for site title color. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Site Title Color - Hover
    $wp_customize->add_setting( 'site_title_color_hover', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'site_title_color_hover', array(
		'label' => __( 'Site Title Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for site title color - hover. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Site Title Color - Active
    $wp_customize->add_setting( 'site_title_color_active', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'site_title_color_active', array(
		'label' => __( 'Site Title Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for site title color - active. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Site Tagline Color
    $wp_customize->add_setting( 'site_tagline_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'site_tagline_color', array(
		'label' => __( 'Site Tagline Color', 'skylab' ),
		'description' => __( 'Choose a value for site tagline color. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Primary Menu Link Color
    $wp_customize->add_setting( 'primary_menu_link_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_menu_link_color', array(
		'label' => __( 'Primary Menu Link Color', 'skylab' ),
		'description' => __( 'Choose a value for primary menu link color. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Primary Menu Link Color - Hover
    $wp_customize->add_setting( 'primary_menu_link_color_hover', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_menu_link_color_hover', array(
		'label' => __( 'Primary Menu Link Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for primary menu link color - hover/active. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Primary Menu Link Color - Active
    $wp_customize->add_setting( 'primary_menu_link_color_active', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_menu_link_color_active', array(
		'label' => __( 'Primary Menu Link Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for primary menu link color - active. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Header Text Color
    $wp_customize->add_setting( 'header_text_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_text_color', array(
		'label' => __( 'Header Text Color', 'skylab' ),
		'description' => __( 'Choose a value for header text color. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Header Link Color
    $wp_customize->add_setting( 'header_link_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_link_color', array(
		'label' => __( 'Header Link Color', 'skylab' ),
		'description' => __( 'Choose a value for header link color. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Header Link Color - Hover
    $wp_customize->add_setting( 'header_link_color_hover', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_link_color_hover', array(
		'label' => __( 'Header Link Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for header link color - hover. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Header Link Color - Active
    $wp_customize->add_setting( 'header_link_color_active', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_link_color_active', array(
		'label' => __( 'Header Link Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for header link color - active. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Header Social Links Color
    $wp_customize->add_setting( 'header_social_links_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_social_links_color', array(
		'label' => __( 'Header Social Links Color', 'skylab' ),
		'description' => __( 'Choose a value for header social links color. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Header Social Links Color - Hover
    $wp_customize->add_setting( 'header_social_links_color_hover', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_social_links_color_hover', array(
		'label' => __( 'Header Social Links Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for header social links color - hover. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Header Social Links Color - Active
    $wp_customize->add_setting( 'header_social_links_color_active', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_social_links_color_active', array(
		'label' => __( 'Header Social Links Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for header social links color - active. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Header Top Border Color
    $wp_customize->add_setting( 'header_top_border_color', array(
		'default' => '#e6e6e6',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_top_border_color', array(
		'label' => __( 'Header Top Border Color', 'skylab' ),
		'description' => __( 'Choose a value for header top border color. Default value is #e6e6e6.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Header Bottom Border Color
    $wp_customize->add_setting( 'header_bottom_border_color', array(
		'default' => '#e6e6e6',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_bottom_border_color', array(
		'label' => __( 'Header Bottom Border Color', 'skylab' ),
		'description' => __( 'Choose a value for header bottom border color. Default value is #e6e6e6.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Secondary Menu Link Color
    $wp_customize->add_setting( 'secondary_menu_link_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_menu_link_color', array(
		'label' => __( 'Secondary Menu Link Color', 'skylab' ),
		'description' => __( 'Choose a value for secondary menu link color. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Secondary Menu Link Color - Hover
    $wp_customize->add_setting( 'secondary_menu_link_color_hover', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_menu_link_color_hover', array(
		'label' => __( 'Secondary Menu Link Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for secondary menu link color - hover. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Secondary Menu Link Color - Active
    $wp_customize->add_setting( 'secondary_menu_link_color_active', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_menu_link_color_active', array(
		'label' => __( 'Secondary Menu Link Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for secondary menu link color - active. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Sliding Menu Link Color
    $wp_customize->add_setting( 'sliding_menu_link_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sliding_menu_link_color', array(
		'label' => __( 'Sliding Menu Link Color', 'skylab' ),
		'description' => __( 'Choose a value for sliding menu link color. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Sliding Menu Link Color - Hover
    $wp_customize->add_setting( 'sliding_menu_link_color_hover', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sliding_menu_link_color_hover', array(
		'label' => __( 'Sliding Menu Link Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for sliding menu link color - hover. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Sliding Menu Link Color - Active
    $wp_customize->add_setting( 'sliding_menu_link_color_active', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sliding_menu_link_color_active', array(
		'label' => __( 'Sliding Menu Link Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for sliding menu link color - active. Default value is #000000.', 'skylab' ),
		'section' => 'header_colors',
	) ) );
	
	// Top Bar Colors Section
	$wp_customize->add_section( 'top_bar_colors' , array(
		'title' => __( 'Top Bar', 'skylab' ),
		'priority' => 10,
		'panel' => 'colors',
	) );
	
	// Top Bar Background Color
    $wp_customize->add_setting( 'top_bar_background_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_background_color', array(
		'label' => __( 'Top Bar Background Color', 'skylab' ),
		'description' => __( 'Choose a value for top bar background color. Default value is #000000.', 'skylab' ),
		'section' => 'top_bar_colors',
	) ) );
	
	// Top Bar Menu Link Color
    $wp_customize->add_setting( 'top_bar_menu_link_color', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_menu_link_color', array(
		'label' => __( 'Top Bar Menu Link Color', 'skylab' ),
		'description' => __( 'Choose a value for top bar menu link color. Default value is #ffffff.', 'skylab' ),
		'section' => 'top_bar_colors',
	) ) );
	
	/* Top Bar Menu Link Color - Hover */
    $wp_customize->add_setting( 'top_bar_menu_link_color_hover', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_menu_link_color_hover', array(
		'label' => __( 'Top Bar Menu Link Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for top bar menu link color - hover. Default value is #ffffff.', 'skylab' ),
		'section' => 'top_bar_colors',
	) ) );
	
	/* Top Bar Menu Link Color - Active */
    $wp_customize->add_setting( 'top_bar_menu_link_color_active', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_menu_link_color_active', array(
		'label' => __( 'Top Bar Menu Link Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for top bar menu link color - active. Default value is #ffffff.', 'skylab' ),
		'section' => 'top_bar_colors',
	) ) );
	
	/* Top Bar Text Color */
    $wp_customize->add_setting( 'top_bar_text_color', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_text_color', array(
		'label' => __( 'Top Bar Text Color', 'skylab' ),
		'description' => __( 'Choose a value for top bar text color. Default value is #ffffff.', 'skylab' ),
		'section' => 'top_bar_colors',
	) ) );
	
	/* Top Bar Link Color */
    $wp_customize->add_setting( 'top_bar_link_color', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_link_color', array(
		'label' => __( 'Top Bar Link Color', 'skylab' ),
		'description' => __( 'Choose a value for top bar link color. Default value is #ffffff.', 'skylab' ),
		'section' => 'top_bar_colors',
	) ) );
	
	/* Top Bar Link Color - Hover */
    $wp_customize->add_setting( 'top_bar_link_color_hover', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_link_color_hover', array(
		'label' => __( 'Top Bar Link Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for top bar link color - hover. Default value is #ffffff.', 'skylab' ),
		'section' => 'top_bar_colors',
	) ) );
	
	/* Top Bar Link Color - Active */
    $wp_customize->add_setting( 'top_bar_link_color_active', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_link_color_active', array(
		'label' => __( 'Top Bar Link Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for top bar link color - active. Default value is #ffffff.', 'skylab' ),
		'section' => 'top_bar_colors',
	) ) );
	
	/* Top Bar Social Links Color */
    $wp_customize->add_setting( 'top_bar_social_links_color', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_social_links_color', array(
		'label' => __( 'Top Bar Social Links Color', 'skylab' ),
		'description' => __( 'Choose a value for top bar social links color. Default value is #ffffff.', 'skylab' ),
		'section' => 'top_bar_colors',
	) ) );
	
	/* Top Bar Social Links Color - Hover */
    $wp_customize->add_setting( 'top_bar_social_links_color_hover', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_social_links_color_hover', array(
		'label' => __( 'Top Bar Social Links Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for top bar social links color - hover. Default value is #ffffff.', 'skylab' ),
		'section' => 'top_bar_colors',
	) ) );
	
	/* Top Bar Social Links Color - Active */
    $wp_customize->add_setting( 'top_bar_social_links_color_active', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_social_links_color_active', array(
		'label' => __( 'Top Bar Social Links Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for top bar social links color - active. Default value is #ffffff.', 'skylab' ),
		'section' => 'top_bar_colors',
	) ) );
	
	// Top Bar Bottom Border Color
    $wp_customize->add_setting( 'top_bar_bottom_border_color', array(
		'default' => '#e6e6e6',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_bar_bottom_border_color', array(
		'label' => __( 'Top Bar Bottom Border Color', 'skylab' ),
		'description' => __( 'Choose a value for top bar bottom border color. Default value is #e6e6e6.', 'skylab' ),
		'section' => 'top_bar_colors',
	) ) );
	
	// Footer Colors Section
	$wp_customize->add_section( 'footer_colors' , array(
		'title' => __( 'Footer', 'skylab' ),
		'priority' => 10,
		'panel' => 'colors',
	) );
	
	// Footer Background Color
    $wp_customize->add_setting( 'footer_background_color', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_background_color', array(
		'label' => __( 'Footer Background Color', 'skylab' ),
		'description' => __( 'Choose a value for footer background color. Default value is #ffffff.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Widget Title Color
    $wp_customize->add_setting( 'footer_widget_title_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_widget_title_color', array(
		'label' => __( 'Footer Widget Title Color', 'skylab' ),
		'description' => __( 'Choose a value for footer widget title color. Default value is #000000.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Text Color
    $wp_customize->add_setting( 'footer_text_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_text_color', array(
		'label' => __( 'Footer Text Color', 'skylab' ),
		'description' => __( 'Choose a value for footer text color. Default value is #000000.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Link Color
    $wp_customize->add_setting( 'footer_link_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_link_color', array(
		'label' => __( 'Footer Link Color', 'skylab' ),
		'description' => __( 'Choose a value for footer link color. Default value is #000000.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Link Color - Hover
    $wp_customize->add_setting( 'footer_link_color_hover', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_link_color_hover', array(
		'label' => __( 'Footer Link Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for footer link color - hover. Default value is #000000.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Link Color - Active
    $wp_customize->add_setting( 'footer_link_color_active', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_link_color_active', array(
		'label' => __( 'Footer Link Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for footer link color - active. Default value is #000000.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Bottom Area Background Color
    $wp_customize->add_setting( 'footer_bottom_area_background_color', array(
		'default' => '#ffffff',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_bottom_area_background_color', array(
		'label' => __( 'Footer Bottom Area Background Color', 'skylab' ),
		'description' => __( 'Choose a value for footer bottom area background color. Default value is #ffffff.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Bottom Area Text Color
    $wp_customize->add_setting( 'footer_bottom_area_text_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_bottom_area_text_color', array(
		'label' => __( 'Footer Bottom Area Text Color', 'skylab' ),
		'description' => __( 'Choose a value for footer bottom area text color. Default value is #000000.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Bottom Area Link Color
    $wp_customize->add_setting( 'footer_bottom_area_link_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_bottom_area_link_color', array(
		'label' => __( 'Footer Bottom Area Link Color', 'skylab' ),
		'description' => __( 'Choose a value for footer bottom area link color. Default value is #000000.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Bottom Area Link Color - Hover
    $wp_customize->add_setting( 'footer_bottom_area_link_color_hover', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_bottom_area_link_color_hover', array(
		'label' => __( 'Footer Bottom Area Link Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for footer bottom area link color - hover. Default value is #000000.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Bottom Area Link Color - Active
    $wp_customize->add_setting( 'footer_bottom_area_link_color_active', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_bottom_area_link_color_active', array(
		'label' => __( 'Footer Bottom Area Link Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for footer bottom area link color - active. Default value is #000000.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Social Links Color
    $wp_customize->add_setting( 'footer_social_links_color', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_social_links_color', array(
		'label' => __( 'Footer Social Links Color', 'skylab' ),
		'description' => __( 'Choose a value for footer social links color. Default value is #000000.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Social Links Color - Hover
    $wp_customize->add_setting( 'footer_social_links_color_hover', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_social_links_color_hover', array(
		'label' => __( 'Footer Social Links Color - Hover', 'skylab' ),
		'description' => __( 'Choose a value for footer social links color - hover. Default value is #000000.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Social Links Color - Active
    $wp_customize->add_setting( 'footer_social_links_color_active', array(
		'default' => '#000000',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_social_links_color_active', array(
		'label' => __( 'Footer Social Links Color - Active', 'skylab' ),
		'description' => __( 'Choose a value for footer social links color - active. Default value is #000000.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Top Border Color
    $wp_customize->add_setting( 'footer_top_border_color', array(
		'default' => '#e6e6e6',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_top_border_color', array(
		'label' => __( 'Footer Top Border Color', 'skylab' ),
		'description' => __( 'Choose a value for Footer top border color. Default value is #e6e6e6.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	// Footer Bottom Area Top Border Color
    $wp_customize->add_setting( 'footer_bottom_area_top_border_color', array(
		'default' => '#e6e6e6',
		'transport' => 'postMessage',
		'sanitize_callback' => 'esc_attr',
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_bottom_area_top_border_color', array(
		'label' => __( 'Footer Bottom Area Top Border Color', 'skylab' ),
		'description' => __( 'Choose a value for footer bottom area top border color. Default value is #e6e6e6.', 'skylab' ),
		'section' => 'footer_colors',
	) ) );
	
	if ( class_exists( 'woocommerce' ) ) {
	
		// WooCommerce Section
		$wp_customize->add_section( 'woocommerce_general' , array(
			'title' => __( 'General', 'skylab' ),
			'priority' => 9,
			'panel' => 'woocommerce',
		) );
		
		// WooCommerce Cart Position
		$wp_customize->add_setting( 'woocommerce_cart_position', array(
			'default' => 'header',
			'transport' => 'refresh',
			'sanitize_callback' => 'esc_attr',
		) );
		$wp_customize->add_control( 'woocommerce_cart_position',
		   array(
			  'label' => __( 'Cart Position', 'skylab' ),
			  'section' => 'woocommerce_general',
			  'type' => 'select',
			  'choices' => array(
				 'none' => __( 'None', 'skylab' ),
				 'header' => __( 'Header', 'skylab' ),
				 'top_bar' => __( 'Top Bar', 'skylab' ),
			  ),
		   )
		);
		
		// WooCommerce My Account Position
		$wp_customize->add_setting( 'woocommerce_my_account_position', array(
			'default' => 'header',
			'transport' => 'refresh',
			'sanitize_callback' => 'esc_attr',
		) );
		$wp_customize->add_control( 'woocommerce_my_account_position',
		   array(
			  'label' => __( 'My Account Position', 'skylab' ),
			  'section' => 'woocommerce_general',
			  'type' => 'select',
			  'choices' => array(
				 'none' => __( 'None', 'skylab' ),
				 'header' => __( 'Header', 'skylab' ),
				 'top_bar' => __( 'Top Bar', 'skylab' ),
			  ),
		   )
		);
		
		// WooCommerce Wishlist Position
		if ( class_exists( 'YITH_WCWL' ) ) {
			$wp_customize->add_setting( 'woocommerce_wishlist_position', array(
				'default' => 'header',
				'transport' => 'refresh',
				'sanitize_callback' => 'esc_attr',
			) );
			$wp_customize->add_control( 'woocommerce_wishlist_position',
			   array(
				  'label' => __( 'Wishlist Position', 'skylab' ),
				  'section' => 'woocommerce_general',
				  'type' => 'select',
				  'choices' => array(
					 'none' => __( 'None', 'skylab' ),
					 'header' => __( 'Header', 'skylab' ),
					 'top_bar' => __( 'Top Bar', 'skylab' ),
				  ),
			   )
			);
		}
	
		// Shop Columns
		$wp_customize->add_setting( 'shop_columns', array(
			'default' => 3,
			'transport' => 'refresh',
			'sanitize_callback' => 'esc_attr',
		) );
		$wp_customize->add_control( 'shop_columns',
		   array(
			  'label' => __( 'Shop Columns', 'skylab' ),
			  'section' => 'woocommerce_general',
			  'type' => 'select',
			  'choices' => array(
				 2 => 2,
				 3 => 3,
				 4 => 4,
			  ),
		   )
		);
	
		// Related Products Slider on Single Product Page
		$wp_customize->add_setting( 'related_products_slider_on_single_product_page', array(
			'transport' => 'refresh',
			'sanitize_callback' => 'esc_attr',
		) );
		$wp_customize->add_control( 'related_products_slider_on_single_product_page', array(
			'label' => __( 'Related Products Slider on Single Product Page', 'skylab' ),
			'section' => 'woocommerce_general',
			'type' => 'checkbox',
		) );
	
		// Single Product Page Info
		$wp_customize->add_setting( 'single_product_page_info', array(
			'transport' => 'refresh',
			'sanitize_callback' => 'mega_sanitize_textarea_field',
		) );
		$wp_customize->add_control( 'single_product_page_info', array(
			'label' => __( 'Single Product Page Info', 'skylab' ),
			'description' => __( 'Enter the info you would like to display on single product page.', 'skylab' ),
			'section' => 'woocommerce_general',
			'type' => 'textarea',
		) );
	
	}
	
}
add_action( 'customize_register', 'mega_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 */
function mega_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 */
function mega_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

// Live settings preview
function mega_customizer_live_preview() {
	wp_enqueue_script(
		  'mega-themecustomizer',
		  get_template_directory_uri().'/inc/customize-preview.js',
		  array( 'jquery', 'customize-preview' ),
		  '',
		  true
	);
}
add_action( 'customize_preview_init', 'mega_customizer_live_preview' );

function mega_customizer_live_preview_css() {
	wp_enqueue_style(
		  'mega-themecustomizer',
		  get_template_directory_uri().'/inc/customize-preview.css'
	);
}
add_action( 'customize_controls_print_styles', 'mega_customizer_live_preview_css' );

// Uploading WOFF and WOFF2 files
function mega_wp_check_filetype_and_ext( $types, $file, $filename, $mimes ) {
	if ( false !== strpos( $filename, '.woff' ) ) {
		$types['ext']  = 'woff';
		$types['type'] = 'font/woff|application/font-woff|application/x-font-woff|application/octet-stream';
	}
	if ( false !== strpos( $filename, '.woff2' ) ) {
		$types['ext']  = 'woff2';
		$types['type'] = 'font/woff2|application/octet-stream|font/x-woff2';
	}

	return $types;
}
add_filter( 'wp_check_filetype_and_ext', 'mega_wp_check_filetype_and_ext', 10, 4 );

function mega_upload_mimes($mimes) {
  $mimes['woff']  = 'font/woff|application/font-woff|application/x-font-woff|application/octet-stream';
  $mimes['woff2'] = 'font/woff2|application/octet-stream|font/x-woff2';
  return $mimes;
}
add_filter( 'upload_mimes', 'mega_upload_mimes' );

// Register Theme
class Mega_Envato_Verify {
	function mega_verify_purchase() {
		if ( isset( $_GET['settings-updated'] ) && $_GET['settings-updated'] == true ) {
			$code = get_option( 'envato_purchase_code_4740718' );

			// If you took $code from user input it's a good idea to trim it:

			$code = trim( $code );

			// Make sure the code is valid before sending it to Envato:
			
			if ( ! preg_match( "/^([a-z0-9]{8})[-](([a-z0-9]{4})[-]){3}([a-z0-9]{12})$/im", $code ) ) {
				add_settings_error( 'mega-theme-license-group', 'mega-envato-verify-admin-notice', esc_html__( 'Invalid code.', 'skylab' ), 'error' );
				update_option( 'mega_theme_verify', false );
				return;
			}

			// Retrieve the raw response
			
			global $wp_version;
			$args = array(
				'timeout'     => 20,
				'redirection' => 5,
				'httpversion' => '1.0',
				'user-agent'  => 'WordPress/' . $wp_version . '; ' . home_url(),
				'blocking'    => true,
				'headers'     => array(
					'Authorization' => 'Bearer Ba9uDI3ThFjSBXKpmDsURPJsJSYhPdUt',
					'User-Agent' => 'Purchase Verification'
				),
				'cookies'     => array(),
				'body'        => null,
				'compress'    => false,
				'decompress'  => true,
				'sslverify'   => true,
				'stream'      => false,
				'filename'    => null
			);
			
			$response = wp_remote_get( 'https://api.envato.com/v3/market/author/sale?code='. $code, $args );
			$responseCode = wp_remote_retrieve_response_code( $response );

			if ( is_wp_error( $response ) ) {
				$error_message = $response->get_error_message();
				add_settings_error( 'mega-theme-license-group', 'mega-envato-verify-admin-notice', esc_html__( 'Failed to query Envato API: ', 'skylab' ) . $error_message, 'error' );
				update_option( 'mega_theme_verify', false );
				return;
			}

			// Validate response:

			$responseCode = wp_remote_retrieve_response_code( $response );

			if ( $responseCode === 404 ) {
				add_settings_error( 'mega-theme-license-group', 'mega-envato-verify-admin-notice', esc_html__( 'The purchase code was invalid.', 'skylab' ), 'error' );
				update_option( 'mega_theme_verify', false );
				return;
			}

			if ( $responseCode !== 200 ) {
				add_settings_error( 'mega-theme-license-group', 'mega-envato-verify-admin-notice', esc_html__( 'Failed to validate code due to an error: HTTP ', 'skylab' ) . $responseCode . '.', 'error' );
				update_option( 'mega_theme_verify', false );
				return;
			}

			// Verify that the purchase code is for the correct item:
			// (Replace the numbers 4740718 with your item's ID from its URL obviously)

			$body = json_decode( $response['body'] );

			if ( $body->item->id !== 4740718 ) {
				add_settings_error( 'mega-theme-license-group', 'mega-envato-verify-admin-notice', esc_html__( 'The purchase code provided is for a different item.', 'skylab' ), 'error' );
				update_option( 'mega_theme_verify', false );
				return;
			}

			// The purchase code was valid, implement logic here.
			add_settings_error( 'mega-theme-license-group', 'mega-envato-verify-admin-notice', esc_html__( 'Theme registered.', 'skylab' ), 'updated' );
			update_option( 'mega_theme_verify', true );
		}
	}
}

function mega_theme_license_menu() {
	add_theme_page( esc_html__( 'Register Theme', 'skylab' ), esc_html__( 'Register Theme', 'skylab' ), 'edit_theme_options', 'mt-theme-license', 'mega_theme_license_page' );
	add_action( 'admin_init', 'mega_theme_license_settings' );
}
add_action( 'admin_menu', 'mega_theme_license_menu', 99 );

function mega_theme_license_settings() {
	register_setting( 'mega-theme-license-group', 'envato_purchase_code_4740718' );
	register_setting( 'mega-theme-license-group', 'mega_theme_verify' );
}

function mega_theme_license_page() {
	$theme = 'Skylab'; ?>
	<div class="wrap">
	<?php $verify = new Mega_Envato_Verify; ?>
	<?php echo trim( $verify->mega_verify_purchase() ); ?>
	<?php $verified = get_option( 'mega_theme_verify' ); ?>
	<?php if ( $verified == true ) { ?>
		<?php $verified_class = 'theme-verified'; ?>
		<?php $verified_text = esc_html__( 'Registered', 'skylab' ); ?>
	<?php } else { ?>
		<?php $verified_class = 'theme-not-verified'; ?>
		<?php $verified_text = esc_html__( 'Not Registered', 'skylab' ); ?>
	<?php } ?>
	<h1><?php echo sprintf( esc_html__( 'Register %1$s Theme', 'skylab' ), $theme ); ?><span class="theme-verification <?php echo esc_attr( $verified_class ); ?>"><?php echo trim( $verified_text ); ?></span></h1>
	<?php settings_errors( 'mega-theme-license-group' ); ?>
	<p><?php _e( 'In order to receive all benefits of Skylab theme, you need to activate your copy of the theme. By activating Skylab license you will unlock premium options - <strong>direct theme updates</strong>, access to <strong>demo content library</strong>, <strong>bundled plugins</strong> and <strong>official support.</strong>', 'skylab' ); ?></p>
	
	<form method="post" action="options.php">
		<?php settings_fields( 'mega-theme-license-group' ); ?>
		<?php do_settings_sections( 'mega-theme-license-group' ); ?>
		
		<table class="form-table">
			<tr valign="top">
				<th scope="row"><?php echo esc_html__( 'Purchase Code', 'skylab' ); ?></th>
				<td>
				<input type="text" class="regular-text" name="envato_purchase_code_4740718" value="<?php echo esc_attr( get_option( 'envato_purchase_code_4740718' ) ); ?>" placeholder="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx" />
				<p class="description"><?php printf(
					esc_html__( '%1$s %2$s', 'skylab' ),
					esc_html__( 'You can learn how to find your purchase code', 'skylab' ),
					sprintf(
						'<a href="%s" target="_blank">%s</a>',
						esc_url( 'https://help.market.envato.com/hc/en-us/articles/202822600-Where-Is-My-Purchase-Code-' ),
						esc_html__( 'here.', 'skylab' )
					)
				); ?></p>
				</td>
			</tr>
		</table>
		
		<?php submit_button( sprintf( esc_html__( 'Register %1$s Theme', 'skylab' ), $theme ) ); ?>
	</form>
	</div>
<?php
}

// Demo Import
function mega_import_files() {
  $verified = get_option( 'mega_theme_verify' );
  if ( $verified == true ) {
	$path = 'http://demo.megathe.me/skylab/demo-import/qqytuvuywmsjwdey/';
  } else {
	$path = '';
  }
  return array(
    array(
      'import_file_name'           => 'Loraine',
      'import_file_url'            => $path .'loraine/barbaraschmid.WordPress.2021-10-28.xml',
      'import_widget_file_url'     => $path .'loraine/demo.megathe.me-skylab-loraine-widgets.wie',
	  'import_customizer_file_url' => $path .'loraine/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2017/11/loraine-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/loraine/',
    ),
    array(
      'import_file_name'           => 'Candie',
      'import_file_url'            => $path .'candie/katelijneverbruggen.WordPress.2021-10-28.xml',
      'import_widget_file_url'     => $path .'candie/demo.megathe.me-skylab-candie-widgets.wie',
	  'import_customizer_file_url' => $path .'candie/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2017/11/candie-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/candie/',
    ),
	array(
      'import_file_name'           => 'Calvin',
      'import_file_url'            => $path .'calvin/kimhyunsoec.WordPress.2021-10-28.xml',
      'import_widget_file_url'     => $path .'calvin/demo.megathe.me-skylab-calvin-widgets.wie',
	  'import_customizer_file_url' => $path .'calvin/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2017/11/calvin-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/calvin/',
    ),
	array(
      'import_file_name'           => 'Noah',
      'import_file_url'            => $path .'noah/saxoncampbell.WordPress.2021-10-28.xml',
      'import_widget_file_url'     => $path .'noah/demo.megathe.me-skylab-noah-widgets.wie',
	  'import_customizer_file_url' => $path .'noah/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2017/11/noah-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/noah/',
    ),
	array(
      'import_file_name'           => 'Trevor',
      'import_file_url'            => $path .'trevor/ibnramn.WordPress.2021-10-28.xml',
      'import_widget_file_url'     => $path .'trevor/demo.megathe.me-skylab-trevor-widgets.wie',
	  'import_customizer_file_url' => $path .'trevor/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2017/11/trevor-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'http://demo.megathe.me/skylab/trevor/',
    ),
	array(
      'import_file_name'           => 'Tashia',
      'import_file_url'            => $path .'tashia/karlaheredia.WordPress.2021-10-28.xml',
      'import_widget_file_url'     => $path .'tashia/demo.megathe.me-skylab-tashia-widgets.wie',
	  'import_customizer_file_url' => $path .'tashia/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2017/11/tashia-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/tashia/',
    ),
	array(
      'import_file_name'           => 'Casey',
      'import_file_url'            => $path .'casey/tobyng.WordPress.2021-10-28.xml',
      'import_widget_file_url'     => $path .'casey/demo.megathe.me-skylab-casey-widgets.wie',
	  'import_customizer_file_url' => $path .'casey/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2017/11/casey-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/casey/',
    ),
	array(
      'import_file_name'           => 'Vernon',
      'import_file_url'            => $path .'vernon/ryanlongnecker.WordPress.2022-01-06.xml',
	  'import_widget_file_url'     => $path .'vernon/demo.megathe.me-skylab-vernon-widgets.wie',
	  'import_customizer_file_url' => $path .'vernon/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2017/11/vernon-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/vernon/',
    ),
	array(
      'import_file_name'           => 'Andre',
      'import_file_url'            => $path .'andre/gregadamski.WordPress.2022-01-06.xml',
	  'import_widget_file_url'     => $path .'andre/demo.megathe.me-skylab-andre-widgets.wie',
	  'import_customizer_file_url' => $path .'andre/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2017/11/andre-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/andre/',
    ),
	array(
      'import_file_name'           => 'Noel',
      'import_file_url'            => $path .'noel/matthewkristall.WordPress.2022-01-06.xml',
	  'import_widget_file_url'     => $path .'noel/demo.megathe.me-skylab-noel-widgets.wie',
	  'import_customizer_file_url' => $path .'noel/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2017/11/noel-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/noel/',
    ),
	array(
      'import_file_name'           => 'Tomas',
      'import_file_url'            => $path .'tomas/davidmandelberg.WordPress.2022-01-06.xml',
	  'import_widget_file_url'     => $path .'tomas/demo.megathe.me-skylab-tomas-widgets.wie',
	  'import_customizer_file_url' => $path .'tomas/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2017/11/tomas-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/tomas/',
    ),
	array(
      'import_file_name'           => 'Sue',
      'import_file_url'            => $path .'sue/oliviakatz.WordPress.2022-01-06.xml',
	  'import_customizer_file_url' => $path .'sue/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2017/11/sue-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/sue/',
    ),
	array(
      'import_file_name'           => 'Heather',
      'import_file_url'            => $path .'heather/vanessazicanfeng.WordPress.2022-01-06.xml',
	  'import_customizer_file_url' => $path .'heather/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2018/12/heather-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/heather/',
    ),
	array(
      'import_file_name'           => 'Brandon',
      'import_file_url'            => $path .'brandon/rudmervanhulzen.WordPress.2021-10-28.xml',
	  'import_customizer_file_url' => $path .'brandon/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2018/12/brandon-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/brandon/',
    ),
	array(
      'import_file_name'           => 'Kirk',
      'import_file_url'            => $path .'kirk/hardyseiler.WordPress.2021-10-28.xml',
	  'import_customizer_file_url' => $path .'kirk/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2018/12/kirk-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/kirk/',
    ),
	array(
      'import_file_name'           => 'Otis',
      'import_file_url'            => $path .'otis/ognjengligorijevic.WordPress.2021-10-28.xml',
	  'import_customizer_file_url' => $path .'otis/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2019/02/otis-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/otis/',
    ),
	array(
      'import_file_name'           => 'Eileen',
      'import_file_url'            => $path .'eileen/mayramonobe.WordPress.2021-10-28.xml',
	  'import_customizer_file_url' => $path .'eileen/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2019/02/eileen-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/eileen/',
    ),
	array(
      'import_file_name'           => 'Kenneth',
      'import_file_url'            => $path .'kenneth/ryanromanes.WordPress.2021-10-28.xml',
	  'import_customizer_file_url' => $path .'kenneth/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2019/02/kenneth-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/kenneth/',
    ),
	array(
      'import_file_name'           => 'Jana',
      'import_file_url'            => $path .'jana/cansumerdamert.WordPress.2021-10-28.xml',
	  'import_widget_file_url'     => $path .'jana/demo.megathe.me-skylab-jana-widgets.wie',
	  'import_customizer_file_url' => $path .'jana/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2019/02/jana-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/jana/',
    ),
	array(
      'import_file_name'           => 'Yvette',
      'import_file_url'            => $path .'yvette/alexiaroux.WordPress.2021-10-28.xml',
	  'import_widget_file_url'     => $path .'yvette/demo.megathe.me-skylab-yvette-widgets.wie',
	  'import_customizer_file_url' => $path .'yvette/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2021/03/yvette-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/yvette/',
    ),
	array(
      'import_file_name'           => 'Andy',
      'import_file_url'            => $path .'andy/ddacballester.WordPress.2021-10-28.xml',
	  'import_widget_file_url'     => $path .'andy/demo.megathe.me-skylab-andy-widgets.wie',
	  'import_customizer_file_url' => $path .'andy/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2019/02/andy-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/andy/',
    ),
	array(
      'import_file_name'           => 'Darrel',
      'import_file_url'            => $path .'darrel/jellemarchal.WordPress.2021-10-28.xml',
	  'import_widget_file_url'     => $path .'darrel/demo.megathe.me-skylab-darrel-widgets.wie',
	  'import_customizer_file_url' => $path .'darrel/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2019/02/darrel-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/darrel/',
    ),
	array(
      'import_file_name'           => 'Todd',
      'import_file_url'            => $path .'todd/oliviercharland.WordPress.2021-10-28.xml',
	  'import_widget_file_url'     => $path .'todd/demo.megathe.me-skylab-todd-widgets.wie',
	  'import_customizer_file_url' => $path .'todd/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2019/02/todd-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/todd/',
    ),
	array(
      'import_file_name'           => 'Brian',
      'import_file_url'            => $path .'brian/villeok.WordPress.2021-10-28.xml',
	  'import_widget_file_url'     => $path .'brian/demo.megathe.me-skylab-brian-widgets.wie',
	  'import_customizer_file_url' => $path .'brian/skylab-export.dat',
      'import_preview_image_url'   => 'https://demo.megathe.me/skylab/wp-content/uploads/2019/02/brian-625x396.jpg',
      'import_notice'              => '',
      'preview_url'                => 'https://demo.megathe.me/skylab/brian/',
    ),
  );
}
add_filter( 'ocdi/import_files', 'mega_import_files' );

// Import button
function mega_remove_import_button( $hook ) {
	$output = '<style>
	.ocdi__gl-item-footer .button-primary {
		display: none !important;
	}
	</style>
	<script>
	document.addEventListener("DOMContentLoaded", function(event) {
		var oneClickDemoImportButton = document.querySelectorAll(".ocdi__gl-item-footer .button-primary");
		Array.prototype.forEach.call( oneClickDemoImportButton, function( node ) {
			node.parentNode.removeChild( node );
		});
	});
	</script>';
	$verified = get_option( 'mega_theme_verify' );
	if ( $hook == 'appearance_page_one-click-demo-import' && $verified != true ) {
		echo trim( $output );
	}
}
add_action( 'admin_enqueue_scripts', 'mega_remove_import_button' );

// Remove widgets before import
function ocdi_before_widgets_import( $selected_import ) {
	$sidebars_widgets = array();
	update_option( 'sidebars_widgets', $sidebars_widgets );
}
add_action( 'ocdi/before_widgets_import', 'ocdi_before_widgets_import' );


function mega_before_content_import( $selected_import ) {
	if ( 'Vernon' === $selected_import['import_file_name'] ) {
		
		// Set thumbnail size in settings > media
		update_option( 'medium_size_w', 300 );
		update_option( 'medium_size_h', 0 );
		update_option( 'large_size_w', 0 );
		update_option( 'large_size_h', 1280 );
		
	} else if ( 'Andre' === $selected_import['import_file_name'] ||
		'Noel' === $selected_import['import_file_name'] ||
		'Tomas' === $selected_import['import_file_name'] ||
		'Sue' === $selected_import['import_file_name'] ||
		'Heather' === $selected_import['import_file_name']
	) {
		
		// Set thumbnail size in settings > media
		update_option( 'medium_size_w', 300 );
		update_option( 'medium_size_h', 0 );
		update_option( 'large_size_w', 0 );
		update_option( 'large_size_h', 1080 );
		
	} else {
		
		// Set thumbnail size in settings > media
		update_option( 'medium_size_w', 300 );
		update_option( 'medium_size_h', 0 );
		update_option( 'large_size_w', 1170 );
		update_option( 'large_size_h', 0 );
		
	}
}
add_action( 'ocdi/before_content_import', 'mega_before_content_import' );

function mega_after_import( $selected_import ) {
	$verified = get_option( 'mega_theme_verify' );
	if ( $verified == true ) {
		$path = '/nfs/c10/h10/mnt/227054/domains/demo.megathe.me/html/skylab/demo-import/qqytuvuywmsjwdey/';
	} else {
		$path = '';
	}
	
	// Blog pages show at most
	update_option( 'posts_per_page', 5 );
	
	// Syndication feeds show the most recent
	update_option( 'posts_per_rss', 5 );
	
	// For each article in a feed, show
	update_option( 'rss_use_excerpt', 1 );
	
	// Easy Social Share Buttons options
	if ( class_exists( 'ESSB_Manager' ) ) {
		$essb_export_data = '{"topbar_contentarea_pos":"left","bottombar_contentarea_pos":"left","flyin_position":"right","sis_network_order":["facebook","twitter","google","linkedin","pinterest","tumblr","reddit","digg","delicious","vkontakte","odnoklassniki"],"sis_position":"top-left","sis_style":"tiny","sis_orientation":"horizontal","heroshare_second_type":"top","postbar_button_style":"recommended","postbar_counter_pos":"hidden","point_position":"bottomright","point_open_auto":"no","point_style":"simple","point_shape":"round","point_button_style":"recommended","point_template":"6","point_counter_pos":"inside","mobile_sharebuttonsbar_count":"1","sharebar_counter_pos":"inside","sharebar_total_counter_pos":"before","sharepoint_counter_pos":"inside","sharepoint_total_counter_pos":"before","display_excerpt_pos":"top","content_position":"content_bottom","afterclose_type":"follow","afterclose_like_cols":"onecol","aftershare_optin_design":"design1","networks":["facebook","twitter"],"more_button_func":"1","share_button_func":"1","share_button_counter":"hidden","twitter_message_optimize_method":"1","subscribe_function":"form","subscribe_optin_design":"design1","subscribe_optin_design_popup":"design1","mail_function":"form","mail_function_security":"level1","flattr_lang":"sq_AL","style":"1001","button_style":"button","counter_pos":"hidden","total_counter_pos":"hidden","fullwidth_align":"left","fullwidth_share_buttons_columns":"1","counter_recover_mode":"unchanged","counter_recover_protocol":"unchanged","counter_recover_prefixdomain":"unchanged","twitter_counters":"self","force_counters_admin_type":"wp","ga_tracking_mode":"simple","esml_history":"1","esml_access":"manage_options","twitter_card_type":"summary","twitter_shareshort":"true","shorturl_type":"wp","shorturl_bitlyapi_version":"previous","affwp_active_mode":"id","user_network_name_facebook":"Facebook","user_network_name_twitter":"Twitter","user_network_name_pinterest":"Pin","user_network_name_tumblr":"Post","apply_clean_buttons_method":"actionremove","live_customizer_disabled":"true","essb_access":"manage_options","limit_editor_fields_access":"manage_options","essb_advanced_token":"315810aa45","_wp_http_referer":"\/skylab\/loraine\/wp-admin\/admin-ajax.php?settings=features&action=essb_advanced_options&cmd=get&essb_advancedoptions_token=55d51386fe","deactivate_ctt":"true","deactivate_module_aftershare":"true","deactivate_module_analytics":"true","deactivate_module_pinterestpro":"true","deactivate_module_shorturl":"true","deactivate_module_affiliate":"true","deactivate_module_customshare":"true","deactivate_module_message":"true","deactivate_module_metrics":"true","deactivate_custombuttons":"true","deactivate_module_translate":"true","deactivate_module_conversions":"true","deactivate_custompositions":"true","deactivate_method_integrations":"true","deactivate_module_followers":"true","deactivate_module_profiles":"true","deactivate_module_natives":"true","deactivate_module_subscribe":"true","deactivate_module_facebookchat":"true","deactivate_module_skypechat":"true","deactivate_module_clicktochat":"true","deactivate_module_instagram":"true","deactivate_module_proofnotifications":"true","deactivate_stylelibrary":"true","deactivate_homepage":"true","hide_content_archive":"true","hide_content_home":"true","deactivate_settings_post_type":"true","optimize_load":"selected","disable_adminbar_menu":"true","display_in_types":["post","portfolio"],"turnoff_essb_advanced_box":"true","turnoff_essb_optimize_box":"true","turnoff_essb_stats_box":"true","use_minified_js":"true","css_mode":"slim","use_stylebuilder":"true","deactivate_fa":"true","precompiled_mode":"js","opengraph_tags":"true"}';
		$essb_export_data = wp_specialchars_decode ( $essb_export_data );
		$essb_export_data = stripslashes ( $essb_export_data );
		$essb_imported_options = json_decode ( $essb_export_data, true );
		if ( is_array( $essb_imported_options ) ) {
			update_option( ESSB3_OPTIONS_NAME, $essb_imported_options );
		}
	}
	
	if ( 'Loraine' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Loraine', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
			)
		);

		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', '' );
		
	} else if ( 'Candie' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Candie', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', '' );
		
	} else if ( 'Calvin' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Calvin', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', '' );
		
	} else if ( 'Noah' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Noah', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', '' );
		
	} else if ( 'Trevor' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Trevor', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', '' );
		
	} else if ( 'Tashia' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Tashia', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', '' );
		
	} else if ( 'Casey' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Casey', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', '' );
		
	} else if ( 'Vernon' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Vernon', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Home' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', '' );
		
	} else if ( 'Andre' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Andre', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Home' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', '' );
		
	} else if ( 'Noel' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Noel', 'nav_menu' );
		$secondary_menu = get_term_by( 'name', 'Noel 2', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
				'secondary' => $secondary_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Fashion' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', '' );
		
	} else if ( 'Tomas' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Tomas', 'nav_menu' );
		$secondary_menu = get_term_by( 'name', 'Tomas 2', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
				'secondary' => $secondary_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Portolio' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', '' );
		
	} else if ( 'Sue' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Sue', 'nav_menu' );
		$secondary_menu = get_term_by( 'name', 'Sue 2', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
				'secondary' => $secondary_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Fashion I' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', '' );
		
	} else if ( 'Heather' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Heather', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Editorials' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		
	} else if ( 'Brandon' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Brandon', 'nav_menu' );
		$secondary_menu = get_term_by( 'name', 'Brandon 2', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
				'secondary' => $secondary_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		
	} else if ( 'Kirk' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Kirk', 'nav_menu' );
		$secondary_menu = get_term_by( 'name', 'Kirk 2', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
				'secondary' => $secondary_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		
	} else if ( 'Otis' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Otis', 'nav_menu' );
		$secondary_menu = get_term_by( 'name', 'Otis 2', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
				'secondary' => $secondary_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		
	} else if ( 'Eileen' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Eileen', 'nav_menu' );
		$secondary_menu = get_term_by( 'name', 'Eileen 2', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
				'secondary' => $secondary_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		
	} else if ( 'Kenneth' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Kenneth', 'nav_menu' );
		$secondary_menu = get_term_by( 'name', 'Kenneth 2', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
				'secondary' => $secondary_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		
	} else if ( 'Jana' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Jana', 'nav_menu' );
		$secondary_menu = get_term_by( 'name', 'Jana Secondary', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
				'secondary' => $secondary_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Works' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		
	} else if ( 'Yvette' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Yvette', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		
	} else if ( 'Andy' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Andy', 'nav_menu' );
		$secondary_menu = get_term_by( 'name', 'Andy Secondary', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
				'secondary' => $secondary_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		
	} else if ( 'Darrel' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Darrel', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );

	} else if ( 'Todd' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Todd', 'nav_menu' );
		$secondary_menu = get_term_by( 'name', 'Todd Secondary', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
				'secondary' => $secondary_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Work' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		
	} else if ( 'Brian' === $selected_import['import_file_name'] ) {
		
		// Assign menus to their locations
		$main_menu = get_term_by( 'name', 'Brian', 'nav_menu' );
		set_theme_mod( 'nav_menu_locations', array(
				'primary' => $main_menu->term_id,
			)
		);
		
		// Assign front page and posts page
		$front_page_id = get_page_by_title( 'Projects' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		
	}

}
add_action( 'ocdi/after_import', 'mega_after_import' );

// Recommended Plugins
function mega_register_plugins( $plugins ) {
  $theme_plugins = [
    [
      'name'        => 'WPBakery Page Builder',
      'description' => __( 'Drag and drop page builder for WordPress. Take full control over your WordPress site, build any layout you can imagine – no programming knowledge required.', 'skylab' ),
	  'slug'        => 'js_composer',  // The slug has to match the extracted folder from the zip.
      'source'      => 'http://megathe.me/bundled-plugins/hm3rz9g3g48qpzx2/js_composer.zip',
      'preselected' => true,
    ],
	[
      'name'        => 'Skylab WPBakery Page Builder Addon',
      'description' => __( 'Enables custom WPBakery Page Builder elements for Skylab theme.', 'skylab' ),
	  'slug'        => 'wpbakery-page-builder-addon-for-skylab-theme',  // The slug has to match the extracted folder from the zip.
      'source'      => 'http://megathe.me/bundled-plugins/hm3rz9g3g48qpzx2/wpbakery-page-builder-addon-for-skylab-theme.zip',
      'preselected' => true,
    ],
	[
      'name'        => 'Portfolio Post Type',
      'description' => __( 'Enables a portfolio post type and taxonomies.', 'skylab' ),
	  'slug'        => 'mega-portfolio-post-type',  // The slug has to match the extracted folder from the zip.
      'source'      => 'http://megathe.me/bundled-plugins/hm3rz9g3g48qpzx2/mega-portfolio-post-type.zip',
      'preselected' => true,
    ],
	[
      'name'        => 'Easy Social Share Buttons for WordPress',
      'description' => __( 'The first true all in one social media plugin for WordPress, including social share buttons, social followers counter, social profile links, click to tweet, Pinnable images, after share events, subscribe forms, Instagram feed, social proof notifications and much more.', 'skylab' ),
	  'slug'        => 'easy-social-share-buttons3',  // The slug has to match the extracted folder from the zip.
      'source'      => 'http://megathe.me/bundled-plugins/hm3rz9g3g48qpzx2/easy-social-share-buttons3.zip',
      'preselected' => true,
    ],
	[
      'name'     => 'Contact Form 7',
	  'description' => __( 'Just another contact form plugin. Simple but flexible.', 'skylab' ),
      'slug'     => 'contact-form-7', // Plugin slug - the same as on WordPress.org plugin repository.
      'preselected' => true,
    ],
	[
      'name'     => 'Yoast Duplicate Post',
	  'description' => __( 'The go-to tool for cloning posts and pages, including the powerful Rewrite & Republish feature.', 'skylab' ),
      'slug'     => 'duplicate-post', // Plugin slug - the same as on WordPress.org plugin repository.
      'preselected' => true,
    ],
	[
      'name'     => 'Autoptimize',
	  'description' => __( 'Makes your site faster by optimizing CSS, JS, Images, Google fonts and more.', 'skylab' ),
      'slug'     => 'autoptimize', // Plugin slug - the same as on WordPress.org plugin repository.
      'preselected' => true,
    ],
	[
      'name'     => 'Disable Gutenberg',
      'description' => __( 'Disables Gutenberg Block Editor and restores the Classic Editor and original Edit Post screen. Provides options to enable on specific post types, user roles, and more.', 'skylab' ),
	  'slug'     => 'disable-gutenberg', // Plugin slug - the same as on WordPress.org plugin repository.
      'preselected' => true,
    ],
	[
      'name'     => 'Disable Embeds',
	  'description' => __( 'Don\'t like the enhanced embeds in WordPress 4.4? Easily disable the feature using this plugin.', 'skylab' ),
      'slug'     => 'disable-embeds', // Plugin slug - the same as on WordPress.org plugin repository.
      'preselected' => true,
    ],
	[
      'name'     => 'Remove jQuery Migrate',
	  'description' => __( 'This plugin removes the jQuery Migrate script from the front end of your site.', 'skylab' ),
      'slug'     => 'remove-jquery-migrate', // Plugin slug - the same as on WordPress.org plugin repository.
      'preselected' => true,
    ],
	[
      'name'     => 'Remove jQuery from Theme',
	  'description' => __( 'Completely remove jQuery from your theme.', 'skylab' ),
      'slug'     => 'remove-jquery', // Plugin slug - the same as on WordPress.org plugin repository.
      'preselected' => true,
    ],
  ];
 
  return array_merge( $plugins, $theme_plugins );
}
add_filter( 'ocdi/register_plugins', 'mega_register_plugins' );

// Auto plugin activation
require_once( get_template_directory() . '/inc/class-tgm-plugin-activation.php' );
add_action( 'tgmpa_register', 'mega_register_required_plugins' );
function mega_register_required_plugins() {
	$plugins = array(
		array(
			'name'     				=> 'WPBakery Page Builder', // The plugin name
			'slug'     				=> 'js_composer', // The plugin slug (typically the folder name)
			'source'   				=> 'http://megathe.me/bundled-plugins/hm3rz9g3g48qpzx2/js_composer.zip', // The plugin source
			'required' 				=> false, // If false, the plugin is only 'recommended' instead of required
			'version' 				=> '', // E.g. 1.0.0. If set, the active plugin must be this version or mega, otherwise a notice is presented
			'force_activation' 		=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
			'force_deactivation' 	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
			'external_url' 			=> '', // If set, overrides default API URL and points to an external URL
		),
		array(
			'name'     				=> 'Skylab WPBakery Page Builder Addon', // The plugin name
			'slug'     				=> 'wpbakery-page-builder-addon-for-skylab-theme', // The plugin slug (typically the folder name)
			'source'   				=> 'http://megathe.me/bundled-plugins/hm3rz9g3g48qpzx2/wpbakery-page-builder-addon-for-skylab-theme.zip', // The plugin source
			'required' 				=> false, // If false, the plugin is only 'recommended' instead of required
			'version' 				=> '', // E.g. 1.0.0. If set, the active plugin must be this version or mega, otherwise a notice is presented
			'force_activation' 		=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
			'force_deactivation' 	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
			'external_url' 			=> '', // If set, overrides default API URL and points to an external URL
		),
		array(
			'name'     				=> 'Portfolio Post Type', // The plugin name
			'slug'     				=> 'mega-portfolio-post-type', // The plugin slug (typically the folder name)
			'source'   				=> 'http://megathe.me/bundled-plugins/hm3rz9g3g48qpzx2/mega-portfolio-post-type.zip', // The plugin source
			'required' 				=> false, // If false, the plugin is only 'recommended' instead of required
			'version' 				=> '', // E.g. 1.0.0. If set, the active plugin must be this version or mega, otherwise a notice is presented
			'force_activation' 		=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
			'force_deactivation' 	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
			'external_url' 			=> '', // If set, overrides default API URL and points to an external URL
		),
		array(
			'name'     				=> 'Easy Social Share Buttons for WordPress', // The plugin name
			'slug'     				=> 'easy-social-share-buttons3', // The plugin slug (typically the folder name)
			'source'   				=> 'http://megathe.me/bundled-plugins/hm3rz9g3g48qpzx2/easy-social-share-buttons3.zip', // The plugin source
			'required' 				=> false, // If false, the plugin is only 'recommended' instead of required
			'version' 				=> '', // E.g. 1.0.0. If set, the active plugin must be this version or mega, otherwise a notice is presented
			'force_activation' 		=> false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
			'force_deactivation' 	=> false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
			'external_url' 			=> '', // If set, overrides default API URL and points to an external URL
		),
		array(
			'name' 		=> 'Contact Form 7',
			'slug' 		=> 'contact-form-7',
			'required' 	=> false
		),
		array(
			'name' 		=> 'One Click Demo Import',
			'slug' 		=> 'one-click-demo-import',
			'required' 	=> false
		),
		array(
			'name' 		=> 'Yoast Duplicate Post',
			'slug' 		=> 'duplicate-post',
			'required' 	=> false
		),
		array(
			'name' 		=> 'Autoptimize',
			'slug' 		=> 'autoptimize',
			'required' 	=> false
		),
		array(
			'name' 		=> 'Disable Gutenberg',
			'slug' 		=> 'disable-gutenberg',
			'required' 	=> false
		),
		array(
			'name' 		=> 'Disable Embeds',
			'slug' 		=> 'disable-embeds',
			'required' 	=> false
		),
		array(
			'name' 		=> 'Remove jQuery Migrate',
			'slug' 		=> 'remove-jquery-migrate',
			'required' 	=> false
		),
		array(
			'name' 		=> 'Remove jQuery from Theme',
			'slug' 		=> 'remove-jquery',
			'required' 	=> false
		)
	);

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'skylab',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => 'http://demo.megathe.me/bundled-plugins/hm3rz9g3g48qpzx2',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'parent_slug'  => 'themes.php',            // Parent menu slug.
		'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa($plugins, $config);
}

// Register theme notice
function mega_register_theme_notice() {
	$verified = get_option( 'mega_theme_verify' );
	if ( $verified != true ) {
		$screen = get_current_screen();
		if ( $screen->id != 'appearance_page_mt-theme-license' ) {
		?>
		<div class="notice notice-warning is-dismissible">
			<p><strong><?php echo __( 'In order to receive all benefits of Skylab theme, you need to activate your copy of the theme. By activating Skylab license you will unlock premium options - <em>direct theme updates</em>, access to <em>demo content library</em>, <em>bundled plugins</em> and <em>official support.</em>', 'skylab' ); ?></strong></p>
			<p><strong><a href="<?php echo admin_url( 'themes.php?page=mt-theme-license' ) ?>"><?php echo __( 'Register Skylab Theme', 'skylab' ) ?></a></strong></p>
		</div>
		<?php
		}
	}
}
add_action( 'admin_notices', 'mega_register_theme_notice' );


/**
 * Sets the post excerpt length.
 *
 * To override this length in a child theme, remove the filter and add your own
 * function tied to the excerpt_length filter hook.
 */
function mega_excerpt_length( $length ) {
	return 55;
}
add_filter( 'excerpt_length', 'mega_excerpt_length' );

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis.
 *
 * To override this in a child theme, remove the filter and add your own
 * function tied to the excerpt_more filter hook.
 */
function mega_auto_excerpt_more( $more ) {
	return ' &hellip;';
}
add_filter( 'excerpt_more', 'mega_auto_excerpt_more' );

// Modify read more link
function mega_modify_read_more_link() {
	return '<div class="more-link-wrapper"><a href="' . get_permalink() . '" class="more-link"><span>'. esc_html__( 'Read more', 'skylab' ) .'</span></a></div>';
}
add_filter( 'the_content_more_link', 'mega_modify_read_more_link' );

// Get current URL
if ( ! function_exists( 'mega_get_current_page_url' ) ) {
	function mega_get_current_page_url() {
	  global $wp;
	  return home_url( add_query_arg( array(), $wp->request ) );
	}
}

/**
 * Remove title attribute from images.
 */
function mega_wp_get_attachment_image_attributes_title_filter( $attr ) {
	unset( $attr['title'] );
	return $attr;
}
add_filter( 'wp_get_attachment_image_attributes', 'mega_wp_get_attachment_image_attributes_title_filter' );

/**
 * Register our sidebars and widgetized areas.
 */
function mega_widgets_init() {
	if ( class_exists( 'woocommerce' ) ) {
		register_sidebar( array(
			'name' => esc_html__( 'Shop Sidebar', 'skylab' ),
			'id' => 'sidebar-3',
			'description' => esc_html__( 'An optional widget area for your shop page.', 'skylab' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => "</aside>",
			'before_title' => '<h3 class="widget-title"><span>',
			'after_title' => '</span></h3>',
		) );
	}
	register_sidebar( array(
		'name' => esc_html__( 'Footer #1', 'skylab' ),
		'id' => 'sidebar-4',
		'description' => esc_html__( 'Widgets in this area will be displayed in the first column in the footer.', 'skylab' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title"><span>',
		'after_title' => '</span></h3>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Footer #2', 'skylab' ),
		'id' => 'sidebar-5',
		'description' => esc_html__( 'Widgets in this area will be displayed in the second column in the footer.', 'skylab' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title"><span>',
		'after_title' => '</span></h3>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Footer #3', 'skylab' ),
		'id' => 'sidebar-6',
		'description' => esc_html__( 'Widgets in this area will be displayed in the third column in the footer.', 'skylab' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title"><span>',
		'after_title' => '</span></h3>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Footer #4', 'skylab' ),
		'id' => 'sidebar-7',
		'description' => esc_html__( 'Widgets in this area will be displayed in the fourth column in the footer.', 'skylab' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title"><span>',
		'after_title' => '</span></h3>',
	) );
	
	register_sidebar( array(
		'name' => esc_html__( 'Subfooter #1', 'skylab' ),
		'id' => 'sidebar-8',
		'description' => esc_html__( 'Widgets in this area will be displayed in the first column in the subfooter.', 'skylab' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title"><span>',
		'after_title' => '</span></h3>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Subfooter #2', 'skylab' ),
		'id' => 'sidebar-9',
		'description' => esc_html__( 'Widgets in this area will be displayed in the second column in the subfooter.', 'skylab' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title"><span>',
		'after_title' => '</span></h3>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Subfooter #3', 'skylab' ),
		'id' => 'sidebar-10',
		'description' => esc_html__( 'Widgets in this area will be displayed in the third column in the subfooter.', 'skylab' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title"><span>',
		'after_title' => '</span></h3>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Blog Sidebar', 'skylab' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title"><span>',
		'after_title' => '</span></h3>',
	) );
}
add_action( 'widgets_init', 'mega_widgets_init' );

/**
 * Display navigation to next/previous pages when applicable
 */
if ( ! function_exists( 'mega_content_nav' ) ) :
	function mega_content_nav( $nav_id ) {
		global $wp_query;

		if ( $wp_query->max_num_pages > 1 ) : ?>
			<nav id="<?php echo sanitize_html_class( $nav_id ); ?>">
				<h3 class="assistive-text"><?php esc_html_e( 'Post navigation', 'skylab' ); ?></h3>
				<div class="nav-previous"><?php next_posts_link( esc_html__( 'Older Posts <i class="nav-pagination-single-right"></i>', 'skylab' ) ); ?></div>
				<div class="nav-next"><?php previous_posts_link( esc_html__( '<i class="nav-pagination-single-left"></i> Newer Posts', 'skylab' ) ); ?></div>
			</nav><!-- #nav-above -->
		<?php endif;
	}
endif; // mega_content_nav

/**
 * Display navigation to next/previous pages with pagination when applicable
 */
if ( ! function_exists( 'mega_pagination_content_nav' ) ) :
	function mega_pagination_content_nav( $nav_id ) {
		global $wp_query;

		if ( $wp_query->max_num_pages > 1 ) : ?>
			<nav class="<?php echo sanitize_html_class( $nav_id ); ?>">
				
				<?php $big = 999999999; // need an unlikely integer

				echo paginate_links( array(
					'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
					'format' => '?paged=%#%',
					'current' => max( 1, get_query_var( 'paged' ) ),
					'total' => $wp_query->max_num_pages,
					'prev_text' => '<span class="meta-nav">'. esc_html__( 'Prev', 'skylab' ) .'</span>',
					'next_text' => '<span class="meta-nav">'. esc_html__( 'Next', 'skylab' ) .'</span>',
					'end_size' => 1,
					'before_page_number' => '<span>',
					'after_page_number' => '</span>'
				) ); ?>
			</nav>
		<?php endif;
	}
endif; // mega_pagination_content_nav

/**
 * Count the number of footer sidebars to enable dynamic classes for the footer
 */
function mega_footer_sidebar_class() {
	$count = 0;

	if ( is_active_sidebar( 'sidebar-4' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-5' ) )
		$count++;
		
	if ( is_active_sidebar( 'sidebar-6' ) )
		$count++;
		
	if ( is_active_sidebar( 'sidebar-7' ) )
		$count++;

	$class = '';

	switch ( $count ) {
		case '1':
			$class = 'one clearfix';
			break;
		case '2':
			$class = 'two clearfix';
			break;
		case '3':
			$class = 'three clearfix';
			break;
		case '4':
			$class = 'four clearfix';
			break;
	}

	if ( $class )
		echo 'class="supplementary ' . $class . '"';
}

/**
 * Count the number of subfooter sidebars to enable dynamic classes for the subfooter
 */
function mega_subfooter_sidebar_class() {
	$count = 0;

	if ( is_active_sidebar( 'sidebar-8' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-9' ) )
		$count++;
		
	if ( is_active_sidebar( 'sidebar-10' ) )
		$count++;

	$class = '';

	switch ( $count ) {
		case '1':
			$class = 'one clearfix';
			break;
		case '2':
			$class = 'two clearfix';
			break;
		case '3':
			$class = 'three clearfix';
			break;
	}

	if ( $class )
		echo 'class="' . $class . '"';
}

/**
 * Template for comments and pingbacks.
 */
if ( ! function_exists( 'mega_comment' ) ) {
	function mega_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
		switch ( $comment->comment_type ) :
			case 'pingback' :
			case 'trackback' :
		?>
		<div class="post pingback">
			<p><?php esc_html_e( 'Pingback:', 'skylab' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( esc_html__( 'Edit', 'skylab' ), '<span class="edit-link">', '</span>' ); ?></p>
		<?php
			break;
			default :
		?>
		<div <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
			<article id="comment-<?php comment_ID(); ?>" class="comment">
				<footer class="comment-meta">
					<div class="avatar vcard">
						<?php
							$avatar_size = 100;
							echo get_avatar( $comment, $avatar_size );
						?>
					</div><!-- .comment-author .vcard -->

					<?php if ( $comment->comment_approved == '0' ) : ?>
						<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'skylab' ); ?></em>
						<br />
					<?php endif; ?>
				</footer>

				<div class="comment-content">
					<div class="comment-author vcard">
						<?php
						// translators: 1: comment author, 2: date and time */
						printf( esc_html__( '%1$s %2$s', 'skylab' ),
							
							sprintf( '<span class="fn">%s</span>', get_comment_author_link() ),
							sprintf( '<a href="%1$s" class="comment-time"><span>%3$s</span></a>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( 'c' ),
								sprintf( esc_html__( '%1$s', 'skylab' ), get_comment_date( 'M j, Y' ) )
							)
						);
						
						$sep = '<span class="sep"> / </span>';
						edit_comment_link( esc_html__( 'Edit', 'skylab' ), '' . $sep . '<span class="edit-link">', '</span>' );
						?>
					</div><!-- .comment-author .vcard -->
						
					<?php comment_text(); ?>
					<?php comment_reply_link( array_merge( $args, array( 'reply_text' => esc_html__( 'Reply', 'skylab' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
				</div>
			</article>
		</div>

		<?php
		break;
		endswitch;
	}
}

/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
if ( ! function_exists( 'mega_posted_on' ) ) {
	function mega_posted_on() {
		echo '<p class="entry-date-wrapper"><span class="entry-date">'. esc_html( get_the_date() ) .'</span></p>';
	}
}

/**
 * Adds classes to the array of body classes.
 */
function mega_body_classes( $classes ) {

	if ( function_exists( 'is_multi_author' ) && ! is_multi_author() )
		$classes[] = 'single-author';

	if ( is_singular() && ! is_home() )
		$classes[] = 'singular';
	
	// Sidebar
	if ( is_active_sidebar( 'sidebar-1' ) && is_home() || is_singular( 'post' ) && is_active_sidebar( 'sidebar-1' ) )
		$classes[] = 'main-sidebar-is-active';
	
	// Page Load Progress Indicator
	$page_load_progress_indicator = get_theme_mod( 'page_load_progress_indicator', 'progress_bar' );
	
	$classes[] = 'hidden';
	
	if ( $page_load_progress_indicator == 'progress_bar' ) {
		$classes[] = 'progress-bar';
	} else {
		$classes[] = 'progress-indicator-disabled';
	}
	
	// Search Position
	$search_position = get_theme_mod( 'search_position', 'none' );
	if ( $search_position == 'top_bar' ) {
		$classes[] = 'search-position-top-bar';
	}
	
	// Primary/Secondary/Top Bar Menu Items Transition Hover
	$primary_secondary_top_bar_menu_items_transition_hover = get_theme_mod( 'primary_secondary_top_bar_menu_items_transition_hover' );
	if ( ! empty( $primary_secondary_top_bar_menu_items_transition_hover ) ) {
		$classes[] = 'primary-secondary-top-bar-menu-items-transition-hover-enabled';
	} else {
		$classes[] = 'primary-secondary-top-bar-menu-items-transition-hover-disabled';
	}
	
	// Buttons Style
	$buttons_style = get_theme_mod( 'buttons_style', 'modern' );
	$classes[] = 'buttons-style-'. $buttons_style .'';
	
	// Buttons Shape
	$buttons_style = get_theme_mod( 'buttons_shape', 'square' );
	$classes[] = 'buttons-shape-'. $buttons_style .'';
	
	// General Arrows Buttons Style
	$general_arrows_buttons_style = get_theme_mod( 'general_arrows_buttons_style', 1 );
	$classes[] = 'general-arrows-buttons-style-'. $general_arrows_buttons_style .'';
	
	// Input Style
	$input_style = get_theme_mod( 'input_style', 1 );
	$classes[] = 'input-style-'. $input_style .'';
	
	// Header Behavior
	$header_behavior = get_theme_mod( 'header_behavior', 'normal' );
	if ( $header_behavior == 'fixed' ) {
		$classes[] = 'sticky-header';
	} else if ( $header_behavior == 'fixed_on_scroll' ) {
		$classes[] = 'sticky-header-on-scroll';
	} else {
		$classes[] = 'non-sticky-header';
	}
	
	// Full Width Header
	$full_width_header = get_theme_mod( 'full_width_header' );
	if ( ! empty( $full_width_header ) ) {
		$classes[] = 'full-width-header-enabled';
	} else {
		$classes[] = 'full-width-header-disabled';
	}
	
	// Header Position
	$header_position = get_theme_mod( 'header_position', 'top' );
	if ( $header_position == 'top' ) {
		$classes[] = 'horizontal-header header-position-top';
	} else if ( $header_position == 'left' ) {
		$classes[] = 'vertical-header header-position-left';
	} else if ( $header_position == 'bottom' ) {
		$classes[] = 'horizontal-header header-position-bottom';
	} else if ( $header_position == 'right' ) {
		$classes[] = 'vertical-header header-position-right';
	}
	
	// Sliding Menu Align
	$sliding_menu_align = get_theme_mod( 'sliding_menu_align', 'right' );
	if ( $sliding_menu_align == 'right' ) {
		$classes[] = 'sliding-menu-align-right';
	} else {
		$classes[] = 'sliding-menu-align-left';
	}
	
	// Full Width Sliding Menu
	$full_width_sliding_menu = get_theme_mod( 'full_width_sliding_menu' );
	if ( ! empty( $full_width_sliding_menu ) ) {
		$classes[] = 'sliding-menu-center-and-full-width-enabled';
	} else {
		$classes[] = 'sliding-menu-center-and-full-width-disabled';
	}
	
	// Center Logo and Menu
	$center_logo_and_menu = get_theme_mod( 'center_logo_and_menu' );
	if ( ! empty( $center_logo_and_menu ) ) {
		$classes[] = 'center-logo-and-menu-enabled';
	} else {
		$classes[] = 'center-logo-and-menu-disabled';
	}
	
	// Back to Top Button Mix Blend Mode
	$back_to_top_button_mix_blend_mode = get_theme_mod( 'back_to_top_button_mix_blend_mode' );
	if ( ! empty( $back_to_top_button_mix_blend_mode ) ) {
		$classes[] = 'back-to-top-button-mix-blend-mode-enabled';
	} else {
		$classes[] = 'back-to-top-button-mix-blend-mode-disabled';
	}
	
	// Full Width Footer
	$full_width_footer = get_theme_mod( 'full_width_footer' );
	if ( ! empty( $full_width_footer ) ) {
		$classes[] = 'full-width-footer-enabled';
	} else {
		$classes[] = 'full-width-footer-disabled';
	}
	
	// Top Bar
	$top_bar = get_theme_mod( 'top_bar' );
	if ( ! empty( $top_bar ) ) {
		$classes[] = 'top-bar-enabled';
	} else {
		$classes[] = 'top-bar-disabled';
	}
	
	// Top Bar Behavior
	if ( ! empty( $top_bar ) ) {
		$top_bar_behavior = get_theme_mod( 'top_bar_behavior', 'normal' );
		if ( $top_bar_behavior == 'fixed' ) {
			$classes[] = 'sticky-top-bar';
		} else if ( $top_bar_behavior == 'fixed_on_scroll' ) {
			$classes[] = 'sticky-top-bar-on-scroll';
		} else {
			$classes[] = 'non-sticky-top-bar';
		}
	}
		
	// Shop Layout
	if ( class_exists( 'woocommerce' ) ) {
		if ( is_shop() || is_product_category() || is_product_tag() ) {
			if ( is_active_sidebar( 'sidebar-3' ) ) {
				$classes[] = 'shop-sidebar-enabled';
			} else {
				$classes[] = 'shop-sidebar-disabled';
			}
		}
	}
	
	// Shop Columns
	if ( class_exists( 'woocommerce' ) ) {
		if ( is_shop() || is_product_category() || is_product_tag() ) {
			$shop_columns = get_theme_mod( 'shop_columns', 3 );
			if ( $shop_columns == 2 ) {
				$classes[] = 'shop-2-columns';
			} else if ( $shop_columns == 3 ) {
				$classes[] = 'shop-3-columns';
			} else if ( $shop_columns == 4 ) {
				$classes[] = 'shop-4-columns';
			}
		}
	}
	
	// Footer Parallax
	$footer_parallax = get_theme_mod( 'footer_parallax' );
	if ( ! empty( $footer_parallax ) ) {
		$classes[] = 'footer-parallax-enabled';
	}

	return $classes;
}
add_filter( 'body_class', 'mega_body_classes' );

/**
 * Admin CSS/JavaScript.
 */
function mega_enqueue_admin_scripts( $hook ) {
	wp_register_style( 'mega-admin', get_template_directory_uri() . '/css/mega-admin.css' );
	if ( $hook == 'appearance_page_mt-theme-license' || $hook == 'appearance_page_one-click-demo-import' ) {
		wp_enqueue_style( 'mega-admin' );
	}
	
	// WPBakery Page Builder
	if ( ! defined( 'WPB_VC_VERSION' ) ) {
		return;
	}
	wp_register_style( 'mega-js_composer_extend', get_template_directory_uri() . '/vc_extend/assets/css/mega-js_composer_extend.css' );
	wp_register_script( 'mega-js_composer_extend', get_template_directory_uri().'/vc_extend/assets/js/mega-js_composer_extend.js', array(), '', true );
	if ( $hook != 'edit.php' && $hook != 'post.php' && $hook != 'post-new.php' )
		return;
	wp_enqueue_script( 'mega-js_composer_extend' );
	wp_enqueue_style( 'mega-js_composer_extend' );
}
add_action( 'admin_enqueue_scripts', 'mega_enqueue_admin_scripts', 9999 );

/**
 * Easy Social Share Buttons
 */
if ( class_exists( 'ESSB_Manager' ) ) {
	function mega_easy_social_share_buttons_core_js() {
		if ( is_singular() ) {
			wp_dequeue_script( 'easy-social-share-buttons-core' );
			$id = get_queried_object_id();
			$post = get_post( $id );
			$display_in_types = essb_option_value( 'display_in_types' );
			$type = get_post_type();
			if ( is_array( $display_in_types ) ) {
				if ( in_array( $type, $display_in_types ) ) {
					$essb_off = get_post_meta( $post->ID, 'essb_off', true );
					if ( $essb_off !== "true" || isset( $post->post_content ) && has_shortcode( $post->post_content, 'easy-social-share' ) ) {
						wp_enqueue_script( 'easy-social-share-buttons-core' );
					}
				}
			}
		}
	}
	add_action( 'wp_enqueue_scripts', 'mega_easy_social_share_buttons_core_js', 9999 );
}

// Easy Social Share Buttons SVG icon
if ( class_exists( 'ESSB_Manager' ) ) {
	$networks = array( 'facebook', 'twitter' );
	foreach ( $networks as $single ) {
		add_filter( "essb_network_svg_icon_{$single}", function( $custom_svg_icon ) use ( $single ) {
			if ( $single == 'facebook' ) {
				return '<svg viewBox="0 0 32 32"><path d="M16.096 0c-8.896 0-16.096 7.2-16.096 16.096 0 8.032 5.888 14.688 13.6 15.904v-11.264h-4.096v-4.64h4.096v-3.552c0-4.032 2.4-6.272 6.080-6.272 1.76 0 3.584 0.32 3.584 0.32v3.968h-2.016c-2.016 0-2.624 1.248-2.624 2.528v3.008h4.448l-0.704 4.64h-3.744v11.264c7.68-1.216 13.568-7.872 13.568-15.904 0-8.896-7.2-16.096-16.096-16.096z"></path></svg>';
			} else if ( $single == 'twitter' ) {
				return '<svg viewBox="0 0 39 32"><path d="M34.816 8.046c0.024 0.34 0.024 0.681 0.024 1.024 0 10.467-7.969 22.54-22.54 22.54v-0.006c-4.304 0.006-8.519-1.227-12.143-3.551 0.626 0.075 1.255 0.113 1.885 0.114 3.567 0.003 7.032-1.194 9.838-3.398-3.39-0.064-6.362-2.274-7.401-5.501 1.187 0.229 2.411 0.182 3.576-0.136-3.696-0.747-6.354-3.994-6.354-7.765 0-0.034 0-0.067 0-0.1 1.101 0.613 2.334 0.954 3.595 0.991-3.481-2.326-4.554-6.957-2.452-10.577 4.022 4.949 9.956 7.958 16.326 8.276-0.638-2.751 0.234-5.635 2.292-7.569 3.191-2.999 8.209-2.845 11.208 0.344 1.774-0.35 3.474-1.001 5.031-1.923-0.591 1.834-1.829 3.391-3.482 4.381 1.57-0.185 3.104-0.606 4.549-1.247-1.064 1.594-2.403 2.982-3.953 4.104z"></path></svg>';
			} else if ( $single == 'pinterest' ) {
				return '<svg viewBox="0 0 32 32"><path d="M16 0c-8.832 0-16 7.168-16 16 0 6.784 4.224 12.576 10.176 14.912-0.16-1.28-0.256-3.232 0.032-4.608 0.288-1.248 1.888-7.936 1.888-7.936s-0.48-0.96-0.48-2.368c0-2.24 1.28-3.904 2.912-3.904 1.344 0 2.016 1.024 2.016 2.272 0 1.344-0.864 3.424-1.344 5.312-0.384 1.6 0.8 2.912 2.368 2.912 2.848 0 5.056-3.008 5.056-7.328 0-3.84-2.752-6.496-6.688-6.496-4.576 0-7.232 3.392-7.232 6.912 0 1.376 0.512 2.848 1.184 3.648 0.128 0.16 0.128 0.32 0.096 0.48-0.128 0.512-0.384 1.6-0.448 1.824-0.064 0.288-0.224 0.352-0.544 0.192-1.984-0.928-3.264-3.84-3.264-6.208 0-5.024 3.68-9.664 10.592-9.664 5.536 0 9.856 3.936 9.856 9.248 0 5.504-3.456 9.952-8.288 9.952-1.632 0-3.136-0.832-3.68-1.856 0 0-0.8 3.072-0.992 3.808-0.352 1.408-1.312 3.136-1.984 4.224 1.504 0.448 3.072 0.704 4.736 0.704 8.832 0 16-7.168 16-16 0.032-8.864-7.136-16.032-15.968-16.032z"></path></svg>';
			}
		});
	}
}

/**
 * SVG Support
 */
if ( defined( 'BODHI_SVGS_PLUGIN_PATH' ) ) {
	function mega_svg_support_js() {
		if ( bodhi_svgs_advanced_mode() ) {
			wp_dequeue_script( 'bodhi_svg_inline' );
			global $bodhi_svgs_options;
			if ( ! empty( $bodhi_svgs_options['force_inline_svg'] ) ) {

				// set variable as true to pass to js
				$force_inline_svg_active = 'true';

				// set the class for use in JS
				if ( ! empty( $bodhi_svgs_options['css_target'] ) ) {

					// use custom class if set
					$css_target_array = array(
						'Bodhi' => 'img.'. $bodhi_svgs_options['css_target'],
						'ForceInlineSVG' => $bodhi_svgs_options['css_target']
					);

				} else {

					// set default class
					$css_target_array = array(
						'Bodhi' => 'img.style-svg',
						'ForceInlineSVG' => 'style-svg'
					);

				}

			} else {

				// set variable as false to pass to JS
				$force_inline_svg_active = 'false';

				// if custom target is set, use that, otherwise use default
				if ( ! empty( $bodhi_svgs_options['css_target'] ) ) {
					$css_target = 'img.'. $bodhi_svgs_options['css_target'];
				} else {
					$css_target = 'img.style-svg';
				}

				// set the array to target for passing to JS
				$css_target_array = $css_target;

			}
			
			if ( ! empty( $bodhi_svgs_options['use_expanded_js'] ) ) {

				$bodhi_svgs_js_file = '';

			} else {

				$bodhi_svgs_js_file = '-min';

			}
			
			if ( ! empty( $bodhi_svgs_options['js_foot_choice'] ) ) {

				$bodhi_svgs_js_footer = true;

			} else {

				$bodhi_svgs_js_footer = false;

			}
			
			wp_register_script( 'mega-bodhi_svg_inline', get_template_directory_uri() . '/js/svgs-inline' . $bodhi_svgs_js_file . '.js', array(), false, $bodhi_svgs_js_footer );
			wp_enqueue_script( 'mega-bodhi_svg_inline' );
			wp_add_inline_script(
				'mega-bodhi_svg_inline',
				sprintf(
				  'var cssTarget=%s;var ForceInlineSVGActive=%s;',
				  json_encode( $css_target_array ),
				  json_encode( $force_inline_svg_active )
				)
			);
		}
	}
	add_action( 'wp_enqueue_scripts', 'mega_svg_support_js', 9999 );
}

/**
 * CSS/JavaScript.
 */
function mega_enqueue_scripts() {
	wp_register_style( 'mega-style', get_template_directory_uri() . '/style.css' );
	wp_register_style( 'mega-top-bar', get_template_directory_uri() . '/css/top-bar.css' );
	wp_register_style( 'mega-vertical-header', get_template_directory_uri() . '/css/vertical-header.css' );
	wp_register_style( 'mega-vc-row', get_template_directory_uri() . '/css/vc_row.css' );
	wp_register_style( 'mega-vc-pixel-icon', get_template_directory_uri() . '/css/vc_pixel_icon.css' );
	wp_register_style( 'mega-vc-txt-align', get_template_directory_uri() . '/css/vc_txt_align.css' );
	wp_register_style( 'mega-vc-message', get_template_directory_uri() . '/css/vc_message.css' );
	wp_register_style( 'mega-social', get_template_directory_uri() . '/css/social.css' );
	wp_register_style( 'mega-vc-toggle', get_template_directory_uri() . '/css/vc_toggle.css' );
	wp_register_style( 'mega-vc-widget-sidebar', get_template_directory_uri() . '/css/vc_widget_sidebar.css' );
	wp_register_style( 'mega-vc-btn', get_template_directory_uri() . '/css/vc_btn.css' );
	wp_register_style( 'mega-vc-custom-heading', get_template_directory_uri() . '/css/vc_custom_heading.css' );
	wp_register_style( 'mega-vc-cta', get_template_directory_uri() . '/css/vc_cta.css' );
	wp_register_style( 'mega-vc-gmaps', get_template_directory_uri() . '/css/vc_gmaps.css' );
	wp_register_style( 'mega-vc-tabs', get_template_directory_uri() . '/css/vc_tabs.css' );
	wp_register_style( 'mega-vc-accordion', get_template_directory_uri() . '/css/vc_accordion.css' );
	wp_register_style( 'mega-vc-gallery', get_template_directory_uri() . '/css/vc_gallery.css' );
	wp_register_style( 'mega-vc-posts-slider', get_template_directory_uri() . '/css/vc_posts_slider.css' );
	wp_register_style( 'mega-vc-flickr', get_template_directory_uri() . '/css/vc_flickr.css' );
	wp_register_style( 'mega-vc-video', get_template_directory_uri() . '/css/vc_video.css' );
	wp_register_style( 'mega-vc-progress-bar', get_template_directory_uri() . '/css/vc_progress_bar.css' );
	wp_register_style( 'mega-vc-pie', get_template_directory_uri() . '/css/vc_pie.css' );
	wp_register_style( 'mega-vc-separator', get_template_directory_uri() . '/css/vc_separator.css' );
	wp_register_style( 'mega-vc-zigzag', get_template_directory_uri() . '/css/vc_zigzag.css' );
	wp_register_style( 'mega-vc-single-image', get_template_directory_uri() . '/css/vc_single_image.css' );
	wp_register_style( 'mega-vc-icon', get_template_directory_uri() . '/css/vc_icon.css' );
	wp_register_style( 'mega-vc-line-chart', get_template_directory_uri() . '/css/vc_line_chart.css' );
	wp_register_style( 'mega-vc-pagination', get_template_directory_uri() . '/css/vc_pagination.css' );
	wp_register_style( 'mega-vc-grid', get_template_directory_uri() . '/css/vc_grid.css' );
	wp_register_style( 'mega-vc-hoverbox', get_template_directory_uri() . '/css/vc_hoverbox.css' );
	wp_register_style( 'mega-animation', get_template_directory_uri() . '/css/animation.css' );
	wp_register_style( 'mega-isotope', get_template_directory_uri() . '/css/isotope.css' );
	wp_register_style( 'mega-posts', get_template_directory_uri() . '/css/mt-posts.css' );
	wp_register_style( 'mega-gallery', get_template_directory_uri() . '/css/mt-gallery.css' );
	wp_register_style( 'mega-lightgallery', get_template_directory_uri() . '/css/lightgallery.css' );
	wp_register_style( 'mega-lightgallery-custom', get_template_directory_uri() . '/css/lightgallery-custom.css' );
	wp_register_style( 'mega-person', get_template_directory_uri() . '/css/mt-person.css' );
	wp_register_style( 'mega-icon-box', get_template_directory_uri() . '/css/mt-icon-box.css' );
	wp_register_style( 'mega-counting', get_template_directory_uri() . '/css/mt-counting.css' );
	wp_register_style( 'mega-testimonial', get_template_directory_uri() . '/css/mt-testimonial.css' );
	wp_register_style( 'mega-owl-carousel', get_template_directory_uri() . '/css/owl-carousel.css' );
	wp_register_style( 'mega-image-slider-owl', get_template_directory_uri() . '/css/mt-image-slider-owl.css' );
	wp_register_style( 'mega-posts-slider', get_template_directory_uri() . '/css/mt-posts-slider.css' );
	wp_register_style( 'mega-slick', get_template_directory_uri() . '/css/slick.css' );
	wp_register_style( 'mega-swiper', get_template_directory_uri() . '/css/swiper-bundle.css' );
	wp_register_style( 'mega-swiper-custom', get_template_directory_uri() . '/css/swiper-custom.css' );
	wp_register_style( 'mega-team-slider', get_template_directory_uri() . '/css/mt-team-slider.css' );
	wp_register_style( 'mega-testimonials-slider', get_template_directory_uri() . '/css/mt-testimonials-slider.css' );
	wp_register_style( 'mega-lightbox-video', get_template_directory_uri() . '/css/mt-lightbox-video.css' );
	wp_register_style( 'mega-scroll-down-button', get_template_directory_uri() . '/css/mt-scroll-down-button.css' );
	wp_register_style( 'mega-contact-form-7', get_template_directory_uri() . '/css/mt-contact-form-7.css' );
	wp_register_style( 'mega-rev-slider', get_template_directory_uri() . '/css/mt-rev-slider.css' );
	wp_register_style( 'mega-yikes-mailchimp', get_template_directory_uri() . '/css/mt-yikes-mailchimp.css' );
	wp_register_style( 'mega-password-required', get_template_directory_uri() . '/css/mt-password-required.css' );
	wp_register_style( 'mega-search-form', get_template_directory_uri() . '/css/mt-search-form.css' );
	wp_register_style( 'mega-gutenberg', get_template_directory_uri() . '/css/mt-gutenberg.css' );
	wp_register_style( 'mega-widgets', get_template_directory_uri() . '/css/mt-widgets.css' );
	wp_register_style( 'mega-comments', get_template_directory_uri() . '/css/mt-comments.css' );
	wp_register_style( 'mega-single-nav', get_template_directory_uri() . '/css/mt-single-nav.css' );
	wp_register_style( 'mega-essb', get_template_directory_uri() . '/css/mt-essb.css' );
	wp_register_style( 'mega-woocommerce', get_template_directory_uri() . '/css/mega-woocommerce.css' );
	wp_register_style( 'mega-select2', get_template_directory_uri() . '/css/select2.css' );
	wp_register_style( 'mega-slimselect', get_template_directory_uri() . '/css/slimselect.css' );
	wp_register_style( 'mega-slimselect-custom', get_template_directory_uri() . '/css/slimselect-custom.css' );
	wp_register_style( 'mega-flatpickr', get_template_directory_uri() . '/css/flatpickr.css' );
	wp_register_style( 'mega-flatpickr-custom', get_template_directory_uri() . '/css/flatpickr-custom.css' );
	wp_register_style( 'fresco', get_template_directory_uri() . '/css/fresco.css' );
	wp_register_style( 'mega-wpml', get_template_directory_uri() . '/css/mt-wpml.css' );
	wp_enqueue_style( 'mega-style', array() );
	$top_bar = get_theme_mod( 'top_bar' );
	if ( ! empty( $top_bar ) ) {
		wp_enqueue_style( 'mega-top-bar', array( 'mega-style' ) );
	}
	$header_position = get_theme_mod( 'header_position', 'top' );
	if ( $header_position == 'left' || $header_position == 'right' ) {
		wp_enqueue_style( 'mega-vertical-header', array( 'mega-style' ) );
	}
	
	$id = get_queried_object_id();
	$post = get_post( $id );
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_row' ) ) {
		wp_enqueue_style( 'mega-vc-row', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_message' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_basic_grid' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_media_grid' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_masonry_grid' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_masonry_media_grid' )
	) {
		wp_enqueue_style( 'mega-vc-pixel-icon', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_acf' )
	) {
		wp_enqueue_style( 'mega-vc-txt-align', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_message' ) ) {
		wp_enqueue_style( 'mega-vc-message', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_facebook' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_pinterest' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_tweetmeme' )
	) {
		wp_enqueue_style( 'mega-social', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_toggle' ) ) {
		wp_enqueue_style( 'mega-vc-toggle', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_widget_sidebar' ) ) {
		wp_enqueue_style( 'mega-vc-widget-sidebar', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_btn' ) ) {
		wp_enqueue_style( 'mega-vc-btn', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_custom_heading' ) ) {
		wp_enqueue_style( 'mega-vc-custom-heading', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_cta' ) ) {
		wp_enqueue_style( 'mega-vc-cta', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_gmaps' ) ) {
		wp_enqueue_style( 'mega-vc-gmaps', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_tta_tabs' ) ) {
		wp_enqueue_style( 'mega-vc-tabs', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_tta_accordion' ) ) {
		wp_enqueue_style( 'mega-vc-accordion', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_gallery' ) ) {
		wp_enqueue_style( 'mega-vc-gallery', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_posts_slider' ) ) {
		wp_enqueue_style( 'mega-vc-posts-slider', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_flickr' ) ) {
		wp_enqueue_style( 'mega-vc-flickr', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_video' ) ) {
		wp_enqueue_style( 'mega-vc-video', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_progress_bar' ) ) {
		wp_enqueue_style( 'mega-vc-progress-bar', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_pie' ) ) {
		wp_enqueue_style( 'mega-vc-pie', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_separator' ) ||
		isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_text_separator' )
	) {
		wp_enqueue_style( 'mega-vc-separator', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_zigzag' ) ) {
		wp_enqueue_style( 'mega-vc-zigzag', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_single_image' ) ) {
		wp_enqueue_style( 'mega-vc-single-image', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_icon' ) ) {
		wp_enqueue_style( 'mega-vc-icon', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_line_chart' ) ) {
		wp_enqueue_style( 'mega-vc-line-chart', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_tta_accordion' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_tta_tabs' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_tta_tour' )
	) {
		wp_enqueue_style( 'mega-vc-pagination', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_basic_grid' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_media_grid' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_masonry_grid' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_masonry_media_grid' )
	) {
		wp_enqueue_style( 'mega-vc-grid', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_hoverbox' ) ) {
		wp_enqueue_style( 'mega-vc-hoverbox', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_posts' ) || isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_gallery' ) ) {
		wp_enqueue_style( 'mega-isotope', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_posts' ) ) {
		wp_enqueue_style( 'mega-posts', array( 'mega-style' ) );
	}
	
	if ( is_archive() || is_author() || is_category() || is_home() || is_tag() || is_search() ) {
		wp_enqueue_style( 'mega-isotope', array( 'mega-style' ) );
		wp_enqueue_style( 'mega-posts', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_gallery' ) ) {
		wp_enqueue_style( 'mega-gallery', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_person' ) ) {
		wp_enqueue_style( 'mega-person', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_icon_box' ) ) {
		wp_enqueue_style( 'mega-icon-box', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_counting' ) ) {
		wp_enqueue_style( 'mega-counting', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_posts_slider' ) ) {
		wp_enqueue_style( 'mega-owl-carousel', array( 'mega-style' ) );
		wp_enqueue_style( 'mega-posts-slider', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_testimonial' ) ) {
		wp_enqueue_style( 'mega-testimonial', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_lightbox_video' ) ) {
		wp_enqueue_style( 'mega-lightbox-video', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_scroll_down_button' ) ) {
		wp_enqueue_style( 'mega-scroll-down-button', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'contact-form-7' ) ) {
		wp_enqueue_style( 'mega-contact-form-7', array( 'mega-style' ) );
    }
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'rev_slider_vc' ) ) {
		wp_enqueue_style( 'mega-rev-slider', array( 'mega-style' ) );
    }
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'yikes-mailchimp' ) ) {
		wp_enqueue_style( 'mega-yikes-mailchimp', array( 'mega-style' ) );
	}
	
	if ( is_singular() ) {
		if ( $post->post_password && post_password_required() ) {
			wp_enqueue_style( 'mega-password-required', array( 'mega-style' ) );
		}
	}
	
	$search_position = get_theme_mod( 'search_position', 'none' );
	if ( $search_position == 'header' || $search_position == 'top_bar' ) {
		wp_enqueue_style( 'mega-search-form', array( 'mega-style' ) );
	}
	
	if ( ! class_exists( 'DisableGutenberg' ) ) {
		wp_enqueue_style( 'mega-gutenberg', array( 'mega-style' ) );
	}
	
	if ( is_active_widget( 0, 0, 'image' ) ||
		 is_active_widget( 0, 0, 'calendar' ) ||
		 is_active_widget( 0, 0, 'archives' ) ||
		 is_active_widget( 0, 0, 'rss' ) ||
		 is_active_widget( 0, 0, 'tags' ) ||
		 is_active_widget( 0, 0, 'search' ) ||
		 is_active_widget( 0, 0, 'monster' )
	) {
		wp_enqueue_style( 'mega-widgets', array( 'mega-style' ) );
	}
	
	if ( is_singular( array( 'post', 'product' ) ) || is_page() && ! is_page_template() ) {
		wp_enqueue_style( 'mega-comments', array( 'mega-style' ) );
	}
	
	$single_post_navigation = get_theme_mod( 'single_post_navigation' );
	$single_portfolio_navigation = get_theme_mod( 'single_portfolio_navigation' );
	if ( ! empty( $single_post_navigation ) && is_singular( 'post' ) || ! empty( $single_portfolio_navigation ) && is_singular( 'portfolio' ) ) {
		wp_enqueue_style( 'mega-single-nav', array( 'mega-style' ) );
	}
	
	if ( class_exists( 'ESSB_Manager' ) ) {
		if ( is_singular() ) {
			$display_in_types = essb_option_value( 'display_in_types' );
			$type = get_post_type();
			if ( is_array( $display_in_types ) ) {
				if ( in_array( $type, $display_in_types ) ) {
					$essb_off = get_post_meta( $post->ID, 'essb_off', true );
					if ( $essb_off !== "true" || isset( $post->post_content ) && has_shortcode( $post->post_content, 'easy-social-share' ) ) {
						wp_enqueue_style( 'mega-essb', array( 'mega-style' ) );
					}
				}
			}
		}
	}
	
	if ( function_exists( 'icl_object_id' ) ) {
		wp_enqueue_style( 'mega-wpml', array( 'mega-style' ) );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_row' ) ) {
		$pattern = get_shortcode_regex();
		preg_match_all( "/$pattern/", $post->post_content, $matches );
		$vc_row_shortcode = array_keys( $matches[2], 'vc_row' );
		
		foreach( $matches[0] as $key => $row ) {
			
			preg_match_all( '~'. $pattern .'~', $row, $matches );
			preg_match_all( '~'. $pattern .'~', $matches[5][0], $matches2 );
			
			$parsed = shortcode_parse_atts( $matches[3][0] );
			
			foreach( $matches2[0] as $key => $val ) {
				
				preg_match_all( '~'. $pattern .'~', $val, $matches2 );
				preg_match_all( '~'. $pattern .'~', $matches2[5][0], $matches3 );
				
				if ( in_array( 'vc_btn', $matches3[2] ) ) {
					foreach( $matches3[2] as $key => $val ) {
						$parsed = shortcode_parse_atts( $matches3[3][$key] );
						// Pixel icons
						if ( ! empty( $parsed ) ) {
							if ( isset( $parsed['i_type'] ) ) {
								if ( $parsed['i_type'] == 'pixelicons' ) {
									wp_enqueue_style( 'mega-vc-pixel-icon', array( 'mega-style' ) );
								}
							}
						}
					}
				}
			
			}
			
		}
	}
	
	wp_register_script( 'waypoints', get_template_directory_uri() . '/js/noframework.waypoints.min.js', array(), false, true );
	wp_register_script( 'lazysizes-unveilhooks', get_template_directory_uri() . '/js/ls.unveilhooks.min.js', array(), false, true );
	wp_register_script( 'lazysizes', get_template_directory_uri() . '/js/lazysizes.min.js', array(), false, true );
	wp_register_script( 'sliding-menu', get_template_directory_uri() . '/js/sliding-menu.js', array( 'jquery' ), false, true );
	wp_register_script( 'select2', get_template_directory_uri() . '/js/select2.full.min.js', array( 'jquery' ), false, true );
	wp_register_script( 'slimselect', get_template_directory_uri() . '/js/slimselect.min.js', array(), false, true );
	wp_register_script( 'flatpickr', get_template_directory_uri() . '/js/flatpickr.js', array(), false, true );
	wp_register_script( 'vivus', get_template_directory_uri() . '/js/vivus.min.js', array(), false, true );
	wp_register_script( 'countUp', get_template_directory_uri() . '/js/countUp.min.js', array(), false, true );
	wp_register_script( 'barrating', get_template_directory_uri() . '/js/jquery.barrating.min.js', array( 'jquery' ), false, true );
	wp_register_script( 'lightgallery', get_template_directory_uri() . '/js/lightgallery.min.js', array(), false, true );
	wp_register_script( 'fresco', get_template_directory_uri() . '/js/fresco.js', array( 'jquery' ), false, true );
	wp_register_script( 'typed', get_template_directory_uri() . '/js/typed.min.js', array(), false, true );
	wp_register_script( 'isotope-pkgd', get_template_directory_uri() . '/js/isotope.pkgd.min.js', array(), false, true );
	wp_register_script( 'mega-posts', get_template_directory_uri() . '/js/mtposts.js', array( 'isotope-pkgd' ), false, true );
	wp_register_script( 'infinite-scroll', get_template_directory_uri() . '/js/infinite-scroll.pkgd.min.js', array(), false, true );
	wp_register_script( 'mega-gallery', get_template_directory_uri() . '/js/mtgallery.js', array( 'isotope-pkgd' ), false, true );
	wp_register_script( 'owl-carousel', get_template_directory_uri() . '/js/owl.carousel.min.js', array( 'jquery' ), false, true );
	wp_register_script( 'owl-carousel-init', get_template_directory_uri() . '/js/owl-carousel-init.js', array( 'jquery', 'owl-carousel' ), false, true );
	wp_register_script( 'slick', get_template_directory_uri() . '/js/slick.min.js', array( 'jquery' ), false, true );
	wp_register_script( 'slick-init', get_template_directory_uri() . '/js/slick-init.js', array( 'jquery', 'slick' ), false, true );
	wp_register_script( 'swiper', get_template_directory_uri() . '/js/swiper-bundle.min.js', array(), false, true );
	wp_register_script( 'swiper-init', get_template_directory_uri() . '/js/swiper-init.js', array(), false, true );
	wp_register_script( 'mega-vc-row-behaviour', get_template_directory_uri() . '/js/vc-row-behaviour.js', array( 'jquery' ), false, true );
	wp_register_script( 'mega-woocommerce', get_template_directory_uri() . '/js/mt-woocommerce.js', array( 'jquery' ), false, true );
	wp_register_script( 'wc-quantity-increment', get_template_directory_uri() . '/js/wc-quantity-increment.min.js', array( 'jquery' ), false, true );
	wp_register_script( 'mega-add-to-cart-single-product-ajax', get_template_directory_uri() . '/js/add-to-cart-single-product-ajax.js', array( 'jquery' ), false, true );
	wp_register_script( 'color-thief', get_template_directory_uri() . '/js/color-thief.min.js', array(), false, true );
	if ( class_exists( 'ESSB_Manager' ) ) {
		$use_minifed_js = (ESSBGlobalSettings::$use_minified_js) ? '.min' : '';
		wp_register_script( 'easy-social-share-buttons-core', get_template_directory_uri() . '/js/essb-core'. $use_minifed_js .'.js', array(), false, true );
	}
	
	wp_register_script( 'mega-flex-init', get_template_directory_uri() . '/js/flex-init.js', array( 'jquery' ), false, true );
	
	wp_register_script( 'mega-script', get_template_directory_uri() . '/js/script.js', array( 'jquery' ), false, true );
	
	// Sliding Menu
	if ( has_nav_menu( 'sliding' ) ) {
		wp_enqueue_script( 'sliding-menu' );
	}
	
	// Comments
	if ( is_singular( 'post' ) && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
	// WooCommerce
	if ( class_exists( 'woocommerce' ) ) {
		wp_enqueue_style( 'mega-woocommerce' );
		wp_enqueue_script( 'mega-woocommerce' );
		
		$id = get_queried_object_id();
		$post = get_post( $id );
		
		// Single Product Slider
		if ( is_product() || ( ! empty( $post->post_content ) && strstr( $post->post_content, '[product_page' ) ) ) {
			wp_enqueue_script( 'slick' );
			wp_enqueue_script( 'slick-init' );
		}
		
		// Quantity Increment
		if ( is_product() || ( ! empty( $post->post_content ) && strstr( $post->post_content, '[product_page' ) ) || is_cart() ) {
			wp_enqueue_script( 'wc-quantity-increment' );
		}
		
		// Related Products Slider on Single Product Page
		$related_products_slider_on_single_product_page = get_theme_mod( 'related_products_slider_on_single_product_page' );
		if ( ! empty( $related_products_slider_on_single_product_page ) ) {
			if ( is_product() || ( ! empty( $post->post_content ) && strstr( $post->post_content, '[product_page' ) ) ) {
				wp_enqueue_script( 'owl-carousel' );
				wp_enqueue_script( 'owl-carousel-init' );
			}
		}
		
		// AJAX Add to Cart Button on Single Product Page
		if ( is_product() || ( ! empty( $post->post_content ) && strstr( $post->post_content, '[product_page' ) ) ) {
			wp_enqueue_script( 'mega-add-to-cart-single-product-ajax' );
		}
		
		// Single Product Lightbox
		wp_dequeue_script( 'prettyPhoto' );
		wp_dequeue_script( 'prettyPhoto-init' );
		wp_dequeue_style( 'woocommerce_prettyPhoto_css' );
		if ( ( is_product() || ( ! empty( $post->post_content ) && strstr( $post->post_content, '[product_page' ) ) ) ) {
			wp_enqueue_script( 'fresco' );
			wp_enqueue_style( 'fresco', array() );
		}
		
		// Single Product
		wp_dequeue_script( 'wc-single-product' );
		wp_register_script( 'mega-wc-single-product', get_template_directory_uri() . '/js/single-product.js', array( 'jquery' ), false, true );
		if ( is_product() || ( ! empty( $post->post_content ) && strstr( $post->post_content, '[product_page' ) ) ) {
			wp_localize_script( 'mega-wc-single-product', 'wc_single_product_params', array( 'i18n_required_rating_text' => esc_attr__( 'Please select a rating', 'skylab' ), 'review_rating_required' => get_option( 'woocommerce_review_rating_required' ) ) );
			wp_enqueue_script( 'mega-wc-single-product' );
		}
		
		// Rating
		if ( is_product() || ( ! empty( $post->post_content ) && strstr( $post->post_content, '[product_page' ) ) ) {
			wp_enqueue_script( 'barrating' );
		}
		
		// select2 dropdowns
		if ( is_account_page() || is_cart() || is_product() || ( ! empty( $post->post_content ) && strstr( $post->post_content, '[product_page' ) ) || is_shop() || is_product_category() || is_product_tag() || is_checkout() ) {
			wp_dequeue_style( 'select2' );
			wp_enqueue_style( 'mega-select2' );
			wp_enqueue_script( 'select2' );
		}
		
	}
	
	// Posts
	if ( is_home() || is_archive() || is_author() || is_category() || is_tag() || is_search() ) {
		wp_enqueue_script( 'lazysizes' );
		wp_enqueue_script( 'isotope-pkgd' );
		wp_enqueue_script( 'waypoints' );
		wp_enqueue_script( 'mega-posts' );
		wp_enqueue_script( 'infinite-scroll' );
	}
	
	if ( is_singular( 'post' ) && has_post_thumbnail( $post ) ) {
		wp_enqueue_script( 'lazysizes' );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_image_slider' ) ) {
		wp_enqueue_style( 'mega-swiper', array( 'mega-style' ) );
		wp_enqueue_style( 'mega-swiper-custom', array( 'mega-style' ) );
		wp_enqueue_script( 'swiper' );
		wp_enqueue_script( 'swiper-init' );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_row' ) ) {
		$pattern = get_shortcode_regex();
		preg_match_all( "/$pattern/", $post->post_content, $matches );
		$vc_row_shortcode = array_keys( $matches[2], 'vc_row' );
		
		foreach( $matches[0] as $key => $row ) {
		
			preg_match_all( '~'. $pattern .'~', $row, $matches );
			preg_match_all( '~'. $pattern .'~', $matches[5][0], $matches2 );
			
			$parsed = shortcode_parse_atts( $matches[3][0] );
			
			if ( ! empty( $parsed ) ) {
				
				// CSS animation
				if ( isset( $parsed['css_animation'] ) ) {
					if ( strpos( $parsed['css_animation'], 'none' ) === false ) {
						wp_enqueue_style( 'mega-animation', array( 'mega-style' ) );
						wp_enqueue_script( 'waypoints' );
					}
				}
			
				if ( isset( $parsed['el_class'] ) ) {
					// Slim Select
					if ( strpos( $parsed['el_class'], 'select2-enabled' ) !== false ) {
						wp_enqueue_style( 'mega-slimselect', array( 'mega-style' ) );
						wp_enqueue_style( 'mega-slimselect-custom', array( 'mega-style' ) );
						wp_enqueue_script( 'slimselect' );
					}
					// flatpickr
					if ( strpos( $parsed['el_class'], 'datepicker-enabled' ) !== false ) {
						wp_enqueue_style( 'mega-flatpickr', array( 'mega-style' ) );
						wp_enqueue_style( 'mega-flatpickr-custom', array( 'mega-style' ) );
						wp_enqueue_script( 'flatpickr' );
					}
					// typed
					if ( strpos( $parsed['el_class'], 'typed-enabled' ) !== false ) {
						wp_enqueue_script( 'typed' );
					}
					// lazysizes
					if ( strpos( $parsed['el_class'], 'vc_parallax-lazy' ) !== false ) {
						wp_enqueue_script( 'lazysizes-unveilhooks' );
						wp_enqueue_script( 'lazysizes' );
					}
				}
			
				if ( isset( $parsed['full_width'] ) ||
					isset( $parsed['full_height'] ) ||
					isset( $parsed['video_bg'] ) ||
					isset( $parsed['parallax'] )
				) {
					wp_enqueue_script( 'mega-vc-row-behaviour' );
				}
			
			}
			
			foreach( $matches2[0] as $key => $val ) {
			
				preg_match_all( '~'. $pattern .'~', $val, $matches2 );
				preg_match_all( '~'. $pattern .'~', $matches2[5][0], $matches3 );
				
				foreach( $matches3[2] as $key => $val ) {
					$parsed = shortcode_parse_atts( $matches3[3][$key] );
					if ( ! empty( $parsed ) ) {
						// CSS animation
						if ( ! empty( $parsed['css_animation'] ) ) {
							if ( strpos( $parsed['css_animation'], 'none' ) === false ) {
								wp_enqueue_style( 'mega-animation', array( 'mega-style' ) );
								wp_enqueue_script( 'waypoints' );
							}
						}
					}
				}
				
				if ( in_array( 'vc_gallery', $matches3[2] ) || in_array( 'vc_posts_slider', $matches3[2] ) ) {
					foreach( $matches3[2] as $key => $val ) {
						$parsed = shortcode_parse_atts( $matches3[3][$key] );
						// flex
						if ( ! empty( $parsed ) ) {
							if ( $parsed['type'] == 'flexslider_slide' ) {
								wp_enqueue_script( 'mega-flex-init' );
							}
						}
					}
				}
				
				$mt_vc_single_image_shortcode = array_keys( $matches3[2], 'vc_single_image' );
				if ( ! empty( $mt_vc_single_image_shortcode ) ) {
					foreach( $matches3[2] as $key => $val ) {
						$parsed = shortcode_parse_atts( $matches3[3][$key] );
						if ( ! empty( $parsed ) ) {
							// lazysizes
							if ( ! empty( $parsed['lazyload'] ) ) {
								if ( $parsed['lazyload'] == '1' ) {
									wp_enqueue_script( 'lazysizes' );
								}
							}
						}
					}
				}
				
				$mt_vc_gallery_shortcode = array_keys( $matches3[2], 'mt_vc_gallery' );
				if ( ! empty( $mt_vc_gallery_shortcode ) ) {
					foreach( $matches3[2] as $key => $val ) {
						$parsed = shortcode_parse_atts( $matches3[3][$key] );
						if ( ! empty( $parsed ) ) {
							// lightGallery
							if ( ! array_key_exists( 'onclick', $parsed ) ) {
								wp_enqueue_style( 'mega-lightgallery', array( 'mega-style' ) );
								wp_enqueue_style( 'mega-lightgallery-custom', array( 'mega-style' ) );
							}
						}
					}
				}
			
			}
		
		}
		
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_tta_team_slider' ) ) {
		wp_enqueue_style( 'mega-slick', array( 'mega-style' ) );
		wp_enqueue_style( 'mega-team-slider', array( 'mega-style' ) );
		wp_enqueue_script( 'slick' );
		wp_enqueue_script( 'slick-init' );
	}
	
	if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_tta_testimonials' ) ) {
		wp_enqueue_style( 'mega-swiper', array( 'mega-style' ) );
		wp_enqueue_style( 'mega-swiper-custom', array( 'mega-style' ) );
		wp_enqueue_style( 'mega-testimonials-slider', array( 'mega-style' ) );
		wp_enqueue_script( 'swiper' );
		wp_enqueue_script( 'swiper-init' );
	}
	
	if ( has_custom_logo() ) {
		wp_enqueue_script( 'imagesloaded' );
	}
	
	wp_enqueue_script( 'mega-script' );
	
}
add_action( 'wp_enqueue_scripts', 'mega_enqueue_scripts', 10 );

/**
 * Page opacity.
 */
function mega_page_opacity_init() {
	$output = '<style data-exclude="true">.hidden #page{opacity:0;visibility:hidden;}';
	$output .='
	</style>';
	echo trim( $output );
}
add_action( 'wp_head', 'mega_page_opacity_init', 0 );

/**
 * Pace options.
 */
function mega_page_load_progress_indicator_init() {
	$page_load_progress_bar_color = get_theme_mod( 'page_load_progress_bar_color', '#000000' );
	$page_load_progress_indicator_color = get_theme_mod( 'page_load_progress_indicator_color', '#999999' );
	$page_load_progress_indicator = get_theme_mod( 'page_load_progress_indicator', 'progress_bar' );
	$output = '<script data-exclude="true">paceOptions = { ajax: false, document: false, restartOnPushState: false, }</script>
	<style data-exclude="true">.pace{position:fixed;top:0;left:0;width:100%;height:2px;z-index:100000;transform-origin:bottom right}.pace .pace-progress{background:'. $page_load_progress_bar_color .';position:absolute;z-index:2000;top:0;right:100%;width:100%;height:2px}.pace .pace-activity{display:block;position:fixed;z-index:2000;width:40px;top:50%;left:50%;transform:translate(-50%,-50%);opacity:0;transition:all .35s ease}.pace .pace-activity.is-active{animation:visible .1s forwards ease}.pace .pace-activity.is-inactive{animation:hidden .1s forwards ease}.pace .pace-activity:before{content:"";display:block;padding-top:100%}.pace .pace-activity .circular{animation:rotate 1s linear infinite;height:100%;transform-origin:center center;width:100%;position:absolute;top:0;bottom:0;left:0;right:0;margin:auto}.pace .pace-activity .path{stroke:'. $page_load_progress_indicator_color .';stroke-dasharray:1,200;stroke-dashoffset:0;animation:dash 1.5s ease-in-out infinite;stroke-linecap:round}@keyframes dash{0%{stroke-dasharray:1,200;stroke-dashoffset:0}50%{stroke-dasharray:89,200;stroke-dashoffset:-35px}100%{stroke-dasharray:89,200;stroke-dashoffset:-124px}}@keyframes fadeOutPace{0%{transform:scaleX(100)}100%{transform:scaleX(0)}}.pace-inactive{animation:fadeOutPace .7s cubic-bezier(0,.9,.3,1) forwards 0s}.pace .pace-progress-percent,.pace .pace-progress-site-title,.progress-bar .pace .pace-activity{display:none}.progress-bar-with-circle .pace .pace-activity{display:block}';
	$output .='
	</style>
	<script data-exclude="true">
	/*!
 * pace.js v1.2.3
 * https://github.com/CodeByZach/pace/
 * Licensed MIT © HubSpot, Inc.
 */
(function(){function o(t,e){return function(){return t.apply(e,arguments)}}var u,c,i,n,y,t,l,v,r,s,a,e,p,w,b,h,f,d,g,m,k,S,q,x,L,P,T,R,j,O,E,M,A,C,N,_,F,U,W,X,D,H,I,z,G,B=[].slice,J={}.hasOwnProperty,K=function(t,e){for(var n in e)J.call(e,n)&&(t[n]=e[n]);function r(){this.constructor=t}return r.prototype=e.prototype,t.prototype=new r,t.__super__=e.prototype,t},Q=[].indexOf||function(t){for(var e=0,n=this.length;e<n;e++)if(e in this&&this[e]===t)return e;return-1};function V(){}for(f={className:"",catchupTime:100,initialRate:.03,minTime:250,ghostTime:100,maxProgressPerFrame:20,easeFactor:1.25,startOnPageLoad:!0,restartOnPushState:!0,restartOnRequestAfter:500,target:"body",elements:{checkInterval:100,selectors:["body"]},eventLag:{minSamples:10,sampleCount:3,lagThreshold:3},ajax:{trackMethods:["GET"],trackWebSockets:!0,ignoreURLs:[]}},L=function(){var t;return null!=(t="undefined"!=typeof performance&&null!==performance&&"function"==typeof performance.now?performance.now():void 0)?t:+new Date},T=window.requestAnimationFrame||window.mozRequestAnimationFrame||window.webkitRequestAnimationFrame||window.msRequestAnimationFrame,h=window.cancelAnimationFrame||window.mozCancelAnimationFrame,a=function(t,e,n){return("function"==typeof t.addEventListener?t.addEventListener(e,n,!1):void 0)||(t["on"+e]=n)},null==T&&(T=function(t){return setTimeout(t,50)},h=function(t){return clearTimeout(t)}),j=function(e){var n=L(),r=function(){var t=L()-n;return 33<=t?(n=L(),e(t,function(){return T(r)})):setTimeout(r,33-t)};return r()},R=function(){var t=arguments[0],e=arguments[1],n=3<=arguments.length?B.call(arguments,2):[];return"function"==typeof t[e]?t[e].apply(t,n):t[e]},d=function(){for(var t,e,n,r=arguments[0],s=2<=arguments.length?B.call(arguments,1):[],o=0,i=s.length;o<i;o++)if(e=s[o])for(t in e)J.call(e,t)&&(n=e[t],null!=r[t]&&"object"==typeof r[t]&&null!=n&&"object"==typeof n?d(r[t],n):r[t]=n);return r},p=function(t){for(var e,n,r=e=0,s=0,o=t.length;s<o;s++)n=t[s],r+=Math.abs(n),e++;return r/e},m=function(t,e){var n,r;if(null==t&&(t="options"),null==e&&(e=!0),r=document.querySelector("[data-pace-"+t+"]")){if(n=r.getAttribute("data-pace-"+t),!e)return n;try{return JSON.parse(n)}catch(t){return"undefined"!=typeof console&&null!==console?console.error("Error parsing inline pace options",t):void 0}}},V.prototype.on=function(t,e,n,r){var s;return null==r&&(r=!1),null==this.bindings&&(this.bindings={}),null==(s=this.bindings)[t]&&(s[t]=[]),this.bindings[t].push({handler:e,ctx:n,once:r})},V.prototype.once=function(t,e,n){return this.on(t,e,n,!0)},V.prototype.off=function(t,e){var n,r,s;if(null!=(null!=(r=this.bindings)?r[t]:void 0)){if(null==e)return delete this.bindings[t];for(n=0,s=[];n<this.bindings[t].length;)this.bindings[t][n].handler===e?s.push(this.bindings[t].splice(n,1)):s.push(n++);return s}},V.prototype.trigger=function(){var t,e,n,r,s,o,i=arguments[0],a=2<=arguments.length?B.call(arguments,1):[];if(null!=(r=this.bindings)&&r[i]){for(n=0,o=[];n<this.bindings[i].length;)e=(s=this.bindings[i][n]).handler,t=s.ctx,s=s.once,e.apply(null!=t?t:this,a),s?o.push(this.bindings[i].splice(n,1)):o.push(n++);return o}},G=V,y=window.Pace||{},window.Pace=y,d(y,G.prototype),P=y.options=d({},f,window.paceOptions,m()),W=0,D=(I=["ajax","document","eventLag","elements"]).length;W<D;W++)!0===P[A=I[W]]&&(P[A]=f[A]);function Y(){return Y.__super__.constructor.apply(this,arguments)}function Z(){this.progress=0}function $(){this.bindings={}}function tt(){var e,o=this;tt.__super__.constructor.apply(this,arguments),e=function(r){var s=r.open;return r.open=function(t,e,n){return M(t)&&o.trigger("request",{type:t,url:e,request:r}),s.apply(r,arguments)}},window.XMLHttpRequest=function(t){t=new U(t);return e(t),t};try{g(window.XMLHttpRequest,U)}catch(t){}if(null!=F){window.XDomainRequest=function(){var t=new F;return e(t),t};try{g(window.XDomainRequest,F)}catch(t){}}if(null!=_&&P.ajax.trackWebSockets){window.WebSocket=function(t,e){var n=null!=e?new _(t,e):new _(t);return M("socket")&&o.trigger("request",{type:"socket",url:t,protocols:e,request:n}),n};try{g(window.WebSocket,_)}catch(t){}}}function et(){this.complete=o(this.complete,this);var t=this;this.elements=[],k().on("request",function(){return t.watch.apply(t,arguments)})}function nt(t){var e,n,r,s;for(null==t&&(t={}),this.complete=o(this.complete,this),this.elements=[],null==t.selectors&&(t.selectors=[]),n=0,r=(s=t.selectors).length;n<r;n++)e=s[n],this.elements.push(new i(e,this.complete))}function rt(t,e){this.selector=t,this.completeCallback=e,this.progress=0,this.check()}function st(){var t,e,n=this;this.progress=null!=(e=this.states[document.readyState])?e:100,t=document.onreadystatechange,document.onreadystatechange=function(){return null!=n.states[document.readyState]&&(n.progress=n.states[document.readyState]),"function"==typeof t?t.apply(null,arguments):void 0}}function ot(t){this.source=t,this.last=this.sinceLastUpdate=0,this.rate=P.initialRate,this.catchup=0,this.progress=this.lastProgress=0,null!=this.source&&(this.progress=R(this.source,"progress"))}G=Error,K(Y,G),n=Y,Z.prototype.getElement=function(){var t;if(null==this.el){if(!(t=document.querySelector(P.target)))throw new n;this.el=document.createElement("div"),this.el.className="pace pace-active",document.body.className=document.body.className.replace(/(pace-done )|/,"pace-running ");var e=""!==P.className?" "+P.className:"";this.el.innerHTML=\'<div class="pace-progress\'+e+\'">\n  <div class="pace-progress-inner"></div>\n</div>\n<div class="pace-activity"></div>\',null!=t.firstChild?t.insertBefore(this.el,t.firstChild):t.appendChild(this.el)}return this.el},Z.prototype.finish=function(){var t=this.getElement();return t.className=t.className.replace("pace-active","pace-inactive"),document.body.className=document.body.className.replace("pace-running ","pace-done ")},Z.prototype.update=function(t){return this.progress=t,y.trigger("progress",t),this.render()},Z.prototype.destroy=function(){try{this.getElement().parentNode.removeChild(this.getElement())}catch(t){n=t}return this.el=void 0},Z.prototype.render=function(){var t,e,n,r,s,o,i;if(null==document.querySelector(P.target))return!1;for(t=this.getElement(),r="translate3d("+this.progress+"%, 0, 0)",s=0,o=(i=["webkitTransform","msTransform","transform"]).length;s<o;s++)e=i[s],t.children[0].style[e]=r;return(!this.lastRenderedProgress||this.lastRenderedProgress|0!==this.progress|0)&&(t.children[0].setAttribute("data-progress-text",(0|this.progress)+"%"),100<=this.progress?n="99":(n=this.progress<10?"0":"",n+=0|this.progress),t.children[0].setAttribute("data-progress",""+n)),y.trigger("change",this.progress),this.lastRenderedProgress=this.progress},Z.prototype.done=function(){return 100<=this.progress},c=Z,$.prototype.trigger=function(t,e){var n,r,s,o,i;if(null!=this.bindings[t]){for(i=[],r=0,s=(o=this.bindings[t]).length;r<s;r++)n=o[r],i.push(n.call(this,e));return i}},$.prototype.on=function(t,e){var n;return null==(n=this.bindings)[t]&&(n[t]=[]),this.bindings[t].push(e)},m=$,U=window.XMLHttpRequest,F=window.XDomainRequest,_=window.WebSocket,g=function(t,e){var n,r=[];for(n in e.prototype)try{null==t[n]&&"function"!=typeof e[n]?"function"==typeof Object.defineProperty?r.push(Object.defineProperty(t,n,{get:function(t){return function(){return e.prototype[t]}}(n),configurable:!0,enumerable:!0})):r.push(t[n]=e.prototype[n]):r.push(void 0)}catch(t){0}return r},q=[],y.ignore=function(){var t=arguments[0],e=2<=arguments.length?B.call(arguments,1):[];return q.unshift("ignore"),e=t.apply(null,e),q.shift(),e},y.track=function(){var t=arguments[0],e=2<=arguments.length?B.call(arguments,1):[];return q.unshift("track"),e=t.apply(null,e),q.shift(),e},M=function(t){if(null==t&&(t="GET"),"track"===q[0])return"force";if(!q.length&&P.ajax){if("socket"===t&&P.ajax.trackWebSockets)return!0;if(t=t.toUpperCase(),0<=Q.call(P.ajax.trackMethods,t))return!0}return!1},K(tt,m),t=tt,X=null,E=function(t){for(var e,n=P.ajax.ignoreURLs,r=0,s=n.length;r<s;r++)if("string"==typeof(e=n[r])){if(-1!==t.indexOf(e))return!0}else if(e.test(t))return!0;return!1},(k=function(){return null==X&&(X=new t),X})().on("request",function(t){var o,i=t.type,a=t.request,e=t.url;if(!E(e))return y.running||!1===P.restartOnRequestAfter&&"force"!==M(i)?void 0:(o=arguments,"boolean"==typeof(e=P.restartOnRequestAfter||0)&&(e=0),setTimeout(function(){var t,e,n,r,s="socket"===i?a.readyState<1:0<(s=a.readyState)&&s<4;if(s){for(y.restart(),r=[],t=0,e=(n=y.sources).length;t<e;t++){if((A=n[t])instanceof u){A.watch.apply(A,o);break}r.push(void 0)}return r}},e))}),et.prototype.watch=function(t){var e=t.type,n=t.request,t=t.url;if(!E(t))return n=new("socket"===e?r:s)(n,this.complete),this.elements.push(n)},et.prototype.complete=function(e){return this.elements=this.elements.filter(function(t){return t!==e})},u=et,s=function(e,n){var t,r,s,o,i=this;if(this.progress=0,null!=window.ProgressEvent)for(a(e,"progress",function(t){return t.lengthComputable?i.progress=100*t.loaded/t.total:i.progress=i.progress+(100-i.progress)/2}),t=0,r=(o=["load","abort","timeout","error"]).length;t<r;t++)a(e,o[t],function(){return n(i),i.progress=100});else s=e.onreadystatechange,e.onreadystatechange=function(){var t;return 0===(t=e.readyState)||4===t?(n(i),i.progress=100):3===e.readyState&&(i.progress=50),"function"==typeof s?s.apply(null,arguments):void 0}},r=function(t,e){for(var n,r=this,s=this.progress=0,o=(n=["error","open"]).length;s<o;s++)a(t,n[s],function(){return e(r),r.progress=100})},nt.prototype.complete=function(e){return this.elements=this.elements.filter(function(t){return t!==e})},G=nt,rt.prototype.check=function(){var t=this;return document.querySelector(this.selector)?this.done():setTimeout(function(){return t.check()},P.elements.checkInterval)},rt.prototype.done=function(){return this.completeCallback(this),this.completeCallback=null,this.progress=100},i=rt,st.prototype.states={loading:0,interactive:50,complete:100},K=st,m=function(){var e,n,r,s,o,i=this;this.progress=0,o=[],s=0,r=L(),n=setInterval(function(){var t=L()-r-50;return r=L(),o.push(t),o.length>P.eventLag.sampleCount&&o.shift(),e=p(o),++s>=P.eventLag.minSamples&&e<P.eventLag.lagThreshold?(i.progress=100,clearInterval(n)):i.progress=3/(e+3)*100},50)},ot.prototype.tick=function(t,e){return null==e&&(e=R(this.source,"progress")),100<=e&&(this.done=!0),e===this.last?this.sinceLastUpdate+=t:(this.sinceLastUpdate&&(this.rate=(e-this.last)/this.sinceLastUpdate),this.catchup=(e-this.progress)/P.catchupTime,this.sinceLastUpdate=0,this.last=e),e>this.progress&&(this.progress+=this.catchup*t),e=1-Math.pow(this.progress/100,P.easeFactor),this.progress+=e*this.rate*t,this.progress=Math.min(this.lastProgress+P.maxProgressPerFrame,this.progress),this.progress=Math.max(0,this.progress),this.progress=Math.min(100,this.progress),this.lastProgress=this.progress,this.progress},v=ot,b=e=N=w=O=C=null,y.running=!1,S=function(){if(P.restartOnPushState)return y.restart()},null!=window.history.pushState&&(H=window.history.pushState,window.history.pushState=function(){return S(),H.apply(window.history,arguments)}),null!=window.history.replaceState&&(z=window.history.replaceState,window.history.replaceState=function(){return S(),z.apply(window.history,arguments)}),l={ajax:u,elements:G,document:K,eventLag:m},(x=function(){var t,e,n,r,s,o,i,a;for(y.sources=C=[],e=0,r=(o=["ajax","elements","document","eventLag"]).length;e<r;e++)!1!==P[t=o[e]]&&C.push(new l[t](P[t]));for(n=0,s=(a=null!=(i=P.extraSources)?i:[]).length;n<s;n++)A=a[n],C.push(new A(P));return y.bar=w=new c,O=[],N=new v})(),y.stop=function(){return y.trigger("stop"),y.running=!1,w.destroy(),b=!0,null!=e&&("function"==typeof h&&h(e),e=null),x()},y.restart=function(){return y.trigger("restart"),y.stop(),y.start()},y.go=function(){var m;return y.running=!0,w.render(),m=L(),b=!1,e=j(function(t,e){w.progress;for(var n,r,s,o,i,a,u,c,l,p,h=a=0,f=!0,d=u=0,g=C.length;u<g;d=++u)for(A=C[d],i=null!=O[d]?O[d]:O[d]=[],s=c=0,l=(r=null!=(p=A.elements)?p:[A]).length;c<l;s=++c)o=r[s],f&=(o=null!=i[s]?i[s]:i[s]=new v(o)).done,o.done||(h++,a+=o.tick(t));return n=a/h,w.update(N.tick(t,n)),w.done()||f||b?(w.update(100),y.trigger("done"),setTimeout(function(){return w.finish(),y.running=!1,y.trigger("hide")},Math.max(P.ghostTime,Math.max(P.minTime-(L()-m),0)))):e()})},y.start=function(t){d(P,t),y.running=!0;try{w.render()}catch(t){n=t}return document.querySelector(".pace")?(y.trigger("start"),y.go()):setTimeout(y.start,50)},"function"==typeof define&&define.amd?define(function(){return y}):"object"==typeof exports?module.exports=y:P.startOnPageLoad&&y.start()}).call(this);
	</script>
	<script data-exclude="true">';
	
	$output .='
	Pace.on("start", function() {
		// Circle
		var paceActivity=document.querySelector(".pace-activity");var paceCircular=\'<svg class="circular" viewBox="25 25 50 50"><circle class="path" cx="50" cy="50" r="20" fill="none" stroke-width="6" stroke-miterlimit="10"/></svg>\';paceActivity.insertAdjacentHTML("beforeend",paceCircular)';
		
	$output .='
	});';
	$output .='
	</script>';
	if ( $page_load_progress_indicator != 'disabled' ) {
		echo trim( $output );
	}
}
add_action( 'wp_head', 'mega_page_load_progress_indicator_init', 0 );

/**
 * Fontello icons.
 */
function mega_fontello_icons_init() {
	$output = '
	<style>
	/* =Fontello icons
	----------------------------------------------- */
	@font-face {
		font-family: "fontello";
		src: url("'. get_template_directory_uri() .'/fonts/fontello/fontello.woff2") format("woff2");
		font-weight: normal;
		font-style: normal;
	}
	</style>
	<link rel="preload" href="'. get_template_directory_uri() .'/fonts/fontello/fontello.woff2" as="font" type="font/woff2" crossorigin>';
	echo trim( $output );
}
add_action( 'wp_head', 'mega_fontello_icons_init', 0 );

/**
 * JavaScript.
 */
function mega_initialize_javascript() {
?>
	<?php $id = get_queried_object_id(); ?>
	<?php $post = get_post( $id ); ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_pinterest' ) ) { ?>
<script>
jQuery(function($) {
  "use strict";
  // vc_pinterest
  vc_pinterest();
  function vc_pinterest() {
	0 < jQuery(".wpb_pinterest").length && function() {
	  var po = document.createElement("script");
	  po.type = "text/javascript",
	  po.async = !0,
	  po.src = "https://assets.pinterest.com/js/pinit.js";
	  var s = document.getElementsByTagName("script")[0];
	  s.parentNode.insertBefore(po, s)
	}()
  }
});
</script>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_progress_bar' ) ) { ?>
<script>
jQuery(function($) {
  "use strict";
  // vc_progress_bar
  vc_progress_bar();
  function vc_progress_bar() {
    void 0 !== jQuery.fn.waypoint && jQuery(".vc_progress_bar").each(function() {
    var $el = jQuery(this);
    $el.waypoint(function() {
      $el.find(".vc_single_bar").each(function(index) {
      var bar = jQuery(this).find(".vc_bar")
        , val = bar.data("percentage-value");
      setTimeout(function() {
        bar.css({
        width: val + "%"
        })
      }, 200 * index)
      })
    }, {
      offset: "85%"
    })
    })
  }
});
</script>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_toggle' ) ) { ?>
<script>
jQuery(function($) {
  "use strict";
  // vc_toggle
  vc_toggleBehaviour();
  function vc_toggleBehaviour($el) {
    function event(content) {
      content && content.preventDefault && content.preventDefault();
      var element = jQuery(this).closest(".vc_toggle")
        , content = element.find(".vc_toggle_content");
      element.hasClass("vc_toggle_active") ? content.slideUp({
        duration: 300,
        complete: function() {
          element.removeClass("vc_toggle_active")
        }
      }) : content.slideDown({
        duration: 300,
        complete: function() {
          element.addClass("vc_toggle_active")
        }
      })
    }
    ($el ? $el.hasClass("vc_toggle_title") ? $el.unbind("click") : $el.find(".vc_toggle_title").off("click") : jQuery(".vc_toggle_title").off("click")).on("click", event)
  }
});
</script>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_tta_tabs' ) ) { ?>
<script>
jQuery(function($) {
  "use strict";
  // vc_tta_tabs
  vc_tabsBehaviour();
  function vc_tabsBehaviour(ver) {
    var $call, old_version;
    jQuery.ui && ($call = ver || jQuery(".wpb_tabs, .wpb_tour"),
    ver = jQuery.ui && jQuery.ui.version ? jQuery.ui.version.split(".") : "1.10",
    old_version = 1 === parseInt(ver[0], 10) && parseInt(ver[1], 10) < 9,
    $call.each(function(index) {
      var interval = jQuery(this).attr("data-interval")
        , tabs_array = []
        , $tabs = jQuery(this).find(".wpb_tour_tabs_wrapper").tabs({
        show: function(event, ui) {
          wpb_prepare_tab_content(event, ui)
        },
        activate: function(event, ui) {
          wpb_prepare_tab_content(event, ui)
        }
      });
      if (interval && 0 < interval)
        try {
          $tabs.tabs("rotate", 1e3 * interval)
        } catch (err) {
          window.console && window.console.warn && console.warn("tabs behaviours error", err)
        }
      jQuery(this).find(".wpb_tab").each(function() {
        tabs_array.push(this.id)
      }),
      jQuery(this).find(".wpb_tabs_nav li").on("click", function(e) {
        return e && e.preventDefault && e.preventDefault(),
        old_version ? $tabs.tabs("select", jQuery("a", this).attr("href")) : $tabs.tabs("option", "active", jQuery(this).index()),
        !1
      }),
      jQuery(this).find(".wpb_prev_slide a, .wpb_next_slide a").on("click", function(length) {
        var index;
        length && length.preventDefault && length.preventDefault(),
        old_version ? (index = $tabs.tabs("option", "selected"),
        jQuery(this).parent().hasClass("wpb_next_slide") ? index++ : index--,
        index < 0 ? index = $tabs.tabs("length") - 1 : index >= $tabs.tabs("length") && (index = 0),
        $tabs.tabs("select", index)) : (index = $tabs.tabs("option", "active"),
        length = $tabs.find(".wpb_tab").length,
        index = jQuery(this).parent().hasClass("wpb_next_slide") ? length <= index + 1 ? 0 : index + 1 : index - 1 < 0 ? length - 1 : index - 1,
        $tabs.tabs("option", "active", index))
      })
    }))
  }
});
</script>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_tta_accordion' ) ) { ?>
<script>
jQuery(function($) {
  "use strict";
  // vc_tta_accordion
  vc_accordionBehaviour();
  function vc_accordionBehaviour() {
    jQuery(".wpb_accordion").each(function(index) {
      var $this = jQuery(this)
        , active_tab = ($this.attr("data-interval"),
      !isNaN(jQuery(this).data("active-tab")) && 0 < parseInt($this.data("active-tab"), 10) && parseInt($this.data("active-tab"), 10) - 1)
        , $tabs = !1 === active_tab || "yes" === $this.data("collapsible")
        , $tabs = $this.find(".wpb_accordion_wrapper").accordion({
        header: "> div > h3",
        autoHeight: !1,
        heightStyle: "content",
        active: active_tab,
        collapsible: $tabs,
        navigation: !0,
        activate: vc_accordionActivate,
        change: function(event, ui) {
          void 0 !== jQuery.fn.isotope && ui.newContent.find(".isotope").isotope("layout")
        }
      });
      !0 === $this.data("vcDisableKeydown") && ($tabs.data("uiAccordion")._keydown = function() {}
      )
    })
  }
  
  vc_ttaActivation();
  
  function wpb_prepare_tab_content(event, ui) {
    var panel = ui.panel || ui.newPanel
      , $pie_charts = panel.find(".vc_pie_chart:not(.vc_ready)")
      , $round_charts = panel.find(".vc_round-chart")
      , $frame = panel.find(".vc_line-chart")
      , $google_maps = panel.find('[data-ride="vc_carousel"]');
    if (typeof vc_plugin_flexslider !== 'undefined') {
    vc_plugin_flexslider(panel);
    }
    ui.newPanel.find(".vc_masonry_media_grid, .vc_masonry_grid").length && ui.newPanel.find(".vc_masonry_media_grid, .vc_masonry_grid").each(function() {
      var grid = jQuery(this).data("vcGrid");
      grid && grid.gridBuilder && grid.gridBuilder.setMasonry && grid.gridBuilder.setMasonry()
    }),
    panel.find(".vc_masonry_media_grid, .vc_masonry_grid").length && panel.find(".vc_masonry_media_grid, .vc_masonry_grid").each(function() {
      var grid = jQuery(this).data("vcGrid");
      grid && grid.gridBuilder && grid.gridBuilder.setMasonry && grid.gridBuilder.setMasonry()
    }),
    $pie_charts.length && jQuery.fn.vcChat && $pie_charts.vcChat(),
    $round_charts.length && jQuery.fn.vcRoundChart && $round_charts.vcRoundChart({
      reload: !1
    }),
    $frame.length && jQuery.fn.vcLineChart && $frame.vcLineChart({
      reload: !1
    }),
    $google_maps.length && jQuery.fn.carousel && $google_maps.carousel("resizeAction"),
    $frame = panel.find(".isotope, .wpb_image_grid_ul"),
    $google_maps = panel.find(".wpb_gmaps_widget"),
    0 < $frame.length && $frame.isotope("layout"),
    $google_maps.length && !$google_maps.is(".map_ready") && (($frame = $google_maps.find("iframe")).attr("src", $frame.attr("src")),
    $google_maps.addClass("map_ready")),
    panel.parents(".isotope").length && panel.parents(".isotope").each(function() {
      jQuery(this).isotope("layout")
    }),
    $(document).trigger("wpb_prepare_tab_content", panel)
  }
  
  function vc_ttaActivation() {
     jQuery("[data-vc-accordion]").on("show.vc.accordion", function(e) {
      var $ = window.jQuery
        , ui = {};
      ui.newPanel = $(this).data("vc.accordion").getTarget(),
      window.wpb_prepare_tab_content(e, ui)
    })
  }
  
  function vc_accordionActivate(event, ui) {
    var $pie_charts, $round_charts, $line_charts, $carousel;
    ui.newPanel.length && ui.newHeader.length && ($pie_charts = ui.newPanel.find(".vc_pie_chart:not(.vc_ready)"),
    $round_charts = ui.newPanel.find(".vc_round-chart"),
    $line_charts = ui.newPanel.find(".vc_line-chart"),
    $carousel = ui.newPanel.find('[data-ride="vc_carousel"]'),
    void 0 !== jQuery.fn.isotope && ui.newPanel.find(".isotope, .wpb_image_grid_ul").isotope("layout"),
    ui.newPanel.find(".vc_masonry_media_grid, .vc_masonry_grid").length && ui.newPanel.find(".vc_masonry_media_grid, .vc_masonry_grid").each(function() {
      var grid = jQuery(this).data("vcGrid");
      grid && grid.gridBuilder && grid.gridBuilder.setMasonry && grid.gridBuilder.setMasonry()
    }),
    vc_plugin_flexslider(ui.newPanel),
    $pie_charts.length && jQuery.fn.vcChat && $pie_charts.vcChat(),
    $round_charts.length && jQuery.fn.vcRoundChart && $round_charts.vcRoundChart({
      reload: !1
    }),
    $line_charts.length && jQuery.fn.vcLineChart && $line_charts.vcLineChart({
      reload: !1
    }),
    $carousel.length && jQuery.fn.carousel && $carousel.carousel("resizeAction"),
    ui.newPanel.parents(".isotope").length && ui.newPanel.parents(".isotope").each(function() {
      jQuery(this).isotope("layout")
    }))
  }
});
</script>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_basic_grid' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_media_grid' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_masonry_grid' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_masonry_media_grid' )
	) { ?>
<script>
jQuery(function($) {
  "use strict";
  // grid
  vc_teaserGrid();
  function vc_teaserGrid() {
    var layout_modes = {
      fitrows: "fitRows",
      masonry: "masonry"
    };
    jQuery(".wpb_grid .teaser_grid_container:not(.wpb_carousel), .wpb_filtered_grid .teaser_grid_container:not(.wpb_carousel)").each(function() {
      var $container = jQuery(this)
        , $thumbs = $container.find(".wpb_thumbnails")
        , layout_mode = $thumbs.attr("data-layout-mode");
      $thumbs.isotope({
        itemSelector: ".isotope-item",
        layoutMode: void 0 === layout_modes[layout_mode] ? "fitRows" : layout_modes[layout_mode]
      }),
      $container.find(".categories_filter a").data("isotope", $thumbs).on("click", function($thumbs) {
        $thumbs && $thumbs.preventDefault && $thumbs.preventDefault();
        $thumbs = jQuery(this).data("isotope");
        jQuery(this).parent().parent().find(".active").removeClass("active"),
        jQuery(this).parent().addClass("active"),
        $thumbs.isotope({
          filter: jQuery(this).attr("data-filter")
        })
      }),
      jQuery(window).on("load resize", function() {
        $thumbs.isotope("layout")
      })
    })
  }
});
</script>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_gmaps' ) ) { ?>
<script>
jQuery(function($) {
  "use strict";
  // vc_gmaps
  vc_googleMapsPointer();
  function vc_googleMapsPointer() {
    var $ = window.jQuery
      , $wpbGmapsWidget = $(".wpb_gmaps_widget");
    $wpbGmapsWidget.on("click", function() {
      $("iframe", this).css("pointer-events", "auto")
    }),
    $wpbGmapsWidget.on("mouseleave", function() {
      $("iframe", this).css("pointer-events", "none")
    }),
    $(".wpb_gmaps_widget iframe").css("pointer-events", "none")
  }
});
</script>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_hoverbox' ) ) { ?>
<script>
jQuery(function($) {
  "use strict";
  // vc_hoverbox
  vc_prepareHoverBox();
  $(window).on("resize", window.vc_prepareHoverBox);
  function vc_setHoverBoxPerspective(hoverBox) {
    hoverBox.each(function() {
      var $this = jQuery(this)
        , perspective = 4 * $this.width() + "px";
      $this.css("perspective", perspective)
    })
  }
  
  function vc_setHoverBoxHeight(hoverBox) {
    hoverBox.each(function() {
      var hoverBoxHeight = jQuery(this)
        , hoverBoxInner = hoverBoxHeight.find(".vc-hoverbox-inner");
      hoverBoxInner.css("min-height", 0);
      var frontHeight = hoverBoxHeight.find(".vc-hoverbox-front-inner").outerHeight()
        , hoverBoxHeight = hoverBoxHeight.find(".vc-hoverbox-back-inner").outerHeight()
        , hoverBoxHeight = hoverBoxHeight < frontHeight ? frontHeight : hoverBoxHeight;
      hoverBoxHeight < 250 && (hoverBoxHeight = 250),
      hoverBoxInner.css("min-height", hoverBoxHeight + "px")
    })
  }
  
  function vc_prepareHoverBox() {
    var hoverBox = jQuery(".vc-hoverbox");
    vc_setHoverBoxHeight(hoverBox),
    vc_setHoverBoxPerspective(hoverBox)
  }
});
</script>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_basic_grid' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_media_grid' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_masonry_grid' ) ||
		 isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_masonry_media_grid' )
	) { ?>
<script>
jQuery(function($) {
  "use strict";
  vc_gridBehaviour();
  function vc_gridBehaviour() {
    jQuery.fn.vcGrid && jQuery("[data-vc-grid]").vcGrid();
  }
});
</script>
	<?php } ?>
	
	<?php $header_position = get_theme_mod( 'header_position', 'top' ); ?>
	<?php if ( in_array( $header_position, array( "left", "right" ) ) ) { ?>
<script>
"use strict";
// Vertical header submenu
var access = document.getElementById("access"),
  mainMenuItemHasSubmenuDrop = access.getElementsByClassName("menu-item-has-children");

function mainMenuSubMenu(el) {
  el.closest(".menu-item-has-children").classList.toggle("active");
  var mainMenuSubMenu = el.nextElementSibling;
  if (mainMenuSubMenu.style.maxHeight) {
	mainMenuSubMenu.style.maxHeight = null;
  } else {
	mainMenuSubMenu.style.maxHeight = mainMenuSubMenu.scrollHeight + "px";
  }
}

for (let i = 0; i < mainMenuItemHasSubmenuDrop.length; i++) {
  var mainMenuItemA = mainMenuItemHasSubmenuDrop[i].firstChild;
  if (mainMenuItemHasSubmenuDrop[i].classList.contains("current-menu-ancestor")) {
	mainMenuSubMenu(mainMenuItemA);
  }
  mainMenuItemA.addEventListener("click", function() {
	mainMenuSubMenu(this);
  });
}
</script>
	<?php } ?>
	
	<?php if ( class_exists( 'ESSB_Manager' ) ) { ?>
		<?php if ( is_single() ) { ?>
			<?php $display_in_types = essb_option_value( 'display_in_types' ); ?>
			<?php $type = get_post_type(); ?>
			<?php if ( is_array( $display_in_types ) ) { ?>
				<?php if ( in_array( $type, $display_in_types ) ) { ?>
					<?php $essb_off = get_post_meta( $post->ID, 'essb_off', true ); ?>
					<?php if ( $essb_off !== "true" || isset( $post->post_content ) && has_shortcode( $post->post_content, 'easy-social-share' ) ) { ?>
<script>
"use strict";
var essbLinks = document.querySelectorAll(".essb_links_list li a");
for (let i = 0; i < essbLinks.length; i++) {
  // Remove Easy Social Share title
  essbLinks[i].removeAttribute("title");
  // Disable page transition
  essbLinks[i].addEventListener("click", function(e) {
	e.stopPropagation();
  });
}
</script>
					<?php } ?>
				<?php } ?>
			<?php } ?>
		<?php } ?>
	<?php } ?>
	
	<?php $primary_secondary_top_bar_menu_items_transition_hover = get_theme_mod( 'primary_secondary_top_bar_menu_items_transition_hover' ); ?>
	<?php if ( ! empty( $primary_secondary_top_bar_menu_items_transition_hover ) ) { ?>
<script>
"use strict";
// Primary/Secondary/Top Bar Menu Items Transition Hover
var headerWrapper = document.getElementById("header-wrapper"),
  menus = headerWrapper.getElementsByClassName("menu-wrapper");
for (let i = 0; i < menus.length; i++) {
  var menuItem = menus[i].querySelectorAll("li");
  for (let j = 0; j < menuItem.length; j++) {
	var menuItemSpan = menuItem[j].querySelector("a span"),
	  menuItemText = menuItemSpan.textContent,
	  menuItemA = menuItem[j].querySelector("a");
	menuItemA.setAttribute("data-hover", menuItemText);
  }
}
</script>
	<?php } ?>
	
	<?php $input_style = get_theme_mod( 'input_style', 1 ); ?>
	<?php if ( $input_style == 2 ) { ?>
<script>
"use strict";
// Input focus
var page = document.getElementById("page"),
  inputFocus = page.querySelectorAll(`input[type=text],
  input[type=password],
  input[type=email],
  input[type=tel],
  input[type=number],
  input[type=search],
  textarea`);
for (let i = 0; i < inputFocus.length; i++) {
  // Wrap
  var inputFocusWrapper = document.createElement("div");
  inputFocusWrapper.className = "input-focus-wrapper";
  var inputFocusParent = inputFocus[i].parentElement;
  inputFocusParent.appendChild(inputFocusWrapper);
  inputFocusWrapper.appendChild(inputFocus[i]);
  
  // Label
  var labelP = inputFocus[i].closest("p");
  if (labelP !== null) {
    var label = labelP.querySelector(".input-focus");
    if (label !== null) {
	  inputFocusWrapper.appendChild(label);
    }
  }
  
  // Input focus transition
  inputFocus[i].addEventListener("focus", function() {
	labelP = this.closest("p");
	if (labelP !== null) {
	  this.closest("p").classList.add("focused", "focused-placeholder");
	}
  });
  
  inputFocus[i].addEventListener("blur", function() {
	labelP = this.closest("p");
	if (labelP !== null) {
	  labelP.classList.remove("focused");
	  if (!this.value) {
	    if (!this.classList.contains("datepicker-item")) {
		  labelP.classList.remove("focused-placeholder");
	    }
	  }
    }
  });
}
</script>
	<?php } ?>
	
	<?php $buttons_style = get_theme_mod( 'buttons_shape', 'square' ); ?>
	<?php if ( $buttons_style == 'superround' ) { ?>
<script>
"use strict";
// Super Round Button
var superRoundButton = document.querySelectorAll(`.vc_btn3-shape-superround,
  .wpcf7-submit,
  #submit,
  .submit-button-wrapper`);
  
for (let i = 0; i < superRoundButton.length; i++) {
  var txt = superRoundButton[i].textContent,
	newTxt = txt.replace(/\w/g, function(c) {
	  return "<span class='char'>" + c + "</span>";
	});
  superRoundButton[i].innerHTML = "<span class='char-wrapper'>" + newTxt + "</span>";
  superRoundButton[i].insertAdjacentHTML("beforeEnd", "<span class='border-helper'></span>");
}
</script>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'contact-form-7' ) ) { ?>
<script>
"use strict";
document.addEventListener('DOMContentLoaded', function(event) {
  var wpcf7Elm = document.getElementsByClassName("wpcf7");
  for (let i = 0; i < wpcf7Elm.length; i++) {
	// Contact Form 7 loader
	var submitButton = wpcf7Elm[i].querySelector(".wpcf7-submit");
	submitButton.insertAdjacentHTML("afterEnd", "<span class='ajax-loader'><svg class='circular' viewBox='25 25 50 50'><circle class='path' cx='50' cy='50' r='20' fill='none' stroke-width='6' stroke-miterlimit='10'/></svg></span>");
  
	// Contact Form 7 hint
	var hint = wpcf7Elm[i].getElementsByClassName("hint");
	if (hint) {
	  for (let j = 0; j < hint.length; j++) {
		var controlWrap = hint[j].previousElementSibling;
		controlWrap.appendChild(hint[j]);
	  }
	}
  }
});
</script>
    <?php } ?>
	
	<?php if ( class_exists( 'woocommerce' ) ) { ?>
		<?php if ( is_woocommerce()
			|| is_cart()
			|| is_checkout()
			|| is_account_page()
		) { ?>
<script>
"use strict";
// select2
jQuery(function($) {
  if ($(".variations select, .woocommerce form .form-row select").length) {
    function formatState(state) {
      if (!state.id) {
        return state.text;
      }
      var state = $(
        "<span>" + state.text + "</span>"
      );
      return state;
    };
    
    $(".variations select, .woocommerce form .form-row select").each(function() {
      var placeholder = $(this).closest("p").find(".select2-placeholder").text();
      var label = $(this).closest(".select-focus-transition").find("label");
      $(this).select2({
        minimumResultsForSearch: -1,
        placeholder: placeholder,
        dropdownParent: $(this).parent(),
        width: "100%",
        templateResult: formatState
      });
      setTimeout( function() {
        $(".select2-selection__rendered").removeAttr("title");
      }, 250)
      $(this).on("change", function(evt) {
        $(this).siblings(".select2-container").find(".select2-selection__rendered").removeAttr("title");
      });
      if (label.length) {
        $(this).siblings(".select2-container").find(".select2-selection").append(label);
        $(this).on("select2:selecting", function(e) {
          label.css({"transform": "translateY(-106%) scale(.75)"});
        });
      }
    });
  }
});
</script>
		<?php } ?>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_row' ) ) { ?>
		<?php $animation_special_2 = false; ?>
		<?php $scrolling_enabled = false; ?>
		
		<?php $pattern = get_shortcode_regex(); ?>
		<?php preg_match_all( "/$pattern/", $post->post_content, $matches ); ?>
		<?php $vc_row_shortcode = array_keys( $matches[2], 'vc_row' ); ?>
		
		<?php if ( preg_match( "/svg-icons-animated/", implode( "|", $matches[0] ) ) ) { ?>
<script>
"use strict";
// Vivus Icon Box MT
jQuery(function($) {
  var svgIconsAnimated = $(".svg-icons-animated");
  if (svgIconsAnimated.length) {
    $(window).on("load", function() {
      setTimeout(function() {
      svgIconsAnimated.each(function() {
        var svgAnimation = $(this).find(".svg-animation-enabled");
        if (svgAnimation.length) {
          var icons = [];
          svgAnimation.each(function(i) {
            var marketingTourWrapper = $(this).find(".svg-icon");
            $(this).attr("id", "marketing-tour-icon-animated-" + i);
            icons[i] = new Vivus(marketingTourWrapper.attr("id"), {
              type: "delayed",
              duration: 125,
              pathTimingFunction: Vivus.EASE_OUT,
              animTimingFunction: Vivus.EASE_OUT,
              start: "manual",
            });
            
            var marketingTourWrapper = $(this);
            
            var waypoint = new Waypoint({
              element: marketingTourWrapper,
              handler: function(direction) {
              this.element.find(".svg-icon").css("opacity", "1");
              var animationDelay = (i*225);
              setTimeout(function() {
                icons[i].reset().play();
              }, animationDelay);
              this.destroy();
              },
              offset: "85%",
            });
            
          });
        }
      });
      }, 200);
    });
  }
});
</script>
		<?php } ?>
		
		<?php foreach( $matches[0] as $key => $row ) { ?>
		
			<?php preg_match_all( '~'. $pattern .'~', $row, $matches ); ?>
			<?php preg_match_all( '~'. $pattern .'~', $matches[5][0], $matches2 ); ?>
			
			<?php $parsed = shortcode_parse_atts( $matches[3][0] ); ?>
			
			<?php if ( ! empty( $parsed ) ) { ?>
				<?php if ( isset( $parsed['el_class'] ) ) { ?>
					
					<?php if ( strpos( $parsed['el_class'], 'datepicker-enabled' ) !== false ) { ?>
<script>
"use strict";
// flatpickr
var datepickerItem = document.querySelectorAll(".datepicker-item");
if (datepickerItem) {
  for (let i = 0; i < datepickerItem.length; i++) {
	// Wrap
    var datepickerItemWrapper = document.createElement("span");
    datepickerItemWrapper.className = "datepicker-wrapper";
    var datepickerItemParent = datepickerItem[i].parentElement;
    datepickerItemParent.appendChild(datepickerItemWrapper);
    datepickerItemWrapper.appendChild(datepickerItem[i]);
	// Icon
	datepickerItemWrapper.insertAdjacentHTML("afterBegin", "<span class='datepicker-icon'><svg viewBox='0 0 32 32'><path d='M30.752 3.744h-6.144v-1.248c0-0.672-0.576-1.248-1.248-1.248s-1.28 0.576-1.28 1.248v1.248h-12.16v-1.248c0-0.672-0.576-1.248-1.248-1.248s-1.28 0.576-1.28 1.248v1.248h-6.144c-0.672 0-1.248 0.576-1.248 1.28v24.48c0 0.672 0.576 1.248 1.248 1.248h29.504c0.704 0 1.248-0.576 1.248-1.248v-24.48c0-0.704-0.544-1.28-1.248-1.28zM29.504 28.256h-27.008v-21.984h4.896v1.248c0 0.704 0.576 1.248 1.28 1.248s1.248-0.544 1.248-1.248v-1.248h12.192v1.248c0 0.704 0.544 1.248 1.248 1.248s1.248-0.544 1.248-1.248v-1.248h4.896v21.984zM17.696 14.688c0 0.928-0.768 1.696-1.696 1.696s-1.696-0.768-1.696-1.696c0-0.928 0.768-1.696 1.696-1.696s1.696 0.768 1.696 1.696zM17.696 22.016c0 0.928-0.768 1.696-1.696 1.696s-1.696-0.768-1.696-1.696c0-0.928 0.768-1.664 1.696-1.664s1.696 0.736 1.696 1.664zM10.336 14.688c0 0.928-0.736 1.696-1.664 1.696s-1.696-0.768-1.696-1.696c0-0.928 0.736-1.696 1.696-1.696s1.664 0.768 1.664 1.696zM25.024 14.688c0 0.928-0.736 1.696-1.664 1.696s-1.696-0.768-1.696-1.696c0-0.928 0.736-1.696 1.696-1.696s1.664 0.768 1.664 1.696zM10.336 22.016c0 0.928-0.736 1.696-1.664 1.696s-1.696-0.768-1.696-1.696c0-0.928 0.736-1.664 1.696-1.664s1.664 0.736 1.664 1.664zM25.024 22.016c0 0.928-0.736 1.696-1.664 1.696s-1.696-0.768-1.696-1.696c0-0.928 0.736-1.664 1.696-1.664s1.664 0.736 1.664 1.664z'/></svg></span>");
    // Plus year
	var d = new Date(),
      year = d.getFullYear(),
      month = d.getMonth(),
      day = d.getDate(),
      maxDate = new Date(year + 1, month, day);
	// Init
	const fp = flatpickr(datepickerItem[i], {
	  monthSelectorType: "static",
	  minDate: "today",
	  maxDate: maxDate,
	  nextArrow: "<svg viewBox='0 0 9 16'><polyline fill='none' stroke-miterlimit='10' points='1.6,1.2 6.5,7.9 1.6,14.7'></polyline></svg>",
	  prevArrow: "<svg viewBox='0 0 9 16'><polyline fill='none' stroke-miterlimit='10' points='7.3,14.7 2.5,8 7.3,1.2'></polyline></svg>",
	  positionElement: datepickerItem[i],
	  onPreCalendarPosition: function() {
  	    setTimeout(function() {
  		  // Offset
    	  fp.calendarContainer.style.top = parseInt(fp.calendarContainer.style.top) - 2 + "px";
  	    }, 0)
 	  },
	  onClose: function(selectedDates, dateStr, instance) {
		// Input focus transition
		if (!instance.input.value) {
		  instance.input.closest("p").classList.remove("focused-placeholder");
		}
      }
	});
  }
}
</script>
					<?php } ?>
					
					<?php if ( strpos( $parsed['el_class'], 'select2-enabled' ) !== false ) { ?>
<script>
"use strict";
// Slim Select
var slimSelectItem = document.querySelectorAll(".select2-item");
if (slimSelectItem) {
  for (let i = 0; i < slimSelectItem.length; i++) {
	var placeholderText = slimSelectItem[i].closest("p").querySelector(".select2-placeholder").textContent,
	  firstOption = slimSelectItem[i].options[0];
	if (firstOption.innerHTML === "---") {
	  firstOption.innerHTML = "";
	  firstOption.setAttribute("data-placeholder", "true");
	}
	
    var pluginInstance = new SlimSelect({
      select: slimSelectItem[i],
	  placeholder: placeholderText,
	  showSearch: false,
	  // Focus transition
	  beforeOnChange: (info) => {
        var selectFocusTransition = slimSelectItem[i].closest(".select-focus-transition");
	    if (selectFocusTransition) {
		  var label = selectFocusTransition.querySelector("label");
		  label.classList.add("select-focused-placeholder");
		}
      }
    });
	// Focus transition
	pluginInstance.slim.container.classList.remove("select2-item");
	
	// Arrow
	var arrowWrapper = pluginInstance.slim.container.querySelector(".ss-arrow span"),
	  arrowIcon = "<svg viewBox='0 0 32 32'><path d='M32 11.008l-3.008-3.008-12.992 12.992-12.992-12.992-3.008 3.008 16 16 16-16z'></path></svg>";
	arrowWrapper.insertAdjacentHTML("afterBegin", arrowIcon);
	
	// Focus transition
	var selectFocusTransition = slimSelectItem[i].closest(".select-focus-transition");
	if (selectFocusTransition) {
	  var label = selectFocusTransition.querySelector("label"),
	    singleSelected = pluginInstance.slim.container.querySelector(".ss-single-selected"),
	    placeholder = pluginInstance.slim.container.querySelector(".placeholder");
	  singleSelected.insertBefore(label, placeholder);
	}
  }
  
  // Contact Form 7
  var wpcf7Elm = document.querySelector(".wpcf7");
  if (wpcf7Elm) {
	  wpcf7Elm.addEventListener("wpcf7mailsent", function(event) {
		var focusedPlaceholder = wpcf7Elm.querySelectorAll(".focused-placeholder"),
		  selectFocusedPlaceholder = wpcf7Elm.querySelectorAll(".select-focused-placeholder"),
		  datepickerItem = wpcf7Elm.querySelectorAll(".datepicker-item");
		  
		// flatpickr
		if (datepickerItem) {
		  for (let i = 0; i < datepickerItem.length; i++) {
			datepickerItem[i]._flatpickr.clear();
		  }
		}
		
        // Focus transition
		if (selectFocusedPlaceholder) {
	      for (let i = 0; i < selectFocusedPlaceholder.length; i++) {
		    selectFocusedPlaceholder[i].classList.remove("select-focused-placeholder");
	      }
		}
		// Focused placeholder
		if (focusedPlaceholder) {
		  for (let i = 0; i < focusedPlaceholder.length; i++) {
            focusedPlaceholder[i].classList.remove("focused-placeholder");
		  }
		}
      }, false);
  }
}
</script>
					<?php } ?>
					
				<?php } ?>
			<?php } ?>
			
			<?php foreach( $matches2[0] as $key => $val ) { ?>
			
				<?php preg_match_all( '~'. $pattern .'~', $val, $matches2 ); ?>
				<?php preg_match_all( '~'. $pattern .'~', $matches2[5][0], $matches3 ); ?>
				
				<?php if ( in_array( 'vc_column_text', $matches3[2] ) ) { ?>
					<?php foreach( $matches3[2] as $key => $val ) { ?>
						<?php $parsed = shortcode_parse_atts( $matches3[3][$key] ); ?>
						<?php if ( ! empty( $parsed ) ) { ?>
							<?php if ( array_key_exists( 'el_class', $parsed ) ) { ?>
								<?php if ( strpos( $parsed['el_class'], 'animation-special-2' ) !== false ) { ?>
								<?php $animation_special_2 = true; ?>
								<?php break; ?>
								<?php } ?>
							<?php } ?>
						<?php } ?>
					<?php } ?>
				<?php } ?>
				
				<?php if ( in_array( 'vc_column_text', $matches3[2] ) ) { ?>
					<?php foreach( $matches3[2] as $key => $val ) { ?>
						<?php $parsed = shortcode_parse_atts( $matches3[3][$key] ); ?>
						<?php if ( ! empty( $parsed ) ) { ?>
							<?php if ( array_key_exists( 'el_class', $parsed ) ) { ?>
								<?php if ( strpos( $parsed['el_class'], 'scrolling-enabled' ) !== false ) { ?>
								<?php $scrolling_enabled = true; ?>
								<?php break; ?>
								<?php } ?>
							<?php } ?>
						<?php } ?>
					<?php } ?>
				<?php } ?>
				
				<?php $mt_vc_posts_shortcode = array_keys( $matches3[2], 'mt_vc_posts' ); ?>
				<?php if ( ! empty( $mt_vc_posts_shortcode ) ) { ?>
					<?php foreach( $matches3[2] as $key => $val ) { ?>
						<?php $parsed = shortcode_parse_atts( $matches3[3][$key] ); ?>
						<?php if ( ! empty( $parsed ) ) { ?>
							<?php if ( isset( $parsed['pagination'] ) ) { ?>
								<?php if ( $parsed['pagination'] == 'infinite_scroll' || $parsed['pagination'] == 'infinite_scroll_with_button' ) { ?>
<script>
"use strict";
document.addEventListener('DOMContentLoaded', function(event) {
  // Infinite Scroll
  var containerWrapper = document.getElementsByClassName("mt-posts-container-wrapper");
  for (let i = 0; i < containerWrapper.length; i++) {
    var container = containerWrapper[i].querySelector(".mt-posts-container"),
	  loaderWrapper = containerWrapper[i].querySelector(".loader-wrapper");
      
	var iso = Isotope.data(container);
    if (containerWrapper[i].classList.contains("infinite-scroll-enabled")) {
	  var scrollThreshold = true;
	} else {
	  var scrollThreshold = false;
	}
	if (containerWrapper[i].getAttribute("id") !== null) {
      var selector = "#" + containerWrapper[i].getAttribute("id") + " .mt-posts-container";
    } else {
      var selector = ".mt-posts-container";
    }
		
    let infScroll = new InfiniteScroll(selector, {
      path: ".next",
      append: "article",
      history: false,
	  outlayer: iso,
	  button: ".load-more",
      scrollThreshold: scrollThreshold,
    });
	infScroll.on("request", function(path, fetchPromise) {
	  loaderWrapper.classList.add("request");
	});
	infScroll.on("load", function(path, fetchPromise) {
	  loaderWrapper.classList.remove("request");
	});
	infScroll.on("append", function(body, path, items, response) {
      if (this.element.parentElement.classList.contains("fadeinup")) {
	    for (let i = 0; i < items.length; i++) {
		  Object.assign(items[i].style, {"opacity": "0", "transform": "translate(0px, 40px)"});
		  var delay = i * 125;
		 (function(i) {
		   setTimeout(function() {
		     Object.assign(items[i].style, {"transition": "opacity ease .35s, transform ease .35s", "opacity": "1", "transform": "translate(0px, 0px)"});
		   }, delay);
		 })(i);
		}
	  } else {
	    for (let i = 0; i < items.length; i++) {
	      var delay = i * 125;
		  (function(i) {
		    setTimeout(function() {
		      Object.assign(items[i].style, {"transition": "opacity ease .35s", "opacity": "1"});
		    }, delay);
		  })(i);
	    }
	  }
    });
  }
});
</script>
								<?php } ?>
							<?php } ?>
						<?php } ?>
					<?php } ?>
				<?php } ?>
				
				<?php $mt_vc_gallery_shortcode = array_keys( $matches3[2], 'mt_vc_gallery' ); ?>
				<?php if ( ! empty( $mt_vc_gallery_shortcode ) ) { ?>
					<?php foreach( $matches3[2] as $key => $val ) { ?>
						<?php $parsed = shortcode_parse_atts( $matches3[3][$key] ); ?>
						<?php if ( ! empty( $parsed ) ) { ?>
							<?php if ( ! array_key_exists( 'onclick', $parsed ) ) { ?>
<script>
"use strict";
// lightGallery
// Hide/show scrollbar
function hideScrollbar() {
  const scrollbarWidth = window.innerWidth - document.documentElement.getBoundingClientRect().width;
  const id = "fancybox-style-noscroll";

  let $style = document.getElementById(id);

  if ($style) {
    return;
  }

  if (scrollbarWidth > 0) {
    $style = document.createElement("style");

    $style.id = id;
    $style.type = "text/css";
    $style.innerHTML = `.compensate-for-scrollbar {padding-right: ${scrollbarWidth}px;}`;

    document.getElementsByTagName("head")[0].appendChild($style);

    document.body.classList.add("compensate-for-scrollbar");
  }
}

function revealScrollbar() {
  document.body.classList.remove("compensate-for-scrollbar");

  const el = document.getElementById("fancybox-style-noscroll");

  if (el) {
    el.remove();
  }
}

var lightgalleryWrapper = document.getElementsByClassName("mt-gallery-container-wrapper");
for (let i = 0; i < lightgalleryWrapper.length; i++) {
  
  // On image click action
  var lightgalleryOnImageClick = lightgalleryWrapper[i].getAttribute("data-lightgallery-onimageclick");
  if (lightgalleryOnImageClick == undefined) {
    lightgalleryOnImageClick = 'next';
  }

  var onimageclicknext;
  if (lightgalleryOnImageClick == "next") {
    onimageclicknext = "lightgallery-next-on-image-click";
  }
  
  let pluginInstance = null;
  lightgalleryWrapper[i].addEventListener('lgInit', (event) => {
     pluginInstance = event.detail.instance;
	 
	 // Lightbox background color
    var lightgalleryBGcolor = lightgalleryWrapper[i].getAttribute("data-lightgallery-bg-color");
    if (lightgalleryBGcolor == undefined) {
      lightgalleryBGcolor = "rgba(0, 0, 0, .9)";
    }
    var lgBackdrop = pluginInstance.$container.selector.querySelector(".lg-backdrop");
    pluginInstance.$container.selector.style.setProperty("--bg-color", lightgalleryBGcolor);

    // Lightbox buttons color
    var lightgalleryButtonsColor = lightgalleryWrapper[i].getAttribute("data-lightgallery-buttons-color");
    if (lightgalleryButtonsColor == undefined) {
      lightgalleryButtonsColor = "#fff";
    }
	 pluginInstance.$container.selector.style.setProperty("--buttons-color", lightgalleryButtonsColor);

    // Lightbox buttons background color
    var lightgalleryButtonsBGcolor = lightgalleryWrapper[i].getAttribute("data-lightgallery-buttons-bg-color");
    if (lightgalleryButtonsBGcolor == undefined) {
      lightgalleryButtonsBGcolor = "rgba(0,0,0,0.74)";
    }
	pluginInstance.$container.selector.style.setProperty("--buttons-bg-color", lightgalleryButtonsBGcolor);

    // Lightbox buttons background color hover
    var lightgalleryButtonsBGcolorHover = lightgalleryWrapper[i].getAttribute('data-lightgallery-buttons-bg-color-hover');
    if (lightgalleryButtonsBGcolorHover == undefined) {
      lightgalleryButtonsBGcolorHover = 'rgba(0,0,0,0.74)';
    }
	pluginInstance.$container.selector.style.setProperty("--buttons-bg-color-on-hover", lightgalleryButtonsBGcolorHover);

    // Lightbox buttons background color active
    var lightgalleryButtonsBGcolorActive = lightgalleryWrapper[i].getAttribute("data-lightgallery-buttons-bg-color-active");
    if (lightgalleryButtonsBGcolorActive == undefined) {
      lightgalleryButtonsBGcolorActive = "rgba(0,0,0,0.74)";
    }
	pluginInstance.$container.selector.style.setProperty("--buttons-bg-color-on-active", lightgalleryButtonsBGcolorActive);
	
	// Close icon
    const closeIcon = "<svg viewBox='0 0 40 40'><path d='M4.3,35.7L35.7,4.3'></path><path d='M4.3,4.3l31.4,31.4'></path></svg>";
    const lgCloseIcon = pluginInstance.$toolbar.selector.querySelector(".lg-close");
    lgCloseIcon.insertAdjacentHTML("beforeEnd", closeIcon);
	
	// Prev icon
	const prevIcon = "<svg viewBox='0 0 9 16'><polyline fill='none' stroke-miterlimit='10' points='7.3,14.7 2.5,8 7.3,1.2'></polyline></svg>";
    const lgPrevIcon = pluginInstance.$content.selector.querySelector(".lg-prev");
    lgPrevIcon.insertAdjacentHTML("beforeEnd", prevIcon);
	
	// Next icon
	const nextIcon = "<svg viewBox='0 0 9 16'><polyline fill='none' stroke-miterlimit='10' points='1.6,1.2 6.5,7.9 1.6,14.7'></polyline></svg>";
    const lgNextIcon = pluginInstance.$content.selector.querySelector(".lg-next");
    lgNextIcon.insertAdjacentHTML("beforeEnd", nextIcon);
  });

  // Lightbox open/close animation type
  var animationEffect = lightgalleryWrapper[i].getAttribute("data-lightgallery-open-close-animation-type");
  if (animationEffect == undefined) {
    animationEffect = "zoom";
  }

  // Lightbox transition effect between slides
  var transitionEffect = lightgalleryWrapper[i].getAttribute("data-lightgallery-transition-effect-between-slides");
  if (transitionEffect == undefined) {
    transitionEffect = "lg-fade";
  }
  
  // Hide/show scrollbar
  var body = document.body;
  lightgalleryWrapper[i].addEventListener("lgBeforeOpen", (event) => {
    hideScrollbar();
  });
  
  lightgalleryWrapper[i].addEventListener("lgAfterClose", (event) => {
    revealScrollbar();
  });
  
  lightgalleryWrapper[i].addEventListener("lgAfterAppendSlide", (event) => {
    const { index } = event.detail;
	// Loader
	lg.getSlideItem(index).selector.insertAdjacentHTML("afterBegin", "<svg class='circular' viewBox='25 25 50 50'><circle class='path' cx='50' cy='50' r='20' fill='none' stroke-width='6' stroke-miterlimit='10'/></svg>");
	
	var img = lg.getSlideItem(index).selector.querySelector(".lg-image");
	if (img) {
	  // Disable right click
	  img.addEventListener("contextmenu", function(event) {
        event.preventDefault();
      });
    }
  });

  var selector = lightgalleryWrapper[i].querySelectorAll("a");
  const lg = lightGallery(lightgalleryWrapper[i], {
    licenseKey: "0000-0000-000-0001",
    speed: 200,
	mode: transitionEffect,
	counter: false,
	selector: selector,
	download: false,
	mobileSettings: {
	  showCloseIcon: true,
	  controls: false,
	},
  });
}
</script>
							<?php } ?>
						<?php } ?>
					<?php } ?>
				<?php } ?>
			
			<?php } ?>
		
		<?php } ?>
		
		<?php if ( $animation_special_2 ) { ?>
<script>
"use strict";
// animation-special-2
var animatedSpecialSecond = document.getElementsByClassName("animation-special-2");
for (let i = 0; i < animatedSpecialSecond.length; i++) {
  var items = animatedSpecialSecond[i].querySelector(".wpb_wrapper").children;
  for (let j = 0; j < items.length; j++) {
    items[j].classList.add("animated-item");
  }
  var itemQueue = [],
    delay = 55,
    queueTimer,
    animation = {
      transition: "opacity cubic-bezier(.215,.61,.355,1) .9s, transform cubic-bezier(.215,.61,.355,1) .9s",
      opacity: "1",
      transform: "translate(0px, 0px)"
    };
              
  function processItemQueue() {
    if (queueTimer) return // We're already processing the queue
    queueTimer = window.setInterval(function() {
      if (itemQueue.length) {
        Object.assign(itemQueue.shift().style, animation);
        processItemQueue();
      } else {
        window.clearInterval(queueTimer);
        queueTimer = null;
      }
    }, delay)
  }
  
  for (let j = 0; j < items.length; j++) {
    var waypoints = new Waypoint({
      element: items[j],
      handler: function(direction) {
        itemQueue.push(this.element);
        processItemQueue();
        this.destroy();
      },
      offset: "94%",
    });
  }
}
</script>
		<?php } ?>
		
		<?php if ( $scrolling_enabled ) { ?>
<script>
"use strict";
// Scrolling effect
var scrollingEnabled = document.querySelector(".scrolling-enabled"),
  wpbWrapper = scrollingEnabled.querySelector(".wpb_wrapper");
window.addEventListener("scroll", function() {
  var scrollTop = this.scrollY,
    height = this.screen.height,
    bottom_of_screen = scrollTop + height,
    top_of_screen = scrollTop,
    top_of_element = scrollingEnabled.getBoundingClientRect().top,
    bottom_of_element = scrollingEnabled.getBoundingClientRect().top + scrollingEnabled.offsetHeight;

  if ((bottom_of_screen > top_of_element) && (top_of_screen < bottom_of_element)) {
	var opacity = ((height - scrollTop * 2) / height),
	  translateY = scrollTop / 2;
	if (opacity > 0) {
	  requestAnimationFrame(function() {
	    Object.assign(wpbWrapper.style,{"opacity": opacity, "transform": "translateY(" + translateY + "px)"});
	  });
	}
  }
});
</script>
		<?php } ?>
		
	<?php } ?>
	
	<?php $single_post_navigation = get_theme_mod( 'single_post_navigation' ); ?>
	<?php $single_portfolio_navigation = get_theme_mod( 'single_portfolio_navigation' ); ?>
	<?php if ( ! empty( $single_post_navigation ) && is_singular( 'post' ) ||
		! empty( $single_portfolio_navigation ) && is_singular( 'portfolio' ) ) { ?>
		<?php $single_navigation_style = get_theme_mod( 'single_navigation_style', 1 ); ?>
		<?php $single_navigation_images = get_theme_mod( 'single_navigation_images' ); ?>
		<?php if ( $single_navigation_style == 1 && ! empty( $single_navigation_images ) ) { ?>
<script>
"use strict";
// Single post navigation
var mouseX,
  mouseY,
  navigationNext = document.querySelector(".nav-pagination-single-wrapper .next"),
  navigationPrev = document.querySelector(".nav-pagination-single-wrapper .previous"),
  navigationNextContent = navigationNext.nextElementSibling,
  navigationPrevContent = navigationPrev.nextElementSibling,
  navigationNextContentHeight = navigationNextContent.offsetHeight,
  navigationPrevContentHeight = navigationPrevContent.offsetHeight,
  navigationWidth = navigationNextContent.offsetWidth,
  rect;
  
navigationNext.addEventListener("mousemove", function(e) {
  rect = this.getBoundingClientRect();
  mouseX = e.clientX - rect.left;
  mouseY = e.clientY - rect.top;
  Object.assign(navigationNextContent.style,{"top": mouseY - navigationNextContentHeight - 25 + "px", "left": mouseX - navigationWidth + "px"});
});
navigationPrev.addEventListener("mousemove", function(e) {
  rect = this.getBoundingClientRect();
  mouseX = e.clientX - rect.left;
  mouseY = e.clientY - rect.top;
  Object.assign(navigationPrevContent.style,{"top": mouseY - navigationPrevContentHeight - 25 + "px", "left": mouseX + "px"});
});

[ navigationNext, navigationPrev ].forEach(function(element) {
   element.addEventListener("mouseover", function() {
      this.parentElement.classList.add("nav-hover");
   });
});
[ navigationNext, navigationPrev ].forEach(function(element) {
   element.addEventListener("mouseout", function() {
      this.parentElement.classList.remove("nav-hover");
   });
});
</script>
		<?php } ?>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_counting' ) ) { ?>
<script>
 // countUp.js
 "use strict";
jQuery(function($) {
  var countWrapper = $(".count-wrapper"),
    countWrapperRow = countWrapper.closest(".wpb_row");
  countWrapperRow.each(function() {
    $(this).find(".count-wrapper").each(function(i, el) {
      var el = $(el),
        target = el.data("count"),
        startVal = 0,
        endVal = el.data("end"),
        decimals = 0;
          
      var theAnimation = new CountUp(target, startVal, endVal, decimals, 2.5, {
        useEasing: true,
        useGrouping: false, 
        separator: "", 
        decimal: ".",
      });

      var countWrapper = $(this);
      if (countWrapper.is(".mt-animate_when_almost_visible-enabled")) {
          
        var waypoint = new Waypoint({
          element: $( "#" + target ),
          handler: function(direction) {
            theAnimation.start();
            var animationDelay = (i*125);
            setTimeout(function() {
              countWrapper.addClass("mt_start_animation");
            }, animationDelay);
            this.destroy();
          },
          offset: "85%",
        });
        
      } else {
          
        var waypoint = new Waypoint({
          element: $( "#" + target ),
          handler: function(direction) {
          theAnimation.start();
          this.destroy();
          },
            offset: "85%",
        });
          
      }
    });
  });
});
</script>
	<?php } ?>
	
	<?php $search_position = get_theme_mod( 'search_position', 'none' ); ?>
	<?php if ( $search_position == 'header' || $search_position == 'top_bar' ) { ?>
<script>
"use strict";
// Header search
var searchHeaderIcon = document.getElementsByClassName("search-header-icon"),
  searchWrapper = document.querySelector("#page .search-wrapper"),
  searchField = document.querySelector("#page .search-wrapper .search-field");
for (let i = 0; i < searchHeaderIcon.length; i++) {
  searchHeaderIcon[i].addEventListener("click", function() {
    if (!this.closest(".search-header-wrapper").classList.contains("search-form-active")) {
      this.closest(".search-header-wrapper").classList.add("search-form-active");
	  searchWrapper.classList.add("active");
    } else {
	  this.closest(".search-header-wrapper").classList.remove("search-form-active");
	  searchWrapper.classList.remove("active");
    }
    setTimeout(function() {
      searchField.focus();
    }, 200);
  });
}

var searchHeaderCloseButton = document.querySelector(".search-wrapper .close-button"),
  searchHeaderWrapper = document.getElementsByClassName("search-header-wrapper");
function searchRemove() {
  for (let i = 0; i < searchHeaderWrapper.length; i++) {
    if (searchHeaderWrapper[i].classList.contains("search-form-active")) {
      searchHeaderWrapper[i].classList.remove("search-form-active");
      searchWrapper.classList.remove("active");
    }
  }
}
  
searchHeaderCloseButton.addEventListener("click", function() {
  searchRemove();
});

document.addEventListener("click", function(e) {
  if (!e.target.matches(`.search-header-icon svg,
    .close-button,
	.search-wrapper .search-field,
	.search-wrapper .search-submit svg,
	.search-form-wrapper`)) {
    searchRemove();
  }
});
</script>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_scroll_down_button' ) ) { ?>
<script>
"use strict";
// Scroll Down Button
jQuery(function($) {
  var header = $(".header-wrapper");
  $(".scroll-down-button, .down-button").on("click", function(e) {
    if ($(this).is(".scroll-down-button-header")) {
    $("html, body").animate({
      scrollTop: $(this).closest(".entry-header-bg").next().offset().top - header.outerHeight() + 1
    }, 900, "easeInOutExpo" );
    } else {
      if ($(this).closest(".wpb_row").next().hasClass("intro")) {
        $("html, body").animate({
          scrollTop: $(this).closest(".wpb_row").next().next().offset().top - header.outerHeight() + 1
        }, 900, "easeInOutExpo" );
      } else {
        $("html, body").animate({
          scrollTop: $(this).closest(".wpb_row").next().offset().top - header.outerHeight() + 1
        }, 900, "easeInOutExpo" );
      }
    }
  });
});
</script>
	<?php } ?>
	
	<?php if ( function_exists( 'icl_object_id' ) ) { ?>
<script>
"use strict";
// WPML
var langSelSel = document.querySelector("#top-bar .lang_sel_sel");
langSelSel.addEventListener("click", function(e) {
  e.preventDefault();
});
</script>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_person' ) ) { ?>
<script>
"use strict";
// Person animation
jQuery(function($) {
  var rowAnimationEnabledForPerson = $(".vc_row.mt-animate_when_almost_visible-enabled-for-person");
  rowAnimationEnabledForPerson.each(function() {
	var rowAnimationEnabledForPersonWrapper = $(this).find(".wrapper");
	var rowAnimationEnabledForPerson = $(this).find(".person");
	rowAnimationEnabledForPerson.addClass("mt-animate_when_almost_visible");
	
	var waypoint = new Waypoint({
	  element: rowAnimationEnabledForPersonWrapper,
	  handler: function(direction) {
	  rowAnimationEnabledForPerson.each(function(i) {
		$(this).delay(i*125).transition({
		  opacity: 1, y: "0px",
		  duration: 700,
		  easing: "ease",
		  complete: function() {
			$(this).removeClass("mt-animate_when_almost_visible");
			$(this).css({ "opacity": '', "transform": "" });
			rowAnimationEnabledForPerson.removeClass("mt-animate_when_almost_visible-enabled-for-person");
		  }
		});
	  });
	  this.destroy();
	  },
	  offset: "85%",
	});
	
  });
});
</script>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'mt_vc_icon_box' ) ) { ?>
<script>
"use strict";
// Icon Box MT
var itemQueue = [];
var delay = 125;
var queueTimer;

function processItemQueue() {
  if (queueTimer) return // We're already processing the queue
  queueTimer = window.setInterval(function() {
    if (itemQueue.length) {
	  itemQueue.shift().classList.add("mt_start_animation");
	  processItemQueue();
    } else {
	  window.clearInterval(queueTimer);
	  queueTimer = null;
    }
  }, delay)
}

var contentAnimated = document.getElementsByClassName("content-animated");
for (let i = 0; i < contentAnimated.length; i++) {
  var marketingTourWrapper = contentAnimated[i].getElementsByClassName("marketing-tour-wrapper");
  for (let j = 0; j < marketingTourWrapper.length; j++) {
    if ( marketingTourWrapper[j].classList.contains("mt_animate_when_almost_visible") ) {
	  var waypoint = new Waypoint({
	    element: marketingTourWrapper[j],
	    handler: function(direction) {
	      itemQueue.push(this.element);
	      processItemQueue();
	      this.destroy();
	    },
	    offset: "85%",
	  });
    }
  }
}
</script>
	<?php } ?>
	
	<?php $back_to_top_button = get_theme_mod( 'back_to_top_button', true ); ?>
	<?php if ( ! empty( $back_to_top_button ) ) { ?>
<script>
"use strict";
// To top
var toTop = document.getElementById("to-top-wrapper");
var offset = 400;
window.addEventListener("scroll", function() {
  if (this.scrollY > offset) {
	requestAnimationFrame(function() {
      toTop.classList.add("to-top-show");
	});
  } else {
	requestAnimationFrame(function() {
      toTop.classList.remove("to-top-show");
	});
  }
});
  
toTop.addEventListener("click", function(e) {
  e.preventDefault();
  scrollToEl(0, 900, easing.easeInOutQuart);
});
</script>
	<?php } ?>
	
	<?php $theme_locations = ['primary', 'secondary', 'sliding', 'top_bar']; ?>
	<?php $locations = get_nav_menu_locations(); ?>
	<?php if ( ! empty( $locations ) ) { ?>
		<?php foreach ( $theme_locations as $theme_location ) { ?>
			<?php if ( ! empty( $locations[$theme_location] ) ) { ?>
				<?php $menu = get_term( $locations[$theme_location], 'nav_menu' ); ?>
				<?php if ( ! empty( $menu->term_id ) ) { ?>
					<?php $menu_items = wp_get_nav_menu_items( $menu->term_id ); ?>
					<?php foreach( $menu_items as $menu_item ) { ?>
						<?php if ( $menu_item->menu_item_parent != 0 ) { ?>
<script>
"use strict";
// Arrows
var menuItemHasChildren = document.querySelectorAll(".dropdown > .menu-item-has-children > a");
for (let i = 0; i < menuItemHasChildren.length; i++) {
  menuItemHasChildren[i].insertAdjacentHTML("beforeEnd", "<i class='arrow-down'><svg viewBox='0 0 32 32'><path d='M32 11.008l-3.008-3.008-12.992 12.992-12.992-12.992-3.008 3.008 16 16 16-16z'></path></svg></i>");
}

// Mobile menu submenu
var mobileMenuWrapper = headerWrapper.querySelector(".mobile-menu-wrapper"),
  mobileMenuItemHasSubmenuDrop = mobileMenuWrapper.getElementsByClassName("menu-item-has-children");

function mobileMenuSubMenu(el) {
  el.closest(".menu-item-has-children").classList.toggle("active");
  var mobileMenuSubMenu = el.nextElementSibling;
  if (mobileMenuSubMenu.style.maxHeight) {
    mobileMenuSubMenu.style.maxHeight = null;
  } else {
    mobileMenuSubMenu.style.maxHeight = mobileMenuSubMenu.scrollHeight + "px";
  }
}

for (let i = 0; i < mobileMenuItemHasSubmenuDrop.length; i++) {
  var mainMenuItemA = mobileMenuItemHasSubmenuDrop[i].firstChild;
  if (mobileMenuItemHasSubmenuDrop[i].classList.contains("current-menu-ancestor")) {
    mobileMenuSubMenu(mainMenuItemA);
  }
  mainMenuItemA.addEventListener("click", function() {
    mobileMenuSubMenu(this);
  });
}
</script>
							<?php break 2; ?>
						<?php } ?>
					<?php } ?>
				<?php } ?>
			<?php } ?>
		<?php } ?>
	<?php } ?>
	
	<?php $footer_parallax = get_theme_mod( 'footer_parallax' ); ?>
	<?php if ( ! empty( $footer_parallax ) ) { ?>
<script>
"use strict";
// Footer Parallax
var bodyParallaxEnabled = document.querySelector(".footer-parallax-enabled"),
  main = document.getElementById("main"),
  mainHeight = main.offsetHeight;
if (mainHeight > window.screen.height) {
  var footerParallaxEnabled = document.getElementById("colophon");
  footerParallaxEnabled.classList.add("footer-parallax-init");
    
  bodyParallaxEnabled.style.paddingBottom = footerParallaxEnabled.offsetHeight + "px";
  window.addEventListener("load", function(event) {
    bodyParallaxEnabled.style.paddingBottom = footerParallaxEnabled.offsetHeight + "px";
  });
    
  var footerParallaxResize = debounce(function() {
    bodyParallaxEnabled.style.paddingBottom = footerParallaxEnabled.offsetHeight + "px";
  }, 250);
  window.addEventListener("resize", footerParallaxResize);
}
</script>
	<?php } ?>
	
	<?php if ( isset( $post->post_content ) && has_shortcode( $post->post_content, 'vc_tta_team_slider' ) ) { ?>
<script>
"use strict";
// Team Slider
jQuery(function($) {
var teamSliderWrapper = $(".team-slider-wrapper");
teamSliderWrapper.each(function() {
  var teamSlider = $(this).find(".team-slider");
    teamSlider.slick({
    slidesToShow: 1,
    slidesToScroll: 1,
    arrows: true,
    fade: true,
    variableWidth: false,
    infinite: true,
    adaptiveHeight: true
  });
  });
});
</script>
	<?php } ?>

	<?php $center_logo_and_menu = get_theme_mod( 'center_logo_and_menu' ); ?>
	<?php if ( empty( $center_logo_and_menu ) ) { ?>
	
	<?php $header_behavior = get_theme_mod( 'header_behavior', 'normal' ); ?>
	<?php $header_position = get_theme_mod( 'header_position', 'top' ); ?>
	<?php if ( $header_behavior == 'fixed' && in_array( $header_position, array( "top", "bottom" ) ) ) { ?>

		<?php $top_bar = get_theme_mod( 'top_bar' ); ?>
		<?php if ( ! empty( $top_bar ) ) { ?>
<script>
"use strict";
// Fixed Header Top Bar Enabled
var topBarEnabled = document.querySelector(".top-bar-enabled.non-sticky-top-bar, .top-bar-enabled.sticky-top-bar-on-scroll");
if (topBarEnabled) {
  var headerWrapper = document.getElementById("header-wrapper"),
    origOffsetY = headerWrapper.getBoundingClientRect().top,
    hasScrollY = 'scrollY' in window;
    
  window.addEventListener("scroll", function() {
    var y = hasScrollY ? window.scrollY : document.documentElement.scrollTop;
    y >= origOffsetY ? headerWrapper.classList.add("fixed") : headerWrapper.classList.remove("fixed");
  });
}
</script>
		<?php } ?>
		
		<?php $header_height_reduction_on_scrolling = get_theme_mod( 'header_height_reduction_on_scrolling' ); ?>
		<?php if ( ! empty( $header_height_reduction_on_scrolling ) ) { ?>
<script>
"use strict";
// Header Height on Scrolling
var body = document.body,
  offset = 1;
window.addEventListener("scroll", function() {
  if (this.scrollY > offset) {
	requestAnimationFrame(function() {
      body.classList.add("header-height-on-scrolling");
	});
  } else {
	requestAnimationFrame(function() {
      body.classList.remove("header-height-on-scrolling");
	});
  }
});
</script>
		<?php } ?>
	<?php } ?>
	
	<?php $header_position = get_theme_mod( 'header_position', 'top' ); ?>
	<?php if ( $header_behavior == 'fixed_on_scroll' && in_array( $header_position, array( "top", "bottom" ) ) ) { ?>
<script>
"use strict";
// Fixed Header on Scroll
var headerWrapper = document.getElementById('header-wrapper');
<?php $custom_logo_type = ''; ?>
<?php if ( has_custom_logo() ) { ?>
	<?php $custom_logo_id = get_theme_mod( 'custom_logo' ); ?>
	<?php // Check logo file type ?>
	<?php $custom_logo_type =  get_post_mime_type( $custom_logo_id ); ?>
	<?php $custom_logo_mime_type = explode( '/', $custom_logo_type ); ?>
	<?php if ( ! isset( $custom_logo_mime_type['1'] ) ) { ?>
	   <?php $custom_logo_mime_type['1'] = null; ?>
	<?php } ?>
	<?php $custom_logo_type = $custom_logo_mime_type['1']; ?>
<?php } ?>
function ghostHeader() {
  var headerWrapperCloned = headerWrapper.cloneNode(true);
  headerWrapperCloned.classList.remove("main-header");
  headerWrapperCloned.classList.add("ghost-header");
  var page = document.getElementById("page");
  page.insertBefore(headerWrapperCloned, headerWrapper);
	
  <?php if ( is_admin_bar_showing() ) { ?>
  var adminBar = document.getElementById("wpadminbar");
  var headerHeight = adminBar.offsetHeight;
  headerWrapperCloned.style.setProperty("top", headerHeight + "px");
  <?php } ?>
	
  var mobileMenuWrapper = headerWrapperCloned.querySelector(".mobile-menu-wrapper");
  mobileMenuWrapper.remove();
	
  <?php if ( has_nav_menu( 'sliding' ) ) { ?>
  var slidingMenuWrapper = headerWrapperCloned.querySelector("#sliding-menu-wrapper");
  slidingMenuWrapper.remove();
  <?php } ?>
  var branding = headerWrapperCloned.querySelector("#branding");
  branding.classList.add("compensate-for-scrollbar");
	
  var offset = headerWrapper.offsetHeight + 10,
    body = document.body;
  window.addEventListener("scroll", function() {
    if (this.scrollY > offset) {
	  requestAnimationFrame(function() {
        body.classList.add("ghost-header-show");
	  });
    } else {
	  requestAnimationFrame(function() {
        body.classList.remove("ghost-header-show");
	  });
    }
  });
}
<?php if ( $custom_logo_type == 'svg+xml' ) { ?>
document.addEventListener("svg.loaded", function(e) {
  ghostHeader();
});
<?php } else { ?>
ghostHeader();
<?php } ?>
</script>
	<?php } ?>
	
	<?php } else { ?>
	
		<?php $header_behavior = get_theme_mod( 'header_behavior', 'normal' ); ?>
		<?php $header_height_reduction_on_scrolling = get_theme_mod( 'header_height_reduction_on_scrolling' ); ?>
		
		<?php if ( $header_behavior == 'fixed' ) { ?>
<script>
"use strict";
// Fixed Header Center Logo and Menu Enabled
var sticky = document.getElementById("access-wrapper"),
  origOffsetY = sticky.getBoundingClientRect().top,
  hasScrollY = 'scrollY' in window;

window.addEventListener("scroll", function() {
  var y = hasScrollY ? window.scrollY : document.documentElement.scrollTop;
  <?php if ( ! empty( $header_height_reduction_on_scrolling ) ) { ?>
  y >= origOffsetY ? sticky.classList.add("fixed", "header-height-on-scrolling") : sticky.classList.remove("fixed", "header-height-on-scrolling");
  <?php } else { ?>
  y >= origOffsetY ? sticky.classList.add("fixed") : sticky.classList.remove("fixed");
  <?php } ?>
});
</script>
		<?php } ?>
		
	<?php } // End if empty( $center_logo_and_menu ) ) ?>
	
	<?php $top_bar = get_theme_mod( 'top_bar' ); ?>
	<?php if ( ! empty( $top_bar ) ) { ?>
		<?php $top_bar_behavior = get_theme_mod( 'top_bar_behavior', 'normal' ); ?>
		<?php if ( $top_bar_behavior == 'fixed' ) { ?>
			<?php $top_bar_height_reduction_on_scrolling = get_theme_mod( 'top_bar_height_reduction_on_scrolling' ); ?>
			<?php if ( ! empty( $top_bar_height_reduction_on_scrolling ) ) { ?>
<script>
"use strict";
// Top Bar Height on Scrolling
window.addEventListener("load", function(event) {
  var body = document.body,
    offset = 1;
  window.addEventListener("scroll", function() {
    if (this.scrollY > offset) {
	  requestAnimationFrame(function() {
        body.classList.add("top-bar-height-on-scrolling");
	  });
    } else {
	  requestAnimationFrame(function() {
        body.classList.remove("top-bar-height-on-scrolling");
	  });
    }
  });
});
</script>
			<?php } ?>
		<?php } ?>
		
		<?php if ( $top_bar_behavior == 'fixed_on_scroll' ) { ?>
<script>
"use strict";
// Fixed Top Bar on Scroll
var topBarWrapper = document.getElementById("top-bar-wrapper");

var topBarWrapperCloned = topBarWrapper.cloneNode(true);
topBarWrapperCloned.classList.add("ghost-top-bar");
var page = document.getElementById("page");
page.insertBefore(topBarWrapperCloned, topBarWrapper);

<?php if ( is_admin_bar_showing() ) { ?>
var adminBar = document.getElementById('wpadminbar');
var headerHeight = adminBar.offsetHeight;
topBarWrapperCloned.style.setProperty('top', headerHeight + 'px');
<?php } ?>

var offset = topBarWrapper.offsetHeight + 10,
  body = document.body;
window.addEventListener("scroll", function() {
  if (this.scrollY > offset) {
	requestAnimationFrame(function() {
      body.classList.add("ghost-top-bar-show");
	});
  } else {
	requestAnimationFrame(function() {
      body.classList.remove("ghost-top-bar-show");
	});
  }
});
</script>
		<?php } ?>
		
	<?php } // End if ! empty( $top_bar ) ) ?>
	
	<?php $header_height_width = get_theme_mod( 'header_height_width', 64 ); ?>
	<?php $header_height_reduction_on_scrolling = get_theme_mod( 'header_height_reduction_on_scrolling' ); ?>
	<?php $header_height_on_scrolling = get_theme_mod( 'header_height_on_scrolling', 54 ); ?>
	<?php $center_logo_and_menu = get_theme_mod( 'center_logo_and_menu' ); ?>
	<?php $menu_height_on_scrolling = 40; ?>
	
	<?php if ( ! empty( $header_height_reduction_on_scrolling ) ) { ?>
		<?php if ( ! empty( $center_logo_and_menu ) ) { ?>
			<?php $offset = $menu_height_on_scrolling; ?>
		<?php } else { ?>
			<?php $offset = $header_height_on_scrolling + 40; ?>
		<?php } ?>
	<?php } else { ?>
		<?php if ( $header_behavior == 'fixed' || $header_behavior == 'fixed_on_scroll' ) { ?>
			<?php $offset = $header_height_width + 40; ?>
		<?php } else { ?>
			<?php $offset = 40; ?>
		<?php } ?>
	<?php } ?>
	
	<?php $top_bar = get_theme_mod( 'top_bar' ); ?>
	<?php if ( ! empty( $top_bar ) ) { ?>
		<?php $top_bar_height = get_theme_mod( 'top_bar_height', 40 ); ?>
		<?php $top_bar_height_reduction_on_scrolling = get_theme_mod( 'top_bar_height_reduction_on_scrolling' ); ?>
		<?php $top_bar_height_on_scrolling = get_theme_mod( 'top_bar_height_on_scrolling', 30 ); ?>
		
		<?php if ( ! empty( $top_bar_height_reduction_on_scrolling ) ) { ?>
			<?php $offset = $offset + $top_bar_height_on_scrolling; ?>
		<?php } else { ?>
			<?php if ( $top_bar_behavior == 'fixed' || $top_bar_behavior == 'fixed_on_scroll' ) { ?>
				<?php $offset = $offset + $top_bar_height; ?>
			<?php } ?>
		<?php } ?>
	<?php } ?>
	
	<?php $header_position = get_theme_mod( 'header_position', 'top' ); ?>
	<?php $offsetBottom = 40; ?>
	<?php if ( $header_position == 'top' ) { ?>
		<?php $offsetTop = $offset; ?>
	<?php } else if ( $header_position == 'bottom' ) { ?>
		<?php $offsetTop = 40; ?>
		<?php $offsetBottom = $offset; ?>
	<?php } else { ?>
		<?php if ( ! empty( $top_bar ) && $top_bar_behavior == 'fixed' || ! empty( $top_bar ) && $top_bar_behavior == 'fixed_on_scroll' ) { ?>
			<?php $offsetTop = 40 + $top_bar_height; ?>
		<?php } else { ?>
			<?php $offsetTop = 40; ?>
		<?php } ?>
	<?php } ?>
	
	<?php if ( is_admin_bar_showing() ) { ?>
		<?php $offsetTop =  $offsetTop + 32; ?>
	<?php } ?>
	
	<?php if ( is_singular( 'post' ) ) { ?>
<script>
"use strict";
// Anchor link offset
function offsetAnchor() {
  if (location.hash.length !== 0) {
    window.scrollTo(window.scrollX, window.scrollY - <?php echo esc_html( $offsetTop ); ?>);
  }
}

// This will capture hash changes while on the page
window.addEventListener("hashchange", offsetAnchor);

// This is here so that when you enter the page with a hash,
// it can provide the offset in that case too. Having a timeout
// seems necessary to allow the browser to jump to the anchor first.
window.setTimeout(offsetAnchor, 1); // The delay of 1 is arbitrary and may not always work right.
</script>
	<?php } ?>
	
	<?php $disable_right_click_on_images = get_theme_mod( 'disable_right_click_on_images' ); ?>
	<?php if ( ! empty( $disable_right_click_on_images ) ) { ?>
<script>
"use strict";
// Disable Right Click on Images
window.addEventListener("load", function(event) {
  var img = document.querySelectorAll("img");
  for (let i = 0; i < img.length; i++) {
    img[i].addEventListener("contextmenu", function(event) {
      event.preventDefault();
    });
  }
});
</script>
	<?php } ?>
	
<?php
}
add_action( 'wp_footer', 'mega_initialize_javascript', 99 );

/**
 * Add a style block to the theme for the logo height.
 */
function mega_print_custom_logo_height_style() {
	
	$custom_logo = get_theme_mod( 'custom_logo' );
	if ( empty( $custom_logo ) )
		return;
	
	$logo_height = get_theme_mod( 'logo_height', 32 );
	
	wp_enqueue_style( 'mega-style' );
	
	$logo_height_css = "
	/* Logo Height */
	#site-title .logo-svg,
	.sticky-header #site-title .logo-svg,
	#site-title .logo-default,
	#site-title .logo-for-transparent-header {
		height: {$logo_height}px;
		max-height: none;
	}";
	
	wp_add_inline_style( 'mega-style', $logo_height_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_custom_logo_height_style' );

/**
 * Add a style block to the theme for the tagline margin.
 */
function mega_print_tagline_margin_style() {
	$tagline_margin = get_theme_mod( 'tagline_margin' );
	if ( empty( $tagline_margin ) )
		return;
		
	wp_enqueue_style( 'mega-style' );
	
	$tagline_margin_css = "
	/* Tagline Margin */
	.site-description-below .site-description {
		margin-top: .575rem;
	}";
	
	wp_add_inline_style( 'mega-style', $tagline_margin_css );
	
}
add_action( 'wp_enqueue_scripts', 'mega_print_tagline_margin_style' );

/**
 * Add a style block to the theme for the search align.
 */
function mega_print_search_align_style() {
	$search_align = get_theme_mod( 'search_align', 'right' );
	if ( $search_align == 'right' )
		return;
	
	if ( $search_align == 'left' ) {
		
		wp_enqueue_style( 'mega-style' );
		
		$search_align_css = "
		/* Search Align */
		.search-header-wrapper {
			float: left;
			margin-left: 0;
			margin-right: 30px;
		}";
		
		wp_add_inline_style( 'mega-style', $search_align_css );
	}
	
}
add_action( 'wp_enqueue_scripts', 'mega_print_search_align_style' );

/**
 * Add a style block to the theme for the primary/secondary/top bar menu items transition hover.
 */
function mega_print_primary_secondary_top_bar_menu_items_transition_hover_style() {
	$primary_secondary_top_bar_menu_items_transition_hover = get_theme_mod( 'primary_secondary_top_bar_menu_items_transition_hover' );
	if ( empty( $primary_secondary_top_bar_menu_items_transition_hover ) )
		return;
		
		wp_enqueue_style( 'mega-style' );
		
		$primary_secondary_top_bar_menu_items_transition_hover_css = "
		/* Menu Items Transition Hover */
		.primary-secondary-top-bar-menu-items-transition-hover-enabled .nav-menu ul li a > span {
			transition: opacity cubic-bezier(.455,.03,.515,.955) .2s, transform cubic-bezier(.455,.03,.515,.955) .2s, visibility cubic-bezier(.455,.03,.515,.955) .2s;
		}
		.primary-secondary-top-bar-menu-items-transition-hover-enabled .nav-menu ul li a:hover > span {
			transform: translate(0, -75%);
			opacity: 0;
			visibility: hidden;
		}
		.primary-secondary-top-bar-menu-items-transition-hover-enabled .nav-menu ul li a:before {
			display: inline-block;
			content: attr(data-hover);
			position: absolute;
			opacity: 0;
			visibility: hidden;
			transform: translate(0, 75%);
			transition: opacity cubic-bezier(.455,.03,.515,.955) .2s, transform cubic-bezier(.455,.03,.515,.955) .2s, visibility cubic-bezier(.455,.03,.515,.955) .2s;
			height: auto;
			background: transparent;
			left: auto;
			top: auto;
			transform-origin: initial;
			width: auto;
		}
		.primary-secondary-top-bar-menu-items-transition-hover-enabled .nav-menu ul li a:hover:before {
			visibility: visible;
			opacity: 1;
			transform: translate(0, 0);
		}
		.primary-secondary-top-bar-menu-items-transition-hover-enabled .nav-menu ul li a:active:before {
			transition: color ease 0s, opacity ease 0s, background ease 0s;
		}";
		
		wp_add_inline_style( 'mega-style', $primary_secondary_top_bar_menu_items_transition_hover_css );
	
}
add_action( 'wp_enqueue_scripts', 'mega_print_primary_secondary_top_bar_menu_items_transition_hover_style' );

/**
 * Add a style block to the theme for the links hover opacity effect.
 */
function mega_print_links_hover_opacity_effect_style() {
	$links_hover_opacity_effect = get_theme_mod( 'links_hover_opacity_effect', true );
	if ( empty( $links_hover_opacity_effect ) )
		return;
		
		wp_enqueue_style( 'mega-style' );
		
		$links_hover_opacity_effect_css = "
		/* Links Hover Effect */
		a:hover,
		#site-title a:hover,
		.social-links .social:hover,
		.search-header-icon:hover,
		.post-info-button:hover,
		.close-button:hover,
		#sliding-menu-wrapper .sliding-menu a:hover,
		#sliding-menu-dropdown:hover,
		#sliding-menu-dropdown:hover i:before,
		.mobile-menu-dropdown:hover,
		.nav-menu .drop-icon:hover,
		#page .search-wrapper .search-submit:hover,
		#page .tag-links a:hover,
		.post-password-form .submit-button-wrapper:hover,
		#page .nav-pagination a:hover,
		#page #nav-pagination-single a:hover:before,
		#page .nav-pagination > .current,
		.skylab.tparrows:hover:before,
		#to-top:hover i,
		#page .easy-social-share-button-custom .essb_links .essb_link_sharebtn.active a,
		.single-product #page .easy-social-share-button-custom .essb_links .essb_link_sharebtn a:hover,
		#page .easy-social-share-button-custom .essb_links_list-drop li a:hover,
		#page .easy-social-share-button-custom-addition .essb_links .essb_link_sharebtn a:hover,
		#page .special-button-2 .vc_btn3.vc_btn3-style-modern:hover,
		#page .special-button-2 .vc_btn3.vc_btn3-style-modern:focus,
		#page .special-button .vc_general.vc_btn3.vc_btn3-style-modern:focus,
		#page .special-button .vc_general.vc_btn3.vc_btn3-style-modern:hover,
		.all-posts-link a:hover,
		.owl-mt-theme .owl-nav [class*='owl-']:hover,
		.slick-prev:hover,
		.slick-prev:focus,
		.slick-next:hover,
		.slick-next:focus,
		#content .scroll-down-button:hover,
		.down-button:hover i,
		.entry-header a:hover,
		.more-link:hover,
		#page #nav-pagination-single a:hover:before,
		#to-top:hover i,
		#content #content .wpcf7-submit:hover,
		#respond #submit:hover,
		.post-password-form .submit-button-wrapper:hover,
		#page a.button.alt:hover,
		#page button.button.alt:hover,
		#page input.button.alt:hover,
		#page #respond input#submit.alt:hover,
		#page #respond #submit.alt:hover,
		#page #main input.button.alt:hover,
		#page a.button:hover,
		#page button.button:hover,
		#page input.button:hover,
		.slick-prev:hover,
		.slick-next:hover {
			opacity: .7;
		}";
		
		wp_add_inline_style( 'mega-style', $links_hover_opacity_effect_css );
	
}
add_action( 'wp_enqueue_scripts', 'mega_print_links_hover_opacity_effect_style' );

/**
 * Add a style block to the theme for the links click opacity effect.
 */
function mega_print_links_click_opacity_effect_style() {
	$links_click_opacity_effect = get_theme_mod( 'links_click_opacity_effect' );
	if ( empty( $links_click_opacity_effect ) )
		return;
		
		wp_enqueue_style( 'mega-style' );
		
		$links_click_opacity_effect_css = "
		/* Links Click Opacity Effect */
		a:active,
		#site-title a:active,
		#page .nav-pagination a:active,
		.social-links .social:active {
			opacity: .4;
			transition: color ease .1s, opacity ease .1s, background ease .1s;
		}";
		
		wp_add_inline_style( 'mega-style', $links_click_opacity_effect_css );
	
}
add_action( 'wp_enqueue_scripts', 'mega_print_links_click_opacity_effect_style' );

/**
 * Add a style block to the theme for the center content horizontally for left/right header.
 */
function mega_print_center_content_horizontally_for_left_right_header_behavior_style() {
	$header_position = get_theme_mod( 'header_position', 'top' );
	if ( $header_position == 'top' || $header_position == 'bottom' )
		return;
	
	$center_content_horizontally_for_left_right_header = get_theme_mod( 'center_content_horizontally_for_left_right_header' );
	if ( empty( $center_content_horizontally_for_left_right_header ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$center_content_horizontally_for_left_right_header_css = "
		/* Center Content Horizontally for Left/Right Header */
		.nav-menu-primary-header-wrapper,
		.nav-menu-secondary-header-wrapper {
			width: 100%;
		}
		.header-elements-wrapper {
			display: flex;
			justify-content: center;
		}
		.header-position-left #site-title,
		.header-position-right #site-title,
		.header-position-left .header .nav-menu ul,
		.header-position-right .header .nav-menu ul,
		.header-position-left .header .nav-menu ul li,
		.header-position-right .header .nav-menu ul li {
			text-align: center;
		}
		.header-position-left .header .nav-menu ul li,
		.header-position-right .header .nav-menu ul li {
			width: 100%;
		}
		.header-position-left .header .social-links-wrapper,
		.header-position-right .header .social-links-wrapper {
			justify-content: center;
		}";
		
		wp_add_inline_style( 'mega-style', $center_content_horizontally_for_left_right_header_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_center_content_horizontally_for_left_right_header_behavior_style' );

/**
 * Add a style block to the theme for the header position bottom.
 */
function mega_print_header_position_bottom_style() {
	$header_position = get_theme_mod( 'header_position', 'top' );
	if ( $header_position == 'bottom' ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$header_position_bottom_css = "
		/* Header Position Bottom */
		.header-position-bottom #header-wrapper.fixed {
			bottom: 0;
		}
		.header-position-bottom .nav-menu ul li ul {
			top: auto !important;
			bottom: 100%;
		}
		.header-position-bottom .nav-menu ul li li ul {
			bottom: 0;
		}
		.header-position-bottom #access .sub-menu {
			padding: 0 0 8px;
		}
		.header-position-bottom #access li li .sub-menu {
			padding: 0;
		}
		.header-position-bottom #access .nav-menu .sf-arrows .sf-with-ul:after {
			transform: perspective(100px) rotateX(180deg);
		}
		.header-position-bottom #access .nav-menu .sf-arrows .sfHover .sf-with-ul:after {
			transform: perspective(100px) rotateX(0deg);
		}
		.header-position-bottom .mobile-menu-wrapper {
			bottom: 0;
			top: auto;
		}
		.header-position-bottom #to-top-wrapper.fixed {
			top: 40px;
			bottom: auto;
		}
		@media (max-width: 1023px) {
			.header-position-bottom #page #main {
				padding-top: 0;
				padding-bottom: 60px;
			}
			.header-position-bottom #to-top-wrapper.fixed {
				top: 15px;
			}
		}";
		
		wp_add_inline_style( 'mega-style', $header_position_bottom_css );
	}
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_position_bottom_style' );

/**
 * Add a style block to the theme for the header info.
 */
function mega_header_info_style() {
	
	$header_info = get_theme_mod( 'header_info' );
	if ( empty( $header_info ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$header_info_css = "
		/* Header Info */
		.info-header {
			float: left;
		}
		.header-wrapper .info-header {
			color: var(--header-text-color);
		}
		.header-wrapper .info-header a {
			color: var(--header-link-color);
		}
		.header-wrapper .info-header a:hover {
			color: var(--header-link-color-hover);
		}
		.header-wrapper .info-header a:active {
			color: var(--header-link-color-active);
			transition: color ease .1s, opacity ease .1s;
		}
		.info-header span:first-child {
			margin-left: 0;
		}
		#page .info-header {
			font-size: inherit;
			float: right;
			height: 100%;
			margin-left: 50px;
			display: flex;
			position: relative;
			-webkit-user-select: text;
			-moz-user-select: text;
			-ms-user-select: text;
			user-select: text;
			align-items: center;
			color: #000;
		}
		.info-header p {
			margin-bottom: 0;
			font-size: inherit;
			line-height: inherit;
		}
		#page #branding .vc_btn3-container {
			margin-bottom: 0;
		}
		@media (max-width: 1023px) {
			#page .mobile-menu-wrapper .info-header {
				margin-left: 0;
				float: left;
				display: block;
			}
			#page .mobile-menu-wrapper .info-header > span {
				float: left;
				clear: both;
				display: block;
				margin-bottom: 1em;
				margin-left: 0 !important;
			}
			#access .info-header {
				display: none;
			}
		}
		@media (max-width: 600px) {
			.info-header {
				float: none;
			}
		}";
		
		wp_add_inline_style( 'mega-style', $header_info_css );
}
add_action( 'wp_enqueue_scripts', 'mega_header_info_style' );

/**
 * Add a style block to the theme for the header top border.
 */
function mega_print_header_top_border_style() {
	$header_top_border = get_theme_mod( 'header_top_border' );
	$header_position = get_theme_mod( 'header_position', 'top' );
	
	if ( empty( $header_top_border ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		if ( $header_position == 'left' ) {
		
			$header_top_border_css = "
			/* Header Right Border */
			#header-wrapper {
				border-right: 1px solid #e6e6e6;
			}";
		
		} else if ( $header_position == 'right' ) {
			
			$header_top_border_css = "
			/* Header Left Border */
			#header-wrapper {
				border-left: 1px solid #e6e6e6;
			}";
			
		} else {
			
			$header_top_border_css = "
			/* Header Top Border */
			#header-wrapper {
				border-top: 1px solid #e6e6e6;
			}";
			
		}
		
		wp_add_inline_style( 'mega-style', $header_top_border_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_top_border_style' );

/**
 * Add a style block to the theme for the header bottom border.
 */
function mega_print_header_bottom_border_style() {
	$header_bottom_border = get_theme_mod( 'header_bottom_border' );
	$header_position = get_theme_mod( 'header_position', 'top' );
	
	if ( empty( $header_bottom_border ) )
		return;
	
	if ( $header_position != 'top' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$header_bottom_border_css = "
		/* Header Bottom Border */
		#header-wrapper {
			border-bottom: 1px solid #e6e6e6;
		}";
		
		wp_add_inline_style( 'mega-style', $header_bottom_border_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_bottom_border_style' );

/**
 * Add a style block to the theme for the primary menu align.
 */
function mega_print_menu_align_style() {
	$menu_align = get_theme_mod( 'menu_align', 'right' );
	$header_position = get_theme_mod( 'header_position', 'top' );
	
	if ( $menu_align == 'right' )
		return;
	
	if ( $menu_align == 'left' ) {
		
		wp_enqueue_style( 'mega-style' );
		
		$menu_align_css = "
		/* Primary Menu Align */
		.header .menu-wrapper-primary {
			float: left;
		}
		.header .menu-wrapper-primary {
			margin-left: 0;
		}";
		
		wp_add_inline_style( 'mega-style', $menu_align_css );
	}
	
	if ( $menu_align == 'center' ) {
		
		wp_enqueue_style( 'mega-style' );
		
		if ( $header_position == 'left' ||  $header_position == 'right' ) {
		
		$menu_align_css = "
		/* Primary Menu Align */
		.header-position-left .menu-wrapper-primary {
			margin-top: auto;
		}";
		
		} else {
			
		$menu_align_css = "
		/* Primary Menu Align */
		.header .menu-wrapper-primary {
			position: absolute;
			width: 100%;
			justify-content: center;
		}
		.header .menu-wrapper-primary {
			margin-left: 0;
		}";
			
		}
		
		wp_add_inline_style( 'mega-style', $menu_align_css );
	}
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_align_style' );

/**
 * Add a style block to the theme for the secondary menu align.
 */
function mega_print_secondary_menu_align_style() {
	$secondary_menu_align = get_theme_mod( 'secondary_menu_align', 'right' );
	$header_position = get_theme_mod( 'header_position', 'top' );
	
	if ( $secondary_menu_align == 'right' )
		return;
	
	if ( $secondary_menu_align == 'left' ) {
		
		wp_enqueue_style( 'mega-style' );
		
		$secondary_menu_align_css = "
		/* Secondary Menu Align */
		.header .menu-wrapper-secondary {
			float: left;
		}
		.header .menu-wrapper-secondary {
			margin-left: 0;
		}";
		
		wp_add_inline_style( 'mega-style', $secondary_menu_align_css );
	}
	
}
add_action( 'wp_enqueue_scripts', 'mega_print_secondary_menu_align_style' );

/**
 * Add a style block to the theme for the mobile menu align.
 */
function mega_print_mobile_menu_align_style() {
	$mobile_menu_align = get_theme_mod( 'mobile_menu_align', 'left' );
	
	if ( $mobile_menu_align == 'left' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$mobile_menu_align_css = "
		/* Mobile Menu Align */
		.mobile-menu-dropdown-wrapper.align-right {
			float: right;
			margin-left: 0;
			margin-right: -15px;
		}
		.mobile-menu-wrapper.align-right {
			left: auto;
			right: 0;
		}
		.mobile-menu-wrapper.align-right .access-mobile-menu-wrapper {
			padding-right: 15px;
			padding-left: 30px;
		}
		.mobile-menu-wrapper.align-right .close-button {
			right: 0;
		}";
		
		wp_add_inline_style( 'mega-style', $mobile_menu_align_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_mobile_menu_align_style' );

/**
 * Add a style block to the theme for the logo align.
 */
function mega_print_logo_align_style() {
	$logo_align = get_theme_mod( 'logo_align', 'left' );
	
	if ( $logo_align == 'left' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		if ( $logo_align == 'center' ) {
		
			$logo_align_css = "
			/* Logo Align */
			#site-title {
				float: none;
				justify-content: center;
				position: absolute;
				width: 100%;
				z-index: 900;
				margin-right: 0;
				
				width: auto;
				left: 50%;
				transform: translateX(-50%);
			}
			.site-title,
			#site-title a .site-description {
				text-align: center;
			}
			.site-description-below .site-title-description-wrapper {
				align-items: center;
			}";
		
		} else {
			
			$logo_align_css = "
			/* Logo Align */
			#site-title {
				float: right;
				margin-right: 0;
				margin-left: 30px;
			}
			.site-description-below .site-title-description-wrapper {
				align-items: flex-end;
			}";
			
		}
		
		wp_add_inline_style( 'mega-style', $logo_align_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_logo_align_style' );

/**
 * Add a style block to the theme for the header height.
 */
function mega_print_header_height_style() {
	
	$center_logo_and_menu = get_theme_mod( 'center_logo_and_menu' );
	$header_position = get_theme_mod( 'header_position', 'top' );
	$header_height_width = get_theme_mod( 'header_height_width', 64 );
	
	if ( empty( $center_logo_and_menu ) ) {
		
		wp_enqueue_style( 'mega-style' );
		
		if ( $header_position == 'left' ) {
			
		$offset = $header_height_width + 30;
		
		$header_height_css = "
		/* Header Width */
		@media (min-width: 1023px) {
			#header-wrapper {
				width: {$header_height_width}px;
			}
			#main-wrapper {
				padding-left: {$header_height_width}px;
			}
		}
		.header-position-left #page #nav-pagination-single .nav-previous {
			left: {$offset}px;
		}
		.header-position-right #page #nav-pagination-single .nav-next {
			right: {$offset}px;
		}";
		
		} else if ( $header_position == 'right' ) {
			
		$offset = $header_height_width + 30;
		
		$header_height_css = "
		/* Header Width */
		@media (min-width: 1023px) {
			#header-wrapper {
				width: {$header_height_width}px;
			}
			#main-wrapper {
				padding-right: {$header_height_width}px;
			}
		}
		.header-position-left #page #nav-pagination-single .nav-previous {
			left: {$offset}px;
		}
		.header-position-right #page #nav-pagination-single .nav-next {
			right: {$offset}px;
		}";
			
		} else if ( $header_position == 'bottom' ) {
			
		$header_top_border = get_theme_mod( 'header_top_border' );
		if ( empty( $header_top_border ) ) {
			$offset = $header_height_width;
		} else {
			$offset = $header_height_width + 1;
		}
			
		$header_height_css = "
		/* Header Height */
		@media (min-width: 1023px) {
			#header-wrapper {
				height: {$header_height_width}px;
			}
			#main {
				padding-bottom: {$offset}px;
			}
		}";
		
		} else {
			
		$header_bottom_border = get_theme_mod( 'header_bottom_border' );
		if ( empty( $header_bottom_border ) ) {
			$offset = $header_height_width;
		} else {
			$offset = $header_height_width + 1;
		}
			
		$header_height_css = "
		/* Header Height */
		@media (min-width: 1023px) {
			#header-wrapper {
				height: {$header_height_width}px;
			}
			#main {
				padding-top: {$offset}px;
			}
		}";
			
		}
		
		wp_add_inline_style( 'mega-style', $header_height_css );
		
	}
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_height_style' );

/**
 * Add a style block to the theme for the header height reduction on scrolling.
 */
function mega_print_header_height_reduction_on_scrolling_style() {
	$header_behavior = get_theme_mod( 'header_behavior', 'normal' );
	if ( $header_behavior != 'fixed' )
		return;
	
	$header_height_reduction_on_scrolling = get_theme_mod( 'header_height_reduction_on_scrolling' );
	if ( empty( $header_height_reduction_on_scrolling ) )
		return;
	
	$header_height_on_scrolling = get_theme_mod( 'header_height_on_scrolling', 54 );
	if ( empty( $header_height_on_scrolling ) )
		return;
	
	$header_position = get_theme_mod( 'header_position', 'top' );
	if ( $header_position == 'left' || $header_position == 'right' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		if ( $header_position == 'bottom' ) {
			
			$header_height_on_scrolling_css = "
			/* Header Height Reduction on Scrolling */
			@media (min-width: 1024px) {
				.header-height-on-scrolling #header-wrapper {
					height: {$header_height_on_scrolling}px;
				}
				#colophon {
					padding-bottom: {$header_height_on_scrolling}px;
				}
			}";
		
		} else {
			
			$header_height_on_scrolling_css = "
			/* Header Height Reduction on Scrolling */
			@media (min-width: 1024px) {
				.header-height-on-scrolling #header-wrapper {
					height: {$header_height_on_scrolling}px;
				}
			}";
			
		}
		
		wp_add_inline_style( 'mega-style', $header_height_on_scrolling_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_height_reduction_on_scrolling_style' );

/**
 * Add a style block to the theme for the header height on scrolling.
 */
function mega_print_header_height_on_scrolling_style() {
	$header_behavior = get_theme_mod( 'header_behavior', 'normal' );
	if ( $header_behavior == 'normal' || $header_behavior == 'fixed' )
		return;
	
	$header_height_reduction_on_scrolling = get_theme_mod( 'header_height_reduction_on_scrolling' );
	if ( empty( $header_height_reduction_on_scrolling ) )
		return;
	
		$header_height_on_scrolling = get_theme_mod( 'header_height_on_scrolling', 54 );
	
		$header_position = get_theme_mod( 'header_position', 'top' );
		if ( $header_position == 'left' || $header_position == 'right' )
			return;
	
		wp_enqueue_style( 'mega-style' );
		
		if ( $header_position == 'bottom' ) {
		
			$header_height_on_scrolling_css = "
			/* Header Height on Scrolling */
			#header-wrapper.ghost-header {
				height: {$header_height_on_scrolling}px;
			}";
		
		} else {
			
			$header_height_on_scrolling_css = "
			/* Header Height on Scrolling */
			#header-wrapper.ghost-header {
				height: {$header_height_on_scrolling}px;
			}";
			
		}
		
		wp_add_inline_style( 'mega-style', $header_height_on_scrolling_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_height_on_scrolling_style' );

/**
 * Add a style block to the theme for the center logo and menu.
 */
function mega_print_center_logo_and_menu_style() {
	$center_logo_and_menu = get_theme_mod( 'center_logo_and_menu' );
	if ( empty( $center_logo_and_menu ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$center_logo_and_menu_css = "
		/* Center Logo and Menu */
		@media (min-width: 1024px) {
			.center-logo-and-menu-enabled #site-title {
				float: none;
				justify-content: center;
				position: relative;
				margin: 0;
			}
			.center-logo-and-menu-enabled #branding {
				margin: 0 auto;
				padding: 0;
			}
			.center-logo-and-menu-enabled.top-bar-enabled #header-wrapper {
				top: auto;
			}
			.center-logo-and-menu-enabled #site-title img {
				max-height: 216px;
			}
			.center-logo-and-menu-enabled .mobile-menu-dropdown {
				float: none;
				text-align: center;
			}
			.center-logo-and-menu-enabled #access-wrapper {
				width: 100%;
				position: relative;
				background: var(--header-background-color);
				margin-top: 20px;
			}
			.center-logo-and-menu-enabled #access {
				position: relative;
				height: 100%;
				margin: 0 auto;
				max-width: none;
				padding: 0;
				z-index: 500;
				box-sizing: border-box;
				max-width: 1170px;
				display: flex;
				align-items: center;
				justify-content: center;
			}
			.center-logo-and-menu-enabled #access .nav-menu {
				position: absolute;
				width: 100%;
				left: 0;
				margin-left: 0;
				height: 100%;
				position: relative;
				float: none;
			}
			.center-logo-and-menu-enabled #nav-menu-wrapper {
				max-width: 1170px;
				margin: 0 auto;
				padding: 0;
				position: relative;
				padding: 0;
				height: 100%;
			}
			.center-logo-and-menu-enabled #access .nav-menu > ul {
				display: inline-block;
				text-align: center;
			}
			.center-logo-and-menu-enabled #access .nav-menu > ul li {
				margin-left: 50px;
			}
			.center-logo-and-menu-enabled #access .nav-menu ul li:first-child,
			.center-logo-and-menu-enabled #access .nav-menu ul ul li {
				margin-left: 0;
			}
			.center-logo-and-menu-enabled #access-wrapper.fixed {
				position: fixed;
				top: 0;
				left: 0;
			}
			.center-logo-and-menu-enabled #header-wrapper {
				padding: 40px 0;
				position: relative;
			}
			.center-logo-and-menu-enabled #header {
				border-top: none;
				border-bottom: none;
				height: auto;
			}
		}";
		
		wp_add_inline_style( 'mega-style', $center_logo_and_menu_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_center_logo_and_menu_style' );

/**
 * Add a style block to the theme for the menu opacity on hover.
 */
function mega_print_menu_opacity_hover_style() {
	$menu_opacity_hover = get_theme_mod( 'menu_opacity_hover' );
	if ( empty( $menu_opacity_hover ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_opacity_hover_css = "
		/* Menu Opacity on Hover */
		.header .nav-menu > ul:hover > li > a {
			opacity: .5;
		}
		.header .nav-menu > ul > li:hover > a {
			opacity: 1;
		}";
		
		wp_add_inline_style( 'mega-style', $menu_opacity_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_opacity_hover_style' );

/**
 * Add a style block to the theme for the mix blend mode.
 */
function mega_print_header_mix_blend_mode_style() {
	$header_mix_blend_mode = get_theme_mod( 'header_mix_blend_mode' );
	if ( empty( $header_mix_blend_mode ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$header_mix_blend_mode_css = "
		/* Header Mix Blend Mode */
		@media (min-width: 1024px) {
			.header-wrapper {
				mix-blend-mode: difference;
				filter: invert(1) grayscale(1) contrast(9);
			}
		}";
		
		wp_add_inline_style( 'mega-style', $header_mix_blend_mode_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_mix_blend_mode_style' );

/**
 * Add a style block to the theme for the justify content.
 */
function mega_print_header_justify_content_style() {
	$header_justify_content = get_theme_mod( 'header_justify_content' );
	if ( empty( $header_justify_content ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$header_justify_content_css = "
		/* Justify Content */
		@media (min-width: 1024px) {
			#access {
				display: flex;
				justify-content: space-between;
			}
			#site-title {
				position: relative;
				left: auto;
				transform: none;
				order: 2;
			}
			.header .menu-wrapper-primary {
				order: 1;
				margin: 0 auto;
				margin-left: 0;
				flex: 1;
			}
			.header .menu-wrapper-secondary {
				order: 3;
				margin: 0 auto;
				margin-right: 0;
				flex: 1;
			}
			.nav-menu-primary-header-wrapper,
			.nav-menu-secondary-header-wrapper,
			.nav-menu-primary-header,
			.nav-menu-secondary-header {
				width: 100%;
			}
			.nav-menu-primary-header ul li,
			.nav-menu-secondary-header ul li {
				flex: 1;
				text-align: center;
			}
			.nav-menu-primary-header ul li:first-of-type,
			.nav-menu-secondary-header ul li:last-of-type {
				flex: none;
			}
			.nav-menu-primary-header ul li ul,
			.nav-menu-secondary-header ul li ul {
				    min-width: auto;
					left: auto;
			}
			.nav-menu-primary-header ul li li,
			.nav-menu-secondary-header ul li li {
				text-align: center;
			}
			.nav-menu-primary-header ul li li a,
			.nav-menu-secondary-header ul li li a {
				width: auto;
			}
			.nav-menu-primary-header ul li ul,
			.nav-menu-secondary-header ul li ul {
				left: 8px;
			}
		}";
		
		wp_add_inline_style( 'mega-style', $header_justify_content_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_justify_content_style' );

/**
 * Add a style block to the theme for the top bar height.
 */
function mega_print_top_bar_height_style() {
	$top_bar = get_theme_mod( 'top_bar' );
	if ( empty( $top_bar ) )
		return;
	
	$top_bar_height = get_theme_mod( 'top_bar_height', 40 );
		
		wp_enqueue_style( 'mega-style' );
		
		$top_bar_height_css = "
		/* Top Bar Height */
		#top-bar-wrapper {
			height: {$top_bar_height}px;
		}
		@media (min-width: 1024px) {
			.top-bar-enabled #main {
				margin-top: {$top_bar_height}px;
			}
			.header-position-top.top-bar-enabled .main-header {
				top: {$top_bar_height}px;
			}
			.header-position-left.top-bar-enabled #header-wrapper,
			.header-position-right.top-bar-enabled #header-wrapper {
				margin-top: {$top_bar_height}px;
			}
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_height_css );
		
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_height_style' );

/**
 * Add a style block to the theme for the top bar height reduction on scrolling.
 */
function mega_print_top_bar_height_reduction_on_scrolling_style() {
	$top_bar = get_theme_mod( 'top_bar' );
	if ( empty( $top_bar ) )
		return;

	$top_bar_behavior = get_theme_mod( 'top_bar_behavior', 'normal' );
	if ( $top_bar_behavior != 'fixed' )
		return;

	$top_bar_height_reduction_on_scrolling = get_theme_mod( 'top_bar_height_reduction_on_scrolling' );
	if ( empty ( $top_bar_height_reduction_on_scrolling ) )
		return;
	
	$top_bar_height_on_scrolling = get_theme_mod( 'top_bar_height_on_scrolling', 30 );
	if ( empty( $top_bar_height_on_scrolling ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$top_bar_height_on_scrolling_css = "
		/* Top Bar Height Reduction on Scrolling */
		.top-bar-height-on-scrolling #top-bar-wrapper {
			height: {$top_bar_height_on_scrolling}px;
		}
		@media (min-width: 1024px) {
			.header-position-top.top-bar-enabled.sticky-top-bar.top-bar-height-on-scrolling #header-wrapper {
				top: {$top_bar_height_on_scrolling}px;
			}
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_height_on_scrolling_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_height_reduction_on_scrolling_style' );

/**
 * Add a style block to the theme for the top bar height on scrolling.
 */
function mega_print_top_bar_height_on_scrolling_style() {
	$top_bar = get_theme_mod( 'top_bar' );
	if ( empty( $top_bar ) )
		return;
	
	$top_bar_behavior = get_theme_mod( 'top_bar_behavior', 'normal' );
	if ( $top_bar_behavior == 'normal' || $top_bar_behavior == 'fixed' )
		return;

	$top_bar_height_reduction_on_scrolling = get_theme_mod( 'top_bar_height_reduction_on_scrolling' );
	if ( empty( $top_bar_height_reduction_on_scrolling ) )
		return;
	
		$top_bar_height_on_scrolling = get_theme_mod( 'top_bar_height_on_scrolling', 30 );
	
		wp_enqueue_style( 'mega-style' );
		
		$top_bar_height_on_scrolling_css = "
		/* Top Bar Height on Scrolling */
		#top-bar-wrapper.ghost-top-bar {
			height: {$top_bar_height_on_scrolling}px;
		}
		.top-bar-enabled.sticky-top-bar-on-scroll.ghost-top-bar-show #header-wrapper {
			top: {$top_bar_height_on_scrolling}px;
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_height_on_scrolling_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_height_on_scrolling_style' );

/**
 * Add a style block to the theme for the top bar bottom border.
 */
function mega_print_top_bar_bottom_border_style() {
	$top_bar_bottom_border = get_theme_mod( 'top_bar_bottom_border' );
	if ( empty( $top_bar_bottom_border ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$top_bar_bottom_border_css = "
		/* Top Bar Bottom Border */
		#top-bar-wrapper {
			border-bottom: 1px solid #e6e6e6;
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_bottom_border_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_bottom_border_style' );

/**
 * Add a style block to the theme for the top bar menu align.
 */
function mega_print_top_bar_menu_align_style() {
	$top_bar_menu_align = get_theme_mod( 'top_bar_menu_align', 'right' );
	if ( $top_bar_menu_align == 'right' )
		return;
	
	if ( $top_bar_menu_align == 'left' ) {
		
		wp_enqueue_style( 'mega-style' );
		
		$top_bar_menu_align_css = "
		/* Top Bar Menu Align */
		#top-bar .menu-wrapper-top-bar {
			float: left;
		}
		#top-bar .menu-wrapper-top-bar .nav-menu {
			margin-left: 0;
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_menu_align_css );
	}
	
	if ( $top_bar_menu_align == 'center' ) {
		
		wp_enqueue_style( 'mega-style' );
			
		$top_bar_menu_align_css = "
		/* Top Bar Menu Align */
		#top-bar .menu-wrapper-top-bar {
			position: absolute;
			width: 100%;
			justify-content: center;
			left: 0;
		}
		#top-bar .menu-wrapper-top-bar .nav-menu {
			margin-left: 0;
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_menu_align_css );
	}
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_menu_align_style' );

/**
 * Add a style block to the theme for the footer bottom area top padding.
 */
function mega_print_footer_bottom_area_top_padding_style() {
	$footer_bottom_area_top_padding = get_theme_mod( 'footer_bottom_area_top_padding', 40 );
	if ( $footer_bottom_area_top_padding == 40 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_bottom_area_top_padding_css = "
		/* Footer Bottom Area Top Padding */
		#site-generator {
			padding-top: {$footer_bottom_area_top_padding}px;
		}";
		
		wp_add_inline_style( 'mega-style', $footer_bottom_area_top_padding_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_bottom_area_top_padding_style' );

/**
 * Add a style block to the theme for the footer bottom area bottom padding.
 */
function mega_print_footer_bottom_area_bottom_padding_style() {
	$footer_bottom_area_bottom_padding = get_theme_mod( 'footer_bottom_area_bottom_padding', 40 );
	if ( empty( $footer_bottom_area_bottom_padding ) || $footer_bottom_area_bottom_padding == 40 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_bottom_area_bottom_padding_css = "
		/* Footer Bottom Area Bottom Padding */
		#site-generator {
			padding-bottom: {$footer_bottom_area_bottom_padding}px;
		}";
		
		wp_add_inline_style( 'mega-style', $footer_bottom_area_bottom_padding_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_bottom_area_bottom_padding_style' );

/**
 * Add a style block to the theme for the footer top border.
 */
function mega_print_footer_top_border_style() {
	$footer_top_border = get_theme_mod( 'footer_top_border' );
	if ( empty( $footer_top_border ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_top_border_css = "
		/* Footer Top Border */
		#colophon {
			border-top: 1px solid #e6e6e6;
		}";
		
		wp_add_inline_style( 'mega-style', $footer_top_border_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_top_border_style' );

/**
 * Add a style block to the theme for the footer bottom area top border.
 */
function mega_print_footer_bottom_area_top_border_style() {
	$footer_bottom_area_top_border = get_theme_mod( 'footer_bottom_area_top_border' );
	if ( empty( $footer_bottom_area_top_border ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_bottom_area_top_border_css = "
		/* Footer Bottom Area Top Border */
		#site-generator-wrapper {
			border-top: 1px solid #e6e6e6;
		}";
		
		wp_add_inline_style( 'mega-style', $footer_bottom_area_top_border_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_bottom_area_top_border_style' );

/**
 * Add a style block to the theme for the social links opacity on hover.
 */
function mega_print_social_links_opacity_hover_style() {
	$social_links_opacity_hover = get_theme_mod( 'social_links_opacity_hover' );
	if ( empty( $social_links_opacity_hover ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$social_links_opacity_hover_css = "
		/* Social Links Opacity on Hover */
		.social-links-wrapper:hover .social {
			opacity: .5;
		}
		.social-links-wrapper:hover .social:hover {
			opacity: 1;
		}";
		
		wp_add_inline_style( 'mega-style', $social_links_opacity_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_social_links_opacity_hover_style' );

/**
 * Add a style block to the theme for the social links align.
 */
function mega_print_social_links_align_style() {
	$social_links_align = get_theme_mod( 'social_links_align', 'right' );
	if ( $social_links_align == 'right' )
		return;
	
	if ( $social_links_align == 'left' ) {
		
		wp_enqueue_style( 'mega-style' );
		
		$social_links_align_css = "
		/* Social Links Align */
		.header .social-links-wrapper {
			float: left;
			padding-left: 0;
			padding-right: 30px;
		}";
		
		wp_add_inline_style( 'mega-style', $social_links_align_css );
	}
	
}
add_action( 'wp_enqueue_scripts', 'mega_print_social_links_align_style' );

/**
 * Add a style block to the theme for the primary typography google font URL.
 */
function mega_enqueue_primary_google_font() {
	$primary_typography_google_font_url = get_theme_mod( 'primary_typography_google_font_url', '' );
	if ( ! empty( $primary_typography_google_font_url ) ) {
		echo '<link href="'. esc_url( $primary_typography_google_font_url ) .'" rel="stylesheet">';
	}
}
add_action( 'wp_head', 'mega_enqueue_primary_google_font', 0 );

/**
 * Add a style block to the theme for the primary typography font.
 */
function mega_enqueue_primary_font() {
	$primary_typography_font = get_theme_mod( 'primary_typography_font', '' );
	
	if ( ! empty( $primary_typography_font ) ) {
		
		$primary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $primary_typography_font );
		foreach ( $primary_typography_font as $font ) {
		
			$font = html_entity_decode( $font );
			$font = json_decode( $font, true );
			if ( ! empty( $font['src'] ) ) {
				$font['src'] = explode( ',', $font['src'] );
				
				$output = "<style>
		/* {$font['name']} */
		@font-face {
			font-family: '{$font['name']}';
			src: "; $url = ""; foreach ( $font['src'] as $val ) {
				$path_parts = pathinfo( $val );
				$url .= "                 url('". $val ."') format('". $path_parts['extension'] ."'),";
				$url .= "\r\n";
				}
				$url = rtrim( trim( $url ), ',' );
				$url = rtrim( trim( $url ), '\r\n' );
				$output .= $url .";";
			$output .= "
			font-weight: {$font['weight']};
			font-style: {$font['style']};
		}</style>";
		foreach ( $font['src'] as $val ) {
		$path_parts = pathinfo( $val );
		$output .= "<link rel='preload' href='". $val ."' as='font' type='font/". $path_parts['extension'] ."' crossorigin>";
		}
		
				echo trim( $output );
			
			}
		
		}
		
	}
}
add_action( 'wp_head', 'mega_enqueue_primary_font', 0 );

function mega_print_primary_font() {
	$primary_typography_google_font_url = get_theme_mod( 'primary_typography_google_font_url', '' );
	$primary_typography_font = get_theme_mod( 'primary_typography_font', '' );
	
	if ( ! empty( $primary_typography_google_font_url ) || ! empty( $primary_typography_font ) ) {
		
		if ( ! empty( $primary_typography_font ) ) {
			
			$primary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $primary_typography_font );
			foreach ( $primary_typography_font as $font ) {
				$font = html_entity_decode( $font );
				$font = json_decode( $font, true );
			}
			$primary_font_name = $font['name'];
			
		}
		
		if ( empty( $primary_font_name ) ) {
			
			if ( ! empty( $primary_typography_google_font_url ) ) {
		
				$primary_google_font_name_offset = substr( $primary_typography_google_font_url, strpos( $primary_typography_google_font_url, "=" ) + 1 );
				if ( ( $primary_google_font_name = strpos( $primary_google_font_name_offset, ":" ) ) !== FALSE ) {
					$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, ":" ) );
				} else {
					$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, "&" ) );
				}
				$primary_google_font_name = str_replace( "+", " ", $primary_google_font_name );
				
				if ( ! empty( $primary_google_font_name ) ) {
					$primary_font_name = $primary_google_font_name;
				}
				
			}
		
		}
	
		wp_enqueue_style( 'mega-style' );
		
		$primary_typography_font_css = "
		/* Primary Typography */
		body,
		input,
		textarea,
		select,
		button,
		#cancel-comment-reply-link,
		#comments-title span {
			font-family: '{$primary_font_name}', sans-serif;
		}
		
		/* Primary Typography Special Class */
		.primary-typography {
			font-family: '{$primary_font_name}', sans-serif !important;
			font-weight: 400 !important;
			letter-spacing: 0 !important;
		}";
		
		wp_add_inline_style( 'mega-style', $primary_typography_font_css );
	}
}
add_action( 'wp_enqueue_scripts', 'mega_print_primary_font' );

/**
 * Add a style block to the theme for the secondary typography google font URL.
 */
function mega_enqueue_secondary_google_font() {
	$secondary_typography_google_font_url = get_theme_mod( 'secondary_typography_google_font_url' );
	if ( ! empty( $secondary_typography_google_font_url ) ) {
		echo '<link href="'. esc_url( $secondary_typography_google_font_url ) .'" rel="stylesheet">';
	}
}
add_action( 'wp_head', 'mega_enqueue_secondary_google_font', 0 );

/**
 * Add a style block to the theme for the secondary typography font.
 */
function mega_enqueue_secondary_font() {
	$secondary_typography_font = get_theme_mod( 'secondary_typography_font', '' );
	
	if ( ! empty( $secondary_typography_font ) ) {
		
		$secondary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $secondary_typography_font );
		foreach ( $secondary_typography_font as $font ) {
		
			$font = html_entity_decode( $font );
			$font = json_decode( $font, true );
			if ( ! empty( $font['src'] ) ) {
				$font['src'] = explode( ',', $font['src'] );
				
				$output = "<style>
		/* {$font['name']} */
		@font-face {
			font-family: '{$font['name']}';
			src: "; $url = ""; foreach ( $font['src'] as $val ) {
				$path_parts = pathinfo( $val );
				$url .= "                 url('". $val ."') format('". $path_parts['extension'] ."'),";
				$url .= "\r\n";
				}
				$url = rtrim( trim( $url ), ',' );
				$url = rtrim( trim( $url ), '\r\n' );
				$output .= $url .";";
			$output .= "
			font-weight: {$font['weight']};
			font-style: {$font['style']};
		}</style>";
		foreach ( $font['src'] as $val ) {
		$path_parts = pathinfo( $val );
		$output .= "<link rel='preload' href='". $val ."' as='font' type='font/". $path_parts['extension'] ."' crossorigin>";
		}
		
				echo trim( $output );
			
			}
		
		}
		
	}
}
add_action( 'wp_head', 'mega_enqueue_secondary_font', 0 );

function mega_print_secondary_font() {
	$secondary_typography_google_font_url = get_theme_mod( 'secondary_typography_google_font_url', '' );
	$secondary_typography_font = get_theme_mod( 'secondary_typography_font', '' );
	
	if ( ! empty( $secondary_typography_google_font_url ) || ! empty( $secondary_typography_font ) ) {
		
		if ( ! empty( $secondary_typography_font ) ) {
			
			$secondary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $secondary_typography_font );
			foreach ( $secondary_typography_font as $font ) {
				$font = html_entity_decode( $font );
				$font = json_decode( $font, true );
			}
			if ( ! empty( $font['name'] ) ) {
				$secondary_font_name = $font['name'];
			}
			
		}
		
		if ( empty( $secondary_font_name ) ) {
			
			if ( ! empty( $secondary_typography_google_font_url ) ) {
		
				$secondary_google_font_name_offset = substr( $secondary_typography_google_font_url, strpos( $secondary_typography_google_font_url, "=" ) + 1 );
				if ( ( $secondary_google_font_name = strpos( $secondary_google_font_name_offset, ":" ) ) !== FALSE ) {
					$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, ":" ) );
				} else {
					$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, "&" ) );
				}
				$secondary_google_font_name = str_replace( "+", " ", $secondary_google_font_name );
				
				if ( ! empty( $secondary_google_font_name ) ) {
					$secondary_font_name = $secondary_google_font_name;
				}
				
			}
		
		}
		
	}
	
	if ( ! empty( $secondary_typography_google_font_url ) || ! empty( $secondary_font_name ) ) {
	
	wp_enqueue_style( 'mega-style' );
	
	$secondary_typography_font_css = "
	/* Secondary Typography */
	h1, h2, h3, h4, h5, h6,
	.site-title,
	.site-description,
	.wpb_content_element .wpb_tour_tabs_wrapper .wpb_tabs_nav a,
	.wpb_content_element .wpb_accordion_header a,
	.woocommerce #page div.product .woocommerce-tabs ul.tabs li a,
	#page #nav-pagination-single .title-wrapper,
	.tparrows.skylab .title-wrapper,
	#page .product .wc-accordion > li > a,
	.pace .pace-progress-percent {
		font-family: '{$secondary_font_name}', sans-serif;
	}
	.gw-go-header,
	.secondary-font,
	#page .woocommerce ul.products li.product h3,
	#page .woocommerce ul.products li.product .price,
	.secondary-typography {
		font-family: '{$secondary_font_name}', sans-serif !important;
	}";
	
	wp_add_inline_style( 'mega-style', $secondary_typography_font_css );
	
	}
}
add_action( 'wp_enqueue_scripts', 'mega_print_secondary_font' );

/**
 * Add a style block to the theme for the additional typography google font URL.
 */
function mega_enqueue_additional_google_font() {
	$additional_typography_google_font_url = get_theme_mod( 'additional_typography_google_font_url' );
	if ( ! empty( $additional_typography_google_font_url ) ) {
		echo '<link href="'. esc_url( $additional_typography_google_font_url ) .'" rel="stylesheet">';
	}
}
add_action( 'wp_head', 'mega_enqueue_additional_google_font', 0 );

/**
 * Add a style block to the theme for the additional typography font.
 */
function mega_enqueue_additional_font() {
	$additional_typography_font = get_theme_mod( 'additional_typography_font', '' );
	
	if ( ! empty( $additional_typography_font ) ) {
		
		$additional_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $additional_typography_font );
		foreach ( $additional_typography_font as $font ) {
		
			$font = html_entity_decode( $font );
			$font = json_decode( $font, true );
			if ( ! empty( $font['src'] ) ) {
				$font['src'] = explode( ',', $font['src'] );
				
				$output = "<style>
		/* {$font['name']} */
		@font-face {
			font-family: '{$font['name']}';
			src: "; $url = ""; foreach ( $font['src'] as $val ) {
				$path_parts = pathinfo( $val );
				$url .= "                 url('". $val ."') format('". $path_parts['extension'] ."'),";
				$url .= "\r\n";
				}
				$url = rtrim( trim( $url ), ',' );
				$url = rtrim( trim( $url ), '\r\n' );
				$output .= $url .";";
			$output .= "
			font-weight: {$font['weight']};
			font-style: {$font['style']};
		}</style>";
		foreach ( $font['src'] as $val ) {
		$path_parts = pathinfo( $val );
		$output .= "<link rel='preload' href='". $val ."' as='font' type='font/". $path_parts['extension'] ."' crossorigin>";
		}
		
				echo trim( $output );
			
			}
		
		}
		
	}
}
add_action( 'wp_head', 'mega_enqueue_additional_font', 0 );

function mega_print_additional_font() {
	$additional_typography_google_font_url = get_theme_mod( 'additional_typography_google_font_url', '' );
	$additional_typography_font = get_theme_mod( 'additional_typography_font', '' );
	
	if ( ! empty( $additional_typography_google_font_url ) || ! empty( $additional_typography_font ) ) {
		
		if ( ! empty( $additional_typography_font ) ) {
			
			$additional_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $additional_typography_font );
			foreach ( $additional_typography_font as $font ) {
				$font = html_entity_decode( $font );
				$font = json_decode( $font, true );
			}
			$additional_font_name = $font['name'];
			
		}
		
		if ( empty( $additional_font_name ) ) {
			
			if ( ! empty( $additional_typography_google_font_url ) ) {
		
				$additional_google_font_name_offset = substr( $additional_typography_google_font_url, strpos( $additional_typography_google_font_url, "=" ) + 1 );
				if ( ( $additional_google_font_name = strpos( $additional_google_font_name_offset, ":" ) ) !== FALSE ) {
					$additional_google_font_name = substr( $additional_google_font_name_offset, 0, strpos( $additional_google_font_name_offset, ":" ) );
				} else {
					$additional_google_font_name = substr( $additional_google_font_name_offset, 0, strpos( $additional_google_font_name_offset, "&" ) );
				}
				$additional_google_font_name = str_replace( "+", " ", $additional_google_font_name );
				
				if ( ! empty( $additional_google_font_name ) ) {
					$additional_font_name = $additional_google_font_name;
				}
				
			}
		
		}
		
	}
	
	if ( ! empty( $additional_typography_google_font_url ) || ! empty( $additional_typography_font ) ) {
	
	wp_enqueue_style( 'mega-style' );
	
	$additional_typography_font_css = "
	/* Additional Typography */
	.additional-font {
		font-family: '{$additional_font_name}', sans-serif;
	}";
	
	wp_add_inline_style( 'mega-style', $additional_typography_font_css );
	
	}
}
add_action( 'wp_enqueue_scripts', 'mega_print_additional_font' );

/**
 * Add a style block to the theme for the body font size.
 */
function mega_print_body_font_size_style() {
	$body_font_size = get_theme_mod( 'body_font_size', 16 );
	if ( empty( $body_font_size ) || $body_font_size == 16 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$body_font_size_css = "
		/* Body Font Size */
		body,
		input,
		textarea,
		select,
		input[type=text],
		input[type=password],
		input[type=email],
		input[type=tel],
		input[type=number],
		input[type=search] {
			font-size: {$body_font_size}px;
		}";
		
		wp_add_inline_style( 'mega-style', $body_font_size_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_body_font_size_style' );

/**
 * Add a style block to the theme for the body font weight.
 */
function mega_print_body_font_weight_style() {
	$body_font_weight = get_theme_mod( 'body_font_weight', 400 );
	if ( $body_font_weight == 400 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$body_font_weight_css = "
		/* Body Font Weight */
		body,
		input,
		textarea,
		select,
		button,
		#respond #cancel-comment-reply-link,
		#comments-title span {
			font-weight: {$body_font_weight};
		}";
		
		wp_add_inline_style( 'mega-style', $body_font_weight_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_body_font_weight_style' );

/**
 * Add a style block to the theme for the bold font weight.
 */
function mega_print_bold_font_weight_style() {
	$bold_font_weight = get_theme_mod( 'bold_font_weight', 700 );
	if ( $bold_font_weight == 700 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$bold_font_weight_css = "
		/* Bold Font Weight */
		strong {
			font-weight: {$bold_font_weight};
		}";
		
		wp_add_inline_style( 'mega-style', $bold_font_weight_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_bold_font_weight_style' );

/**
 * Add a style block to the theme for the heading font weight.
 */
function mega_print_heading_font_weight_style() {
	$heading_font_weight = get_theme_mod( 'heading_font_weight', 700 );
	if ( $heading_font_weight == 700 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$heading_font_weight_css = "
		/* Heading Font Weight */
		h1,
		h2,
		h3,
		h4,
		h5,
		h6,
		#page #nav-pagination-single .title-wrapper,
		.tparrows.skylab .title-wrapper,
		.pace .pace-progress-percent {
			font-weight: {$heading_font_weight};
		}";
		
		wp_add_inline_style( 'mega-style', $heading_font_weight_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_heading_font_weight_style' );

/**
 * Add a style block to the theme for the links text decoration style.
 */
function mega_print_links_text_decoration_style() {
	$links_text_decoration = get_theme_mod( 'links_text_decoration', 'underline' );
	if ( $links_text_decoration == 'underline' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$links_text_decoration_css = "
		/* Links Text Decoration */
		#page .entry-content a,
		#page .widget a,
		#page .entry-summary a,
		#page .entry-header .entry-meta a,
		#page .comment-author a,
		#page #respond a,
		#page .entry-header .entry-meta a,
		.more-link span,
		.posts-template-title_visible3 article h2 a,
		#page .grecaptcha a {
			box-shadow: none;
		}";
		
		wp_add_inline_style( 'mega-style', $links_text_decoration_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_links_text_decoration_style' );

/**
 * Add a style block to the theme for the links text decoration weight.
 */
function mega_print_links_text_decoration_weight_style() {
	$links_text_decoration_weight = get_theme_mod( 'links_text_decoration_weight', 1 );
	if ( $links_text_decoration_weight == 1 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$links_text_decoration_weight_css = "
		/* Links Text Decoration Weight */
		.comment-author a,
		#respond a,
		.entry-header .entry-meta a,
		.more-link span,
		#page .posts-template-title_visible3 article h2 a,
		#page .grecaptcha a {
			box-shadow: 0 2px 0;
		}";
		
		wp_add_inline_style( 'mega-style', $links_text_decoration_weight_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_links_text_decoration_weight_style' );

/**
 * Add a style block to the theme for the links font style.
 */
function mega_print_links_font_style_style() {
	$links_font_style = get_theme_mod( 'links_font_style', 'normal' );
	if ( $links_font_style == 'normal' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$links_font_style_css = "
		/* Links Font Style */
		a {
			font-style: {$links_font_style};
		}";
		
		wp_add_inline_style( 'mega-style', $links_font_style_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_links_font_style_style' );

/**
 * Add a style block to the theme for the buttons font.
 */
function mega_print_buttons_typography() {
	$buttons_font = get_theme_mod( 'buttons_font' );
	
	if ( $buttons_font == 'secondary' ) {
		
		$secondary_typography_google_font_url = get_theme_mod( 'secondary_typography_google_font_url', '' );
		$secondary_typography_font = get_theme_mod( 'secondary_typography_font', '' );
		
		if ( ! empty( $secondary_typography_google_font_url ) || ! empty( $secondary_typography_font ) ) {
			
			if ( ! empty( $secondary_typography_font ) ) {
			
				$secondary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $secondary_typography_font );
				foreach ( $secondary_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				if ( ! empty( $buttons_font_name['name'] ) ) {
					$buttons_font_name = $font['name'];
				}
				
			}
			
			if ( empty( $buttons_font_name ) ) {
				
				if ( ! empty( $secondary_typography_google_font_url ) ) {
			
					$secondary_google_font_name_offset = substr( $secondary_typography_google_font_url, strpos( $secondary_typography_google_font_url, "=" ) + 1 );
					if ( ( $secondary_google_font_name = strpos( $secondary_google_font_name_offset, ":" ) ) !== FALSE ) {
						$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, ":" ) );
					} else {
						$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, "&" ) );
					}
					$secondary_google_font_name = str_replace( "+", " ", $secondary_google_font_name );
					
					if ( ! empty( $secondary_google_font_name ) ) {
						$buttons_font_name = $secondary_google_font_name;
					}
					
				}
			
			}
			
		}
		
	} else if ( $buttons_font == 'primary' ) {
		
		$primary_typography_google_font_url = get_theme_mod( 'primary_typography_google_font_url', '' );
		$primary_typography_font = get_theme_mod( 'primary_typography_font', '' );
		
		if ( ! empty( $primary_typography_google_font_url ) || ! empty( $primary_typography_font ) ) {
			
			if ( ! empty( $primary_typography_font ) ) {
			
				$primary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $primary_typography_font );
				foreach ( $primary_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				$buttons_font_name = $font['name'];
				
			}
			
			if ( empty( $buttons_font_name ) ) {
				
				if ( ! empty( $primary_typography_google_font_url ) ) {
			
					$primary_google_font_name_offset = substr( $primary_typography_google_font_url, strpos( $primary_typography_google_font_url, "=" ) + 1 );
					if ( ( $primary_google_font_name = strpos( $primary_google_font_name_offset, ":" ) ) !== FALSE ) {
						$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, ":" ) );
					} else {
						$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, "&" ) );
					}
					$primary_google_font_name = str_replace( "+", " ", $primary_google_font_name );
					
					if ( ! empty( $primary_google_font_name ) ) {
						$buttons_font_name = $primary_google_font_name;
					}
					
				}
			
			}
			
		}
		
	}
	
	if ( ! empty( $buttons_font_name ) ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$buttons_font_css = "
		/* Buttons Font */
		#content .wpcf7-submit,
		#respond #submit,
		.post-password-form .submit-button-wrapper,
		#page .vc_general.vc_btn3 {
			font-family: '{$buttons_font_name}', sans-serif !important;
		}";
		
		wp_add_inline_style( 'mega-style', $buttons_font_css );
		
	}
		
}
add_action( 'wp_enqueue_scripts', 'mega_print_buttons_typography' );

/**
 * Add a style block to the theme for the buttons font size.
 */
function mega_print_buttons_font_size_style() {
	$buttons_font_size = get_theme_mod( 'buttons_font_size', 10 );
	if ( empty( $buttons_font_size ) || $buttons_font_size == 10 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$buttons_font_size_css = "
		/* Buttons Font Size */
		#content .wpcf7-submit,
		#respond #submit,
		.post-password-form .submit-button-wrapper,
		#page .vc_general.vc_btn3,
		#page .essb_template_skylab li a .essb_network_name,
		#page .share-helper {
			font-size: {$buttons_font_size}px !important;
		}";
		
		wp_add_inline_style( 'mega-style', $buttons_font_size_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_buttons_font_size_style' );

/**
 * Add a style block to the theme for the buttons text transform.
 */
function mega_print_buttons_text_transform_style() {
	$buttons_text_transform = get_theme_mod( 'buttons_text_transform', 'uppercase' );
	if ( $buttons_text_transform == 'uppercase' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$buttons_text_transform_css = "
		/* Buttons Text Transform */
		#content .wpcf7-submit,
		#respond #submit,
		.post-password-form .submit-button-wrapper,
		#page .vc_general.vc_btn3,
		.share-helper,
		#page .essb_template_skylab li a .essb_network_name {
			text-transform: {$buttons_text_transform} !important;
		}";
		
		wp_add_inline_style( 'mega-style', $buttons_text_transform_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_buttons_text_transform_style' );

/**
 * Add a style block to the theme for the buttons font weight.
 */
function mega_print_buttons_font_weight_style() {
	$buttons_font_weight = get_theme_mod( 'buttons_font_weight', 400 );
	
	wp_enqueue_style( 'mega-style' );
	
	$buttons_font_weight_css = "
	/* Buttons Font Weight */
	#content .wpcf7-submit,
	#respond #submit,
	.post-password-form .submit-button-wrapper,
	#page .vc_general.vc_btn3,
	#page .essb_template_skylab li a .essb_network_name,
	.share-helper {
		font-weight: {$buttons_font_weight} !important;
	}";
	
	wp_add_inline_style( 'mega-style', $buttons_font_weight_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_buttons_font_weight_style' );

/**
 * Add a style block to the theme for the buttons letter spacing.
 */
function mega_print_buttons_letter_spacing_style() {
	$buttons_letter_spacing = get_theme_mod( 'buttons_letter_spacing', 2 );
	if ( $buttons_letter_spacing == 2 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$buttons_letter_spacing_css = "
		/* Buttons Letter Spacing */
		#content .wpcf7-submit,
		#respond #submit,
		.post-password-form .submit-button-wrapper,
		#page .vc_general.vc_btn3,
		#page .essb_template_skylab li a .essb_network_name,
		.share-helper {
			letter-spacing: {$buttons_letter_spacing}px !important;
		}";
		
		wp_add_inline_style( 'mega-style', $buttons_letter_spacing_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_buttons_letter_spacing_style' );

/**
 * Add a style block to the theme for the site title font.
 */
function mega_print_site_title_typography() {
	$site_title_font = get_theme_mod( 'site_title_font' );
	
	if ( $site_title_font == 'secondary' ) {
		
		$secondary_typography_google_font_url = get_theme_mod( 'secondary_typography_google_font_url', '' );
		$secondary_typography_font = get_theme_mod( 'secondary_typography_font', '' );
		
		if ( ! empty( $secondary_typography_google_font_url ) || ! empty( $secondary_typography_font ) ) {
			
			if ( ! empty( $secondary_typography_font ) ) {
			
				$secondary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $secondary_typography_font );
				foreach ( $secondary_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				if ( ! empty( $site_title_font_name['name'] ) ) {
					$site_title_font_name = $font['name'];
				}
				
			}
			
			if ( empty( $site_title_font_name ) ) {
				
				if ( ! empty( $secondary_typography_google_font_url ) ) {
			
					$secondary_google_font_name_offset = substr( $secondary_typography_google_font_url, strpos( $secondary_typography_google_font_url, "=" ) + 1 );
					if ( ( $secondary_google_font_name = strpos( $secondary_google_font_name_offset, ":" ) ) !== FALSE ) {
						$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, ":" ) );
					} else {
						$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, "&" ) );
					}
					$secondary_google_font_name = str_replace( "+", " ", $secondary_google_font_name );
					
					if ( ! empty( $secondary_google_font_name ) ) {
						$site_title_font_name = $secondary_google_font_name;
					}
					
				}
			
			}
			
		}
	
	} else if ( $site_title_font == 'additional' ) {
		
		$additional_typography_google_font_url = get_theme_mod( 'additional_typography_google_font_url', '' );
		$additional_typography_font = get_theme_mod( 'additional_typography_font', '' );
		
		if ( ! empty( $additional_typography_google_font_url ) || ! empty( $additional_typography_font ) ) {
			
			if ( ! empty( $additional_typography_font ) ) {
			
				$additional_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $additional_typography_font );
				foreach ( $additional_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				$site_title_font_name = $font['name'];
				
			}
			
			if ( empty( $site_title_font_name ) ) {
				
				if ( ! empty( $additional_typography_google_font_url ) ) {
			
					$additional_google_font_name_offset = substr( $additional_typography_google_font_url, strpos( $additional_typography_google_font_url, "=" ) + 1 );
					if ( ( $additional_google_font_name = strpos( $additional_google_font_name_offset, ":" ) ) !== FALSE ) {
						$additional_google_font_name = substr( $additional_google_font_name_offset, 0, strpos( $additional_google_font_name_offset, ":" ) );
					} else {
						$additional_google_font_name = substr( $additional_google_font_name_offset, 0, strpos( $additional_google_font_name_offset, "&" ) );
					}
					$additional_google_font_name = str_replace( "+", " ", $additional_google_font_name );
					
					if ( ! empty( $additional_google_font_name ) ) {
						$site_title_font_name = $additional_google_font_name;
					}
					
				}
			
			}
			
		}
		
	} else if ( $site_title_font == 'primary' ) {
		
		$primary_typography_google_font_url = get_theme_mod( 'primary_typography_google_font_url', '' );
		$primary_typography_font = get_theme_mod( 'primary_typography_font', '' );
		
		if ( ! empty( $primary_typography_google_font_url ) || ! empty( $primary_typography_font ) ) {
			
			if ( ! empty( $primary_typography_font ) ) {
			
				$primary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $primary_typography_font );
				foreach ( $primary_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				$site_title_font_name = $font['name'];
				
			}
			
			if ( empty( $site_title_font_name ) ) {
				
				if ( ! empty( $primary_typography_google_font_url ) ) {
			
					$primary_google_font_name_offset = substr( $primary_typography_google_font_url, strpos( $primary_typography_google_font_url, "=" ) + 1 );
					if ( ( $primary_google_font_name = strpos( $primary_google_font_name_offset, ":" ) ) !== FALSE ) {
						$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, ":" ) );
					} else {
						$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, "&" ) );
					}
					$primary_google_font_name = str_replace( "+", " ", $primary_google_font_name );
					
					if ( ! empty( $primary_google_font_name ) ) {
						$site_title_font_name = $primary_google_font_name;
					}
					
				}
			
			}
			
		}
		
	}
	
	if ( ! empty( $site_title_font_name ) ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$site_title_font_css = "
		/* Site Title Font */
		.site-title {
			font-family: '{$site_title_font_name}', sans-serif !important;
		}";
		
		wp_add_inline_style( 'mega-style', $site_title_font_css );
		
	}
		
}
add_action( 'wp_enqueue_scripts', 'mega_print_site_title_typography' );

/**
 * Add a style block to the theme for the site title font size.
 */
function mega_print_site_title_font_size_style() {
	$site_title_font_size = get_theme_mod( 'site_title_font_size', 24 );
	if ( empty( $site_title_font_size ) || $site_title_font_size == 24 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		if ( strpos( $site_title_font_size, 'rem' ) !== false ) {
			$site_title_font_size_css = "
			/* Site Title Font Size */
			.site-title {
				font-size: calc(1.2vw + {$site_title_font_size});
			}";
		} else {
			$site_title_font_size_css = "
			/* Site Title Font Size */
			.site-title {
				font-size: {$site_title_font_size}px;
			}";
		}
		
		wp_add_inline_style( 'mega-style', $site_title_font_size_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_site_title_font_size_style' );

/**
 * Add a style block to the theme for the site title font size for header height on scrolling.
 */
function mega_print_site_title_font_size_for_header_height_on_scrolling_style() {
	$site_title_font_size_for_header_height_on_scrolling = get_theme_mod( 'site_title_font_size_for_header_height_on_scrolling', 24 );
	$header_behavior = get_theme_mod( 'header_behavior', 'normal' );
	if ( $header_behavior == 'normal' )
		return;
	
	$header_height_reduction_on_scrolling = get_theme_mod( 'header_height_reduction_on_scrolling' );
	if ( empty( $header_height_reduction_on_scrolling ) )
		return;
	
	if ( empty( $site_title_font_size_for_header_height_on_scrolling ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		if ( strpos( $site_title_font_size_for_header_height_on_scrolling, 'rem' ) !== false ) {
			$site_title_font_size_for_header_height_on_scrolling_css = "
			/* Site Title Font Size for Header Height on Scrolling */
			@media (min-width: 1024px) {
				.ghost-header .site-title,
				.header-height-on-scrolling .site-title {
					font-size: calc(1.2vw + {$site_title_font_size_for_header_height_on_scrolling});
				}
			}";
		} else {
			/* Site Title Font Size for Header Height on Scrolling */
			$site_title_font_size_for_header_height_on_scrolling_css = "
			@media (min-width: 1024px) {
				.ghost-header .site-title,
				.header-height-on-scrolling .site-title {
					font-size: {$site_title_font_size_for_header_height_on_scrolling}px;
				}
			}";
		}
		
		wp_add_inline_style( 'mega-style', $site_title_font_size_for_header_height_on_scrolling_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_site_title_font_size_for_header_height_on_scrolling_style' );

/**
 * Add a style block to the theme for the site title text transform.
 */
function mega_print_site_title_text_transform_style() {
	$site_title_text_transform = get_theme_mod( 'site_title_text_transform', 'none' );
	if ( $site_title_text_transform == 'none' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$site_title_text_transform_css = "
		/* Site Title Text Transform */
		.site-title {
			text-transform: {$site_title_text_transform};
		}";
		
		wp_add_inline_style( 'mega-style', $site_title_text_transform_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_site_title_text_transform_style' );

/**
 * Add a style block to the theme for the site title font weight.
 */
function mega_print_site_title_font_weight_style() {
	$site_title_font_weight = get_theme_mod( 'site_title_font_weight', 700 );
	if ( $site_title_font_weight == 700 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$site_title_font_weight_css = "
		/* Site Title Font Weight */
		.site-title {
			font-weight: {$site_title_font_weight};
		}";
		
		wp_add_inline_style( 'mega-style', $site_title_font_weight_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_site_title_font_weight_style' );

/**
 * Add a style block to the theme for the site title letter spacing.
 */
function mega_print_site_title_letter_spacing_style() {
	$site_title_letter_spacing = get_theme_mod( 'site_title_letter_spacing', 0 );
	if ( empty( $site_title_letter_spacing ) || $site_title_letter_spacing == 0 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		if ( strpos( $site_title_letter_spacing, 'em' ) !== false ) {
			$site_title_letter_spacing_css = "
			/* Site Title Letter Spacing */
			.site-title {
				letter-spacing: {$site_title_letter_spacing};
			}";
		} else {
			$site_title_letter_spacing_css = "
			/* Site Title Letter Spacing */
			.site-title {
				letter-spacing: {$site_title_letter_spacing}px;
			}";
		}
		
		wp_add_inline_style( 'mega-style', $site_title_letter_spacing_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_site_title_letter_spacing_style' );

/**
 * Add a style block to the theme for the site title font style.
 */
function mega_print_site_title_font_style_style() {
	$site_title_font_style = get_theme_mod( 'site_title_font_style', 'normal' );
	if ( $site_title_font_style == 'normal' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$site_title_font_style_css = "
		/* Site Title Font Style */
		.site-title {
			font-style: {$site_title_font_style};
		}";
		
		wp_add_inline_style( 'mega-style', $site_title_font_style_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_site_title_font_style_style' );

/**
 * Add a style block to the theme for the site tagline font.
 */
function mega_print_site_tagline_typography() {
	$site_tagline_font = get_theme_mod( 'site_tagline_font' );
	
	if ( $site_tagline_font == 'secondary' ) {
		
		$secondary_typography_google_font_url = get_theme_mod( 'secondary_typography_google_font_url', '' );
		$secondary_typography_font = get_theme_mod( 'secondary_typography_font', '' );
		
		if ( ! empty( $secondary_typography_google_font_url ) || ! empty( $secondary_typography_font ) ) {
			
			if ( ! empty( $secondary_typography_font ) ) {
			
				$secondary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $secondary_typography_font );
				foreach ( $secondary_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				if ( ! empty( $site_tagline_font_name['name'] ) ) {
					$site_tagline_font_name = $font['name'];
				}
				
			}
			
			if ( empty( $site_tagline_font_name ) ) {
				
				if ( ! empty( $secondary_typography_google_font_url ) ) {
			
					$secondary_google_font_name_offset = substr( $secondary_typography_google_font_url, strpos( $secondary_typography_google_font_url, "=" ) + 1 );
					if ( ( $secondary_google_font_name = strpos( $secondary_google_font_name_offset, ":" ) ) !== FALSE ) {
						$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, ":" ) );
					} else {
						$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, "&" ) );
					}
					$secondary_google_font_name = str_replace( "+", " ", $secondary_google_font_name );
					
					if ( ! empty( $secondary_google_font_name ) ) {
						$site_tagline_font_name = $secondary_google_font_name;
					}
					
				}
			
			}
			
		}
		
	} else if ( $site_tagline_font == 'primary' ) {
		
		$primary_typography_google_font_url = get_theme_mod( 'primary_typography_google_font_url', '' );
		$primary_typography_font = get_theme_mod( 'primary_typography_font', '' );
		
		if ( ! empty( $primary_typography_google_font_url ) || ! empty( $primary_typography_font ) ) {
			
			if ( ! empty( $primary_typography_font ) ) {
			
				$primary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $primary_typography_font );
				foreach ( $primary_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				$site_tagline_font_name = $font['name'];
				
			}
			
			if ( empty( $site_tagline_font_name ) ) {
				
				if ( ! empty( $primary_typography_google_font_url ) ) {
			
					$primary_google_font_name_offset = substr( $primary_typography_google_font_url, strpos( $primary_typography_google_font_url, "=" ) + 1 );
					if ( ( $primary_google_font_name = strpos( $primary_google_font_name_offset, ":" ) ) !== FALSE ) {
						$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, ":" ) );
					} else {
						$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, "&" ) );
					}
					$primary_google_font_name = str_replace( "+", " ", $primary_google_font_name );
					
					if ( ! empty( $primary_google_font_name ) ) {
						$site_tagline_font_name = $primary_google_font_name;
					}
					
				}
			
			}
			
		}
		
	}
	
	if ( ! empty( $site_tagline_font_name ) ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$site_tagline_font_css = "
		/* Tagline Font */
		#site-title a .site-description {
			font-family: '{$site_tagline_font_name}', sans-serif !important;
		}";
		
		wp_add_inline_style( 'mega-style', $site_tagline_font_css );
		
	}
		
}
add_action( 'wp_enqueue_scripts', 'mega_print_site_tagline_typography' );

/**
 * Add a style block to the theme for the tagline font size.
 */
function mega_print_tagline_font_size_style() {
	$tagline_font_size = get_theme_mod( 'tagline_font_size', 24 );
	if ( empty( $tagline_font_size ) || $tagline_font_size == 24 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		if ( strpos( $tagline_font_size, 'rem' ) !== false ) {
			$tagline_font_size_css = "
			/* Tagline Font Size */
			#site-title a .site-description {
				font-size: calc(1.2vw + {$tagline_font_size});
			}";
		} else {
			$tagline_font_size_css = "
			/* Tagline Font Size */
			#site-title a .site-description {
				font-size: {$tagline_font_size}px;
			}";
		}
		
		wp_add_inline_style( 'mega-style', $tagline_font_size_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_tagline_font_size_style' );

/**
 * Add a style block to the theme for the tagline font size for header height on scrolling.
 */
function mega_print_tagline_font_size_for_header_height_on_scrolling_style() {
	$tagline_font_size_for_header_height_on_scrolling = get_theme_mod( 'tagline_font_size_for_header_height_on_scrolling', 24 );
	$header_behavior = get_theme_mod( 'header_behavior', 'normal' );
	if ( $header_behavior == 'normal' )
		return;
	
	$header_height_reduction_on_scrolling = get_theme_mod( 'header_height_reduction_on_scrolling' );
	if ( empty( $header_height_reduction_on_scrolling ) )
		return;
	
	if ( empty( $tagline_font_size_for_header_height_on_scrolling ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		if ( strpos( $tagline_font_size_for_header_height_on_scrolling, 'rem' ) !== false ) {
			$tagline_font_size_for_header_height_on_scrolling_css = "
			/* Tagline Font Size for Header Height on Scrolling */
			@media (min-width: 1024px) {
				.ghost-header #site-title a .site-description,
				.header-height-on-scrolling #site-title a .site-description {
					font-size: calc(1.2vw + {$tagline_font_size_for_header_height_on_scrolling});
				}
			}";
		} else {
			$tagline_font_size_for_header_height_on_scrolling_css = "
			/* Tagline Font Size for Header Height on Scrolling */
			@media (min-width: 1024px) {
				.ghost-header #site-title a .site-description,
				.header-height-on-scrolling #site-title a .site-description {
					font-size: {$tagline_font_size_for_header_height_on_scrolling}px;
				}
			}";
		}
		
		wp_add_inline_style( 'mega-style', $tagline_font_size_for_header_height_on_scrolling_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_tagline_font_size_for_header_height_on_scrolling_style' );

/**
 * Add a style block to the theme for the tagline text transform.
 */
function mega_print_tagline_text_transform_style() {
	$tagline_text_transform = get_theme_mod( 'tagline_text_transform', 'none' );
	if ( $tagline_text_transform == 'none' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$tagline_text_transform_css = "
		/* Tagline Text Transform */
		#site-title a .site-description {
			text-transform: {$tagline_text_transform};
		}";
		
		wp_add_inline_style( 'mega-style', $tagline_text_transform_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_tagline_text_transform_style' );

/**
 * Add a style block to the theme for the tagline font weight.
 */
function mega_print_tagline_font_weight_style() {
	$tagline_font_weight = get_theme_mod( 'tagline_font_weight', 700 );
	if ( $tagline_font_weight == 700 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$tagline_font_weight_css = "
		/* Tagline Font Weight */
		#site-title a .site-description {
			font-weight: {$tagline_font_weight};
		}";
		
		wp_add_inline_style( 'mega-style', $tagline_font_weight_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_tagline_font_weight_style' );

/**
 * Add a style block to the theme for the tagline letter spacing.
 */
function mega_print_tagline_letter_spacing_style() {
	$tagline_letter_spacing = get_theme_mod( 'tagline_letter_spacing', 0 );
	if ( empty( $tagline_letter_spacing ) || $tagline_letter_spacing == 0 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$tagline_letter_spacing_css = "
		/* Tagline Letter Spacing */
		#site-title a .site-description {
			letter-spacing: {$tagline_letter_spacing}px;
		}";
		
		wp_add_inline_style( 'mega-style', $tagline_letter_spacing_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_tagline_letter_spacing_style' );

/**
 * Add a style block to the theme for the tagline font style.
 */
function mega_print_tagline_font_style_style() {
	$tagline_font_style = get_theme_mod( 'tagline_font_style', 'normal' );
	if ( $tagline_font_style == 'normal' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$tagline_font_style_css = "
		/* Tagline Font Style */
		#site-title a .site-description {
			font-style: {$tagline_font_style};
		}";
		
		wp_add_inline_style( 'mega-style', $tagline_font_style_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_tagline_font_style_style' );

/**
 * Add a style block to the theme for the menu font.
 */
function mega_print_menu_typography() {
	$menu_font = get_theme_mod( 'menu_font' );
	
	if ( $menu_font == 'secondary' ) {
		
		$secondary_typography_google_font_url = get_theme_mod( 'secondary_typography_google_font_url', '' );
		$secondary_typography_font = get_theme_mod( 'secondary_typography_font', '' );
		
		if ( ! empty( $secondary_typography_google_font_url ) || ! empty( $secondary_typography_font ) ) {
			
			if ( ! empty( $secondary_typography_font ) ) {
			
				$secondary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $secondary_typography_font );
				foreach ( $secondary_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				if ( ! empty( $menu_font_name['name'] ) ) {
					$menu_font_name = $font['name'];
				}
				
			}
			
			if ( empty( $menu_font_name ) ) {
				
				if ( ! empty( $secondary_typography_google_font_url ) ) {
			
					$secondary_google_font_name_offset = substr( $secondary_typography_google_font_url, strpos( $secondary_typography_google_font_url, "=" ) + 1 );
					if ( ( $secondary_google_font_name = strpos( $secondary_google_font_name_offset, ":" ) ) !== FALSE ) {
						$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, ":" ) );
					} else {
						$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, "&" ) );
					}
					$secondary_google_font_name = str_replace( "+", " ", $secondary_google_font_name );
					
					if ( ! empty( $secondary_google_font_name ) ) {
						$menu_font_name = $secondary_google_font_name;
					}
					
				}
			
			}
			
		}
		
	} else if ( $menu_font == 'primary' ) {
		
		$primary_typography_google_font_url = get_theme_mod( 'primary_typography_google_font_url', '' );
		$primary_typography_font = get_theme_mod( 'primary_typography_font', '' );
		
		if ( ! empty( $primary_typography_google_font_url ) || ! empty( $primary_typography_font ) ) {
			
			if ( ! empty( $primary_typography_font ) ) {
			
				$primary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $primary_typography_font );
				foreach ( $primary_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				$menu_font_name = $font['name'];
				
			}
			
			if ( empty( $menu_font_name ) ) {
				
				if ( ! empty( $primary_typography_google_font_url ) ) {
			
					$primary_google_font_name_offset = substr( $primary_typography_google_font_url, strpos( $primary_typography_google_font_url, "=" ) + 1 );
					if ( ( $primary_google_font_name = strpos( $primary_google_font_name_offset, ":" ) ) !== FALSE ) {
						$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, ":" ) );
					} else {
						$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, "&" ) );
					}
					$primary_google_font_name = str_replace( "+", " ", $primary_google_font_name );
					
					if ( ! empty( $primary_google_font_name ) ) {
						$menu_font_name = $primary_google_font_name;
					}
					
				}
			
			}
			
		}
		
	}
	
	if ( ! empty( $menu_font_name ) ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_font_css = "
		/* Primary Menu Font */
		.header-wrapper .nav-menu-primary-header ul,
		.access-mobile-menu-wrapper .nav-menu-primary-header ul,
		#log-wrapper,
		#wpml-wrapper,
		.button-wrapper {
			font-family: '{$menu_font_name}', sans-serif !important;
		}";
		
		wp_add_inline_style( 'mega-style', $menu_font_css );
		
	}
		
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_typography' );

/**
 * Add a style block to the theme for the menu font size.
 */
function mega_print_menu_font_size_style() {
	$menu_font_size = get_theme_mod( 'menu_font_size', 16 );
	if ( empty( $menu_font_size ) || $menu_font_size == 16 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		if ( strpos( $menu_font_size, 'rem' ) !== false ) {
			$menu_font_size_css = "
			/* Menu Font Size */
			.header-wrapper .nav-menu-primary-header ul,
			.mt-slick-slider-container-wrapper .mt-btn {
				font-size: calc(1.2vw + {$menu_font_size});
			}";
		} else {
			$menu_font_size_css = "
			/* Menu Font Size */
			.header-wrapper .nav-menu-primary-header ul,
			.mt-slick-slider-container-wrapper .mt-btn {
				font-size: {$menu_font_size}px;
			}";
		}
		
		wp_add_inline_style( 'mega-style', $menu_font_size_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_font_size_style' );

/**
 * Add a style block to the theme for the menu text transform.
 */
function mega_print_menu_text_transform_style() {
	$menu_text_transform = get_theme_mod( 'menu_text_transform', 'none' );
	if ( $menu_text_transform == 'none' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_text_transform_css = "
		/* Menu Text Transform */
		.header-wrapper .nav-menu-primary-header ul,
		.mt-slick-slider-container-wrapper .mt-btn {
			text-transform: {$menu_text_transform};
		}";
		
		wp_add_inline_style( 'mega-style', $menu_text_transform_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_text_transform_style' );

/**
 * Add a style block to the theme for the menu font weight.
 */
function mega_print_menu_font_weight_style() {
	$menu_font_weight = get_theme_mod( 'menu_font_weight', 400 );
	if ( $menu_font_weight == 400 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_font_weight_css = "
		/* Menu Font Weight */
		.header-wrapper .nav-menu-primary-header ul,
		.mt-slick-slider-container-wrapper .mt-btn {
			font-weight: {$menu_font_weight};
		}";
		
		wp_add_inline_style( 'mega-style', $menu_font_weight_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_font_weight_style' );

/**
 * Add a style block to the theme for the menu letter spacing.
 */
function mega_print_menu_letter_spacing_style() {
	$menu_letter_spacing = get_theme_mod( 'menu_letter_spacing', 0 );
	if ( empty( $menu_letter_spacing ) || $menu_letter_spacing == 0 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_letter_spacing_css = "
		/* Menu Letter Spacing */
		.header-wrapper .nav-menu-primary-header ul,
		.mt-slick-slider-container-wrapper .mt-btn {
			letter-spacing: {$menu_letter_spacing}px;
		}";
		
		wp_add_inline_style( 'mega-style', $menu_letter_spacing_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_letter_spacing_style' );

/**
 * Add a style block to the theme for the menu font style.
 */
function mega_print_menu_font_style_style() {
	$menu_font_style = get_theme_mod( 'menu_font_style', 'normal' );
	if ( $menu_font_style == 'normal' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_font_style_css = "
		/* Menu Font Style */
		.header-wrapper .nav-menu-primary-header ul a,
		.mt-slick-slider-container-wrapper .mt-btn {
			font-style: {$menu_font_style};
		}";
		
		wp_add_inline_style( 'mega-style', $menu_font_style_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_font_style_style' );

/**
 * Add a style block to the theme for the menu text decoration - hover/active style.
 */
function mega_print_menu_text_decoration_hover_style() {
	$menu_text_decoration_hover = get_theme_mod( 'menu_text_decoration_hover', 'underline' );
	if ( $menu_text_decoration_hover == 'underline' )
		return;
	
	if ( $menu_text_decoration_hover == 'none' ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_text_decoration_hover_css = "
		/* Menu Text Decoration - Hover/Active */
		.header-wrapper .nav-menu-primary-header ul li a span:after,
		.header-position-left #page .nav-menu-primary-header ul li a span:after,
		.header-position-right #page .nav-menu-primary-header ul li a span:after,
		.primary-secondary-top-bar-menu-style-2 .nav-menu ul li li a span:after,
		.mt-slick-slider-container-wrapper .mt-btn span:hover:after {
			display: none;
		}";
		
	} else if ( $menu_text_decoration_hover == 'overline' ) {
		
		$menu_text_decoration_hover_css = "
		/* Menu Text Decoration - Hover/Active */
		.header-wrapper .nav-menu-primary-header ul li a span:after,
		.header-position-left #page .nav-menu-primary-header ul li a span:after,
		.header-position-right #page .nav-menu-primary-header ul li a span:after {
			top: 0;
		}";
		
	} else if ( $menu_text_decoration_hover == 'line_through' ) {
		
		$menu_text_decoration_hover_css = "
		/* Menu Text Decoration - Hover/Active */
		.header-wrapper .nav-menu-primary-header ul li a span:after,
		.header-position-left #page .nav-menu-primary-header ul li a span:after,
		.header-position-right #page .nav-menu-primary-header ul li a span:after,
		.mt-slick-slider-container-wrapper .mt-btn span:after,
		.mt-slick-slider-container-wrapper .mt-btn span:hover:after {
			top: 50%;
		}";
		
	} else if ( $menu_text_decoration_hover == 'underline_overline' ) {
		
		$menu_text_decoration_hover_css = "
		/* Menu Text Decoration - Hover/Active */
		.header-wrapper .nav-menu-primary-header ul li a span:before,
		.header-position-left #page .nav-menu-primary-header ul li a span:before,
		.header-position-right #page .nav-menu-primary-header ul li a span:before {
			display: block;
		}";
		
	}
		
		wp_add_inline_style( 'mega-style', $menu_text_decoration_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_text_decoration_hover_style' );

/**
 * Add a style block to the theme for the secondary menu font.
 */
function mega_print_menu_secondary_typography() {
	$menu_secondary_font = get_theme_mod( 'menu_secondary_font' );
	
	if ( $menu_secondary_font == 'secondary' ) {
		
		$secondary_typography_google_font_url = get_theme_mod( 'secondary_typography_google_font_url', '' );
		$secondary_typography_font = get_theme_mod( 'secondary_typography_font', '' );
		
		if ( ! empty( $secondary_typography_google_font_url ) || ! empty( $secondary_typography_font ) ) {
			
			if ( ! empty( $secondary_typography_font ) ) {
			
				$secondary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $secondary_typography_font );
				foreach ( $secondary_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				$menu_secondary_font_name = $font['name'];
				
			}
			
			if ( empty( $menu_secondary_font_name ) ) {
				
				if ( ! empty( $secondary_typography_google_font_url ) ) {
			
					$secondary_google_font_name_offset = substr( $secondary_typography_google_font_url, strpos( $secondary_typography_google_font_url, "=" ) + 1 );
					if ( ( $secondary_google_font_name = strpos( $secondary_google_font_name_offset, ":" ) ) !== FALSE ) {
						$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, ":" ) );
					} else {
						$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, "&" ) );
					}
					$secondary_google_font_name = str_replace( "+", " ", $secondary_google_font_name );
					
					if ( ! empty( $secondary_google_font_name ) ) {
						$menu_secondary_font_name = $secondary_google_font_name;
					}
					
				}
			
			}
			
		}
		
	} else if ( $menu_secondary_font == 'primary' ) {
		
		$primary_typography_google_font_url = get_theme_mod( 'primary_typography_google_font_url', '' );
		$primary_typography_font = get_theme_mod( 'primary_typography_font', '' );
		
		if ( ! empty( $primary_typography_google_font_url ) || ! empty( $primary_typography_font ) ) {
			
			if ( ! empty( $primary_typography_font ) ) {
			
				$primary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $primary_typography_font );
				foreach ( $primary_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				$menu_secondary_font_name = $font['name'];
				
			}
			
			if ( empty( $menu_secondary_font_name ) ) {
				
				if ( ! empty( $primary_typography_google_font_url ) ) {
			
					$primary_google_font_name_offset = substr( $primary_typography_google_font_url, strpos( $primary_typography_google_font_url, "=" ) + 1 );
					if ( ( $primary_google_font_name = strpos( $primary_google_font_name_offset, ":" ) ) !== FALSE ) {
						$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, ":" ) );
					} else {
						$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, "&" ) );
					}
					$primary_google_font_name = str_replace( "+", " ", $primary_google_font_name );
					
					if ( ! empty( $primary_google_font_name ) ) {
						$menu_secondary_font_name = $primary_google_font_name;
					}
					
				}
			
			}
			
		}
		
	}
	
	if ( ! empty( $menu_secondary_font_name ) ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_secondary_font_css = "
		/* Secondary Menu Font */
		.header-wrapper .nav-menu-secondary-header ul {
			font-family: '{$menu_secondary_font_name}', sans-serif !important;
		}";
		
		wp_add_inline_style( 'mega-style', $menu_secondary_font_css );
		
	}
		
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_secondary_typography' );

/**
 * Add a style block to the theme for the secondary menu font size.
 */
function mega_print_menu_secondary_font_size_style() {
	$menu_secondary_font_size = get_theme_mod( 'menu_secondary_font_size', 16 );
	if ( empty( $menu_secondary_font_size ) || $menu_secondary_font_size == 16 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		if ( strpos( $menu_secondary_font_size, 'rem' ) !== false ) {
			$menu_secondary_font_size_css = "
			/* Secondary Menu Font Size */
			.nav-menu-secondary-header ul {
				font-size: calc(1.2vw + {$menu_secondary_font_size});
			}";
		} else {
			$menu_secondary_font_size_css = "
			/* Secondary Menu Font Size */
			.nav-menu-secondary-header ul {
				font-size: {$menu_secondary_font_size}px;
			}";
		}
		
		wp_add_inline_style( 'mega-style', $menu_secondary_font_size_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_secondary_font_size_style' );

/**
 * Add a style block to the theme for the secondary menu text transform.
 */
function mega_print_menu_secondary_text_transform_style() {
	$menu_secondary_text_transform = get_theme_mod( 'menu_secondary_text_transform', 'none' );
	if ( $menu_secondary_text_transform == 'none' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_secondary_text_transform_css = "
		/* Secondary Menu Text Transform */
		.nav-menu-secondary-header ul {
			text-transform: {$menu_secondary_text_transform};
		}";
		
		wp_add_inline_style( 'mega-style', $menu_secondary_text_transform_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_secondary_text_transform_style' );

/**
 * Add a style block to the theme for the secondary menu font weight.
 */
function mega_print_menu_secondary_font_weight_style() {
	$menu_secondary_font_weight = get_theme_mod( 'menu_secondary_font_weight', 400 );
	if ( $menu_secondary_font_weight == 400 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_secondary_font_weight_css = "
		/* Secondary Menu Font Weight */
		.nav-menu-secondary-header ul {
			font-weight: {$menu_secondary_font_weight};
		}";
		
		wp_add_inline_style( 'mega-style', $menu_secondary_font_weight_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_secondary_font_weight_style' );

/**
 * Add a style block to the theme for the secondary menu letter spacing.
 */
function mega_print_menu_secondary_letter_spacing_style() {
	$menu_secondary_letter_spacing = get_theme_mod( 'menu_secondary_letter_spacing', 0 );
	if ( empty( $menu_secondary_letter_spacing ) || $menu_secondary_letter_spacing == 0 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_secondary_letter_spacing_css = "
		/* Secondary Menu Letter Spacing */
		.nav-menu-secondary-header ul {
			letter-spacing: {$menu_secondary_letter_spacing}px;
		}";
		
		wp_add_inline_style( 'mega-style', $menu_secondary_letter_spacing_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_secondary_letter_spacing_style' );

/**
 * Add a style block to the theme for the secondary menu font style.
 */
function mega_print_menu_secondary_font_style_style() {
	$menu_secondary_font_style = get_theme_mod( 'menu_secondary_font_style', 'normal' );
	if ( $menu_secondary_font_style == 'normal' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_secondary_font_style_css = "
		/* Secondary Menu Font Style */
		.nav-menu-secondary-header ul a {
			font-style: {$menu_secondary_font_style};
		}";
		
		wp_add_inline_style( 'mega-style', $menu_secondary_font_style_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_secondary_font_style_style' );

/**
 * Add a style block to the theme for the secondary menu text decoration - hover/active style.
 */
function mega_print_menu_secondary_text_decoration_hover_style() {
	$menu_secondary_text_decoration_hover = get_theme_mod( 'menu_secondary_text_decoration_hover', 'underline' );
	if ( $menu_secondary_text_decoration_hover == 'underline' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_secondary_text_decoration_hover_css = "
		/* Secondary Menu Text Decoration - Hover/Active */
		.header-wrapper .nav-menu-secondary-header ul li a span:after,
		.header-position-left #page .nav-menu-secondary-header ul li a:hover span:after,
		.header-position-right #page .nav-menu-secondary-header ul li a:hover span:after,
		.header-position-left #page .nav-menu-secondary-header > ul .current-menu-item > a span:after,
		.header-position-right #page .nav-menu-secondary-header > ul .current-menu-item > a span:after,
		.header-position-left #page .nav-menu-secondary-header > ul .current_page_item > a span:after,
		.header-position-right #page .nav-menu-secondary-header > ul .current_page_item > a span:after,
		.header-position-left #page .nav-menu-secondary-header > ul .current-menu-ancestor > a span:after,
		.header-position-right #page .nav-menu-secondary-header > ul .current-menu-ancestor > a span:after,
		.header-position-left #page .nav-menu-secondary-header > ul .current-menu-item > span a span:after,
		.header-position-right #page .nav-menu-secondary-header > ul .current-menu-item > span a span:after,
		.header-position-left #page .nav-menu-secondary-header > ul .current_page_item > span a span:after,
		.header-position-right #page .nav-menu-secondary-header > ul .current_page_item > span a span:after,
		.header-position-left #page .nav-menu-secondary-header > ul .current-menu-ancestor > span a span:after,
		.header-position-right #page .nav-menu-secondary-header > ul .current-menu-ancestor > span a span:after,
		.primary-secondary-top-bar-menu-style-2 .nav-menu-secondary-header ul li li a span:after {
			display: none;
		}";
		
		wp_add_inline_style( 'mega-style', $menu_secondary_text_decoration_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_secondary_text_decoration_hover_style' );

/**
 * Add a style block to the theme for the sliding menu font.
 */
function mega_print_menu_sliding_typography() {
	$menu_sliding_font = get_theme_mod( 'menu_sliding_font' );
	
	if ( $menu_sliding_font == 'secondary' ) {
		
		$secondary_typography_google_font_url = get_theme_mod( 'secondary_typography_google_font_url', '' );
		$secondary_typography_font = get_theme_mod( 'secondary_typography_font', '' );
		
		if ( ! empty( $secondary_typography_google_font_url ) || ! empty( $secondary_typography_font ) ) {
			
			if ( ! empty( $secondary_typography_font ) ) {
			
				$secondary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $secondary_typography_font );
				foreach ( $secondary_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				if ( ! empty( $menu_sliding_font_name['name'] ) ) {
					$menu_sliding_font_name = $font['name'];
				}
				
			}
			if ( empty( $menu_sliding_font_name ) ) {
			
				
				if ( ! empty( $secondary_typography_google_font_url ) ) {
			
					$secondary_google_font_name_offset = substr( $secondary_typography_google_font_url, strpos( $secondary_typography_google_font_url, "=" ) + 1 );
					if ( ( $secondary_google_font_name = strpos( $secondary_google_font_name_offset, ":" ) ) !== FALSE ) {
						$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, ":" ) );
					} else {
						$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, "&" ) );
					}
					$secondary_google_font_name = str_replace( "+", " ", $secondary_google_font_name );
					
					if ( ! empty( $secondary_google_font_name ) ) {
						$menu_sliding_font_name = $secondary_google_font_name;
					}
					
				}
			
			}
			
		}
		
	} else if ( $menu_sliding_font == 'primary' ) {
		
		$primary_typography_google_font_url = get_theme_mod( 'primary_typography_google_font_url', '' );
		$primary_typography_font = get_theme_mod( 'primary_typography_font', '' );
		
		if ( ! empty( $primary_typography_google_font_url ) || ! empty( $primary_typography_font ) ) {
			
			if ( ! empty( $primary_typography_font ) ) {
			
				$primary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $primary_typography_font );
				foreach ( $primary_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				$menu_sliding_font_name = $font['name'];
				
			}
			
			if ( empty( $menu_sliding_font_name ) ) {
				
				if ( ! empty( $primary_typography_google_font_url ) ) {
			
					$primary_google_font_name_offset = substr( $primary_typography_google_font_url, strpos( $primary_typography_google_font_url, "=" ) + 1 );
					if ( ( $primary_google_font_name = strpos( $primary_google_font_name_offset, ":" ) ) !== FALSE ) {
						$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, ":" ) );
					} else {
						$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, "&" ) );
					}
					$primary_google_font_name = str_replace( "+", " ", $primary_google_font_name );
					
					if ( ! empty( $primary_google_font_name ) ) {
						$menu_sliding_font_name = $primary_google_font_name;
					}
					
				}
			
			}
			
		}
		
	}
	
	if ( ! empty( $menu_sliding_font_name ) ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_sliding_font_css = "
		/* Sliding Menu Font */
		#sliding-menu-wrapper .sliding-menu {
			font-family: '{$menu_sliding_font_name}', sans-serif !important;
		}";
		
		wp_add_inline_style( 'mega-style', $menu_sliding_font_css );
		
	}
		
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_sliding_typography' );

/**
 * Add a style block to the theme for the sliding menu font size.
 */
function mega_print_menu_sliding_font_size_style() {
	$menu_sliding_font_size = get_theme_mod( 'menu_sliding_font_size', 16 );
	if ( empty( $menu_sliding_font_size ) || $menu_sliding_font_size == 16 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		if ( strpos( $menu_sliding_font_size, 'rem' ) !== false ) {
			$menu_sliding_font_size_css = "
			/* Sliding Menu Font Size */
			#sliding-menu-wrapper .sliding-menu {
				font-size: calc(1.2vw + {$menu_sliding_font_size});
			}";
		} else {
			$menu_sliding_font_size_css = "
			/* Sliding Menu Font Size */
			#sliding-menu-wrapper .sliding-menu {
				font-size: {$menu_sliding_font_size}px;
			}";
		}
		
		wp_add_inline_style( 'mega-style', $menu_sliding_font_size_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_sliding_font_size_style' );

/**
 * Add a style block to the theme for the sliding menu text transform.
 */
function mega_print_menu_sliding_text_transform_style() {
	$menu_sliding_text_transform = get_theme_mod( 'menu_sliding_text_transform', 'none' );
	if ( $menu_sliding_text_transform == 'none' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_sliding_text_transform_css = "
		/* Sliding Menu Text Transform */
		#sliding-menu-wrapper .sliding-menu {
			text-transform: {$menu_sliding_text_transform};
		}";
		
		wp_add_inline_style( 'mega-style', $menu_sliding_text_transform_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_sliding_text_transform_style' );

/**
 * Add a style block to the theme for the sliding menu font weight.
 */
function mega_print_menu_sliding_font_weight_style() {
	$menu_sliding_font_weight = get_theme_mod( 'menu_sliding_font_weight', 400 );
	if ( $menu_sliding_font_weight == 400 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_sliding_font_weight_css = "
		/* Sliding Menu Font Weight */
		#sliding-menu-wrapper .sliding-menu {
			font-weight: {$menu_sliding_font_weight};
		}";
		
		wp_add_inline_style( 'mega-style', $menu_sliding_font_weight_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_sliding_font_weight_style' );

/**
 * Add a style block to the theme for the sliding menu letter spacing.
 */
function mega_print_menu_sliding_letter_spacing_style() {
	$menu_sliding_letter_spacing = get_theme_mod( 'menu_sliding_letter_spacing', 0 );
	if ( empty( $menu_sliding_letter_spacing ) || $menu_sliding_letter_spacing == 0 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_sliding_letter_spacing_css = "
		/* Sliding Menu Letter Spacing */
		#sliding-menu-wrapper .sliding-menu {
			letter-spacing: {$menu_sliding_letter_spacing}px;
		}";
		
		wp_add_inline_style( 'mega-style', $menu_sliding_letter_spacing_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_sliding_letter_spacing_style' );

/**
 * Add a style block to the theme for the sliding menu font style.
 */
function mega_print_menu_sliding_font_style_style() {
	$menu_sliding_font_style = get_theme_mod( 'menu_sliding_font_style', 'normal' );
	if ( $menu_sliding_font_style == 'normal' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_sliding_font_style_css = "
		/* Sliding Menu Font Style */
		#sliding-menu-wrapper .sliding-menu a {
			font-style: {$menu_sliding_font_style};
		}";
		
		wp_add_inline_style( 'mega-style', $menu_sliding_font_style_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_sliding_font_style_style' );

/**
 * Add a style block to the theme for the sliding menu text decoration - hover/active style.
 */
function mega_print_menu_sliding_text_decoration_hover_style() {
	$menu_sliding_text_decoration_hover = get_theme_mod( 'menu_sliding_text_decoration_hover', 'underline' );
	if ( $menu_sliding_text_decoration_hover == 'underline' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_sliding_text_decoration_hover_css = "
		/* Sliding Menu Text Decoration - Hover/Active */
		#sliding-menu-wrapper .sliding-menu li a span:after,
		.access-mobile-menu-wrapper .nav-menu-sliding ul li a span:after {
			display: none;
		}";
		
		wp_add_inline_style( 'mega-style', $menu_sliding_text_decoration_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_sliding_text_decoration_hover_style' );

/**
 * Add a style block to the theme for the top bar menu font.
 */
function mega_print_menu_top_bar_typography() {
	$menu_top_bar_font = get_theme_mod( 'menu_top_bar_font' );
	
	if ( $menu_top_bar_font == 'secondary' ) {
		
		$secondary_typography_google_font_url = get_theme_mod( 'secondary_typography_google_font_url', '' );
		$secondary_typography_font = get_theme_mod( 'secondary_typography_font', '' );
		
		if ( ! empty( $secondary_typography_google_font_url ) || ! empty( $secondary_typography_font ) ) {
			
			if ( ! empty( $secondary_typography_font ) ) {
			
				$secondary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $secondary_typography_font );
				foreach ( $secondary_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				if ( ! empty( $menu_top_bar_font_name['name'] ) ) {
					$menu_top_bar_font_name = $font['name'];
				}
				
			}
			
			if ( empty( $menu_top_bar_font_name ) ) {
				
				if ( ! empty( $secondary_typography_google_font_url ) ) {
			
					$secondary_google_font_name_offset = substr( $secondary_typography_google_font_url, strpos( $secondary_typography_google_font_url, "=" ) + 1 );
					if ( ( $secondary_google_font_name = strpos( $secondary_google_font_name_offset, ":" ) ) !== FALSE ) {
						$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, ":" ) );
					} else {
						$secondary_google_font_name = substr( $secondary_google_font_name_offset, 0, strpos( $secondary_google_font_name_offset, "&" ) );
					}
					$secondary_google_font_name = str_replace( "+", " ", $secondary_google_font_name );
					
					if ( ! empty( $secondary_google_font_name ) ) {
						$menu_top_bar_font_name = $secondary_google_font_name;
					}
					
				}
			
			}
			
		}
		
	} else if ( $menu_top_bar_font == 'primary' ) {
		
		$primary_typography_google_font_url = get_theme_mod( 'primary_typography_google_font_url', '' );
		$primary_typography_font = get_theme_mod( 'primary_typography_font', '' );
		
		if ( ! empty( $primary_typography_google_font_url ) || ! empty( $primary_typography_font ) ) {
			
			if ( ! empty( $primary_typography_font ) ) {
			
				$primary_typography_font = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $primary_typography_font );
				foreach ( $primary_typography_font as $font ) {
					$font = html_entity_decode( $font );
					$font = json_decode( $font, true );
				}
				$menu_top_bar_font_name = $font['name'];
				
			}
			
			if ( empty( $menu_top_bar_font_name ) ) {
				
				if ( ! empty( $primary_typography_google_font_url ) ) {
			
					$primary_google_font_name_offset = substr( $primary_typography_google_font_url, strpos( $primary_typography_google_font_url, "=" ) + 1 );
					if ( ( $primary_google_font_name = strpos( $primary_google_font_name_offset, ":" ) ) !== FALSE ) {
						$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, ":" ) );
					} else {
						$primary_google_font_name = substr( $primary_google_font_name_offset, 0, strpos( $primary_google_font_name_offset, "&" ) );
					}
					$primary_google_font_name = str_replace( "+", " ", $primary_google_font_name );
					
					if ( ! empty( $primary_google_font_name ) ) {
						$menu_top_bar_font_name = $primary_google_font_name;
					}
					
				}
			
			}
			
		}
		
	}
	
	if ( ! empty( $menu_top_bar_font_name ) ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_top_bar_font_css = "
		/* Top Bar Menu Font */
		.nav-menu-top-bar ul {
			font-family: '{$menu_top_bar_font_name}', sans-serif !important;
		}";
		
		wp_add_inline_style( 'mega-style', $menu_top_bar_font_css );
		
	}
		
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_top_bar_typography' );

/**
 * Add a style block to the theme for the top bar menu font size.
 */
function mega_print_menu_top_bar_font_size_style() {
	$menu_top_bar_font_size = get_theme_mod( 'menu_top_bar_font_size', 16 );
	if ( empty( $menu_top_bar_font_size ) || $menu_top_bar_font_size == 16 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_top_bar_font_size_css = "
		/* Top Bar Menu Font Size */
		.nav-menu-top-bar ul {
			font-size: {$menu_top_bar_font_size}px;
		}";
		
		wp_add_inline_style( 'mega-style', $menu_top_bar_font_size_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_top_bar_font_size_style' );

/**
 * Add a style block to the theme for the top bar menu text transform.
 */
function mega_print_menu_top_bar_text_transform_style() {
	$menu_top_bar_text_transform = get_theme_mod( 'menu_top_bar_text_transform', 'none' );
	if ( $menu_top_bar_text_transform == 'none' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_top_bar_text_transform_css = "
		/* Top Bar Menu Text Transform */
		.nav-menu-top-bar ul {
			text-transform: {$menu_top_bar_text_transform};
		}";
		
		wp_add_inline_style( 'mega-style', $menu_top_bar_text_transform_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_top_bar_text_transform_style' );

/**
 * Add a style block to the theme for the top bar menu font weight.
 */
function mega_print_menu_top_bar_font_weight_style() {
	$menu_top_bar_font_weight = get_theme_mod( 'menu_top_bar_font_weight', 400 );
	if ( $menu_top_bar_font_weight == 400 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_top_bar_font_weight_css = "
		/* Top Bar Menu Font Weight */
		.nav-menu-top-bar ul {
			font-weight: {$menu_top_bar_font_weight};
		}";
		
		wp_add_inline_style( 'mega-style', $menu_top_bar_font_weight_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_top_bar_font_weight_style' );

/**
 * Add a style block to the theme for the top bar menu letter spacing.
 */
function mega_print_menu_top_bar_letter_spacing_style() {
	$menu_top_bar_letter_spacing = get_theme_mod( 'menu_top_bar_letter_spacing', 0 );
	if ( empty( $menu_top_bar_letter_spacing ) || $menu_top_bar_letter_spacing == 0 )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_top_bar_letter_spacing_css = "
		/* Top Bar Menu Letter Spacing */
		.nav-menu-top-bar ul {
			letter-spacing: {$menu_top_bar_letter_spacing}px;
		}";
		
		wp_add_inline_style( 'mega-style', $menu_top_bar_letter_spacing_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_top_bar_letter_spacing_style' );

/**
 * Add a style block to the theme for the top bar menu font style.
 */
function mega_print_menu_top_bar_font_style_style() {
	$menu_top_bar_font_style = get_theme_mod( 'menu_top_bar_font_style', 'normal' );
	if ( $menu_top_bar_font_style == 'normal' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_top_bar_font_style_css = "
		/* Top Bar Menu Font Style */
		.nav-menu-top-bar ul a {
			font-style: {$menu_top_bar_font_style};
		}";
		
		wp_add_inline_style( 'mega-style', $menu_top_bar_font_style_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_top_bar_font_style_style' );

/**
 * Add a style block to the theme for the top bar menu text decoration - hover/active style.
 */
function mega_print_menu_top_bar_text_decoration_hover_style() {
	$menu_top_bar_text_decoration_hover = get_theme_mod( 'menu_top_bar_text_decoration_hover', 'underline' );
	if ( $menu_top_bar_text_decoration_hover == 'underline' )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$menu_top_bar_text_decoration_hover_css = "
		/* Top Bar Menu Text Decoration - Hover/Active */
		.nav-menu-top-bar ul li a span:after,
		.access-mobile-menu-wrapper .nav-menu-top bar ul li a span:after {
			display: none;
		}";
		
		wp_add_inline_style( 'mega-style', $menu_top_bar_text_decoration_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_menu_top_bar_text_decoration_hover_style' );

/**
 * Add a style block to the theme for the accent color.
 */
function mega_print_accent_color_style() {
	$accent_color = get_theme_mod( 'accent_color', '#000000' );
	if ( empty( $accent_color ) && ! is_customize_preview() || $accent_color == '#000000' && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$accent_color_css = "
		/* Accent Color */
		:root {
			--accent-color: {$accent_color};
		}
		.lightbox-video-wrapper.lightbox-video-style-3 .play-button,
		.lightbox-video-wrapper.lightbox-video-style-2 .play-button,
		.pace .pace-progress,
		#page .title-visible a.content-wrapper:hover .special-button .vc_btn3:after,
		#page .title-visible a.content-wrapper:hover .special-button .vc_btn3 span:before,
		#page .cart-contents-count {
			background: var(--accent-color);
		}
		#content .wpb_accordion .wpb_accordion_wrapper .ui-state-active .ui-icon,
		#content .wpb_content_element.tabs-custom .wpb_tabs_nav li.ui-tabs-active,
		#content .wpb_content_element.tabs-custom-2 .wpb_tabs_nav li.ui-tabs-active a,
		#content .wpb_content_element.tabs-custom-3 .wpb_tabs_nav li.ui-tabs-active a,
		#order_review_wrapper,
		#content .skylab-navigation .sb-navigation-left:hover:after,
		#content .skylab-navigation .sb-navigation-right:hover:after,
		#content .testimonialsslider .flex-control-paging li a.flex-active,
		.lightbox-video-wrapper.lightbox-video-style-3 .play-button,
		#main .skylab .tp-bullet.selected,
		.owl-mt-theme .owl-dots .owl-dot.active span,
		.owl-carousel.nav-style-2 .owl-nav .owl-next:hover,
		.owl-carousel.nav-style-2 .owl-nav .owl-prev:hover,
		#content .style-4 .social-links .social:hover,
		.lightbox-video-wrapper.lightbox-video-style-2 .play-button,
		#page .ubermenu-skin-none .ubermenu-item .ubermenu-submenu-type-mega,
		#page .ubermenu-skin-none .ubermenu-item .ubermenu-submenu-drop {
			border-color: var(--accent-color);
		}
		#main .skylab .tp-bullet.selected {
			border-color: var(--accent-color) !important;
		}
		.date-wrapper .entry-date,
		body #page .woocommerce-mini-cart-wrapper .woocommerce-mini-cart-checkout a.button.alt:hover,
		.woocommerce #page a.button.alt:hover,
		.woocommerce #page button.button.alt:hover,
		.woocommerce #page input.button.alt:hover,
		.woocommerce #page #respond input#submit.alt:hover,
		.woocommerce #page #main input.button.alt:hover,
		.woocommerce-page #page a.button.alt:hover,
		.woocommerce-page #page button.button.alt:hover,
		.woocommerce-page #page input.button.alt:hover,
		.woocommerce-page #page #respond input#submit.alt:hover,
		.woocommerce-page #page #main input.button.alt:hover,
		.woocommerce #page #respond input#submit:hover,
		.woocommerce-page #page #respond input#submit:hover,
		body #page .woocommerce-mini-cart-wrapper .woocommerce-mini-cart-checkout a.button.alt,
		.marketing-tour .custom-pack-icon:after,
		.row-header-center h2:before,
		.testimonial-wrapper .custom-pack-icon:after,
		#content .testimonialsslider .flex-control-paging li a.flex-active,
		.testimonial-big .testimonial-name-title-wrapper .testimonial-name:before,
		#page .woocommerce ul.products li.product h3:after,
		.horizontal-border h1:before,
		.woocommerce-page #page ul.products li.product h3:after,
		#page .woocommerce span.onsale,
		.woocommerce #page span.onsale,
		.woocommerce #page a.button.alt,
		.woocommerce #page button.button.alt,
		.woocommerce #page input.button.alt,
		.woocommerce #page #respond input#submit.alt,
		.woocommerce #page #main input.button.alt,
		.woocommerce-page #page a.button.alt,
		.woocommerce-page #page button.button.alt,
		.woocommerce-page #page input.button.alt,
		.woocommerce-page #page #respond input#submit.alt,
		.woocommerce-page #page #main input.button.alt,
		.select2-results .select2-highlighted,
		#content .full-width .marketing-tour-8:hover,
		#content .style-4 .social-links .social:hover,
		#content .marketing-tour-wrapper.marketing-tour-10:hover .wpb_button_a span:before,
		#content .gallery-alternative-view-content .wpb_button_a,
		.image-carousel-alternative-style-3 .image-carousel-item:hover,
		.person.person-style-7:hover,
		#page .special-button .vc_btn3:hover span:before,
		#page .special-button-2 .vc_btn3:hover span:before,
		#page .special-button .vc_btn3:hover:after,
		.title-visible a.content-wrapper:hover h2 span:before {
			background: var(--accent-color);
		}
		.detailholder .entry-meta:after,
		#page .special .woocommerce ul.products li.product .price:before {
			background: var(--accent-color) !important;
		}
		#page .woocommerce form .form-row .required,
		.single-post .big-header-enabled .entry-header-wrapper .entry-meta a,
		.require,
		.social-icons-text,
		.special-list li strong,
		#supplementary .marketing-tour .custom-pack-icon,
		.testimonialsslider .slides .testimonial-name-title-wrapper .testimonial-title,
		#content #filters a,
		.info-header [class^='icon-'],
		.info-header [class*=' icon-'],
		.below-content-entry-meta a:hover,
		a,
		a:hover,
		#wp-calendar #today,
		.comment-reply-link:hover,
		.comment-edit-link:hover,
		.comment-author a:hover,
		#page .grecaptcha a:hover,
		#site-generator a:hover,
		#site-generator .social-links .social:hover,
		.columns_count_1 .entry-meta a:hover,
		#content .wpb_accordion .wpb_accordion_wrapper .ui-state-active .ui-icon:before,
		#content .wpb_accordion .wpb_accordion_wrapper .ui-state-active .ui-icon,
		#content .wpb_accordion .wpb_accordion_wrapper .wpb_accordion_header a:focus,
		#content .wpb_accordion .wpb_accordion_wrapper .wpb_accordion_header a:active,
		#content .wpb_accordion .wpb_accordion_wrapper .wpb_accordion_header a:hover,
		#content .wpb_content_element .wpb_tabs_nav li.ui-tabs-active a,
		#content .wpb_content_element.tabs-custom-2 .wpb_tabs_nav li.ui-state-hover a,
		#content .wpb_content_element.tabs-custom-3 .wpb_tabs_nav li.ui-state-hover a,
		#content .wpb_tour.wpb_content_element .wpb_tabs_nav li a.ui-tabs-active,
		#content .wpb_tour.wpb_content_element .wpb_tabs_nav li a:hover,
		.person-desc-wrapper a,
		.more-link,
		.archive footer.entry-meta .tag-links a:hover,
		.search footer.entry-meta .tag-links a:hover,
		.blog footer.entry-meta .tag-links a:hover,
		.single-post footer.entry-meta .tag-links a:hover,
		#colophon .social-links .social:hover,
		#content .skylab-navigation .sb-navigation-left:hover:after,
		#content .skylab-navigation .sb-navigation-right:hover:after,
		.owl-carousel.nav-style-2 .owl-nav .owl-next:hover:before,
		.owl-carousel.nav-style-2 .owl-nav .owl-prev:hover:before,
		.lightbox-video-wrapper.lightbox-video-style-2 .play-button:hover i:before,
		.person-desc-wrapper .social:hover,
		#content .style-2 .social-links .social:hover,
		#content .marketing-tour-1:hover .marketing-tour .custom-pack-icon,
		.marketing-tour-wrapper.marketing-tour-10 .wpb_button_a,
		.marketing-tour-wrapper.marketing-tour-10 .wpb_button_a:hover,
		.mt-testimonials-style-1 .mt-testimonial:before,
		#content .team-slider-wrapper .wpb_content_element:before,
		.team-slider-wrapper .social:hover,
		.testimonial-single-style-1 .testimonial-single-name-title-wrapper:before,
		#content .mt-testimonials-style-8 .wpb_content_element:before,
		.testimonial-single-style-2 .testimonial-single-content:before,
		.person-style-6 .person-title,
		.mt-testimonials-style-3 .mt-testimonial:before,
		.person-style-7 .person-author,
		#page .special-button .vc_btn3,
		#page .special-button-2 .vc_btn3,
		#page .dark .special-button .vc_btn3:hover:after,
		#page .text-disabled .scroll-down-button:hover,
		.gallery-alternative-style-4 .gallery-alternative-item:hover h2:after,
		.gallery-alternative-style-5 .gallery-alternative-item:hover h2:after,
		#page .br-theme-custom-stars .br-widget a:hover,
		#page .br-theme-custom-stars .br-widget a.br-active,
		#page .br-theme-custom-stars .br-widget a.br-selected {
			color: var(--accent-color);
		}
		.marketing-tour-content-wpb-button-wrapper,
		#content .gallery-alternative-view-content .wpb_button_a,
		#page .special-button .vc_btn3:after,
		.title-visible .entry-header h2:after {
			border-color: var(--accent-color);
		}
		#page .sd-social-icon .sd-content ul li[class*='share-'] a.sd-button:hover,
		#top-bar #lang_sel:hover .lang_sel_sel,
		#top-bar #lang_sel a:hover,
		.tagcloud a:hover,
		#page .woocommerce .return-to-shop a.button {
			color: var(--accent-color) !important;
		}
		#top-bar #lang_sel:hover .lang_sel_sel {
			color: var(--accent-color) !important;
		}";
		
		wp_add_inline_style( 'mega-style', $accent_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_accent_color_style' );

/**
 * Add a style block to the theme for the body color.
 */
function mega_print_body_color_style() {
	$body_color = get_theme_mod( 'body_color', '#ffffff' );
	if ( empty( $body_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$body_color_rgb = mega_hex2rgb( $body_color );
		
		$body_color_css = "
		/* Body Color */
		:root {
			--body-color: {$body_color};
		}
		#page #main .woocommerce .blockUI.blockOverlay,
		#page #main .woocommerce .loader {
			background: rgba({$body_color_rgb[0]}, {$body_color_rgb[1]}, {$body_color_rgb[2]}, .7) !important;
		}";
		wp_add_inline_style( 'mega-style', $body_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_body_color_style' );

/**
 * Add a style block to the theme for the primary color.
 */
function mega_print_primary_color_style() {
	$primary_color = get_theme_mod( 'primary_color', '#000000' );
	if ( empty( $primary_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$primary_color_css = "
		/* Primary Color */
		:root {
			--primary-color: {$primary_color};
		}";
		
		wp_add_inline_style( 'mega-style', $primary_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_primary_color_style' );

/**
 * Add a style block to the theme for the secondary color.
 */
function mega_print_secondary_color_style() {
	$secondary_color = get_theme_mod( 'secondary_color', '#999999' );
	if ( empty( $secondary_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$secondary_color_css = "
		/* Secondary Color */
		:root {
			--secondary-color: {$secondary_color};
		}";
		
		wp_add_inline_style( 'mega-style', $secondary_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_secondary_color_style' );

/**
 * Add a style block to the theme for the third color.
 */
function mega_print_third_color_style() {
	$third_color = get_theme_mod( 'third_color', '#f2f2f2' );
	if ( empty( $third_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$third_color_css = "
		/* Third Color */
		:root {
			--third-color: {$third_color};
		}";
		
		wp_add_inline_style( 'mega-style', $third_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_third_color_style' );

/**
 * Add a style block to the theme for the borders color.
 */
function mega_print_borders_color_style() {
	$borders_color = get_theme_mod( 'borders_color', '#e6e6e6' );
	if ( empty( $borders_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$borders_color_css = "
		/* Borders Color */
		:root {
			--borders-color: {$borders_color};
		}";
		
		wp_add_inline_style( 'mega-style', $borders_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_borders_color_style' );

/**
 * Add a style block to the theme for the links color.
 */
function mega_print_links_color_style() {
	$links_color = get_theme_mod( 'links_color', '#000000' );
	if ( empty( $links_color ) && ! is_customize_preview() )
		return;
	
		$enable_links_color_on_underline_only = get_theme_mod( 'enable_links_color_on_underline_only' );
		$links_text_decoration_weight = get_theme_mod( 'links_text_decoration_weight', 1 );
		
		$links_color_hover = get_theme_mod( 'links_color_hover', '#000000' );
	
	
		wp_enqueue_style( 'mega-style' );
		
		if ( ! empty( $enable_links_color_on_underline_only ) ) {
		
		$links_color_css = "
		/* Links Color */
		:root {
			--links-color: {$links_color};
		}
		.entry-content a,
		.commentlist a,
		.widget a,
		.entry-summary a,
		.entry-header .entry-meta a,
		#page .posts-template-title_visible3 article h2 a {
			color: var(--links-color);
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--links-color-hover);
		}
		.entry-content .more-link span {
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--links-color-hover);
		}
		#page .link-transition a:after {
			background: var(--links-color-hover);
			height: {$links_text_decoration_weight}px;
		}";
		
		} else {
			
		$links_color_css = "
		/* Links Color */
		:root {
			--links-color: {$links_color};
			--links-color-hover: {$links_color_hover};
		}
		.entry-content a,
		.commentlist a,
		.widget a,
		.entry-summary a,
		.entry-header .entry-meta a,
		#page .posts-template-title_visible3 article h2 a {
			color: var(--links-color);
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--links-color);
		}
		.entry-content .more-link {
			color: var(--links-color);
		}
		.entry-content .more-link span {
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--links-color);
		}
		#page .link-transition a:after {
			background: var(--links-color);
			height: {$links_text_decoration_weight}px;
		}";
			
		}
		
		wp_add_inline_style( 'mega-style', $links_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_links_color_style' );

/**
 * Add a style block to the theme for the links color - hover.
 */
function mega_print_links_color_hover_style() {
	$links_color_hover = get_theme_mod( 'links_color_hover', '#000000' );
	if ( empty( $links_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$enable_links_color_on_underline_only = get_theme_mod( 'enable_links_color_on_underline_only' );
		$links_text_decoration_weight = get_theme_mod( 'links_text_decoration_weight', 1 );
			
		if ( ! empty( $enable_links_color_on_underline_only ) ) {
		
		$links_color_hover_css = "
		/* Links Color - Hover */
		:root {
			--links-color-hover: {$links_color_hover};
		}
		.entry-content a:hover,
		.commentlist a:hover,
		.widget a:hover,
		.entry-summary a:hover,
		.entry-header .entry-meta a:hover,
		.entry-content .more-link:hover,
		#page .posts-template-title_visible3 article h2 a:hover {
			color: var(--links-color-hover);
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--links-color-hover);
		}
		.entry-content .more-link:hover span {
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--links-color-hover);
		}
		#page .link-transition a:hover:after {
			background: var(--links-color-hover);
		}";
		
		} else {
			
		$links_color_hover_css = "
		/* Links Color - Hover */
		:root {
			--links-color-hover: {$links_color_hover};
		}
		.entry-content a:hover,
		.commentlist a:hover,
		.widget a:hover,
		.entry-summary a:hover,
		.entry-header .entry-meta a:hover,
		.entry-content .more-link:hover,
		#page .posts-template-title_visible3 article h2 a:hover {
			color: var(--links-color-hover);
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--links-color-hover);
		}
		.entry-content .more-link:hover span {
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--links-color-hover);
		}
		#page .link-transition a:hover:after {
			background: var(--links-color-hover);
		}";
			
		}
		
		wp_add_inline_style( 'mega-style', $links_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_links_color_hover_style' );

/**
 * Add a style block to the theme for the links color - active.
 */
function mega_print_links_color_active_style() {
	$links_color_active = get_theme_mod( 'links_color_active', '#000000' );
	if ( empty( $links_color_active ) && ! is_customize_preview() )
		return;
	
		$enable_links_color_on_underline_only = get_theme_mod( 'enable_links_color_on_underline_only' );
		$links_text_decoration_weight = get_theme_mod( 'links_text_decoration_weight', 1 );
	
		wp_enqueue_style( 'mega-style' );
		
		if ( ! empty( $enable_links_color_on_underline_only ) ) {
		
		$links_color_active_css = "
		/* Links Color - Active */
		:root {
			--links-color-active: {$links_color_active};
			--links-text-decoration-weight: {$links_text_decoration_weight};
		}
		.entry-content a:active,
		.commentlist a:active,
		.widget a:active,
		.entry-summary a:active,
		.entry-header .entry-meta a:active,
		#page .posts-template-title_visible3 article h2 a:active {
			color: var(--links-color-active);
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--links-color-active);
			transition: color ease .1s, opacity ease .1s, box-shadow ease .1s;
		}
		.entry-content .more-link:active {
			color: var(--links-color-active);
			transition: color ease .1s, opacity ease .1s, box-shadow ease .1s;
		}
		.entry-content .more-link:active span {
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--links-color-active);
			transition: box-shadow ease .1s;
		}
		#page .link-transition a:active:after {
			background: var(--links-color-active);
		}";
		
		} else {
			
		$links_color_active_css = "
		/* Links Color - Active */
		:root {
			--links-color-active: {$links_color_active};
		}
		.entry-content a:active,
		.commentlist a:active,
		.widget a:active,
		.entry-summary a:active,
		.entry-header .entry-meta a:active,
		.entry-content .more-link:active,
		#page .posts-template-title_visible3 article h2 a:active {
			color: var(--links-color-active);
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--links-color-active);
			transition: color ease .1s, opacity ease .1s, box-shadow ease .1s;
		}
		.entry-content .more-link:active span {
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--links-color-active);
			transition: box-shadow ease .1s;
		}
		#page .link-transition a:active:after {
			background: var(--links-color-active);
		}";
			
		}
		
		wp_add_inline_style( 'mega-style', $links_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_links_color_active_style' );

/**
 * Add a style block to the theme for the buttons background color.
 */
function mega_print_buttons_background_color_style() {
	$buttons_background_color = get_theme_mod( 'buttons_background_color', '#000000' );
	if ( empty( $buttons_background_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$buttons_background_color_css = "
		/* Buttons Background Color */
		:root {
			--buttons-background-color: {$buttons_background_color};
		}";
		
		wp_add_inline_style( 'mega-style', $buttons_background_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_buttons_background_color_style' );

/**
 * Add a style block to the theme for the buttons background color - hover.
 */
function mega_print_buttons_background_color_hover_style() {
	$buttons_background_color_hover = get_theme_mod( 'buttons_background_color_hover', '#000000' );
	if ( empty( $buttons_background_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$buttons_background_color_hover_css = "
		/* Buttons Background Color - Hover */
		:root {
			--buttons-background-color-hover: {$buttons_background_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $buttons_background_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_buttons_background_color_hover_style' );

/**
 * Add a style block to the theme for the buttons background color - active.
 */
function mega_print_buttons_background_color_active_style() {
	$buttons_background_color_active = get_theme_mod( 'buttons_background_color_active', '#000000' );
	if ( empty( $buttons_background_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$buttons_background_color_active_css = "
		/* Buttons Background Color - Active */
		:root {
			--buttons-background-color-active: {$buttons_background_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $buttons_background_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_buttons_background_color_active_style' );

/**
 * Add a style block to the theme for the buttons text color.
 */
function mega_print_buttons_text_color_style() {
	$buttons_text_color = get_theme_mod( 'buttons_text_color', '#ffffff' );
	if ( empty( $buttons_text_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$buttons_text_color_css = "
		/* Buttons Text Color */
		:root {
			--buttons-text-color: {$buttons_text_color};
		}";
		
		wp_add_inline_style( 'mega-style', $buttons_text_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_buttons_text_color_style' );

/**
 * Add a style block to the theme for the buttons text color - hover.
 */
function mega_print_buttons_text_color_hover_style() {
	$buttons_text_color_hover = get_theme_mod( 'buttons_text_color_hover', '#ffffff' );
	if ( empty( $buttons_text_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$buttons_text_color_hover_css = "
		/* Buttons Text Color - Hover */
		:root {
			--buttons-text-color-hover: {$buttons_text_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $buttons_text_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_buttons_text_color_hover_style' );

/**
 * Add a style block to the theme for the buttons text color - active.
 */
function mega_print_buttons_text_color_active_style() {
	$buttons_text_color_active = get_theme_mod( 'buttons_text_color_active', '#ffffff' );
	if ( empty( $buttons_text_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$buttons_text_color_active_css = "
		/* Buttons Text Color - Active */
		:root {
			--buttons-text-color-active: {$buttons_text_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $buttons_text_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_buttons_text_color_active_style' );

/**
 * Add a style block to the theme for the inputs placeholders color.
 */
function mega_print_inputs_placeholders_color_style() {
	$inputs_placeholders_color = get_theme_mod( 'inputs_placeholders_color', '#999999' );
	if ( empty( $inputs_placeholders_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$inputs_placeholders_color_css = "
		/* Inputs Placeholders Color */
		:root {
			--inputs-placeholders-color: {$inputs_placeholders_color};
		}";
		
		wp_add_inline_style( 'mega-style', $inputs_placeholders_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_inputs_placeholders_color_style' );

/**
 * Add a style block to the theme for the inputs borders color.
 */
function mega_print_inputs_borders_color_style() {
	$inputs_borders_color = get_theme_mod( 'inputs_borders_color', '#e6e6e6' );
	if ( empty( $inputs_borders_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$inputs_borders_color_css = "
		/* Inputs Borders Color */
		:root {
			--inputs-borders-color: {$inputs_borders_color};
		}";
		
		wp_add_inline_style( 'mega-style', $inputs_borders_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_inputs_borders_color_style' );

/**
 * Add a style block to the theme for the inputs borders color - hover.
 */
function mega_print_inputs_borders_color_hover_style() {
	$inputs_borders_color_hover = get_theme_mod( 'inputs_borders_color_hover', '#999999' );
	if ( empty( $inputs_borders_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$inputs_borders_color_hover_css = "
		/* Inputs Borders Color - Hover */
		:root {
			--inputs-borders-color-hover: {$inputs_borders_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $inputs_borders_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_inputs_borders_color_hover_style' );

/**
 * Add a style block to the theme for the inputs borders color - focus.
 */
function mega_print_inputs_borders_color_focus_style() {
	$inputs_borders_color_focus = get_theme_mod( 'inputs_borders_color_focus', '#000000' );
	if ( empty( $inputs_borders_color_focus ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$inputs_borders_color_focus_css = "
		/* Inputs Borders Color - Focus */
		:root {
			--inputs-borders-color-focus: {$inputs_borders_color_focus};
		}";
		
		wp_add_inline_style( 'mega-style', $inputs_borders_color_focus_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_inputs_borders_color_focus_style' );

/**
 * Add a style block to the theme for the general arrows icons color.
 */
function mega_print_general_arrows_icons_color_style() {
	$general_arrows_icons_color = get_theme_mod( 'general_arrows_icons_color', '#000000' );
	if ( empty( $general_arrows_icons_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$general_arrows_icons_color_css = "
		/* General Arrows Icons Color */
		:root {
			--general-arrows-icons-color: {$general_arrows_icons_color};
		}";
		
		wp_add_inline_style( 'mega-style', $general_arrows_icons_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_general_arrows_icons_color_style' );

/**
 * Add a style block to the theme for the general arrows icons color - hover.
 */
function mega_print_general_arrows_icons_color_hover_style() {
	$general_arrows_icons_color_hover = get_theme_mod( 'general_arrows_icons_color_hover', '#000000' );
	if ( empty( $general_arrows_icons_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$general_arrows_icons_color_hover_css = "
		/* General Arrows Icons Color - Hover */
		:root {
			--general-arrows-icons-color-hover: {$general_arrows_icons_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $general_arrows_icons_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_general_arrows_icons_color_hover_style' );

/**
 * Add a style block to the theme for the general arrows icons color - active.
 */
function mega_print_general_arrows_icons_color_active_style() {
	$general_arrows_icons_color_active = get_theme_mod( 'general_arrows_icons_color_active', '#000000' );
	if ( empty( $general_arrows_icons_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$general_arrows_icons_color_active_css = "
		/* General Arrows Icons Color - Active */
		:root {
			--general-arrows-icons-color-active: {$general_arrows_icons_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $general_arrows_icons_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_general_arrows_icons_color_active_style' );

/**
 * Add a style block to the theme for the general arrows background color.
 */
function mega_print_general_arrows_background_color_style() {
	$general_arrows_background_color = get_theme_mod( 'general_arrows_background_color', '#f2f2f2' );
	if ( empty( $general_arrows_background_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$general_arrows_background_color_css = "
		/* General Arrows Background Color */
		:root {
			--general-arrows-background-color: {$general_arrows_background_color};
		}";
		
		wp_add_inline_style( 'mega-style', $general_arrows_background_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_general_arrows_background_color_style' );

/**
 * Add a style block to the theme for the general arrows background color - hover.
 */
function mega_print_general_arrows_background_color_hover_style() {
	$general_arrows_background_color_hover = get_theme_mod( 'general_arrows_background_color_hover', '#000000' );
	if ( empty( $general_arrows_background_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$general_arrows_background_color_hover_css = "
		/* General Arrows Background Color - Hover */
		:root {
			--general-arrows-background-color-hover: {$general_arrows_background_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $general_arrows_background_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_general_arrows_background_color_hover_style' );

/**
 * Add a style block to the theme for the general arrows background color - active.
 */
function mega_print_general_arrows_background_color_active_style() {
	$general_arrows_background_color_active = get_theme_mod( 'general_arrows_background_color_active', '#000000' );
	if ( empty( $general_arrows_background_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$general_arrows_background_color_active_css = "
		/* General Arrows Background Color - Active */
		:root {
			--general-arrows-background-color-active: {$general_arrows_background_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $general_arrows_background_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_general_arrows_background_color_active_style' );

/**
 * Add a style block to the theme for the links click color effect.
 */
function mega_print_links_click_color_effect_style() {
	$links_click_color_effect = get_theme_mod( 'links_click_color_effect' );
	if ( empty( $links_click_color_effect ) )
		return;
		
		$primary_color = get_theme_mod( 'primary_color', '#000000' );
		$secondary_color = get_theme_mod( 'secondary_color', '#999999' );
		$third_color = get_theme_mod( 'third_color', '#f2f2f2' );
		
		wp_enqueue_style( 'mega-style' );
		
		$links_click_color_effect_css = "
		/* Links Click Color Effect */
		:root {
			--primary-color: {$primary_color};
			--secondary-color: {$secondary_color};
			--third-color: {$third_color};
		}
		#page .nav-pagination a:active,
		.comments-nav a:active,
		#page .comment-reply-link:active,
		#page #respond a:active,
		#page .single-post-navigation-style-2 #nav-pagination-single a:hover:active h2 {
			color: var(--primary-color);
			transition: opacity ease .1s, color ease .1s, background ease .1s;
		}
		#page .essb_template_skylab li a:active .essb_network_name,
		#page .essb_template_skylab .essb_link_facebook a:active .essb_network_name,
		#page .essb_template_skylab .essb_link_twitter a:active .essb_network_name {
			color: var(--secondary-color);
			transition: opacity ease .1s, color ease .1s, background ease .1s;
		}
		#page .essb_template_skylab li a:active .essb_network_name:after,
		#page .essb_template_skylab .essb_link_facebook a:active .essb_network_name:after,
		#page .essb_template_skylab .essb_link_twitter a:active .essb_network_name:after {
			background: var(--secondary-color);
			transition: background ease .1s;
		}
		#page .single-post-navigation-style-1 #nav-pagination-single .next:active,
		#page .single-post-navigation-style-1 #nav-pagination-single .previous:active,
		#page .single-post-navigation-style-1 #nav-pagination-single .next:active:after,
		#page .single-post-navigation-style-1 #nav-pagination-single .previous:active:after,
		#page .single-post-navigation-style-1 #nav-pagination-single .previous:active:before,
		.slick-prev:active:before,
		.slick-next:active:before,
		#page .comment-author a:active,
		#page #respond #cancel-comment-reply-link:active,
		#page .grecaptcha a:active {
			color: var(--secondary-color);
			transition: opacity ease .1s, color ease .1s, background ease .1s;
		}
		#page .tag-links a:active {
			background: var(--third-color);
			transition: opacity ease .1s, color ease .1s, background ease .1s;
		}";
		
		wp_add_inline_style( 'mega-style', $links_click_color_effect_css );
	
}
add_action( 'wp_enqueue_scripts', 'mega_print_links_click_color_effect_style' );

/**
 * Add a style block to the theme for the header background color.
 */
function mega_print_header_background_color_style() {
	$header_background_color = get_theme_mod( 'header_background_color', '#ffffff' );
	if ( empty( $header_background_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$header_background_color_css = "
		/* Header Background Color */
		:root {
			--header-background-color: {$header_background_color};
		}";
		
		wp_add_inline_style( 'mega-style', $header_background_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_background_color_style' );

/**
 * Add a style block to the theme for the site title color.
 */
function mega_print_site_title_color_style() {
	$site_title_color = get_theme_mod( 'site_title_color', '#000000' );
	if ( empty( $site_title_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$site_title_color_css = "
		/* Site Title Color */
		:root {
			--site-title-color: {$site_title_color};
		}";
		
		wp_add_inline_style( 'mega-style', $site_title_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_site_title_color_style' );

/**
 * Add a style block to the theme for the site title color - hover.
 */
function mega_print_site_title_color_hover_style() {
	$site_title_color_hover = get_theme_mod( 'site_title_color_hover', '#000000' );
	if ( empty( $site_title_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$site_title_color_hover_css = "
		/* Site Title Color - Hover */
		:root {
			--site-title-color-hover: {$site_title_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $site_title_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_site_title_color_hover_style' );

/**
 * Add a style block to the theme for the site title color - active.
 */
function mega_print_site_title_color_active_style() {
	$site_title_color_active = get_theme_mod( 'site_title_color_active', '#000000' );
	if ( empty( $site_title_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$site_title_color_active_css = "
		/* Site Title Color - Active */
		:root {
			--site-title-color-active: {$site_title_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $site_title_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_site_title_color_active_style' );

/**
 * Add a style block to the theme for site tagline color.
 */
function mega_print_site_tagline_color_style() {
	$site_tagline_color = get_theme_mod( 'site_tagline_color', '#000000' );
	if ( empty( $site_tagline_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$site_tagline_color_css = "
		/* Site Tagline Color */
		:root {
			--site-tagline-color: {$site_tagline_color};
		}";
		
		wp_add_inline_style( 'mega-style', $site_tagline_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_site_tagline_color_style' );

/**
 * Add a style block to the theme for the primary menu link color.
 */
function mega_print_primary_menu_link_color_style() {
	$primary_menu_link_color = get_theme_mod( 'primary_menu_link_color', '#000000' );
	if ( empty( $primary_menu_link_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$primary_menu_link_color_css = "
		/* Primary Menu Link Color */
		:root {
			--primary-menu-link-color: {$primary_menu_link_color};
		}";
		
		wp_add_inline_style( 'mega-style', $primary_menu_link_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_primary_menu_link_color_style' );

/**
 * Add a style block to the theme for the primary menu link color - hover/active.
 */
function mega_print_primary_menu_link_color_hover_style() {
	$primary_menu_link_color_hover = get_theme_mod( 'primary_menu_link_color_hover', '#000000' );
	if ( empty( $primary_menu_link_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$primary_menu_link_color_hover_css = "
		/* Primary Menu Link Color - Hover */
		:root {
			--primary-menu-link-color-hover: {$primary_menu_link_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $primary_menu_link_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_primary_menu_link_color_hover_style' );

/**
 * Add a style block to the theme for the primary menu link color - active.
 */
function mega_print_primary_menu_link_color_active_style() {
	$primary_menu_link_color_active = get_theme_mod( 'primary_menu_link_color_active', '#000000' );
	if ( empty( $primary_menu_link_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$primary_menu_link_color_active_css = "
		/* Primary Menu Link Color - Active */
		:root {
			--primary-menu-link-color-active: {$primary_menu_link_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $primary_menu_link_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_primary_menu_link_color_active_style' );

/**
 * Add a style block to the theme for the header text color.
 */
function mega_print_header_text_color_style() {
	$header_text_color = get_theme_mod( 'header_text_color', '#000000' );
	if ( empty( $header_text_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$header_text_color_css = "
		/* Header Text Color */
		:root {
			--header-text-color: {$header_text_color};
		}";
		
		wp_add_inline_style( 'mega-style', $header_text_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_text_color_style' );

/**
 * Add a style block to the theme for the header link color.
 */
function mega_print_header_link_color_style() {
	$header_link_color = get_theme_mod( 'header_link_color', '#000000' );
	if ( empty( $header_link_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$header_link_color_css = "
		/* Header Link Color */
		:root {
			--header-link-color: {$header_link_color};
		}";
		
		wp_add_inline_style( 'mega-style', $header_link_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_link_color_style' );

/**
 * Add a style block to the theme for the header link color - hover.
 */
function mega_print_header_link_color_hover_style() {
	$header_link_color_hover = get_theme_mod( 'header_link_color_hover', '#000000' );
	if ( empty( $header_link_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$header_link_color_hover_css = "
		/* Header Link Color - Hover */
		:root {
			--header-link-color-hover: {$header_link_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $header_link_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_link_color_hover_style' );

/**
 * Add a style block to the theme for the header link color - active.
 */
function mega_print_header_link_color_active_style() {
	$header_link_color_active = get_theme_mod( 'header_link_color_active', '#000000' );
	if ( empty( $header_link_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$header_link_color_active_css = "
		/* Header Link Color - Active */
		:root {
			--header-link-color-active: {$header_link_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $header_link_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_link_color_active_style' );

/**
 * Add a style block to the theme for the header social links color.
 */
function mega_print_header_social_links_color_style() {
	$header_social_links_color = get_theme_mod( 'header_social_links_color', '#000000' );
	if ( empty( $header_social_links_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$social_links_style = get_theme_mod( 'social_links_style', 1 );
			
		$header_social_links_color_css = "
		/* Header Social Links Color */
		:root {
			--header-social-links-color: {$header_social_links_color};
		}";
		
		wp_add_inline_style( 'mega-style', $header_social_links_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_social_links_color_style' );

/**
 * Add a style block to the theme for the header social links color - hover.
 */
function mega_print_header_social_links_color_hover_style() {
	$header_social_links_color_hover = get_theme_mod( 'header_social_links_color_hover', '#000000' );
	if ( empty( $header_social_links_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$social_links_style = get_theme_mod( 'social_links_style', 1 );
			
		$header_social_links_color_hover_css = "
		/* Header Social Links Color - Hover */
		:root {
			--header-social-links-color-hover: {$header_social_links_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $header_social_links_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_social_links_color_hover_style' );

/**
 * Add a style block to the theme for the header social links color - active.
 */
function mega_print_header_social_links_color_active_style() {
	$header_social_links_color_active = get_theme_mod( 'header_social_links_color_active', '#000000' );
	if ( empty( $header_social_links_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$social_links_style = get_theme_mod( 'social_links_style', 1 );
			
		$header_social_links_color_active_css = "
		/* Header Social Links Color - Active */
		:root {
			--header-social-links-color-active: {$header_social_links_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $header_social_links_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_social_links_color_active_style' );

/**
 * Add a style block to the theme for the header top border color.
 */
function mega_print_header_top_border_color_style() {
	$header_top_border_color = get_theme_mod( 'header_top_border_color', '#e6e6e6' );
	$header_position = get_theme_mod( 'header_position', 'top' );
	if ( empty( $header_top_border_color ) && ! is_customize_preview() || $header_top_border_color == '#e6e6e6' && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		if ( $header_position == 'left' ) {
		
		$header_top_border_color_css = "
		/* Header Right Border Color */
		:root {
			--header-top-border-color: {$header_top_border_color};
		}
		#header-wrapper {
			border-right-color: var(--header-top-border-color);
		}";
			
		} else if ( $header_position == 'right' ) {
			
		$header_top_border_color_css = "
		/* Header Left Border Color */
		:root {
			--header-top-border-color: {$header_top_border_color};
		}
		#header-wrapper {
			border-left-color: var(--header-top-border-color);
		}";
		
		} else {
			
		$header_top_border_color_css = "
		/* Header Top Border Color */
		:root {
			--header-top-border-color: {$header_top_border_color};
		}
		#header-wrapper {
			border-top-color: var(--header-top-border-color);
		}";
			
		}
		
		wp_add_inline_style( 'mega-style', $header_top_border_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_top_border_color_style' );

/**
 * Add a style block to the theme for the header bottom border color.
 */
function mega_print_header_bottom_border_color_style() {
	$header_bottom_border_color = get_theme_mod( 'header_bottom_border_color', '#e6e6e6' );
	$header_position = get_theme_mod( 'header_position', 'top' );
	if ( empty( $header_bottom_border_color ) && ! is_customize_preview() || $header_bottom_border_color == '#e6e6e6' && ! is_customize_preview() || in_array( $header_position, array( "left", "right" ) ) )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$header_bottom_border_color_css = "
		/* Header Bottom Border Color */
		:root {
			--header-bottom-border-color: {$header_bottom_border_color};
		}
		#header-wrapper {
			border-bottom-color: var(--header-bottom-border-color);
		}";
		
		wp_add_inline_style( 'mega-style', $header_bottom_border_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_header_bottom_border_color_style' );

/**
 * Add a style block to the theme for the secondary menu link color.
 */
function mega_print_secondary_menu_link_color_style() {
	$secondary_menu_link_color = get_theme_mod( 'secondary_menu_link_color', '#000000' );
	if ( empty( $secondary_menu_link_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$secondary_menu_link_color_css = "
		/* Secondary Menu Link Color */
		:root {
			--secondary-menu-link-color: {$secondary_menu_link_color};
		}
		.header-wrapper .nav-menu-secondary-header ul li a span:after {
			background: var(--secondary-menu-link-color);
		}";
		
		wp_add_inline_style( 'mega-style', $secondary_menu_link_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_secondary_menu_link_color_style' );

/**
 * Add a style block to the theme for the secondary menu link color - hover.
 */
function mega_print_secondary_menu_link_color_hover_style() {
	$secondary_menu_link_color_hover = get_theme_mod( 'secondary_menu_link_color_hover', '#000000' );
	if ( empty( $secondary_menu_link_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$secondary_menu_link_color_hover_css = "
		/* Secondary Menu Link Color - Hover */
		:root {
			--secondary-menu-link-color-hover: {$secondary_menu_link_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $secondary_menu_link_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_secondary_menu_link_color_hover_style' );

/**
 * Add a style block to the theme for the secondary menu link color - active.
 */
function mega_print_secondary_menu_link_color_active_style() {
	$secondary_menu_link_color_active = get_theme_mod( 'secondary_menu_link_color_active', '#000000' );
	if ( empty( $secondary_menu_link_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$secondary_menu_link_color_active_css = "
		/* Secondary Menu Link Color - Active */
		:root {
			--secondary-menu-link-color-active: {$secondary_menu_link_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $secondary_menu_link_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_secondary_menu_link_color_active_style' );

/**
 * Add a style block to the theme for the sliding menu link color.
 */
function mega_print_sliding_menu_link_color_style() {
	$sliding_menu_link_color = get_theme_mod( 'sliding_menu_link_color', '#000000' );
	if ( empty( $sliding_menu_link_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$sliding_menu_link_color_css = "
		/* Sliding Menu Link Color */
		:root {
			--sliding-menu-link-color: {$sliding_menu_link_color};
		}";
		
		wp_add_inline_style( 'mega-style', $sliding_menu_link_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_sliding_menu_link_color_style' );

/**
 * Add a style block to the theme for the sliding menu link color - hover.
 */
function mega_print_sliding_menu_link_color_hover_style() {
	$sliding_menu_link_color_hover = get_theme_mod( 'sliding_menu_link_color_hover', '#000000' );
	if ( empty( $sliding_menu_link_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$sliding_menu_link_color_hover_css = "
		/* Sliding Menu Link Color - Hover */
		:root {
			--sliding-menu-link-color-hover: {$sliding_menu_link_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $sliding_menu_link_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_sliding_menu_link_color_hover_style' );

/**
 * Add a style block to the theme for the sliding menu link color - active.
 */
function mega_print_sliding_menu_link_color_active_style() {
	$sliding_menu_link_color_active = get_theme_mod( 'sliding_menu_link_color_active', '#000000' );
	if ( empty( $sliding_menu_link_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$sliding_menu_link_color_active_css = "
		/* Sliding Menu Link Color - Active */
		:root {
			--sliding-menu-link-color-active: {$sliding_menu_link_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $sliding_menu_link_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_sliding_menu_link_color_active_style' );

/**
 * Add a style block to the theme for the top bar background color.
 */
function mega_print_top_bar_background_color_style() {
	$top_bar_background_color = get_theme_mod( 'top_bar_background_color', '#000000' );
	if ( empty( $top_bar_background_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$top_bar_background_color_css = "
		/* Top Bar Background Color */
		:root {
			--top-bar-background-color: {$top_bar_background_color};
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_background_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_background_color_style' );

/**
 * Add a style block to the theme for the top bar text color.
 */
function mega_print_top_bar_text_color_style() {
	$top_bar_text_color = get_theme_mod( 'top_bar_text_color', '#ffffff' );
	if ( empty( $top_bar_text_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$top_bar_text_color_css = "
		/* Top Bar Text Color */
		:root {
			--top-bar-text-color: {$top_bar_text_color};
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_text_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_text_color_style' );

/**
 * Add a style block to the theme for the top bar menu link color.
 */
function mega_print_top_bar_menu_link_color_style() {
	$top_bar_menu_link_color = get_theme_mod( 'top_bar_menu_link_color', '#ffffff' );
	if ( empty( $top_bar_menu_link_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$top_bar_menu_link_color_css = "
		/* Top Bar Menu Link Color */
		:root {
			--top-bar-menu-link-color: {$top_bar_menu_link_color};
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_menu_link_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_menu_link_color_style' );

/**
 * Add a style block to the theme for the top bar menu link color - hover.
 */
function mega_print_top_bar_menu_link_color_hover_style() {
	$top_bar_menu_link_color_hover = get_theme_mod( 'top_bar_menu_link_color_hover', '#ffffff' );
	if ( empty( $top_bar_menu_link_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$top_bar_menu_link_color_hover_css = "
		/* Top Bar Menu Link Color - Hover */
		:root {
			--top-bar-menu-link-color-hover: {$top_bar_menu_link_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_menu_link_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_menu_link_color_hover_style' );

/**
 * Add a style block to the theme for the top bar menu link color - active.
 */
function mega_print_top_bar_menu_link_color_active_style() {
	$top_bar_menu_link_color_active = get_theme_mod( 'top_bar_menu_link_color_active', '#ffffff' );
	if ( empty( $top_bar_menu_link_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$top_bar_menu_link_color_active_css = "
		/* Top Bar Menu Link Color - Active */
		:root {
			--top-bar-menu-link-color-active: {$top_bar_menu_link_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_menu_link_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_menu_link_color_active_style' );

/**
 * Add a style block to the theme for the top bar link color.
 */
function mega_print_top_bar_link_color_style() {
	$top_bar_link_color = get_theme_mod( 'top_bar_link_color', '#ffffff' );
	if ( empty( $top_bar_link_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$top_bar_link_color_css = "
		/* Top Bar Link Color */
		:root {
			--top-bar-link-color: {$top_bar_link_color};
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_link_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_link_color_style' );

/**
 * Add a style block to the theme for the top bar link color - hover.
 */
function mega_print_top_bar_link_color_hover_style() {
	$top_bar_link_color_hover = get_theme_mod( 'top_bar_link_color_hover', '#ffffff' );
	if ( empty( $top_bar_link_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$top_bar_link_color_hover_css = "
		/* Top Bar Link Color - Hover */
		:root {
			--top-bar-link-color-hover: {$top_bar_link_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_link_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_link_color_hover_style' );

/**
 * Add a style block to the theme for the top bar link color - active.
 */
function mega_print_top_bar_link_color_active_style() {
	$top_bar_link_color_active = get_theme_mod( 'top_bar_link_color_active', '#ffffff' );
	if ( empty( $top_bar_link_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$top_bar_link_color_active_css = "
		/* Top Bar Link Color - Active */
		:root {
			--top-bar-link-color-active: {$top_bar_link_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_link_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_link_color_active_style' );

/**
 * Add a style block to the theme for the top bar social links color.
 */
function mega_print_top_bar_social_links_color_style() {
	$top_bar_social_links_color = get_theme_mod( 'top_bar_social_links_color', '#ffffff' );
	if ( empty( $top_bar_social_links_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$social_links_style = get_theme_mod( 'social_links_style', 1 );
			
		$top_bar_social_links_color_css = "
		/* Top Bar Social Links Color */
		:root {
			--top-bar-social-links-color: {$top_bar_social_links_color};
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_social_links_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_social_links_color_style' );

/**
 * Add a style block to the theme for the top bar social links color - hover.
 */
function mega_print_top_bar_social_links_color_hover_style() {
	$top_bar_social_links_color_hover = get_theme_mod( 'top_bar_social_links_color_hover', '#ffffff' );
	if ( empty( $top_bar_social_links_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$social_links_style = get_theme_mod( 'social_links_style', 1 );
			
		$top_bar_social_links_color_hover_css = "
		/* Top Bar Social Links Color - Hover */
		:root {
			--top-bar-social-links-color-hover: {$top_bar_social_links_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_social_links_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_social_links_color_hover_style' );

/**
 * Add a style block to the theme for the top bar social links color - active.
 */
function mega_print_top_bar_social_links_color_active_style() {
	$top_bar_social_links_color_active = get_theme_mod( 'top_bar_social_links_color_active', '#ffffff' );
	if ( empty( $top_bar_social_links_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$social_links_style = get_theme_mod( 'social_links_style', 1 );
		
		$top_bar_social_links_color_active_css = "
		/* Top Bar Social Links Color - Active */
		:root {
			--top-bar-social-links-color: {$top_bar_social_links_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_social_links_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_social_links_color_active_style' );

/**
 * Add a style block to the theme for the top bar bottom border color.
 */
function mega_print_top_bar_bottom_border_color_style() {
	$top_bar_bottom_border = get_theme_mod( 'top_bar_bottom_border' );
	$top_bar_bottom_border_color = get_theme_mod( 'top_bar_bottom_border_color', '#e6e6e6' );
	if ( empty( $top_bar_bottom_border ) && empty( $top_bar_bottom_border_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$top_bar_bottom_border_color_css = "
		/* Top Bar Bottom Border Color */
		:root {
			--top-bar-bottom-border-color: {$top_bar_bottom_border_color};
		}
		#top-bar-wrapper {
			border-bottom-color: var(--top-bar-bottom-border-color);
		}";
		
		wp_add_inline_style( 'mega-style', $top_bar_bottom_border_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_top_bar_bottom_border_color_style' );

/**
 * Add a style block to the theme for the secondary menu.
 */
function mega_print_secondary_menu_style() {
	if ( has_nav_menu( 'secondary' ) ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$secondary_menu_css = "
		/* Secondary Menu */
		#access .nav-menu-secondary-header {
			float: right;
		}
		.header-wrapper .nav-menu-secondary-header > ul > li > a {
			color: var(--secondary-menu-link-color);
		}
		.header-wrapper .nav-menu-secondary-header ul li a span:after {
			background: var(--secondary-menu-link-color);
		}
		.single-portfolio .header-wrapper .nav-menu-secondary-header > ul .menu-item-portfolio > a span:after,
		.single-post .header-wrapper .nav-menu-secondary-header > ul .menu-item-blog > a span:after {
			background: var(--secondary-menu-link-color);
		}
		.header-wrapper .nav-menu-secondary-header > ul > li > a:active,
		.header-wrapper .nav-menu-secondary-header > ul > li > a:hover,
		.header-wrapper .nav-menu-secondary-header > ul > .current-menu-item > a,
		.header-wrapper .nav-menu-secondary-header > ul > .current_page_item > a,
		.header-wrapper .nav-menu-secondary-header > ul > .current-menu-ancestor > a {
			color: var(--secondary-menu-link-color-hover);
		}
		.header-wrapper .nav-menu-secondary-header > ul > li a:active span:after,
		.header-wrapper .nav-menu-secondary-header > ul > li a:hover span:after,
		.header-wrapper .nav-menu-secondary-header > ul > .current-menu-item > a span:after,
		.header-wrapper .nav-menu-secondary-header > ul > .current_page_item > a span:after,
		.header-wrapper .nav-menu-secondary-header > ul > .current-menu-parent > a span:after {
			background: var(--secondary-menu-link-color-hover);
		}
		.single-portfolio .header-wrapper .nav-menu-secondary-header ul > .menu-item-portfolio > a,
		.single-post .header-wrapper .nav-menu-secondary-header ul > .menu-item-blog > a {
			color: var(--secondary-menu-link-color-hover);
		}
		.single-portfolio .header-wrapper .nav-menu-secondary-header > ul .menu-item-portfolio > a span:after,
		.single-post .header-wrapper .nav-menu-secondary-header > ul .menu-item-blog > a span:after {
			background: var(--secondary-menu-link-color-hover);
		}
		.nav-menu-secondary-header ul li li {
			margin-top: .5em;
		}

		.header-wrapper .nav-menu-secondary-header > ul > li a:active {
			color: var(--secondary-menu-link-color-active);
			transition: color ease .1s, opacity ease .1s, background ease .1s;
		}
		.single-portfolio .header-wrapper .nav-menu-secondary-header ul > .menu-item-portfolio > a:active,
		.single-post .header-wrapper .nav-menu-secondary-header ul > .menu-item-blog > a:active {
			color: var(--secondary-menu-link-color-active);
			transition: color ease .1s, opacity ease .1s, background ease .1s;
		}
		.header-wrapper .nav-menu-secondary-header > ul > li a:active span:after,
		.header-wrapper .nav-menu-secondary-header > ul > .current-menu-item > a:active span:after,
		.header-wrapper .nav-menu-secondary-header > ul > .current_page_item > a:active span:after,
		.header-wrapper .nav-menu-secondary-header > ul > .current-menu-parent > a:active span:after {
			background: var(--secondary-menu-link-color-active);
			transition: color ease .1s, opacity ease .1s, background ease .1s;
		}
		.single-portfolio .header-wrapper .nav-menu-secondary-header > ul .menu-item-portfolio > a:active span:after,
		.single-post .header-wrapper .nav-menu-secondary-header > ul .menu-item-blog > a:active span:after {
			background: var(--secondary-menu-link-color-active);
			transition: color ease .1s, opacity ease .1s, background ease .1s;
		}";
		
		wp_add_inline_style( 'mega-style', $secondary_menu_css );
	}
}
add_action( 'wp_enqueue_scripts', 'mega_print_secondary_menu_style' );

/**
 * Add a style block to the theme for the sliding menu.
 */
function mega_print_sliding_menu_style() {
	if ( has_nav_menu( 'sliding' ) ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$sliding_menu_css = "
		/* Sliding Menu */
		#sliding-menu-wrapper {
			background: var(--header-background-color);
			height: 100%;
			position: fixed;
			width: 300px;
			z-index: 1000;
			margin: 0;
			transform: translate(-100%, 0);
			top: 0;
			border-left: 1px solid var(--borders-color);
			height: 100vh;
		}
		#sliding-menu-wrapper.align-left.center-and-full-width-disabled {
			border-left: none;
			border-right: 1px solid var(--borders-color);
		}
		.sliding-menu-wrapper-helper {
			height: 100%;
			position: relative;
			overflow-y: auto;
			overflow-x: hidden;
		}
		.admin-bar #sliding-menu-wrapper {
			padding-top: 32px;
			box-sizing: border-box;
		}
		#sliding-menu-wrapper.center-and-full-width-enabled,
		#sliding-menu-wrapper.align-left.center-and-full-width-enabled,
		#sliding-menu-wrapper.align-right.center-and-full-width-enabled {
			width: 100%;
			left: 0;
			right: auto;
			top: auto;
			text-align: right;
			height: 0;
			opacity: 0;
			visibility: hidden;
		}
		#sliding-menu-wrapper.align-left.center-and-full-width-disabled {
			left: 0;
			transform: translate(-100%, 0);
		}
		#sliding-menu-wrapper.align-right.center-and-full-width-disabled {
			right: 0;
			transform: translate(100%, 0);
		}
		#access-sliding-menu-wrapper {
			padding: 75px 30px 40px;
			position: relative;
			height: 100%;
			box-sizing: border-box;
			width: 100%;
			opacity: 0;
		}
		.align-left #access-sliding-menu-wrapper {
			transform: translate(-50px, 0);
		}
		.align-right #access-sliding-menu-wrapper {
			transform: translate(50px, 0);
		}
		#sliding-menu-wrapper.align-left.center-and-full-width-enabled #access-sliding-menu-wrapper,
		#sliding-menu-wrapper.align-right.center-and-full-width-enabled #access-sliding-menu-wrapper {
			transform: translate(0, 0);
		}
		#access-sliding-menu {
			height: 100%;
		}
		#access-sliding-menu > div {
			margin: .5em auto 30px;
			float: left;
			width: 100%;
			position: relative;
			height: auto;
		}

		#sliding-menu-wrapper .sliding-menu {
			list-style: none;
			margin: 0;
			text-align: left;
			line-height: 1.45;
			float: left;
			display: block;
		}
		#sliding-menu-wrapper.center-and-full-width-enabled .sliding-menu {
			text-align: center;
		}
		#sliding-menu-wrapper .sub-menu {
			margin: 0;
			list-style: none;
		}
		#sliding-menu-wrapper .menu-item .sub-menu {
			background: transparent;
			border: none;
			padding: 0;
			overflow: hidden;
			max-height: 0;
			transition-property: margin-top, opacity, visibility, max-height, padding;
			transition-timing-function: cubic-bezier(.57,.06,.05,.95);
			transition-duration: .3s;
			transition-delay: 0s;
			position: relative;
			width: 100%;
			margin-left: 0;
			visibility: visible;
			opacity: 1;
			transform: none;
			display: block !important;
			left: 0;
			max-width: none;
		}
		#sliding-menu-wrapper .menu-item-has-children.active > .sub-menu {
			max-height: 5000px;
		}
		#sliding-menu-wrapper .sliding-menu .menu-item {
			padding: 0;
			width: 100%;
			display: inline-block;
			float: left;
			margin: 0;
			border-top: 1px solid var(--borders-color);
			margin-top: 5px;
			padding-top: 5px;
		}
		#sliding-menu-wrapper .sliding-menu .menu-item > span {
			display: block;
			float: left;
			position: relative;
			width: 100%;
		}
		#sliding-menu-wrapper.center-and-full-width-enabled .sliding-menu .menu-item {
			text-align: center;
		}
		#sliding-menu-wrapper.align-left.center-and-full-width-enabled .sliding-menu > li,
		#sliding-menu-wrapper.align-right.center-and-full-width-enabled .sliding-menu > li {
			transform: translate(0px, 50px);
			opacity: 0;
		}
		#sliding-menu-wrapper .sliding-menu .sub-menu li {
			padding-left: 10px;
			box-sizing: border-box;
		}
		#sliding-menu-wrapper .sliding-menu a {
			font-style: normal;
			display: inline-block;
			position: relative;
			left: 10px;
		}
		#sliding-menu-wrapper .nav-menu ul li li a span:after {
			display: block;
		}
		#sliding-menu-wrapper .sliding-menu a {
			color: color: var(--sliding-menu-link-color);
		}
		.header .nav-menu-sliding ul li a span:after {
			background: var(--sliding-menu-link-color);
		}
		#sliding-menu-wrapper .nav-menu-sliding a:active,
		#sliding-menu-wrapper .nav-menu-sliding a:hover,
		#sliding-menu-wrapper .nav-menu-sliding > ul > .current-menu-item > span a,
		#sliding-menu-wrapper .nav-menu-sliding > ul > .current_page_item > span a,
		#sliding-menu-wrapper .nav-menu-sliding > ul > .current-menu-ancestor > span a,
		.single-portfolio #page .header #sliding-menu-wrapper .nav-menu-sliding > ul .menu-item-portfolio > span a,
		.single-post #page .header #sliding-menu-wrapper .nav-menu-sliding > ul .menu-item-blog > span a {
			color: var(--sliding-menu-link-color-hover);
		}
		#sliding-menu-wrapper .nav-menu-sliding > ul div > .current-menu-item > span a,
		#sliding-menu-wrapper .nav-menu-sliding > ul div > .current_page_item > span a,
		#sliding-menu-wrapper .nav-menu-sliding > ul div > .current-menu-ancestor > span a {
			color: var(--sliding-menu-link-color-hover);
		}
		#sliding-menu-wrapper .nav-menu-sliding li a:active span:after,
		#sliding-menu-wrapper .nav-menu-sliding li a:hover span:after,
		#sliding-menu-wrapper .nav-menu-sliding > ul > .current-menu-item > span a span:after,
		#sliding-menu-wrapper .nav-menu-sliding > ul > .current_page_item > span a span:after,
		#sliding-menu-wrapper .nav-menu-sliding > ul > .current-menu-parent > span a span:after,
		#sliding-menu-wrapper .nav-menu-sliding ul > div > .current-menu-item > span a span:after,
		#sliding-menu-wrapper .nav-menu-sliding ul > div > .current_page_item > span a span:after,
		#sliding-menu-wrapper .nav-menu-sliding ul > div > .current-menu-ancestor > span a span:after,
		.single-portfolio .header #sliding-menu-wrapper .nav-menu-sliding > ul .menu-item-portfolio > span a span:after,
		.single-post #page .header #sliding-menu-wrapper .nav-menu-sliding > ul .menu-item-blog > span a span:after {
			background: var(--sliding-menu-link-color-hover);
		}
		#page #sliding-menu-wrapper .nav-menu-sliding ul > div > .current-menu-item > span a span:after,
		#page #sliding-menu-wrapper .nav-menu-sliding ul > div > .current_page_item > span a span:after,
		#page #sliding-menu-wrapper .nav-menu-sliding ul > div > .current-menu-ancestor > span a span:after {
			background: var(--sliding-menu-link-color-hover);
		}

		#page #sliding-menu-wrapper .nav-menu-sliding a:active,
		#page #sliding-menu-wrapper .nav-menu-sliding > ul > .current-menu-item > span a:active,
		#page #sliding-menu-wrapper .nav-menu-sliding > ul > .current_page_item > span a:active,
		#page #sliding-menu-wrapper .nav-menu-sliding > ul > .current-menu-ancestor > span a:active,
		#page #sliding-menu-wrapper .nav-menu-sliding > ul div > .current-menu-item > span a:active,
		#page #sliding-menu-wrapper .nav-menu-sliding > ul div > .current_page_item > span a:active,
		#page #sliding-menu-wrapper .nav-menu-sliding > ul div > .current-menu-ancestor > span a:active,
		.single-portfolio #page .header #sliding-menu-wrapper .nav-menu-sliding > ul .menu-item-portfolio > span a:active,
		.single-post #page .header #sliding-menu-wrapper .nav-menu-sliding > ul .menu-item-blog > span a:active {
			color: var(--sliding-menu-link-color-active);
		}
		#sliding-menu-wrapper .nav-menu-sliding li a:active span:after,
		#page #sliding-menu-wrapper .nav-menu-sliding > ul > .current-menu-item > span a:active span:after,
		#page #sliding-menu-wrapper .nav-menu-sliding > ul > .current_page_item > span a:active span:after,
		#page #sliding-menu-wrapper .nav-menu-sliding > ul > .current-menu-ancestor > span a:active span:after,
		#page #sliding-menu-wrapper .nav-menu-sliding ul > div > .current-menu-item > span a:active span:after,
		#page #sliding-menu-wrapper .nav-menu-sliding ul > div > .current_page_item > span a:active span:after,
		#page #sliding-menu-wrapper .nav-menu-sliding ul > div > .current-menu-ancestor > span a:active span:after {
			background: var(--sliding-menu-link-color-active);
		}

		#sliding-menu-wrapper ul > .current-menu-item > span a span:after,
		#sliding-menu-wrapper ul > .current_page_item > span a span:after,
		.single-portfolio .header #sliding-menu-wrapper .nav-menu-sliding > ul .menu-item-portfolio > span a span:after,
		.single-post .header #sliding-menu-wrapper .nav-menu-sliding > ul .menu-item-blog > span a span:after {
			transform-origin: bottom left;
			transform: scaleX(1);
		}
		#sliding-menu-wrapper ul div > .current-menu-item > span a span:after,
		#sliding-menu-wrapper ul div > .current_page_item > span a span:after,
		.single-portfolio .header #sliding-menu-wrapper .nav-menu-sliding ul div > .menu-item-portfolio > span a span:after,
		.single-post .header #sliding-menu-wrapper .nav-menu-sliding ul div > .menu-item-blog > span a span:after {
			transform-origin: bottom left;
			transform: scaleX(1);
		}
		#sliding-menu-wrapper ul div > .current-menu-ancestor > span a span:after,
		#sliding-menu-wrapper ul div > .current-menu-parent > span a span:after {
			transform-origin: bottom left;
			transform: scaleX(1);
		}
		#sliding-menu-wrapper .sliding-menu a span {
			padding: 8px 0;
			display: inline-block;
		}
		#sliding-menu-wrapper.center-and-full-width-enabled .sliding-menu a {
			padding: 0 10px;
		}
		#sliding-menu-wrapper .menu-item .sub-menu div:first-child {
			padding-bottom: 0;
			opacity: 0;
			transform: translateY(-100px);
			transition: opacity .2s, transform .2s;
		}
		#sliding-menu-wrapper .menu-item.active .sub-menu div:first-child {
			opacity: 1;
			transform: translateY(0);
		}
		#sliding-menu-wrapper .menu-item.active > span .drop-icon:before {
			transform: rotate(180deg);
		}

		#sliding-menu-dropdown-wrapper {
			margin: 0;
			float: right;
			position: relative;
			margin-left: 30px;
			display: inline-flex;
			height: 100%;
			align-items: center;
			width: 24px;
		}
		.sliding-menu-align-left #sliding-menu-dropdown-wrapper {
			float: left;
			margin-left: 0;
			margin-right: 30px;
		}
		.sticky-header.full-width-header-enabled.top-bar-disabled #sliding-menu-dropdown-wrapper {
			z-index: 1000;
		}
		#sliding-menu-dropdown {
			display: block;
			margin: auto;
			width: 24px;
			height: 16px;
			cursor: pointer;
			position: relative;
			transition: all ease .2s;
		}
		#sliding-menu-dropdown:hover {
			opacity: .7;
		}
		#sliding-menu-dropdown .menu-line {
			position: absolute;
			left: 0;
			width: 100%;
			height: 2px;
			background: #000;
			top: 50%;
			margin-top: -1px;
			transition-duration: .25s;
			width: 24px;
		}
		#sliding-menu-dropdown .menu-line:before,
		#sliding-menu-dropdown .menu-line:after {
			transition-duration: .25s;
			position: absolute;
			width: 24px;
			height: 2px;
			background: #000;
			content: '';
			left: 0;
		}
		#sliding-menu-dropdown .menu-line:before {
			transform: translateY(-7px);
		}
		#sliding-menu-dropdown .menu-line:after {
			transform: translateY(7px);
		}
		.sticky-header.full-width-header-enabled.top-bar-disabled #sliding-menu-dropdown.open .menu-line {
			background: transparent;
			width: 0;
		}
		.sticky-header.full-width-header-enabled.top-bar-disabled #sliding-menu-dropdown.open .menu-line:before {
			background: var(--primary-color);
			transform: matrix(.7071, -.7071, .7071, .7071, 0, 0) !important;
			top: 50% !important;
			margin-top: -1px;
		}
		.sticky-header.full-width-header-enabled.top-bar-disabled #sliding-menu-dropdown.open .menu-line:after {
			background: var(--primary-color);
			transform: matrix(.7071, .7071, -.7071, .7071, 0, 0) !important;
			top: 50% !important;
			margin-top: -1px;
		}
		#sliding-menu-dropdown:hover i:before {
			opacity: .7;
		}
		#sliding-menu-dropdown:hover .menu-line:before {
			transform: matrix(1, 0, 0, 1, 0, -9);
		}
		#sliding-menu-dropdown:hover .menu-line:after {
			transform: matrix(1, 0, 0, 1, 0, 9);
		}
		.center-logo-and-menu-enabled #sliding-menu-dropdown-wrapper {
			width: auto;
			display: block;
		}
		.center-logo-and-menu-enabled #sliding-menu-dropdown {
			width: auto;
			height: auto;
			height: 100%;
			display: flex;
			align-items: center;
			justify-content: center;
		}
		#sliding-menu-dropdown:hover {
			opacity: .7;
		}
		#sliding-menu-dropdown .menu-circle {
			position: relative;
			left: 0;
			width: 100%;
			height: 6px;
			background: #000;
			margin-top: -1px;
			transition-duration: .25s;
			width: 6px;
			display: block;
			float: left;
			margin-left: 5px;
			border-radius: 50%;
		}
		#sliding-menu-dropdown .menu-circle:first-of-type {
			margin-left: 0;
		}
		.center-logo-and-menu-enabled #access .sliding-menu {
			list-style: none;
			margin: 0;
			font-size: 10px;
			letter-spacing: 2px;
			font-weight: 700;
			text-transform: uppercase;
		}
		#sliding-menu-wrapper .close-button {
			position: absolute;
			top: 20px;
			right: 30px;
			z-index: 100;
			border: none;
			color: var(--header-link-color);
		}
		#sliding-menu-wrapper.align-left.center-and-full-width-disabled .close-button {
			right: auto;
			left: 30px;
		}
		#sliding-menu-wrapper .close-button:hover {
			transform: scale(1.15);
		}
		.sticky-header.full-width-header-enabled.top-bar-disabled #sliding-menu-wrapper .close-button {
			display: none;
		}
		#sliding-menu-wrapper .widget {
			text-align: left;
		}
		.sticky-header.full-width-header-enabled.top-bar-disabled #sliding-menu-dropdown.open .menu-line {
			background: transparent;
			width: 0;
		}
		@media (max-width: 1023px) {
			#sliding-menu-dropdown-wrapper {
				display: none;
			}
		}";
		
		wp_add_inline_style( 'mega-style', $sliding_menu_css );
	}
}
add_action( 'wp_enqueue_scripts', 'mega_print_sliding_menu_style' );

/**
 * Add a style block to the theme for the footer background color.
 */
function mega_print_footer_background_color_style() {
	$footer_background_color = get_theme_mod( 'footer_background_color', '#ffffff' );
	if ( empty( $footer_background_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_background_color_css = "
		/* Footer Background Color */
		:root {
			--footer-background-color: {$footer_background_color};
		}";
		
		wp_add_inline_style( 'mega-style', $footer_background_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_background_color_style' );

/**
 * Add a style block to the theme for the footer widget title color.
 */
function mega_print_footer_widget_title_color_style() {
	$footer_widget_title_color = get_theme_mod( 'footer_widget_title_color', '#000000' );
	if ( empty( $footer_widget_title_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_widget_title_color_css = "
		/* Footer Widget Title Color */
		:root {
			--footer-widget-title-color: {$footer_widget_title_color};
		}";
		
		wp_add_inline_style( 'mega-style', $footer_widget_title_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_widget_title_color_style' );

/**
 * Add a style block to the theme for the footer text color.
 */
function mega_print_footer_text_color_style() {
	$footer_text_color = get_theme_mod( 'footer_text_color', '#000000' );
	if ( empty( $footer_text_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_text_color_css = "
		/* Footer Text Color */
		:root {
			--footer-text-color: {$footer_text_color};
		}";
		
		wp_add_inline_style( 'mega-style', $footer_text_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_text_color_style' );

/**
 * Add a style block to the theme for the footer link color.
 */
function mega_print_footer_link_color_style() {
	$footer_link_color = get_theme_mod( 'footer_link_color', '#000000' );
	if ( empty( $footer_link_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_link_color_css = "
		/* Footer Link Color */
		:root {
			--footer-link-color: {$footer_link_color};
		}";
		
		wp_add_inline_style( 'mega-style', $footer_link_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_link_color_style' );

/**
 * Add a style block to the theme for the footer link color - hover.
 */
function mega_print_footer_link_color_hover_style() {
	$footer_link_color_hover = get_theme_mod( 'footer_link_color_hover', '#000000' );
	if ( empty( $footer_link_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_link_color_hover_css = "
		/* Footer Link Color - Hover */
		:root {
			--footer-link-color-hover: {$footer_link_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $footer_link_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_link_color_hover_style' );

/**
 * Add a style block to the theme for the footer link color - active.
 */
function mega_print_footer_link_color_active_style() {
	$footer_link_color_active = get_theme_mod( 'footer_link_color_active', '#000000' );
	if ( empty( $footer_link_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_link_color_active_css = "
		/* Footer Link Color - Active */
		:root {
			--footer-link-color-active: {$footer_link_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $footer_link_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_link_color_active_style' );

/**
 * Add a style block to the theme for the footer bottom area background color.
 */
function mega_print_footer_bottom_area_background_color_style() {
	$footer_bottom_area_background_color = get_theme_mod( 'footer_bottom_area_background_color', '#ffffff' );
	if ( empty( $footer_bottom_area_background_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_bottom_area_background_color_css = "
		/* Footer Bottom Area Background Color */
		:root {
			--footer-bottom-area-background-color: {$footer_bottom_area_background_color};
		}";
		
		wp_add_inline_style( 'mega-style', $footer_bottom_area_background_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_bottom_area_background_color_style' );

/**
 * Add a style block to the theme for the footer bottom area text color.
 */
function mega_print_footer_bottom_area_text_color_style() {
	$footer_bottom_area_text_color = get_theme_mod( 'footer_bottom_area_text_color', '#000000' );
	if ( empty( $footer_bottom_area_text_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_bottom_area_text_color_css = "
		/* Footer Bottom Area Text Color */
		:root {
			--footer-bottom-area-text-color: {$footer_bottom_area_text_color};
		}";
		
		wp_add_inline_style( 'mega-style', $footer_bottom_area_text_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_bottom_area_text_color_style' );

/**
 * Add a style block to the theme for the footer bottom area link color.
 */
function mega_print_footer_bottom_area_link_color_style() {
	$footer_bottom_area_link_color = get_theme_mod( 'footer_bottom_area_link_color', '#000000' );
	if ( empty( $footer_bottom_area_link_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$enable_links_color_on_underline_only = get_theme_mod( 'enable_links_color_on_underline_only' );
		$links_text_decoration_weight = get_theme_mod( 'links_text_decoration_weight', 1 );
		
		if ( ! empty( $enable_links_color_on_underline_only ) ) {
		
		$footer_bottom_area_link_color_css = "
		/* Footer Bottom Area Link Color */
		:root {
			--footer-bottom-area-link-color: {$footer_bottom_area_link_color};
		}
		#site-generator p a {
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--footer-bottom-area-link-color);
		}";
		
		} else {
			
		
		$footer_bottom_area_link_color_css = "
		/* Footer Bottom Area Link Color */
		:root {
			--footer-bottom-area-link-color: {$footer_bottom_area_link_color};
		}
		#site-generator p a {
			color: var(--footer-bottom-area-link-color);
		}";
			
		}
		
		wp_add_inline_style( 'mega-style', $footer_bottom_area_link_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_bottom_area_link_color_style' );

/**
 * Add a style block to the theme for the footer bottom area link color - hover.
 */
function mega_print_footer_bottom_area_link_color_hover_style() {
	$footer_bottom_area_link_color_hover = get_theme_mod( 'footer_bottom_area_link_color_hover', '#000000' );
	if ( empty( $footer_bottom_area_link_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$enable_links_color_on_underline_only = get_theme_mod( 'enable_links_color_on_underline_only' );
		$links_text_decoration_weight = get_theme_mod( 'links_text_decoration_weight', 1 );
		
		if ( ! empty( $enable_links_color_on_underline_only ) ) {
		
		$footer_bottom_area_link_color_hover_css = "
		/* Footer Bottom Area Link Color - Hover */
		:root {
			--footer-bottom-area-link-color-hover: {$footer_bottom_area_link_color_hover};
		}
		#site-generator p a:hover {
			color: var(--footer-bottom-area-link-color-hover);
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--footer-bottom-area-link-color-hover);
		}";
		
		} else {
			
		
		$footer_bottom_area_link_color_hover_css = "
		/* Footer Bottom Area Link Color - Hover */
		:root {
			--footer-bottom-area-link-color-hover: {$footer_bottom_area_link_color_hover};
		}
		#site-generator p a:hover {
			color: var(--footer-bottom-area-link-color-hover);
		}";
			
		}
		
		wp_add_inline_style( 'mega-style', $footer_bottom_area_link_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_bottom_area_link_color_hover_style' );

/**
 * Add a style block to the theme for the footer bottom area link color - active.
 */
function mega_print_footer_bottom_area_link_color_active_style() {
	$footer_bottom_area_link_color_active = get_theme_mod( 'footer_bottom_area_link_color_active', '#000000' );
	if ( empty( $footer_bottom_area_link_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$enable_links_color_on_underline_only = get_theme_mod( 'enable_links_color_on_underline_only' );
		$links_text_decoration_weight = get_theme_mod( 'links_text_decoration_weight', 1 );
		
		if ( ! empty( $enable_links_color_on_underline_only ) ) {
		
		$footer_bottom_area_link_color_active_css = "
		/* Footer Bottom Area Link Color - Active */
		:root {
			--footer-bottom-area-link-color-active: {$footer_bottom_area_link_color_active};
		}
		#site-generator p a:active {
			color: var(--footer-bottom-area-link-color-active);
			transition: color ease .1s, opacity ease .1s, box-shadow ease .1s;
			box-shadow: 0 {$links_text_decoration_weight}px 0 var(--footer-bottom-area-link-color-active);
		}";
		
		} else {
			
		
		$footer_bottom_area_link_color_active_css = "
		/* Footer Bottom Area Link Color - Active */
		:root {
			--footer-bottom-area-link-color-active: {$footer_bottom_area_link_color_active};
		}
		#site-generator p a:active {
			color: var(--footer-bottom-area-link-color-active);
			transition: color ease .1s, opacity ease .1s, box-shadow ease .1s;
		}";
			
		}
		
		wp_add_inline_style( 'mega-style', $footer_bottom_area_link_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_bottom_area_link_color_active_style' );

/**
 * Add a style block to the theme for the footer social links color.
 */
function mega_print_footer_social_links_color_style() {
	$footer_social_links_color = get_theme_mod( 'footer_social_links_color', '#000000' );
	if ( empty( $footer_social_links_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_social_links_color_css = "
		/* Footer Social Links Color */
		:root {
			--footer-social-links-color: {$footer_social_links_color};
		}";
		
		wp_add_inline_style( 'mega-style', $footer_social_links_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_social_links_color_style' );

/**
 * Add a style block to the theme for the footer social links color - hover.
 */
function mega_print_footer_social_links_color_hover_style() {
	$footer_social_links_color_hover = get_theme_mod( 'footer_social_links_color_hover', '#000000' );
	if ( empty( $footer_social_links_color_hover ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_social_links_color_hover_css = "
		/* Footer Social Links Color - Hover */
		:root {
			--footer-social-links-color-hover: {$footer_social_links_color_hover};
		}";
		
		wp_add_inline_style( 'mega-style', $footer_social_links_color_hover_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_social_links_color_hover_style' );

/**
 * Add a style block to the theme for the footer social links color - active.
 */
function mega_print_footer_social_links_color_active_style() {
	$footer_social_links_color_active = get_theme_mod( 'footer_social_links_color_active', '#000000' );
	if ( empty( $footer_social_links_color_active ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_social_links_color_active_css = "
		/* Footer Social Links Color - Active */
		:root {
			--footer-social-links-color-active: {$footer_social_links_color_active};
		}";
		
		wp_add_inline_style( 'mega-style', $footer_social_links_color_active_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_social_links_color_active_style' );

/**
 * Add a style block to the theme for the footer top border color.
 */
function mega_print_footer_top_border_color_style() {
	$footer_top_border_color = get_theme_mod( 'footer_top_border_color', '#e6e6e6' );
	if ( empty( $footer_top_border_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_top_border_color_css = "
		/* Footer Top Border Color */
		:root {
			--footer-top-border-color: {$footer_top_border_color};
		}
		#colophon {
			border-color: var(--footer-top-border-color);
		}";
		
		wp_add_inline_style( 'mega-style', $footer_top_border_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_top_border_color_style' );

/**
 * Add a style block to the theme for the footer bottom area top border color.
 */
function mega_print_footer_bottom_area_top_border_color_style() {
	$footer_bottom_area_top_border_color = get_theme_mod( 'footer_bottom_area_top_border_color', '#e6e6e6' );
	if ( empty( $footer_bottom_area_top_border_color ) && ! is_customize_preview() )
		return;
	
		wp_enqueue_style( 'mega-style' );
		
		$footer_bottom_area_top_border_color_css = "
		/* Footer Bottom Area Top Border Color */
		:root {
			--footer-bottom-area-top-border-color: {$footer_bottom_area_top_border_color};
		}";
		
		wp_add_inline_style( 'mega-style', $footer_bottom_area_top_border_color_css );
}
add_action( 'wp_enqueue_scripts', 'mega_print_footer_bottom_area_top_border_color_style' );

/**
 * Add a style block to the theme for the full width menu.
 */
function mega_print_full_width_menu_style() {
		$theme_location = 'primary';
		$locations = get_nav_menu_locations();
		if ( ! empty( $locations ) ) {
			$menu = get_term( $locations[$theme_location], 'nav_menu' );
			if ( ! empty( $menu->term_id ) ) {
				$menu_items = wp_get_nav_menu_items( $menu->term_id );
				foreach( $menu_items as $menu_item ) {
					$classes = $menu_item->classes;
					if ( $classes ) {
						if ( strpos( json_encode( $classes ), 'menu-has-submenu-mega') !== false ) {
							wp_enqueue_style( 'mega-style' );
				
							$full_width_menu_css = "
				/* Full Width Menu */
				.nav-menu ul .menu-has-submenu-mega {
					position: initial;
				}
				.menu-has-submenu-mega > .sub-menu {
					width: 100vw;
					position: absolute;
					margin-left: calc(-50vw + 50%);
					min-width: auto;
					max-width: none;
					left: 0;
					background: rgba(0,0,0,.85);
				}
				.menu-has-submenu-mega > .sub-menu div:first-child {
					max-width: 1170px;
					margin: 20px auto 22px;
					column-count: 4;
					column-gap: 40px;
					column-rule: 1px solid rgba(255, 255, 255, .08);
				}
				.menu-has-submenu-mega.submenu-mega-3cols > .sub-menu div:first-child {
					column-count: 3;
				}
				.nav-menu ul .menu-has-submenu-mega li:first-child {
					padding-top: 0;
				}
				.nav-menu ul .menu-has-submenu-mega li:last-child {
					padding-bottom: 0;
				}
				.nav-menu .menu-has-submenu-mega ul .top-item {
					margin-top: 10px;
				}";
							
							wp_add_inline_style( 'mega-style', $full_width_menu_css );
						}
					}
				}
			}
		}
}
add_action( 'wp_enqueue_scripts', 'mega_print_full_width_menu_style' );

/**
 * Add a style block to the theme for the error 404.
 */
function mega_print_error_404_style() {
	if ( is_404() ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$error_404_css = "
		/* Error 404 */
		.error404 #content h1 {
			text-align: center;
		}
		.error404 #content h1,
		.error404 #content .wpb_content_element p {
			text-align: center;
		}";
		
		wp_add_inline_style( 'mega-style', $error_404_css );
		
	}
}
add_action( 'wp_enqueue_scripts', 'mega_print_error_404_style' );

/**
 * Add a style block to the theme for the customizer.
 */
function mega_print_customizer_style() {
	if ( is_customize_preview() ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$customizer_css = "
		/* Customizer Edit Icon */
		.customize-partial-edit-shortcut,
		.widget .customize-partial-edit-shortcut {
			left: 0;
		}";
		
		wp_add_inline_style( 'mega-style', $customizer_css );
		
	}
}
add_action( 'wp_enqueue_scripts', 'mega_print_customizer_style' );

/**
 * Add a style block to the theme for the social links.
 */
function mega_print_social_links_style() {
	$social_accounts_widgets = get_option( 'widget_social_accounts_widget' );
	$social_links_additional_style = false;
	if ( is_array( $social_accounts_widgets ) || is_object( $social_accounts_widgets ) ) {
		foreach ( $social_accounts_widgets as $social_accounts_widget ) {
			if ( ! empty( $social_accounts_widget['style'] ) ) {
				if ( $social_accounts_widget['style'] == '2' || $social_accounts_widget['style'] == '3' ) {
					$social_links_additional_style = true;
				}
			}
		}
	}
	
	$social_links_style = get_theme_mod( 'social_links_style', 1 );
	
	if ( $social_links_additional_style == '1' || $social_links_style == '2' || $social_links_style == '3' ) {
	
	wp_enqueue_style( 'mega-style' );
	
	$social_links_css = "
	/* Social Links */
	.social-links-style-2 .social-links .social,
	.social-links-style-3 .social-links .social {
		padding: 2px 0;
		clear: both;
	}
	.social-links-style-2 .social-text {
		display: inline-block;
		margin-left: 10px;
	}
	.social-links-style-3 .social-text {
		display: inline-block;
	}
	.social-links-style-3 .social-icon {
		display: none;
	}";
	
	wp_add_inline_style( 'mega-style', $social_links_css );
	
	}
		
}
add_action( 'wp_enqueue_scripts', 'mega_print_social_links_style' );

/**
 * Add a style block to the theme for the comments.
 */
function mega_print_comments_style() {
	if ( is_singular() ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$comments_css = "
		/* Comments */
		#comments-wrapper {
			background: var(--body-color);
			padding: 50px 0;
			border-top: 1px solid var(--borders-color);
			margin: 0 auto;
			width: 100%;
			position: relative;
			z-index: 2;
		}
		#comments {
			padding: 0;
			margin: 0 auto;
			float: none;
			max-width: 608px;
			margin-bottom: 35px;
		}
		.nopassword,
		.nocomments {
			text-align: center;
		}
		@media (max-width: 1023px) {
			.single-post #comments,
			.page-template-default #comments {
				padding: 0 15px;
			}
			#comments-wrapper {
				padding-bottom: 0;
			}
		}";
		
		wp_add_inline_style( 'mega-style', $comments_css );
		
	}
}
add_action( 'wp_enqueue_scripts', 'mega_print_comments_style' );

/**
 * Add a style block to the theme for the sidebar.
 */
function mega_print_sidebar_style() {
	if ( is_active_sidebar( 'sidebar-1' ) && is_home() || is_singular( 'post' ) && is_active_sidebar( 'sidebar-1' ) ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$sidebar_css = "
		/* Sidebar */
		.main-sidebar-is-active #primary > .vc_column-inner {
			padding-right: 30px;
		}
		.single-post.main-sidebar-is-active #primary {
			margin-bottom: 85px;
		}
		#secondary {
			float: left;
			width: 25%;
			position: relative;
			padding-top: 50px;
			box-sizing: border-box;
		}
		.single-post.main-sidebar-is-active.vertical-header #primary > .vc_column-inner,
		.blog.main-sidebar-is-active.vertical-header #primary > .vc_column-inner {
			padding-left: 30px;
			padding-right: 30px;
		}
		.single-post.main-sidebar-is-active.header-position-left #secondary > .vc_column-inner,
		.blog.main-sidebar-is-active.header-position-left #secondary > .vc_column-inner {
			padding-right: 30px;
		}
		.single-post.main-sidebar-is-active.header-position-right #secondary > .vc_column-inner,
		.blog.main-sidebar-is-active.header-position-right #secondary > .vc_column-inner {
			padding-left: 30px;
		}
		.blog.main-sidebar-is-active #primary,
		.single-post.main-sidebar-is-active #primary {
			width: 75%;
			float: left;
		}
		.blog.main-sidebar-is-active.header-position-right #page #primary,
		.single-post.main-sidebar-is-active.header-position-right #page #primary {
			float: right;
		}
		@media (max-width: 1023px) {
			#secondary {
				width: 100%;
				float: none;
				margin: 0 auto 50px;
			}
			#secondary > .vc_column-inner {
				padding-left: 15px;
				padding-right: 15px;
			}
			.single-post.main-sidebar-is-active.header-position-left #secondary > .vc_column-inner,
			.blog.main-sidebar-is-active.header-position-left #secondary > .vc_column-inner {
				padding-right: 15px;
			}
			.single-post.main-sidebar-is-active.header-position-right #secondary > .vc_column-inner,
			.blog.main-sidebar-is-active.header-position-right #secondary > .vc_column-inner {
				padding-left: 15px;
			}
			.single-post.main-sidebar-is-active #primary {
				margin-bottom: 50px;
			}
			.blog.main-sidebar-is-active #secondary > .vc_column-inner,
			.single-post.main-sidebar-is-active #secondary > .vc_column-inner {
				padding: 0 15px;
			}
			.single-post.main-sidebar-is-active #main #secondary {
				margin-top: 50px;
			}
			.blog.main-sidebar-is-active #primary,
			.single-post.main-sidebar-is-active #primary {
				width: 100%;
				margin: 0 auto;
				float: none;
				padding: 0;
				padding-top: 40px;
			}
			@media (max-width: 768px) {
				.blog.main-sidebar-is-active #primary .wpb_row > .wrapper > .inner-wrapper > .vc_column_container > .vc_column-inner,
				.single-post.main-sidebar-is-active #primary .wpb_row > .wrapper > .inner-wrapper > .vc_column_container > .vc_column-inner {
					padding-left: 0;
					padding-right: 0;
				}
			}
		}";
		
		wp_add_inline_style( 'mega-style', $sidebar_css );
		
	}
}
add_action( 'wp_enqueue_scripts', 'mega_print_sidebar_style' );

/**
 * Add a style block to the theme for the attachment.
 */
function mega_print_attachment_style() {
	if ( is_attachment() ) {
	
		wp_enqueue_style( 'mega-style' );
		
		$attachment_css = "
		/* Attachments */
		.single-attachment .attachment {
			text-align: center;
		}
		.single-attachment .attachment a {
			box-shadow: none;
		}
		.single-attachment .image-attachment .entry-content {
			margin: 0 auto 100px;
			width: auto;
		}
		.single-attachment .image-attachment .entry-description {
			margin: 50px auto;
			max-width: 780px;
			text-align: center;
		}";
		
		wp_add_inline_style( 'mega-style', $attachment_css );
		
	}
}
add_action( 'wp_enqueue_scripts', 'mega_print_attachment_style' );

// Remove RevSlider admin CSS on front-end
function remove_revslider_admin_css_on_front_end() {
	if ( ! is_admin() ) {
		wp_dequeue_style( 'revslider-material-icons' );
		wp_dequeue_style( 'revslider-basics-css' );
		wp_dequeue_style( 'rs-color-picker-css' );
		wp_dequeue_style( 'revbuilder-select2RS' );
		wp_dequeue_style( 'rs-roboto' );
		wp_dequeue_style( 'tp-material-icons' );
	}
}	
add_action( 'wp_enqueue_scripts', 'remove_revslider_admin_css_on_front_end' ); 

// Convert Hex Color to RGB
if ( ! function_exists( 'mega_hex2rgb' ) ) {
	function mega_hex2rgb( $hex ) {
	   $hex = str_replace( "#", "", $hex );

	   if ( strlen( $hex ) == 3 ) {
		  $r = hexdec( substr( $hex, 0, 1).substr( $hex, 0, 1 ) );
		  $g = hexdec( substr( $hex, 1, 1 ).substr( $hex, 1, 1 ) );
		  $b = hexdec( substr( $hex, 2, 1 ).substr( $hex, 2, 1 ) );
	   } else {
		  $r = hexdec( substr( $hex, 0, 2 ) );
		  $g = hexdec( substr( $hex, 2, 2 ) );
		  $b = hexdec( substr( $hex, 4, 2 ) );
	   }
	   $rgb = array( $r, $g, $b );
	   return $rgb; // returns an array with the rgb values
	}
}

// Parses an RGBA string and returns and array with each color
function mega_parseRGBA( $str ) {
    // Match the rgba string and get it's part
    if ( preg_match( '/rgba\( *([\d\.-]+), *([\d\.-]+), *([\d\.-]+), *([\d\.-]+) *\)/i', $str, $m ) ) {
        $out = array(
            'r' => intval($m[1]), // get the red
            'g' => intval($m[2]), // get the green
            'b' => intval($m[3]), // get the blue
            'a' => round( floatval( $m[4]) * 255 ), // get the alpha and scale to 0-255
        );

        //clamp each  value between 0 and 255
        array_walk( $out, function( &$v ){
			$v = min( 255, max( 0, $v ) );
		} );

        return $out;
    }
    return false;
}

// Hex Validation
function mega_validHex( $hex ) {
   return preg_match( '/^#?(([a-f0-9]{3}){1,2})$/i', $hex );
}

// Search Results Number
function mega_change_wp_search_size( $query ) {
    if ( $query->is_search ) // Make sure it is a search page
        $query->query_vars['posts_per_page'] = 10;

    return $query; // Return our modified query variables
}
add_filter( 'pre_get_posts', 'mega_change_wp_search_size' );

// Easy Social Share Buttons Plugin
if ( class_exists( 'ESSB_Manager' ) ) {
	// Easy Social Share Buttons for WordPress Theme Integration
	function mega_essb_is_in_theme() {
		return true;
	}
	add_filter( 'essb_is_theme_integrated', 'mega_essb_is_in_theme' );

	// Easy Social Share Buttons template
	function mega_essb_skylab_initialze( $templates ) {
		$templates['1001'] = 'Skylab';
		$templates['1002'] = 'Skylab Minimal';
		return $templates;
	}
	add_filter( 'essb4_templates', 'mega_essb_skylab_initialze' );

	function mega_essb_skylab_class( $class, $template_id ) {
		if ( $template_id == '1001' ) {
			$class = 'skylab';
		} else if ( $template_id == '1002' ) {
			$class = 'skylab-minimal';
		}
		
		return $class;
	}
	add_filter( 'essb4_templates_class', 'mega_essb_skylab_class', 10, 2 );
}

// Password Form
function mega_password_form() {
    $id = get_queried_object_id();
	$post = get_post( $id );
    $label = 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );
    $output = '<form action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" class="post-password-form" method="post">
    <p>'. esc_html__( "This content is password protected. To view it please enter your password below:", 'skylab' ) .'</p><label for="'. $label . '">' . esc_html__( "Password:", 'skylab' ) .' </label><input name="post_password" id="'. $label .'" type="password" size="20" maxlength="20" placeholder="'. esc_attr__( 'Password', 'skylab' ) .'" /><span class="submit-button-wrapper post_password"><input type="submit" name="Submit" value="' . esc_attr__( "Enter", 'skylab' ) . '" /></span></form>';
	
    return $output;
}
add_filter( 'the_password_form', 'mega_password_form' );

// Content Before, After
function mega_content_before_after( $content ) {
	// Single Post Tags List
    if( is_singular( 'post' ) ) {
		$after_content = '';
		
		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', '' );
		if ( $tags_list ) {
			$after_content .= '<span class="tag-links">';
				$after_content .= '<span class="tag-title">'. esc_html__( 'Tags: ', 'skylab' ) .'</span>';
				$after_content .= $tags_list;
			$after_content .= '</span>';
		}
		$full_content = $content . $after_content;
		
		return $full_content;
	} else {
		return $content;
	}
}
add_filter( 'the_content', 'mega_content_before_after' );

// WPBakery Page Builder Define Post Types by Default
$vc_default_post_types_list = array(
    'page',
    'portfolio'
);

if ( function_exists( 'vc_set_default_editor_post_types' ) ) {
	vc_set_default_editor_post_types( $vc_default_post_types_list );
}

// WPBakery Page Builder and Slider Revolution Remove License Activation Notice
function mega_remove_license_activation_notice() {
	$output = '<style>
	.vc_license-activation-notice,
	.rs-update-notice-wrap,
	.rs-dashboard #activation_dw .rs-status-red {
		display: none;
	}
	.rs-dashboard #activation_dw .rs-status-red-wrap .rs-dash-title {
		color: inherit;
	}
	</style>';
	echo trim( $output );
}
add_action( 'admin_head', 'mega_remove_license_activation_notice' );

// Remove WordPress JSON API links in header
remove_action( 'wp_head', 'rest_output_link_header', 10 );
remove_action( 'template_redirect', 'rest_output_link_header', 11 );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function mega_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'mega_pingback_header' );

// Custom class for Customizer Export/Import plugin
if ( class_exists( 'CEI_Core' ) ) {
	remove_action( 'customize_register', 'CEI_Core::init', 999999 );
	add_action( 'customize_register', 'mega_CEI_Core::init', 999999 );
}

/**
 * The main export/import class.
 *
 * @since 0.1
 */
class mega_CEI_Core {
	
	/**
	 * An array of core options that shouldn't be imported.
	 *
	 * @since 0.3
	 * @access private
	 * @var array $core_options
	 */
	static private $core_options = array(
		'blogname',
		'blogdescription',
		'show_on_front',
		'page_on_front',
		'page_for_posts',
	);

	/**
	 * Check to see if we need to do an export or import.
	 * This should be called by the customize_register action.
	 *
	 * @since 0.1
	 * @since 0.3 Passing $wp_customize to the export and import methods.
	 * @param object $wp_customize An instance of WP_Customize_Manager.
	 * @return void
	 */
	static public function init( $wp_customize ) {
		if ( current_user_can( 'edit_theme_options' ) ) {

			if ( isset( $_REQUEST['cei-export'] ) ) {
				self::_export( $wp_customize );
			}
			if ( isset( $_REQUEST['cei-import'] ) && isset( $_FILES['cei-import-file'] ) ) {
				self::_import( $wp_customize );
			}
		}
	}

	/**
	 * Export customizer settings.
	 *
	 * @since 0.1
	 * @since 0.3 Added $wp_customize param and exporting of options.
	 * @access private
	 * @param object $wp_customize An instance of WP_Customize_Manager.
	 * @return void
	 */
	static private function _export( $wp_customize ) {
		if ( ! wp_verify_nonce( $_REQUEST['cei-export'], 'cei-exporting' ) ) {
			return;
		}

		$theme		= get_stylesheet();
		$template	= get_template();
		$charset	= get_option( 'blog_charset' );
		$mods		= get_theme_mods();
		$data		= array(
						  'template'  => $template,
						  'mods'	  => $mods ? $mods : array(),
						  'options'	  => array()
					  );

		// Get options from the Customizer API.
		$settings = $wp_customize->settings();

		foreach ( $settings as $key => $setting ) {

			if ( 'option' == $setting->type ) {

				// Don't save widget data.
				if ( 'widget_' === substr( strtolower( $key ), 0, 7 ) ) {
					continue;
				}

				// Don't save sidebar data.
				if ( 'sidebars_' === substr( strtolower( $key ), 0, 9 ) ) {
					continue;
				}

				// Don't save core options.
				if ( in_array( $key, self::$core_options ) ) {
					continue;
				}

				$data['options'][ $key ] = $setting->value();
			}
		}

		// Plugin developers can specify additional option keys to export.
		$option_keys = apply_filters( 'cei_export_option_keys', array() );

		foreach ( $option_keys as $option_key ) {
			$data['options'][ $option_key ] = get_option( $option_key );
		}

		if( function_exists( 'wp_get_custom_css_post' ) ) {
			$data['wp_css'] = wp_get_custom_css();
		}

		// Set the download headers.
		header( 'Content-disposition: attachment; filename=' . $theme . '-export.dat' );
		header( 'Content-Type: application/octet-stream; charset=' . $charset );

		// Serialize the export data.
		echo serialize( $data );

		// Start the download.
		die();
	}

	/**
	 * Imports uploaded mods and calls WordPress core customize_save actions so
	 * themes that hook into them can act before mods are saved to the database.
	 *
	 * @since 0.1
	 * @since 0.3 Added $wp_customize param and importing of options.
	 * @access private
	 * @param object $wp_customize An instance of WP_Customize_Manager.
	 * @return void
	 */
	static private function _import( $wp_customize ) {
		// Make sure we have a valid nonce.
		if ( ! wp_verify_nonce( $_REQUEST['cei-import'], 'cei-importing' ) ) {
			return;
		}

		// Make sure WordPress upload support is loaded.
		if ( ! function_exists( 'wp_handle_upload' ) ) {
			require_once( ABSPATH . 'wp-admin/includes/file.php' );
		}

		// Load the export/import option class.
		require_once CEI_PLUGIN_DIR . 'classes/class-cei-option.php';

		// Setup global vars.
		global $wp_customize;
		global $cei_error;

		// Setup internal vars.
		$cei_error	 = false;
		$template	 = get_template();
		$overrides   = array( 'test_form' => false, 'test_type' => false, 'mimes' => array('dat' => 'text/plain') );
		$file        = wp_handle_upload( $_FILES['cei-import-file'], $overrides );

		// Make sure we have an uploaded file.
		if ( isset( $file['error'] ) ) {
			$cei_error = $file['error'];
			return;
		}
		if ( ! file_exists( $file['file'] ) ) {
			$cei_error = __( 'Error importing settings! Please try again.', 'skylab' );
			return;
		}

		// Get the upload data.
		require_once ABSPATH . 'wp-admin/includes/class-wp-filesystem-base.php';
		require_once ABSPATH . 'wp-admin/includes/class-wp-filesystem-direct.php';
		
		$raw  = WP_Filesystem_Direct::get_contents( $file['file'] );
		$data = @unserialize( $raw );

		// Remove the uploaded file.
		unlink( $file['file'] );

		// Data checks.
		if ( 'array' != gettype( $data ) ) {
			$cei_error = __( 'Error importing settings! Please check that you uploaded a customizer export file.', 'skylab' );
			return;
		}
		if ( ! isset( $data['template'] ) || ! isset( $data['mods'] ) ) {
			$cei_error = __( 'Error importing settings! Please check that you uploaded a customizer export file.', 'skylab' );
			return;
		}
		if ( $data['template'] != $template ) {
			$cei_error = __( 'Error importing settings! The settings you uploaded are not for the current theme.', 'skylab' );
			return;
		}

		// Import images.
		if ( isset( $_REQUEST['cei-import-images'] ) ) {
			$data['mods'] = self::_import_images( $data['mods'] );
			// Import fonts.
			$data['mods'] = self::_import_fonts( $data['mods'] );
		}

		// Import custom options.
		if ( isset( $data['options'] ) ) {

			foreach ( $data['options'] as $option_key => $option_value ) {

				$option = new CEI_Option( $wp_customize, $option_key, array(
					'default'		=> '',
					'type'			=> 'option',
					'capability'	=> 'edit_theme_options'
				) );

				$option->import( $option_value );
			}
		}

		// If wp_css is set then import it.
		if( function_exists( 'wp_update_custom_css_post' ) && isset( $data['wp_css'] ) && '' !== $data['wp_css'] ) {
			wp_update_custom_css_post( $data['wp_css'] );
		}

		// Call the customize_save action.
		do_action( 'customize_save', $wp_customize );

		// Loop through the mods.
		foreach ( $data['mods'] as $key => $val ) {

			// Call the customize_save_ dynamic action.
			do_action( 'customize_save_' . $key, $wp_customize );

			// Save the mod.
			set_theme_mod( $key, $val );
		}

		// Call the customize_save_after action.
		do_action( 'customize_save_after', $wp_customize );
	}

	/**
	 * Imports images for settings saved as mods.
	 *
	 * @since 0.1
	 * @access private
	 * @param array $mods An array of customizer mods.
	 * @return array The mods array with any new import data.
	 */
	static private function _import_images( $mods ) {
		foreach ( $mods as $key => $val ) {

			if ( self::_is_image_url( $val ) ) {

				$data = self::_sideload_image( $val );

				if ( ! is_wp_error( $data ) ) {

					$mods[ $key ] = $data->url;

					// Handle header image controls.
					if ( isset( $mods[ $key . '_data' ] ) ) {
						$mods[ $key . '_data' ] = $data;
						update_post_meta( $data->attachment_id, '_wp_attachment_is_custom_header', get_stylesheet() );
					}
				}
			}
		}

		return $mods;
	}
	
	/**
	 * Imports fonts for settings saved as mods.
	 *
	 * @since 0.1
	 * @access private
	 * @param array $mods An array of customizer mods.
	 * @return array The mods array with any new import data.
	 */
	static private function _import_fonts( $mods ) {
		
		foreach ( $mods as $f => $val ) {
			
			if ( is_string( $val ) ) {
				if ( strpos( $f, '_typography_font' ) !== false ) {
					$val = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $val );
					foreach ( $val as $font => $v ) {
						$v = html_entity_decode( $v );
						$v = json_decode( $v, true );
						$v['src'] = explode( ',', $v['src'] );
						foreach ( $v['src'] as $key => $i ) {
							
							if ( self::_is_font_url( $i ) ) {
						
								if ( is_string( $i ) ) {
									$data = self::_sideload_font( $i );
									if ( ! is_wp_error( $data ) ) {
										if ( isset( $data->url ) ) {
											$i = $data->url;
											$v['src'][$key] = $i;
										}
									}
								}
								
							}
							
						}
						$v['src'] = implode( ',', $v['src'] );
						$v = json_encode( $v, JSON_UNESCAPED_SLASHES );
						$val[$font] = $v;
					}
					$val = implode( ',', $val );
					$mods[$f] = $val;
				}
			}
		
		}

		return $mods;
	}

	/**
	 * Taken from the core media_sideload_image function and
	 * modified to return an array of data instead of html.
	 *
	 * @since 0.1
	 * @access private
	 * @param string $file The image file path.
	 * @return array An array of image data.
	 */
	static private function _sideload_image( $file ) {
		$data = new stdClass();

		if ( ! function_exists( 'media_handle_sideload' ) ) {
			require_once( ABSPATH . 'wp-admin/includes/media.php' );
			require_once( ABSPATH . 'wp-admin/includes/file.php' );
			require_once( ABSPATH . 'wp-admin/includes/image.php' );
		}
		if ( ! empty( $file ) ) {

			// Set variables for storage, fix file filename for query strings.
			preg_match( '/[^\?]+\.(jpe?g|jpe|gif|png)\b/i', $file, $matches );
			$file_array = array();
			$file_array['name'] = basename( $matches[0] );

			// Download file to temp location.
			$file_array['tmp_name'] = download_url( $file );

			// If error storing temporarily, return the error.
			if ( is_wp_error( $file_array['tmp_name'] ) ) {
				return $file_array['tmp_name'];
			}

			// Do the validation and storage stuff.
			$id = media_handle_sideload( $file_array, 0 );

			// If error storing permanently, unlink.
			if ( is_wp_error( $id ) ) {
				@unlink( $file_array['tmp_name'] );
				return $id;
			}

			// Build the object to return.
			$meta					= wp_get_attachment_metadata( $id );
			$data->attachment_id	= $id;
			$data->url				= wp_get_attachment_url( $id );
			$data->thumbnail_url	= wp_get_attachment_thumb_url( $id );
			$data->height			= $meta['height'];
			$data->width			= $meta['width'];
		}

		return $data;
	}
	
	/**
	 * Taken from the core media_sideload_image function and
	 * modified to return an array of data instead of html.
	 *
	 * @since 0.1
	 * @access private
	 * @param string $file The image file path.
	 * @return array An array of image data.
	 */
	static private function _sideload_font( $file ) {
		$data = new stdClass();

		if ( ! function_exists( 'media_handle_sideload' ) ) {
			require_once( ABSPATH . 'wp-admin/includes/media.php' );
			require_once( ABSPATH . 'wp-admin/includes/file.php' );
			require_once( ABSPATH . 'wp-admin/includes/image.php' );
		}
		if ( ! empty( $file ) ) {

			// Set variables for storage, fix file filename for query strings.
			preg_match( '/[^\?]+\.(woff|woff2)\b/i', $file, $matches );
			if ( isset( $matches[0] ) ) {
				$file_array = array();
				$file_array['name'] = basename( $matches[0] );

				// Download file to temp location.
				$file_array['tmp_name'] = download_url( $file );

				// If error storing temporarily, return the error.
				if ( is_wp_error( $file_array['tmp_name'] ) ) {
					return $file_array['tmp_name'];
				}

				// Do the validation and storage stuff.
				$id = media_handle_sideload( $file_array, 0 );

				// If error storing permanently, unlink.
				if ( is_wp_error( $id ) ) {
					@unlink( $file_array['tmp_name'] );
					return $id;
				}

				// Build the object to return.
				$meta					= wp_get_attachment_metadata( $id );
				$data->attachment_id	= $id;
				$data->url				= wp_get_attachment_url( $id );
			}
		}

		return $data;
	}

	/**
	 * Checks to see whether a string is an image url or not.
	 *
	 * @since 0.1
	 * @access private
	 * @param string $string The string to check.
	 * @return bool Whether the string is an image url or not.
	 */
	static private function _is_image_url( $string = '' ) {
		if ( is_string( $string ) ) {

			if ( preg_match( '/\.(jpg|jpeg|png|gif)/i', $string ) ) {
				return true;
			}
		}

		return false;
	}
	
	/**
	 * Checks to see whether a string is an font url or not.
	 *
	 * @since 0.1
	 * @access private
	 * @param string $string The string to check.
	 * @return bool Whether the string is an font url or not.
	 */
	static private function _is_font_url( $string = '' ) {
		if ( is_string( $string ) ) {

			if ( preg_match( '/\.(woff|woff2)/i', $string ) ) {
				return true;
			}
		}

		return false;
	}
}

// Import customizer fonts
function mega_customizer_import_execution() {
	$mods = get_theme_mods();
	
	foreach ( $mods as $f => $val ) {
			
		if ( is_string( $val ) ) {
			if ( strpos( $f, '_typography_font' ) !== false ) {
				$val = preg_split( '/(,)(?=(?:[^}]|{[^{]*})*$)/', $val );
					foreach ( $val as $font => $v ) {
						$v = html_entity_decode( $v );
						$v = json_decode( $v, true );
						$v['src'] = explode( ',', $v['src'] );
						foreach ( $v['src'] as $key => $i ) {
							
							if ( mega_is_font_url( $i ) ) {
							
								if ( is_string( $i ) ) {
									$data = mega_sideload_font( $i );
									if ( ! is_wp_error( $data ) ) {
										if ( isset( $data->url ) ) {
											$i = $data->url;
											$v['src'][$key] = $i;
										}
									}
								}
									
							}
								
						}
					$v['src'] = implode( ',', $v['src'] );
					$v = json_encode( $v, JSON_UNESCAPED_SLASHES );
					$val[$font] = $v;
				}
				$val = implode( ',', $val );
				$mods[$f] = $val;
				set_theme_mod( $f, $val );
			}
		}
		
	}
	
}
add_action( 'ocdi/customizer_import_execution', 'mega_customizer_import_execution', 11, 1 );

function mega_sideload_font( $file ) {
	$data = new stdClass();

	if ( ! function_exists( 'media_handle_sideload' ) ) {
		require_once( ABSPATH . 'wp-admin/includes/media.php' );
		require_once( ABSPATH . 'wp-admin/includes/file.php' );
		require_once( ABSPATH . 'wp-admin/includes/image.php' );
	}
	if ( ! empty( $file ) ) {

		// Set variables for storage, fix file filename for query strings.
		preg_match( '/[^\?]+\.(woff|woff2)\b/i', $file, $matches );
		if ( isset( $matches[0] ) ) {
			$file_array = array();
			$file_array['name'] = basename( $matches[0] );

			// Download file to temp location.
			$file_array['tmp_name'] = download_url( $file );

			// If error storing temporarily, return the error.
			if ( is_wp_error( $file_array['tmp_name'] ) ) {
				return $file_array['tmp_name'];
			}

			// Do the validation and storage stuff.
			$id = media_handle_sideload( $file_array, 0 );

			// If error storing permanently, unlink.
			if ( is_wp_error( $id ) ) {
				@unlink( $file_array['tmp_name'] );
				return $id;
			}

			// Build the object to return.
			$meta					= wp_get_attachment_metadata( $id );
			$data->attachment_id	= $id;
			$data->url				= wp_get_attachment_url( $id );
		}
	}

	return $data;
}

function mega_is_font_url( $string = '' ) {
	if ( is_string( $string ) ) {

		if ( preg_match( '/\.(woff|woff2)/i', $string ) ) {
			return true;
		}
	}

	return false;
}

// Label for Save my name, email, and website in this browser
function mega_comment_form_default_fields( $fields ) {
	$commenter = wp_get_current_commenter();

	$consent = empty( $commenter['comment_author_email'] ) ? '' : ' checked="checked"';

	$fields['cookies'] = '<p class="comment-form-cookies-consent"><input id="wp-comment-cookies-consent" name="wp-comment-cookies-consent" type="checkbox" value="yes"' . $consent . ' />' .
					 '<label for="wp-comment-cookies-consent"><span>'. __('Save my name, email, and website in this browser for the next time I comment.', 'skylab') .'</span></label></p>';
	return $fields;
}
add_filter( 'comment_form_default_fields', 'mega_comment_form_default_fields' );

// Remove defer attribute from js file in Autoptimize plugin
add_filter( 'autoptimize_filter_js_defer', 'mega_no_defer', 10, 1 );
function mega_no_defer( $defer ) {
	return '';
}

// Site Icon
function mega_site_icon_meta_tags( $meta_tags ) {
	$meta_tags = array();
	
	// Default
	$icon_32   = get_site_icon_url( 32 );
	if ( empty( $icon_32 ) && is_customize_preview() ) {
		$icon_32 = '/favicon.ico'; // Serve default favicon URL in customizer so element can be updated for preview.
	}
	if ( $icon_32 ) {
		$meta_tags[] = sprintf( '<link rel="icon" href="%s" sizes="32x32" media="(prefers-color-scheme:no-preference)" />', esc_url( $icon_32 ) );
	}
	$icon_192 = get_site_icon_url( 192 );
	if ( $icon_192 ) {
		$meta_tags[] = sprintf( '<link rel="icon" href="%s" sizes="192x192" media="(prefers-color-scheme:no-preference)" />', esc_url( $icon_192 ) );
	}
	$icon_180 = get_site_icon_url( 180 );
	if ( $icon_180 ) {
		$meta_tags[] = sprintf( '<link rel="apple-touch-icon" href="%s" media="(prefers-color-scheme:no-preference)" />', esc_url( $icon_180 ) );
	}
	$icon_270 = get_site_icon_url( 270 );
	if ( $icon_270 ) {
		$meta_tags[] = sprintf( '<meta name="msapplication-TileImage" content="%s" media="(prefers-color-scheme:no-preference)" />', esc_url( $icon_270 ) );
	}
	
	// Dark
	$site_icon_dark_id = get_theme_mod( 'site_icon_dark' );
	
	$icon_32_dark = wp_get_attachment_image_url( $site_icon_dark_id,  array( 32, 32 ) );
	if ( empty( $icon_32_dark ) && is_customize_preview() ) {
		$icon_32_dark = '/favicon.ico'; // Serve default favicon URL in customizer so element can be updated for preview.
	}
	if ( $icon_32_dark ) {
		$meta_tags[] = sprintf( '<link rel="icon" href="%s" sizes="32x32" media="(prefers-color-scheme:dark)" />', esc_url( $icon_32_dark ) );
	}
	$icon_192_dark = wp_get_attachment_image_url( $site_icon_dark_id,  array( 192, 192 ) );
	if ( $icon_192_dark ) {
		$meta_tags[] = sprintf( '<link rel="icon" href="%s" sizes="192x192" media="(prefers-color-scheme:dark)" />', esc_url( $icon_192_dark ) );
	}
	$icon_180_dark = wp_get_attachment_image_url( $site_icon_dark_id,  array( 180, 180 ) );
	if ( $icon_180_dark ) {
		$meta_tags[] = sprintf( '<link rel="apple-touch-icon" href="%s" media="(prefers-color-scheme:dark)" />', esc_url( $icon_180_dark ) );
	}
	$icon_270_dark = wp_get_attachment_image_url( $site_icon_dark_id,  array( 270, 270 ) );
	if ( $icon_270_dark ) {
		$meta_tags[] = sprintf( '<meta name="msapplication-TileImage" content="%s" media="(prefers-color-scheme:dark)" />', esc_url( $icon_270_dark ) );
	}
	
	// Light
	if ( empty( $icon_32 ) && is_customize_preview() ) {
		$icon_32 = '/favicon.ico'; // Serve default favicon URL in customizer so element can be updated for preview.
	}
	if ( $icon_32 ) {
		$meta_tags[] = sprintf( '<link rel="icon" href="%s" sizes="32x32" media="(prefers-color-scheme:light)" />', esc_url( $icon_32 ) );
	}
	$icon_192 = get_site_icon_url( 192 );
	if ( $icon_192 ) {
		$meta_tags[] = sprintf( '<link rel="icon" href="%s" sizes="192x192" media="(prefers-color-scheme:light)" />', esc_url( $icon_192 ) );
	}
	$icon_180 = get_site_icon_url( 180 );
	if ( $icon_180 ) {
		$meta_tags[] = sprintf( '<link rel="apple-touch-icon" href="%s" media="(prefers-color-scheme:light)" />', esc_url( $icon_180 ) );
	}
	$icon_270 = get_site_icon_url( 270 );
	if ( $icon_270 ) {
		$meta_tags[] = sprintf( '<meta name="msapplication-TileImage" content="%s" media="(prefers-color-scheme:light)" />', esc_url( $icon_270 ) );
	}

	return $meta_tags;
}
$site_icon_dark_id = get_theme_mod( 'site_icon_dark' );
if ( ! empty( $site_icon_dark_id ) ) {
add_filter( 'site_icon_meta_tags', 'mega_site_icon_meta_tags' );
}
