<?php
/*
Plugin Name: Skylab WPBakery Page Builder Addon
Plugin URI: megathe.me
Description: Enables custom WPBakery Page Builder elements for Skylab theme.
Version: 1.0
Author: MegaTheme
Author URI: megathe.me
*/

/**
 * Register widgetized areas.
 */
function mega_register_widgets() {
	register_widget( 'Mega_Social_Accounts' );
}
add_action( 'widgets_init', 'mega_register_widgets' );

/**
 * Adds Mega_Social_Accounts widget.
 */
class Mega_Social_Accounts extends WP_Widget {

	/**
	 * Register widget.
	 */
	function __construct() {
		parent::__construct(
			'social_accounts_widget',
			esc_html__( 'Social Links', 'mega' ),
			array(
				'description' => esc_html__( 'A Social Links Widget', 'mega' ), 
				'customize_selective_refresh' => true,
			)
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		echo $args['before_widget'];
		$align = isset( $instance['align'] ) ? esc_attr( $instance['align'] ) : 'left';
		$style = isset( $instance['style'] ) ? esc_attr( $instance['style'] ) : '1';
		?>
		<div class="social-links-wrapper align-<?php echo esc_attr( $align ); ?> social-links-style-<?php echo esc_attr( $style ); ?>  clearfix">
		<?php
		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ). $args['after_title'];
		}
		get_template_part( 'social-links' );
		?>
		</div>
		<?php
		echo $args['after_widget'];
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		$title = ! empty( $instance['title'] ) ? $instance['title'] : '';
		$align = isset( $instance['align'] ) ? esc_attr( $instance['align'] ) : '';
		$style = isset( $instance['style'] ) ? esc_attr( $instance['style'] ) : '';
		?>
		<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'mega' ); ?></label> 
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>
		
		<p><label><?php esc_html_e( 'Align', 'mega' ); ?>:</label>
            <select id="<?php echo esc_attr( $this->get_field_id( 'align' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'align' ) ); ?>">
            <?php $options = array( 'left', 'center', 'right' );
			 foreach ( $options as $option ) {
				echo '<option value="' . esc_attr( $option ) . '" id="' . esc_attr( $option ) . '"',
				$align == $option ? ' selected="selected"' : '', '>', esc_html( $option ), '</option>';
			}
			?>
            </select>
        </p>
		
		<p><label><?php esc_html_e( 'Style', 'mega' ); ?>:</label>
            <select id="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'style' ) ); ?>">
            <?php $options = array( 1, 2, 3 );
			 foreach ( $options as $option ) {
				echo '<option value="' . esc_attr( $option ) . '" id="' . esc_attr( $option ) . '"',
				$style == $option ? ' selected="selected"' : '', '>', esc_html( $option ), '</option>';
			}
			?>
            </select>
        </p>
		<?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['align'] = strip_tags( $new_instance['align'] );
		$instance['style'] = strip_tags( $new_instance['style'] );

		return $instance;
	}

} // class Mega_Social_Accounts

/**
 * WPBakery Page Builder with custom set of shortcodes.
 */

// don't load directly
if ( ! defined( 'ABSPATH' ) ) die( '-1' );

/*
Display notice if WPBakery Page Builder is not installed or activated.
*/
if ( ! defined( 'WPB_VC_VERSION' ) ) {
	return;
}

/**
 * Remove scripts and styles when wpbakery shortcode isn't used.
 */
function mega_remove_wpbakery_scripts_styles() {
	wp_deregister_style( 'js_composer_front' );
	wp_deregister_script( 'wpb_composer_front_js' );
	wp_deregister_script( 'vc_waypoints' );
}
add_action( 'wp_enqueue_scripts', 'mega_remove_wpbakery_scripts_styles', 9999 );

/**
 * Contact Form 7
 */
if ( defined( 'WPCF7_VERSION' ) ) {
	function mega_cf7_scripts_styles() {
		// Remove 'wp-polyfill' dependency
		wp_dequeue_script( 'contact-form-7' );
		wp_deregister_script( 'contact-form-7' );
		wp_register_script(
			'contact-form-7',
			wpcf7_plugin_url( 'includes/js/index.js' ),
			array(),
			WPCF7_VERSION,
			'header' !== wpcf7_load_js()
		);
		
		wp_enqueue_script( 'contact-form-7' );

		$wpcf7 = array(
			'api' => array(
				'root' => esc_url_raw( get_rest_url() ),
				'namespace' => 'contact-form-7/v1',
			),
		);

		if ( defined( 'WP_CACHE' ) and WP_CACHE ) {
			$wpcf7['cached'] = 1;
		}

		wp_localize_script( 'contact-form-7', 'wpcf7', $wpcf7 );
		
		// Remove scripts and styles when shortcode isn't used
		$id = get_queried_object_id();
		$post = get_post( $id );
		if ( isset( $post->post_content ) && ! has_shortcode( $post->post_content, 'contact-form-7' ) || is_archive() || is_author() || is_category() || is_home() || is_tag() || is_search() ) {
			wp_dequeue_style( 'contact-form-7' );
			wp_dequeue_script( 'contact-form-7' );
		}
	}
	add_action( 'wp_enqueue_scripts', 'mega_cf7_scripts_styles', 9999 );
}


// Remove “Edit with WPBakery Page Builder” from WordPress admin bar
function mega_vc_remove_wp_admin_bar_button() {
	remove_action( 'admin_bar_menu', array( vc_frontend_editor(), 'adminBarEditLink' ), 1000 );
}
add_action( 'vc_after_init', 'mega_vc_remove_wp_admin_bar_button' );

// Convert Hex Color to RGB
if ( ! function_exists( 'mega_hex2rgb' ) ) {
	function mega_hex2rgb( $hex ) {
	   $hex = str_replace( "#", "", $hex );

	   if ( strlen( $hex ) == 3 ) {
		  $r = hexdec( substr( $hex, 0, 1).substr( $hex, 0, 1 ) );
		  $g = hexdec( substr( $hex, 1, 1 ).substr( $hex, 1, 1 ) );
		  $b = hexdec( substr( $hex, 2, 1 ).substr( $hex, 2, 1 ) );
	   } else {
		  $r = hexdec( substr( $hex, 0, 2 ) );
		  $g = hexdec( substr( $hex, 2, 2 ) );
		  $b = hexdec( substr( $hex, 4, 2 ) );
	   }
	   $rgb = array( $r, $g, $b );
	   return $rgb; // returns an array with the rgb values
	}
}

/**
 * Get taxonomies terms links.
 */
function mega_custom_taxonomies_terms_links() {
	global $post, $post_id;
	// get post by post id
	$post = get_post( $post->ID );
	// get post type by post
	$post_type = $post->post_type;
	// get post type taxonomies
	$taxonomies = get_object_taxonomies( $post_type );
	foreach ( $taxonomies as $taxonomy ) {
		// get the terms related to post
		$terms = get_the_terms( $post->ID, $taxonomy );
		if ( ! empty( $terms ) ) {
			$out = array();
			foreach ( $terms as $term ) {
				$out[] = $term->name;
			}
			$return = join( ', ', $out );
			return $return;
		}
	}
}

// JavaScript
function mega_enqueue_addon_scripts() {
	wp_register_script( 'mega-addon-script', '', '', false, true );
}
add_action( 'wp_enqueue_scripts', 'mega_enqueue_addon_scripts', 10 );

// Posts MT
function mt_vc_posts( $atts, $content = null ) {
	wp_enqueue_script( 'isotope-pkgd' );
	
    extract( shortcode_atts( array(
		'data_source' => 'portfolio',
		'number' => 15,
		'layout' => '',
		'row_width' => '20',
		'columns' => '3',
		'margin' => '30px',
		'img_size' => 'large',
		'lazyload' => '',
		'pagination' => '',
		'first_page_number' => '',
		'animation' => '',
		'animation_type' => 'fadeinup',
		'delayed_animation' => '',
		'filter' => '',
		'filter_align' => '',
		'custom_url_target' => '',
		'disable_links' => '',
		'el_id' => '',
		'css_class' => '',
		'meta_data' => 'image,title',
		'link_text' => 'Read more',
		'orderby' => 'date',
		'order' => 'DESC',
		'category' => '',
		'category_not_in' => '',
		'post_in' => '',
		'post_not_in' => '',
		'template' => 'title_visible',
		'title_underline_on_hover' => '',
		'show_overlay_on_hover' => '',
		'overlay_mix_blend_mode' => '',
		'meta_data_mix_blend_mode_difference' => '',
		'overlay_background_color' => 'rgba(0,0,0,0.8)',
		'overlay_background_color_palette' => '',
		'title_color' => '',
		'title_color_on_hover' => '',
		'title_color_on_active' => '',
		'meta_data_color' => '',
		'excerpt_color' => '',
		'meta_data_align' => '',
		'meta_data_position' => '',
		'meta_data_animation' => '',
		'hover_scale_effect' => '',
		'click_scale_effect' => '',
		'hover_opacity_effect' => '',
		'click_opacity_effect' => '',
		'title_font_size' => '',
		'title_text_transform' => '',
		'title_font_weight' => '',
		'title_letter_spacing' => '',
		'title_font_style' => '',
		'title_font_family' => '',
		'meta_data_font_size' => '',
		'meta_data_text_transform' => '',
		'meta_data_font_weight' => '',
		'meta_data_letter_spacing' => '',
		'meta_data_font_style' => ''
    ), $atts ) );
	
	// Layout type
	if ( $layout == 'justified' ) {
		$layout_class = 'layout-justified';
	} else if ( $layout == 'cellsbyrow' ) {
		$layout_class = 'layout-cellsbyrow';
	} else if ( $layout == 'fitrows' ) {
		$layout_class = 'layout-fitrows';
	} else {
		$layout_class = 'layout-masonry';
	}
	
	// Columns count
	if ( $columns == 3 ) {
		$columns_class = 'col-3';
	} else if ( $columns == 4 ) {
		$columns_class = 'col-4';
	} else if ( $columns == 2 ) {
		$columns_class = 'col-2';
	} else if ( $columns == 1 ) {
		$columns_class = 'col-1';
	} else {
		$columns_class = '';
	}
	
	if ( $layout == 'justified' ) {
		$columns_class = '';
	}
	
	// Margin between items
	if ( $margin == '0px' ) {
		$margin_class = 'margin-0px';
	} else if ( $margin == '1px' ) {
		$margin_class = 'margin-1px';
	} else if ( $margin == '5px' ) {
		$margin_class = 'margin-5px';
	} else if ( $margin == '10px' ) {
		$margin_class = 'margin-10px';
	} else if ( $margin == '20px' ) {
		$margin_class = 'margin-20px';
	} else if ( $margin == '30px' ) {
		$margin_class = 'margin-30px';
	} else {
		$margin_class = '';
	}
	
	if ( $pagination == 'infinite_scroll' || $pagination == 'infinite_scroll_with_button' ) {
		wp_enqueue_script( 'mega-posts' );
		wp_enqueue_script( 'infinite-scroll' );
	} else {
		wp_enqueue_script( 'mega-posts' );
	}
	
	if ( $pagination == 'default' || $pagination == 'infinite_scroll' || $pagination == 'infinite_scroll_with_button' ) {
       $no_found_rows = false;
    } else {
	   $no_found_rows = true;
	}
	
	if ( get_query_var( 'paged' ) ) {
		$paged = get_query_var( 'paged' );
	} else if ( get_query_var( 'page' ) ) {
		$paged = get_query_var( 'page' );
	} else {
		$paged = 1;
	}
	
	// First page items count
	if ( ! empty( $first_page_number ) ) {
		// Changing posts_per_page for first of paginated pages
		$subsequent_pages_post_count = $number;
		
		if ( $paged > 1 ) {
			// not first page
			$posts_per_page = $subsequent_pages_post_count;

			if ( $paged == 2 ) {
				// second page
				$offset = $first_page_number;
			} else {
				// subsequent pages
				$offset = $first_page_number + ( $subsequent_pages_post_count * ( $paged - 2 ) );
			}

		} else {
			// first page
			$offset = 0;
			$posts_per_page = $first_page_number;
		}
	
	}
	
	global $wp_query, $post;
    $temp = $wp_query;
    $wp_query= null;
	
	$args = array();
	
	// Exclude items IDs
	$not_in = array();
	if ( $post_not_in != '' ) {
		$post_not_in = str_ireplace( " ", "", $post_not_in );
		$not_in = explode( ",", $post_not_in );
	}
	
	// Items IDs
	if ( $post_in != '' ) {
		$post_in = str_ireplace( " ", "", $post_in );
		$args['post__in'] = explode( ",", $post_in );
	}
	if ( $post_in == '' || $post_not_in != '' ) {
		$args['post__not_in'] = $not_in;
	}
	
	// Order by
	if ( $orderby != NULL ) {
		$args['orderby'] = $orderby;
	}
	
	// Order way
	$args['order'] = $order;
	
	// Data source
	$args['post_type'] = $data_source;
	
	// Category
	if ( $data_source == 'portfolio' ) {
		$data_source_args = 'portfolio-category';
	} else {
		$data_source_args = 'category_name';
	}
	$args[$data_source_args] = $category;
	
	if ( ! empty( $first_page_number ) ) {
		$args['posts_per_page'] = $posts_per_page;
		$args['offset'] = $offset;
	} else {
		$args['posts_per_page'] = $number;
	}
	$args['paged'] = $paged;
	$args['no_found_rows'] = $no_found_rows;
	$args['post_status'] = 'publish';
	$wp_query = new WP_Query( $args );
	ob_start();
	
	if ( ! $lazyload ) {
		wp_enqueue_script( 'imagesloaded' );
	}
	
	// Lazy-loading
	if ( $lazyload != '' && $lazyload != '0' ) {
		wp_enqueue_script( 'lazysizes' );
		$lazyload_class = 'lazyload-enabled';
	} else {
		$lazyload_class = 'lazyload-disabled';
	}
	
	// Pagination
	if ( $pagination == 'infinite_scroll' ) {
		$infinite_scroll = 'infinite-scroll-enabled';
	} else if ( $pagination == 'infinite_scroll_with_button' ) {
		$infinite_scroll = 'infinite-scroll-enabled-with-button';
	} else {
		$infinite_scroll = 'infinite-scroll-disabled';
	}
	
	// Animation
	if ( $animation != '' && $animation != '0' ) {
		wp_enqueue_script( 'waypoints' );
		$animation_class = 'mt-animate_when_almost_visible-enabled';
		if ( $delayed_animation != '' && $delayed_animation != '0' ) {
			$delayed_animation_class = 'mt-animate_when_almost_visible-delayed-enabled';
		} else {
			$delayed_animation_class = 'mt-animate_when_almost_visible-delayed-disabled';
		}
	} else {
		$animation_class = 'mt-animate_when_almost_visible-disabled';
		$delayed_animation_class = 'animation-for-every-item-in-viewport-disabled';
	}
	
	// Template
	if ( $template == 'title_visible' || $template == 'title_visible2' ) {
		$title_position = 'title-visible';
	} else {
		$title_position = 'title-hidden';
	}
	
	// Meta data mix blend mode difference
	if ( $meta_data_mix_blend_mode_difference != '' && $meta_data_mix_blend_mode_difference != '0' ) {
		$meta_data_mix_blend_mode_difference_class = 'meta-data-mix-blend-mode-difference-enabled';
	} else {
		$meta_data_mix_blend_mode_difference_class = 'meta-data-mix-blend-mode-difference-disabled';
	}
	
	// Overlay background color palette from an image
	if ( $overlay_background_color_palette != '' && $overlay_background_color_palette != '0' ) {
		wp_enqueue_script( 'color-thief' );
		$overlay_background_color_palette_class = 'overlay-background-color-palette-enabled';
	} else {
		$overlay_background_color_palette_class = 'overlay-background-color-palette-disabled';
	}
	
	// Title underline on hover
	if ( $title_underline_on_hover != '' && $title_underline_on_hover != '0' ) {
		$title_underline_on_hover_class = 'title-underline-hover-enabled';
	} else {
		$title_underline_on_hover_class = 'title-underline-hover-disabled';
	}
	
	// Meta data align
	$meta_data_align_class = '';
	if ( $template !== 'title_hidden' && $template !== 'title_hidden2'  ) {
		if ( $meta_data_align == 'left' ) {
			$meta_data_align_class = 'meta-data-align-left';
		} else {
			$meta_data_align_class = 'meta-data-align-center';
		}
	}
	
	// Meta data position
	$meta_data_position_class = '';
	if ( $template == 'title_hidden' || $template == 'title_hidden2' ) {
		if ( $meta_data_position == 'top_left' ) {
			$meta_data_position_class = 'meta-data-position-top-left';
		} else {
			$meta_data_position_class = 'meta-data-position-center';
		}
	}
	
	// Meta data animation
	$meta_data_animation_class = '';
	if ( $template == 'title_hidden' || $template == 'title_hidden2' ) {
		if ( $meta_data_animation == 'fadein' ) {
			$meta_data_animation_class = 'meta-data-animation-fadein';
		} else if ( $meta_data_animation == 'fadeinup' ) {
			$meta_data_animation_class = 'meta-data-animation-fadeinup';
		} else if ( $meta_data_animation == 'fadeinflip' ) {
			$meta_data_animation_class = 'meta-data-animation-fadeinflip';
		} else {
			$meta_data_animation_class = 'meta-data-animation-disabled';
		}
	}
	
	// Hover scale effect
	if ( $hover_scale_effect == 'scale' ) {
		$hover_scale_effect_class = 'hover-scale-effect-scale';
	} else if ( $hover_scale_effect == 'scale2' ) {
		$hover_scale_effect_class = 'hover-scale-effect-scale2';
	} else if ( $hover_scale_effect == 'scale3' ) {
		$hover_scale_effect_class = 'hover-scale-effect-scale3';
	} else {
		$hover_scale_effect_class = 'hover-scale-effect-none';
	}
	
	// Click scale effect
	if ( $click_scale_effect == 'scale' ) {
		$click_scale_effect_class = 'click-scale-effect-scale';
	} else if ( $click_scale_effect == 'scale2' ) {
		$click_scale_effect_class = 'click-scale-effect-scale2';
	} else {
		$click_scale_effect_class = 'click-scale-effect-none';
	}
	
	// Hover opacity effect
	if ( $hover_opacity_effect != '' && $hover_opacity_effect != '0' ) {
		$hover_opacity_effect_class = 'hover-opacity-effect-enabled';
	} else {
		$hover_opacity_effect_class = 'hover-opacity-effect-disabled';
	}
	
	// Click opacity effect
	if ( $click_opacity_effect != '' && $click_opacity_effect != '0' ) {
		$click_opacity_effect_class = 'click-opacity-effect-enabled';
	} else {
		$click_opacity_effect_class = 'click-opacity-effect-disabled';
	}
	?>
	
	<?php if ( ! empty( $show_overlay_on_hover ) && ! empty( $overlay_background_color_palette ) ) { ?>
		<?php if ( ! empty( $overlay_background_color ) ) { ?>
			<?php $overlay_background_color_arr = explode( ',', $overlay_background_color ); ?>
			<?php if ( ! empty( $overlay_background_color_arr[3] ) ) { ?>
				<?php $overlay_background_color_opacity = rtrim( $overlay_background_color_arr[3], ")" ); ?>
			<?php } else { ?>
				<?php $overlay_background_color_opacity = 1; ?>
			<?php } ?>
		<?php } ?>
	<?php } ?>
	
	<div <?php if ( ! empty( $el_id ) ) { ?>id="mt-posts-container-wrapper-<?php echo esc_attr( $el_id ); ?>"<?php } ?> class="mt-posts-container-wrapper <?php echo esc_attr( $layout_class ); ?> <?php echo esc_attr( $columns_class ); ?> <?php echo esc_attr( $margin_class ); ?> <?php echo esc_attr( $lazyload_class ); ?> <?php echo esc_attr( $infinite_scroll ); ?> <?php echo esc_attr( $animation_class ); ?> <?php echo esc_attr( $animation_type ); ?> <?php echo esc_attr( $delayed_animation_class ); ?> posts-template-<?php echo esc_attr( $template ); ?> <?php echo esc_attr( $title_position ); ?> <?php echo esc_attr( $meta_data_mix_blend_mode_difference_class ); ?> <?php echo esc_attr( $overlay_background_color_palette_class ); ?> <?php echo esc_attr( $title_underline_on_hover_class ); ?> <?php echo esc_attr( $hover_scale_effect_class ); ?> <?php echo esc_attr( $click_scale_effect_class ); ?> <?php echo esc_attr( $hover_opacity_effect_class ); ?> <?php echo esc_attr( $click_opacity_effect_class ); ?> <?php echo esc_attr( $meta_data_align_class ); ?> <?php echo esc_attr( $meta_data_position_class ); ?> <?php echo esc_attr( $meta_data_animation_class ); ?> <?php echo esc_attr( $css_class ); ?> clearfix" <?php if ( $layout == 'masonry' ) { ?>data-columns="<?php echo esc_attr( $columns ); ?>"<?php } ?> <?php if ( ! empty( $show_overlay_on_hover ) && ! empty( $overlay_background_color_palette ) ) { ?>data-overlay-bg-color-opacity="<?php echo esc_attr( $overlay_background_color_opacity ); ?>"<?php } ?>>
	
		<?php if ( $filter != '' && $filter != '0' ) { ?>
			<?php if ( $filter_align != '' && $filter_align != '0' ) { ?>
				<?php $filter_align_class = 'filter-center'; ?>
			<?php } else { ?>
				<?php $filter_align_class = 'filter-left'; ?>
			<?php } ?>
					
			<?php $wp_list_categories = wp_list_categories( array( 'title_li' => '', 'show_option_none' => '', 'taxonomy' => $data_source_args, 'walker' => new Mega_Walker_Portfolio_Category(), 'orderby' => 'name', 'style' => 'none', 'echo' => 0, 'exclude' => $category_not_in ) ); ?>
						
			<?php if ( ! empty( $wp_list_categories ) ) { ?>
							
				<nav class="filters <?php echo esc_attr( $filter_align_class ); ?> option-set">
					<div>
					<?php $sep = '<span class="sep"></span>'; ?>
					<?php $wp_list_categories = str_replace( '<br />', $sep, $wp_list_categories ); ?>
					<a href="#" data-filter="*" class="selected"><?php echo esc_html__( 'All', 'mega' ) ?></a>
					<?php echo $sep; ?>						
					
					<?php
					if ( $sep != '' ) {
						$wp_list_categories = strrev( $wp_list_categories );
						$sep = strrev( $sep );
						$wp_list_categories = explode( $sep, $wp_list_categories, 2 );
						$wp_list_categories = implode( '', $wp_list_categories );
						$wp_list_categories = strrev( $wp_list_categories );
					}
					?>	
													
					<?php echo $wp_list_categories; ?>
					</div>
				</nav>
							
			<?php } ?>
						
		<?php } ?>
	
		<?php if ( ! $lazyload ) { ?>
		<div class="loader-lg">
			<svg class="circular" viewBox="25 25 50 50">
				<circle class="path" cx="50" cy="50" r="20" fill="none" stroke-width="6" stroke-miterlimit="10"/>
			</svg>
		</div>
		<?php } ?>
		
		<div class="mt-posts-container clearfix">
			
			<span class="grid-sizer"></span>
			<span class="gutter-sizer"></span>
			
			<?php if ( $wp_query->have_posts() ) : ?>
		
				<?php while ( $wp_query->have_posts() ) : $wp_query->the_post(); ?>
				
					<?php
					$post_id = $wp_query->post->ID;
					$thumbnail = '';
						
					$post_thumbnail = $p_img_large = '';

					if ( $lazyload != '' && $lazyload != '0' ) {
						$lazyload = 'lazyload';
					} else {
						$lazyload = '';
					}
					$post_thumbnail = wpb_getImageBySize( array( 'post_id' => $post_id, 'thumb_size' => $img_size, 'class' => 'attachment '. $lazyload ) );
					$thumbnail = $post_thumbnail['thumbnail'];
					$p_img_large = $post_thumbnail['p_img_large'];
					?>
					
					<?php // Remove title tag ?>
					<?php $thumbnail = preg_replace( '/(<[^>]+) title=".*?"/i', '\1', $thumbnail ); ?>
					
					<?php if ( $thumbnail ) { ?>
						<?php if ( $lazyload != '' && $lazyload != '0' ) { ?>

							<?php $thumbnail_lazy = preg_replace( '/(<[^>]+) sizes=".*?"/i', '\1', $thumbnail ); ?>
							<?php $thumbnail_lazy = preg_replace( '/(<[^>]+) width=".*?"/i', '\1', $thumbnail_lazy ); ?>
							<?php $thumbnail_lazy = preg_replace( '/(<[^>]+) height=".*?"/i', '\1', $thumbnail_lazy ); ?>
							<?php $thumbnail_lazy = preg_replace( '/(<[^>]+) loading=".*?"/i', '\1', $thumbnail_lazy ); ?>
							<?php if ( strpos( $thumbnail_lazy, 'srcset=' ) !== false ) { ?>
								<?php $thumbnail_lazy = preg_replace( '/(<[^>]+) src=".*?"/i', '\1', $thumbnail_lazy ); ?>
								<?php $thumbnail_lazy = str_replace( 'srcset=', 'data-srcset=', $thumbnail_lazy ); ?>
							<?php } else { ?>
								<?php $thumbnail_lazy = str_replace( 'src=', 'data-src=', $thumbnail_lazy ); ?>
							<?php } ?>
							<?php //$thumbnail_lazy = str_replace( '/>', 'src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7"/>', $thumbnail_lazy ); ?>
							<?php if ( $overlay_background_color_palette != '' && $overlay_background_color_palette != '0' ) { ?>
								<?php $thumbnail_lazy = str_replace( '/>', 'crossorigin="anonymous"/>', $thumbnail_lazy ); ?>
							<?php } ?>
							<?php if ( in_array( $img_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full', ) ) ) { ?>
								<?php $thumbnail_src = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), $img_size ); ?>
								<?php $width = $thumbnail_src[1]; ?>
								<?php $height = $thumbnail_src[2]; ?>
							<?php } else { ?>
								<?php $size = str_replace( 'x', ',', $img_size ); ?>
								<?php $width = explode( ',', $size ); ?>
								<?php $width = $width[0]; ?>
								<?php $height = substr( $size, strpos( $size, "," ) + 1 ); ?>
							<?php } ?>
						<?php } ?>
						<?php $title = get_post( get_post_thumbnail_id() )->post_title; ?>
					<?php } ?>
					
					<?php $custom_url = get_post_meta( get_the_ID(), 'custom_url', true ); ?>
				
					<?php // Title visible ?>
					<?php if ( $template == 'title_visible' ) { ?>
					
						<?php // Portfolio Gallery ?>
						<?php $gallery_attachments = get_post_meta( get_the_ID(), 'portfolio_image_gallery', true ); ?>
						<?php if ( ! empty( $gallery_attachments ) ) { ?>
							<?php $gallery_class = 'gallery-enabled'; ?>
						<?php } else { ?>
							<?php $gallery_class = 'gallery-disabled'; ?>
						<?php } ?>
						<?php $gallery_attachments = explode( ',', $gallery_attachments ); ?>
					
						<?php
						$classes = array(
							'clearfix',
							'isotope-item',
							$gallery_class
						);
						?>
					
						<article id="post-<?php the_ID(); ?>" <?php post_class( $classes ); ?> <?php if ( $layout == 'justified' ) { ?>style="--w: <?php echo esc_attr( $width ) ?>; --row-width: <?php echo esc_attr( $row_width ) ?>vw; --h: <?php echo esc_attr( $height ) ?>;"<?php } ?>>
							<div class="content-wrapper-helper">
								<a class="content-wrapper" href="<?php if ( ! empty( $disable_links ) ) { ?>javascript:void(null);<?php } else { if ( ! empty( $custom_url ) ) { echo esc_url( $custom_url ); } else { the_permalink(); } } ?>" <?php if ( ! empty( $custom_url ) && $custom_url_target == 'blank' ) { ?>target="_blank" <?php } ?>>
									
									<?php $containers = vc_sorted_list_parse_value( $meta_data ); ?>
									<?php $i = 0; ?>
									<?php $len = count( $containers ); ?>
									<?php foreach ( $containers as $container_data ) { ?>
										<?php $container = $container_data[0]; ?>
										
										<?php if ( $container === 'image' ) { ?>
											<?php if ( $thumbnail ) { ?>
												<div class="post-thumbnail-wrapper-1">
													<div class="post-thumbnail-wrapper-2">
														<div class="post-thumbnail-wrapper-helper">
															<div class="post-thumbnail <?php if ( $lazyload != '' && $lazyload != '0' ) echo 'lazy'?>" <?php if ( $lazyload != '' && $lazyload != '0' ) { echo 'style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';"'; }?>>
																<?php $text_color = get_post_meta( get_the_ID(), 'text_color', true ); ?>
																<?php $background_color = get_post_meta( get_the_ID(), 'background_color', true ); ?>
																<?php $background_color_rgb = mega_hex2rgb( $background_color ); ?>
																<?php $opacity = .8; ?>
																<?php $background_color_rgba = "rgba(" . $background_color_rgb[0] . ", " . $background_color_rgb[1] . ", " . $background_color_rgb[2] . ", " . $opacity . ")"; ?>
																<?php if ( ! empty( $show_overlay_on_hover ) ) { ?>
																<div class="overlay" style="<?php if ( $overlay_mix_blend_mode != '' ) { ?>mix-blend-mode: <?php echo esc_attr( $overlay_mix_blend_mode ); ?>;<?php } ?><?php if ( ! empty( $background_color ) || ! empty( $overlay_background_color ) ) { ?>background-color: <?php if ( ! empty( $background_color ) ) { echo esc_attr( $background_color_rgba ); } else { echo esc_attr( $overlay_background_color ); } ?>;<?php } ?>"></div>
																<?php } ?>
																<?php if ( $lazyload != '' && $lazyload != '0' ) { ?>
																	<?php echo $thumbnail_lazy; ?>
																	<span class="loaderbg"></span>
																	
																	<?php // Portfolio Gallery ?>
																	<?php if ( ! empty( $gallery_attachments ) ) { ?>
																		<?php foreach ( $gallery_attachments as $gallery_attachment_id ) { ?>
																			<?php if ( $gallery_attachment_id > 0 ) { ?>
																				<?php $gallery_post_thumbnail = wpb_getImageBySize( array( 'attach_id' => $gallery_attachment_id, 'thumb_size' => $img_size, 'class' => 'gallery-attachment' ) ); ?>
																				<?php $gallery_thumbnail = $gallery_post_thumbnail['thumbnail']; ?>
																			
																				<?php $gallery_thumbnail_lazy = preg_replace( '/(<[^>]+) srcset=".*?"/i', '\1', $gallery_thumbnail ); ?>
																				<?php $gallery_thumbnail_lazy = preg_replace( '/(<[^>]+) sizes=".*?"/i', '\1', $gallery_thumbnail_lazy ); ?>
																				<?php $gallery_thumbnail_lazy = str_replace( 'src=', 'data-src=', $gallery_thumbnail_lazy ); ?>
																				<?php $gallery_thumbnail_lazy = str_replace( '/>', 'src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7">', $gallery_thumbnail_lazy ); ?>
																				<?php if ( in_array( $img_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full', ) ) ) { ?>
																					<?php $gallery_image_attributes = wp_get_attachment_image_src( get_post_thumbnail_id( $gallery_attachment_id ), $img_size ); ?>
																					<?php $gallery_width = $image_attributes[1]; ?>
																					<?php $gallery_height = $image_attributes[2]; ?>
																				<?php } else { ?>
																					<?php $gallery_size = str_replace( 'x', ',', $img_size ); ?>
																					<?php $gallery_width = explode( ',', $gallery_size ); ?>
																					<?php $gallery_width = $width[0]; ?>
																					<?php $gallery_height = substr( $gallery_size, strpos( $gallery_size, "," ) + 1 ); ?>
																				<?php } ?>
																				
																				<?php echo $gallery_thumbnail_lazy; ?>
																			<?php } ?>
																		<?php } ?>
																	<?php } ?>
																	
																<?php } else { ?>
																	<?php echo $thumbnail; ?>
																	<?php // Portfolio Gallery ?>
																	<?php if ( ! empty( $gallery_attachments ) ) { ?>
																		<?php foreach ( $gallery_attachments as $gallery_attachment_id ) { ?>
																			<?php if ( $gallery_attachment_id > 0 ) { ?>
																				<?php $gallery_post_thumbnail = wpb_getImageBySize( array( 'attach_id' => $gallery_attachment_id, 'thumb_size' => $img_size, 'class' => 'gallery-attachment' ) ); ?>
																				<?php $gallery_thumbnail = $gallery_post_thumbnail['thumbnail']; ?>
																				<?php echo $gallery_thumbnail; ?>
																			<?php } ?>
																		<?php } ?>
																	<?php } ?>
																<?php } ?>
															</div>
														</div>
													</div>
												</div>
											<?php } ?>
										<?php } ?>
										
										<?php if ( $i == 0 ) { ?>
										<div class="posts-content-wrapper">
											<div class="posts-content">
										<?php } ?>
										
											<?php if ( $container === 'title' ) { ?>
											<header class="entry-header">
												<h2 style="<?php if ( ! empty( $title_color ) ) { ?>color: <?php echo esc_attr( $title_color ); ?>; --title-color: <?php echo esc_attr( $title_color ); ?>; <?php } ?><?php if ( ! empty( $title_color_on_hover ) ) { ?>--title-color-on-hover: <?php echo esc_attr( $title_color_on_hover ); ?>; <?php } ?><?php if ( ! empty( $title_color_on_active ) ) { ?>--title-color-on-active: <?php echo esc_attr( $title_color_on_active ); ?>; <?php } ?><?php if ( ! empty( $title_font_size ) ) { ?>font-size: <?php if ( strpos( $title_font_size, 'rem' ) !== false ) { ?>calc(1.44vw + <?php echo esc_attr( $title_font_size ); ?>);<?php } else { echo esc_attr( $title_font_size ); ?>px;<?php } ?> <?php } ?><?php if ( ! empty( $title_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $title_text_transform ); ?>; <?php } ?><?php if ( ! empty( $title_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $title_font_weight ); ?>; <?php } ?><?php if ( ! empty( $title_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $title_letter_spacing ); ?><?php if ( strpos( $title_letter_spacing, 'em' ) == false ) { ?>px<?php } ?>; <?php } ?><?php if ( ! empty( $title_font_style ) ) { ?>font-style: <?php echo esc_attr( $title_font_style ); ?>; <?php } ?><?php if ( $title_font_family == 'primary' ) { ?>font-family: inherit; <?php } ?>"><span><?php the_title(); ?></span></h2>
											</header><!-- .entry-header -->
											<?php } ?>
											
											<?php if ( $container == 'excerpt' ) { ?>
											<?php if ( has_excerpt() ) { ?>
											<div class="entry-excerpt" style="<?php if ( ! empty( $excerpt_color ) ) { ?>color: <?php echo esc_attr( $excerpt_color ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_size ) ) { ?>font-size: <?php echo esc_attr( $meta_data_font_size ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $meta_data_text_transform ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $meta_data_font_weight ); ?>; <?php } ?><?php if ( ! empty( $meta_data_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $meta_data_letter_spacing ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_font_style ) ) { ?>font-style: <?php echo esc_attr( $meta_data_font_style ); ?>; <?php } ?>">
											<?php if ( $columns == 1 ) { ?>
												<?php get_template_part( 'content', get_post_format() ); ?>
											<?php } else { ?>
												<?php the_excerpt(); ?>
											<?php } ?>
											</div>
											<?php } ?>
											<?php } ?>
											
											<?php if ( $container == 'categories' ) { ?>
											<div class="entry-meta" style="<?php if ( ! empty( $meta_data_color ) ) { ?>color: <?php echo esc_attr( $meta_data_color ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_size ) ) { ?>font-size: <?php echo esc_attr( $meta_data_font_size ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $meta_data_text_transform ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $meta_data_font_weight ); ?>; <?php } ?><?php if ( ! empty( $meta_data_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $meta_data_letter_spacing ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_font_style ) ) { ?>font-style: <?php echo esc_attr( $meta_data_font_style ); ?>; <?php } ?>">
												<span class="entry-category"><?php echo esc_html( mega_custom_taxonomies_terms_links() ); ?></span>
											</div>
											<?php } ?>
											
											<?php if ( $container == 'date' ) { ?>
											<div class="entry-meta" style="<?php if ( ! empty( $meta_data_color ) ) { ?>color: <?php echo esc_attr( $meta_data_color ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_size ) ) { ?>font-size: <?php echo esc_attr( $meta_data_font_size ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $meta_data_text_transform ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $meta_data_font_weight ); ?>; <?php } ?><?php if ( ! empty( $meta_data_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $meta_data_letter_spacing ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_font_style ) ) { ?>font-style: <?php echo esc_attr( $meta_data_font_style ); ?>; <?php } ?>">
												<span class="entry-date"><?php echo esc_html( get_the_date() ); ?></span>
											</div>
											<?php } ?>
									
										<?php if ( $i == $len - 1 ) { ?>
											</div>
										</div>
										<?php } ?>
										
										<?php $i++; ?>
									<?php } ?>
								</a><!-- .content-wrapper -->
							</div><!-- .content-wrapper-helper -->
						</article>
						
					<?php // Title visible 2 ?>
					<?php } else if ( $template == 'title_visible2' ) { ?>
					
						<?php // Portfolio Gallery ?>
						<?php $gallery_attachments = get_post_meta( get_the_ID(), 'portfolio_image_gallery', true ); ?>
						<?php if ( ! empty( $gallery_attachments ) ) { ?>
							<?php $gallery_class = 'gallery-enabled'; ?>
						<?php } else { ?>
							<?php $gallery_class = 'gallery-disabled'; ?>
						<?php } ?>
						<?php $gallery_attachments = explode( ',', $gallery_attachments ); ?>
					
						<?php
						$classes = array(
							'clearfix',
							'isotope-item',
							$gallery_class
						);
						?>
					
						<article id="post-<?php the_ID(); ?>" <?php post_class( $classes ); ?> <?php if ( $layout == 'justified' ) { ?>style="--w: <?php echo esc_attr( $width ) ?>; --row-width: <?php echo esc_attr( $row_width ) ?>vw; --h: <?php echo esc_attr( $height ) ?>;"<?php } ?>>
							<div class="content-wrapper-helper">
								<div class="content-wrapper">
							
									<?php $containers = vc_sorted_list_parse_value( $meta_data ); ?>
									<?php $i = 0; ?>
									<?php $len = count( $containers ); ?>
									<?php foreach ( $containers as $container_data ) { ?>
										<?php $container = $container_data[0]; ?>
									
										<?php if ( $container === 'image' ) { ?>
											<?php if ( $thumbnail ) { ?>
												<a class="post-thumbnail-link" href="<?php if ( ! empty( $disable_links ) ) { ?>javascript:void(null);<?php } else { if ( ! empty( $custom_url ) ) { echo esc_url( $custom_url ); } else { the_permalink(); } } ?>" <?php if ( ! empty( $custom_url ) && $custom_url_target == 'blank' ) { ?>target="_blank" <?php } ?>>
													<div class="post-thumbnail-wrapper-1">
														<div class="post-thumbnail-wrapper-2">
															<div class="post-thumbnail-wrapper-helper">
																<div class="post-thumbnail <?php if ( $lazyload != '' && $lazyload != '0' ) echo 'lazy'?>" <?php if ( $lazyload != '' && $lazyload != '0' ) { echo 'style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';"'; }?>>
																	<?php $text_color = get_post_meta( get_the_ID(), 'text_color', true ); ?>
																	<?php $background_color = get_post_meta( get_the_ID(), 'background_color', true ); ?>
																	<?php $background_color_rgb = mega_hex2rgb( $background_color ); ?>
																	<?php $opacity = .8; ?>
																	<?php $background_color_rgba = "rgba(" . $background_color_rgb[0] . ", " . $background_color_rgb[1] . ", " . $background_color_rgb[2] . ", " . $opacity . ")"; ?>
																	<?php if ( ! empty( $show_overlay_on_hover ) ) { ?>
																	<div class="overlay" style="<?php if ( $overlay_mix_blend_mode != '' ) { ?>mix-blend-mode: <?php echo esc_attr( $overlay_mix_blend_mode ); ?>;<?php } ?><?php if ( ! empty( $background_color ) || ! empty( $overlay_background_color ) ) { ?>background-color: <?php if ( ! empty( $background_color ) ) { echo esc_attr( $background_color_rgba ); } else { echo esc_attr( $overlay_background_color ); } ?>;<?php } ?>"></div>
																	<?php } ?>
																	<?php if ( $lazyload != '' && $lazyload != '0' ) { ?>
																		<?php echo $thumbnail_lazy; ?>
																		<span class="loaderbg"></span>
																		
																		<?php // Portfolio Gallery ?>
																		<?php if ( ! empty( $gallery_attachments ) ) { ?>
																			<?php foreach ( $gallery_attachments as $gallery_attachment_id ) { ?>
																				<?php if ( $gallery_attachment_id > 0 ) { ?>
																					<?php $gallery_post_thumbnail = wpb_getImageBySize( array( 'attach_id' => $gallery_attachment_id, 'thumb_size' => $img_size, 'class' => 'gallery-attachment' ) ); ?>
																					<?php $gallery_thumbnail = $gallery_post_thumbnail['thumbnail']; ?>
																				
																					<?php $gallery_thumbnail_lazy = preg_replace( '/(<[^>]+) srcset=".*?"/i', '\1', $gallery_thumbnail ); ?>
																					<?php $gallery_thumbnail_lazy = preg_replace( '/(<[^>]+) sizes=".*?"/i', '\1', $gallery_thumbnail_lazy ); ?>
																					<?php $gallery_thumbnail_lazy = str_replace( 'src=', 'data-src=', $gallery_thumbnail_lazy ); ?>
																					<?php $gallery_thumbnail_lazy = str_replace( '/>', 'src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7">', $gallery_thumbnail_lazy ); ?>
																					<?php if ( in_array( $img_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full', ) ) ) { ?>
																						<?php $gallery_image_attributes = wp_get_attachment_image_src( get_post_thumbnail_id( $gallery_attachment_id ), $img_size ); ?>
																						<?php $gallery_width = $image_attributes[1]; ?>
																						<?php $gallery_height = $image_attributes[2]; ?>
																					<?php } else { ?>
																						<?php $gallery_size = str_replace( 'x', ',', $img_size ); ?>
																						<?php $gallery_width = explode( ',', $gallery_size ); ?>
																						<?php $gallery_width = $width[0]; ?>
																						<?php $gallery_height = substr( $gallery_size, strpos( $gallery_size, "," ) + 1 ); ?>
																					<?php } ?>
																					
																					<?php echo $gallery_thumbnail_lazy; ?>
																				<?php } ?>
																			<?php } ?>
																		<?php } ?>

																	<?php } else { ?>
																		<?php echo $thumbnail; ?>
																		<?php // Portfolio Gallery ?>
																		<?php if ( ! empty( $gallery_attachments ) ) { ?>
																			<?php foreach ( $gallery_attachments as $gallery_attachment_id ) { ?>
																				<?php if ( $gallery_attachment_id > 0 ) { ?>
																					<?php $gallery_post_thumbnail = wpb_getImageBySize( array( 'attach_id' => $gallery_attachment_id, 'thumb_size' => $img_size, 'class' => 'gallery-attachment' ) ); ?>
																					<?php $gallery_thumbnail = $gallery_post_thumbnail['thumbnail']; ?>
																					<?php echo $gallery_thumbnail; ?>
																				<?php } ?>
																			<?php } ?>
																		<?php } ?>
																	<?php } ?>
																</div>
															</div>
														</div>
													</div>
												</a>
												<?php } ?>
											<?php } ?>
											
											<?php if ( $i == 0 ) { ?>
											<div class="posts-content-wrapper">
												<div class="posts-content">
											<?php } ?>
										
											<?php if ( $container === 'title' ) { ?>
											<header class="entry-header">
												<h2 style="<?php if ( ! empty( $title_font_size ) ) { ?>font-size: <?php if ( strpos( $title_font_size, 'rem' ) !== false ) { ?>calc(1.44vw + <?php echo esc_attr( $title_font_size ); ?>);<?php } else { echo esc_attr( $title_font_size ); ?>px;<?php } ?> <?php } ?><?php if ( ! empty( $title_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $title_text_transform ); ?>; <?php } ?><?php if ( ! empty( $title_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $title_font_weight ); ?>; <?php } ?><?php if ( ! empty( $title_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $title_letter_spacing ); ?><?php if ( strpos( $title_letter_spacing, 'em' ) == false ) { ?>px<?php } ?>; <?php } ?><?php if ( ! empty( $title_font_style ) ) { ?>font-style: <?php echo esc_attr( $title_font_style ); ?>; <?php } ?><?php if ( $title_font_family == 'primary' ) { ?>font-family: inherit; <?php } ?>">
													<a style="<?php if ( ! empty( $title_color ) ) { ?>color: <?php echo esc_attr( $title_color ); ?>; --title-color: <?php echo esc_attr( $title_color ); ?>; <?php } ?><?php if ( ! empty( $title_color_on_hover ) ) { ?>--title-color-on-hover: <?php echo esc_attr( $title_color_on_hover ); ?>; <?php } ?><?php if ( ! empty( $title_color_on_active ) ) { ?>--title-color-on-active: <?php echo esc_attr( $title_color_on_active ); ?>; <?php } ?>" href="<?php if ( ! empty( $disable_links ) ) { ?>javascript:void(null);<?php } else { if ( ! empty( $custom_url ) ) { echo esc_url( $custom_url ); } else { the_permalink(); } } ?>" <?php if ( ! empty( $custom_url ) && $custom_url_target == 'blank' ) { ?>target="_blank" <?php } ?>>
														<span><?php the_title(); ?></span>
													</a>
												</h2>
											</header><!-- .entry-header -->
											<?php } ?>
										
											<?php if ( $container == 'excerpt' ) { ?>
											<?php if ( has_excerpt() ) { ?>
											<div class="entry-excerpt" style="<?php if ( ! empty( $excerpt_color ) ) { ?>color: <?php echo esc_attr( $excerpt_color ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_size ) ) { ?>font-size: <?php echo esc_attr( $meta_data_font_size ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $meta_data_text_transform ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $meta_data_font_weight ); ?>; <?php } ?><?php if ( ! empty( $meta_data_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $meta_data_letter_spacing ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_font_style ) ) { ?>font-style: <?php echo esc_attr( $meta_data_font_style ); ?>; <?php } ?>">
											<?php if ( $columns == 1 ) { ?>
												<?php get_template_part( 'content', get_post_format() ); ?>
											<?php } else { ?>
												<?php the_excerpt(); ?>
											<?php } ?>
											</div>
											<?php } ?>
											<?php } ?>
										
											<?php if ( $container == 'categories' ) { ?>
											<div class="entry-meta" style="<?php if ( ! empty( $meta_data_color ) ) { ?>color: <?php echo esc_attr( $meta_data_color ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_size ) ) { ?>font-size: <?php echo esc_attr( $meta_data_font_size ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $meta_data_text_transform ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $meta_data_font_weight ); ?>; <?php } ?><?php if ( ! empty( $meta_data_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $meta_data_letter_spacing ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_font_style ) ) { ?>font-style: <?php echo esc_attr( $meta_data_font_style ); ?>; <?php } ?>">
												<span class="entry-category"><?php echo esc_html( mega_custom_taxonomies_terms_links() ); ?></span>
											</div>
											<?php } ?>
										
											<?php if ( $container == 'date' ) { ?>
											<div class="entry-meta" style="<?php if ( ! empty( $meta_data_color ) ) { ?>color: <?php echo esc_attr( $meta_data_color ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_size ) ) { ?>font-size: <?php echo esc_attr( $meta_data_font_size ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $meta_data_text_transform ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $meta_data_font_weight ); ?>; <?php } ?><?php if ( ! empty( $meta_data_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $meta_data_letter_spacing ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_font_style ) ) { ?>font-style: <?php echo esc_attr( $meta_data_font_style ); ?>; <?php } ?>">
												<span class="entry-date"><?php echo esc_html( get_the_date() ); ?></span>
											</div>
											<?php } ?>
										
											<?php if ( $container == 'link' ) { ?>
											<?php $url = esc_url( get_permalink() ); ?>
											<?php $link = '<a class="more-link" href="'. esc_url( $url ) .'"><span>'. esc_html__( "Read more", 'mega') .'</span></a>'; ?>
											<div class="more-link-wrapper"><?php echo $link; ?></div>
											<?php } ?>
											
											<?php if ( $i == $len - 1 ) { ?>
												</div>
											</div>
											<?php } ?>
									
										<?php $i++; ?>
									<?php } ?>
								</div><!-- .content-wrapper -->
							</div><!-- .content-wrapper-helper -->
						</article>

					<?php // Title hidden 2 ?>
					<?php } else if ( $template == 'title_hidden2' ) { ?>
					
						<?php // Portfolio Gallery ?>
						<?php $gallery_attachments = get_post_meta( get_the_ID(), 'portfolio_image_gallery', true ); ?>
						<?php if ( ! empty( $gallery_attachments ) ) { ?>
							<?php $gallery_class = 'gallery-enabled'; ?>
						<?php } else { ?>
							<?php $gallery_class = 'gallery-disabled'; ?>
						<?php } ?>
						<?php $gallery_attachments = explode( ',', $gallery_attachments ); ?>
					
						<?php
						$classes = array(
							'clearfix',
							'isotope-item',
							$gallery_class
						);
						?>
					
						<article id="post-<?php the_ID(); ?>" <?php post_class( $classes ); ?> <?php if ( $layout == 'justified' ) { ?>style="--w: <?php echo esc_attr( $width ) ?>; --row-width: <?php echo esc_attr( $row_width ) ?>vw; --h: <?php echo esc_attr( $height ) ?>;"<?php } ?>>
							<div class="content-wrapper-helper">
								<div class="content-wrapper">
										
										<?php if ( $thumbnail ) { ?>
											<div class="post-thumbnail-wrapper-1">
												<div class="post-thumbnail-wrapper-2">
													<div class="post-thumbnail-wrapper-helper">
														<div class="post-thumbnail <?php if ( $lazyload != '' && $lazyload != '0' ) echo 'lazy'?>" <?php if ( $lazyload != '' && $lazyload != '0' ) { echo 'style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';"'; }?>>
															<?php $text_color = get_post_meta( get_the_ID(), 'text_color', true ); ?>
															<?php $background_color = get_post_meta( get_the_ID(), 'background_color', true ); ?>
															<?php $background_color_rgb = mega_hex2rgb( $background_color ); ?>
															<?php $opacity = .8; ?>
															<?php $background_color_rgba = "rgba(" . $background_color_rgb[0] . ", " . $background_color_rgb[1] . ", " . $background_color_rgb[2] . ", " . $opacity . ")"; ?>
															
															<div class="posts-content-wrapper">
															
																<div class="posts-content">
																	
																	<?php $containers = vc_sorted_list_parse_value( $meta_data ); ?>
																	<?php foreach ( $containers as $key => $container_data ) { ?>
																	
																		<?php $container = $container_data[0]; ?>
																		
																		<?php // Meta data animation ?>
																		<?php $delay = ( $key - 1 ) * .05; ?>
																		
																		<?php if ( $container === 'title' ) { ?>
																		<header class="entry-header <?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>animated-item<?php } ?>" <?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>style="--delay: <?php echo esc_attr( $delay ); ?>s;"<?php } ?>>
																			<h2 style="<?php if ( ! empty( $text_color ) ) { ?>color: <?php echo esc_attr( $text_color ); ?>; --title-color: <?php echo esc_attr( $text_color ); ?>; <?php } else if ( ! empty( $title_color ) ) { ?>color: <?php echo esc_attr( $title_color ); ?>; --title-color: <?php echo esc_attr( $title_color ); ?>; <?php } ?><?php if ( ! empty( $title_color_on_hover ) ) { ?>--title-color-on-hover: <?php echo esc_attr( $title_color_on_hover ); ?>; <?php } ?><?php if ( ! empty( $title_color_on_active ) ) { ?>--title-color-on-active: <?php echo esc_attr( $title_color_on_active ); ?>; <?php } ?><?php if ( ! empty( $title_font_size ) ) { ?>font-size: <?php if ( strpos( $title_font_size, 'rem' ) !== false ) { ?>calc(1.44vw + <?php echo esc_attr( $title_font_size ); ?>);<?php } else { echo esc_attr( $title_font_size ); ?>px;<?php } ?> <?php } ?><?php if ( ! empty( $title_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $title_text_transform ); ?>; <?php } ?><?php if ( ! empty( $title_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $title_font_weight ); ?>; <?php } ?><?php if ( ! empty( $title_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $title_letter_spacing ); ?><?php if ( strpos( $title_letter_spacing, 'em' ) == false ) { ?>px<?php } ?>; <?php } ?><?php if ( ! empty( $title_font_style ) ) { ?>font-style: <?php echo esc_attr( $title_font_style ); ?>; <?php } ?><?php if ( $title_font_family == 'primary' ) { ?>font-family: inherit; <?php } ?>"><span><?php the_title(); ?></span></h2>
																		</header><!-- .entry-header -->
																		<?php } ?>
																		
																		<?php if ( $container == 'excerpt' ) { ?>
																		<?php if ( has_excerpt() ) { ?>
																		<div class="entry-excerpt <?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>animated-item<?php } ?>" style="<?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>--delay: <?php echo esc_attr( $delay ); ?>s;<?php } ?> <?php if ( ! empty( $excerpt_color ) ) { ?>color: <?php echo esc_attr( $excerpt_color ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_size ) ) { ?>font-size: <?php echo esc_attr( $meta_data_font_size ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $meta_data_text_transform ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $meta_data_font_weight ); ?>; <?php } ?><?php if ( ! empty( $meta_data_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $meta_data_letter_spacing ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_font_style ) ) { ?>font-style: <?php echo esc_attr( $meta_data_font_style ); ?>; <?php } ?>">
																			<?php the_excerpt(); ?>
																		</div>
																		<?php } ?>
																		<?php } ?>
																		
																		<?php if ( $container == 'categories' ) { ?>
																		<div class="entry-meta <?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>animated-item<?php } ?>" style="<?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>--delay: <?php echo esc_attr( $delay ); ?>s;<?php } ?> <?php if ( ! empty( $meta_data_color ) ) { ?>color: <?php echo esc_attr( $meta_data_color ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_size ) ) { ?>font-size: <?php echo esc_attr( $meta_data_font_size ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $meta_data_text_transform ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $meta_data_font_weight ); ?>; <?php } ?><?php if ( ! empty( $meta_data_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $meta_data_letter_spacing ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_font_style ) ) { ?>font-style: <?php echo esc_attr( $meta_data_font_style ); ?>; <?php } ?>">
																			<span class="entry-category"><?php echo esc_html( mega_custom_taxonomies_terms_links() ); ?></span>
																		</div>
																		<?php } ?>
																		
																		<?php if ( $container == 'date' ) { ?>
																		<div class="entry-meta <?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>animated-item<?php } ?>" style="<?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>--delay: <?php echo esc_attr( $delay ); ?>s;<?php } ?> <?php if ( ! empty( $meta_data_color ) ) { ?>color: <?php echo esc_attr( $meta_data_color ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_size ) ) { ?>font-size: <?php echo esc_attr( $meta_data_font_size ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $meta_data_text_transform ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $meta_data_font_weight ); ?>; <?php } ?><?php if ( ! empty( $meta_data_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $meta_data_letter_spacing ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_font_style ) ) { ?>font-style: <?php echo esc_attr( $meta_data_font_style ); ?>; <?php } ?>">
																			<span class="entry-date"><?php echo esc_html( get_the_date() ); ?></span>
																		</div>
																		<?php } ?>
																		
																		<?php if ( $container == 'link' ) { ?>
																		<?php if ( ! empty( $custom_url ) ) { ?>
																			<?php $url = esc_url( $custom_url ); ?>
																		<?php } else { ?>
																			<?php $url = esc_url( get_permalink() ); ?>
																		<?php } ?>
																		<?php $link = '<div class="vc_btn3-container no-margin vc_btn3-inline"><a class="vc_general vc_btn3 vc_btn3-size-lg vc_btn3-shape-square vc_btn3-style-modern vc_btn3-color-white" href="'. $url .'" target="_blank"><span>' . esc_html( $link_text ) . '</span></a></div>'; ?>
																		<div class="entry-meta more-link-wrapper <?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>animated-item<?php } ?>" style="<?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>--delay: <?php echo esc_attr( $delay ); ?>s;<?php } ?>"><?php echo $link; ?></div>
																		<?php } ?>
																		
																	<?php } ?>
																
																</div>
															</div>
															
															<?php if ( ! empty( $show_overlay_on_hover ) ) { ?>
															<div class="overlay" style="<?php if ( $overlay_mix_blend_mode != '' ) { ?>mix-blend-mode: <?php echo esc_attr( $overlay_mix_blend_mode ); ?>;<?php } ?><?php if ( ! empty( $background_color ) || ! empty( $overlay_background_color ) ) { ?>background-color: <?php if ( ! empty( $background_color ) ) { echo esc_attr( $background_color_rgba ); } else { echo esc_attr( $overlay_background_color ); } ?>;<?php } ?>"></div>
															<?php } ?>
															
															<?php if ( $lazyload != '' && $lazyload != '0' ) { ?>
																<?php echo $thumbnail_lazy; ?>
																<span class="loaderbg"></span>
																
																<?php // Portfolio Gallery ?>
																<?php if ( ! empty( $gallery_attachments ) ) { ?>
																	<?php foreach ( $gallery_attachments as $gallery_attachment_id ) { ?>
																		<?php if ( $gallery_attachment_id > 0 ) { ?>
																			<?php $gallery_post_thumbnail = wpb_getImageBySize( array( 'attach_id' => $gallery_attachment_id, 'thumb_size' => $img_size, 'class' => 'gallery-attachment' ) ); ?>
																			<?php $gallery_thumbnail = $gallery_post_thumbnail['thumbnail']; ?>
																		
																			<?php $gallery_thumbnail_lazy = preg_replace( '/(<[^>]+) srcset=".*?"/i', '\1', $gallery_thumbnail ); ?>
																			<?php $gallery_thumbnail_lazy = preg_replace( '/(<[^>]+) sizes=".*?"/i', '\1', $gallery_thumbnail_lazy ); ?>
																			<?php $gallery_thumbnail_lazy = str_replace( 'src=', 'data-src=', $gallery_thumbnail_lazy ); ?>
																			<?php $gallery_thumbnail_lazy = str_replace( '/>', 'src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7">', $gallery_thumbnail_lazy ); ?>
																			<?php if ( in_array( $img_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full', ) ) ) { ?>
																				<?php $gallery_image_attributes = wp_get_attachment_image_src( get_post_thumbnail_id( $gallery_attachment_id ), $img_size ); ?>
																				<?php $gallery_width = $image_attributes[1]; ?>
																				<?php $gallery_height = $image_attributes[2]; ?>
																			<?php } else { ?>
																				<?php $gallery_size = str_replace( 'x', ',', $img_size ); ?>
																				<?php $gallery_width = explode( ',', $gallery_size ); ?>
																				<?php $gallery_width = $width[0]; ?>
																				<?php $gallery_height = substr( $gallery_size, strpos( $gallery_size, "," ) + 1 ); ?>
																			<?php } ?>
																			
																			<?php echo $gallery_thumbnail_lazy; ?>
																		<?php } ?>
																	<?php } ?>
																<?php } ?>
																
															<?php } else { ?>
																<?php echo $thumbnail; ?>
																<?php // Portfolio Gallery ?>
																<?php if ( ! empty( $gallery_attachments ) ) { ?>
																	<?php foreach ( $gallery_attachments as $gallery_attachment_id ) { ?>
																		<?php if ( $gallery_attachment_id > 0 ) { ?>
																			<?php $gallery_post_thumbnail = wpb_getImageBySize( array( 'attach_id' => $gallery_attachment_id, 'thumb_size' => $img_size, 'class' => 'gallery-attachment' ) ); ?>
																			<?php $gallery_thumbnail = $gallery_post_thumbnail['thumbnail']; ?>
																			<?php echo $gallery_thumbnail; ?>
																		<?php } ?>
																	<?php } ?>
																<?php } ?>
															<?php } ?>
														</div>
													</div>
												</div>
											</div>
										<?php } ?>
									
								</div><!-- .content-wrapper -->
							</div><!-- .content-wrapper-helper -->
						</article>
					
					<?php // Title hidden ?>
					<?php } else { ?>
						
						<?php // Portfolio Gallery ?>
						<?php $gallery_attachments = get_post_meta( get_the_ID(), 'portfolio_image_gallery', true ); ?>
						<?php if ( ! empty( $gallery_attachments ) ) { ?>
							<?php $gallery_class = 'gallery-enabled'; ?>
						<?php } else { ?>
							<?php $gallery_class = 'gallery-disabled'; ?>
						<?php } ?>
						<?php $gallery_attachments = explode( ',', $gallery_attachments ); ?>
					
						<?php
						$classes = array(
							'clearfix',
							'isotope-item',
							$gallery_class
						);
						?>
					
						<article id="post-<?php the_ID(); ?>" <?php post_class( $classes ); ?> <?php if ( $layout == 'justified' ) { ?>style="--w: <?php echo esc_attr( $width ) ?>; --row-width: <?php echo esc_attr( $row_width ) ?>vw; --h: <?php echo esc_attr( $height ) ?>;"<?php } ?>>
							<div class="content-wrapper-helper">
								<a class="content-wrapper" href="<?php if ( ! empty( $disable_links ) ) { ?>javascript:void(null);<?php } else { if ( ! empty( $custom_url ) ) { echo esc_url( $custom_url ); } else { the_permalink(); } } ?>" <?php if ( ! empty( $custom_url ) && $custom_url_target == 'blank' ) { ?>target="_blank" <?php } ?>>
										
										<?php if ( $thumbnail ) { ?>
											<div class="post-thumbnail-wrapper-1">
												<div class="post-thumbnail-wrapper-2">
													<div class="post-thumbnail-wrapper-helper">
														<div class="post-thumbnail <?php if ( $lazyload != '' && $lazyload != '0' ) echo 'lazy'?>" <?php if ( $lazyload != '' && $lazyload != '0' ) { echo 'style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';"'; }?>>
															<?php $text_color = get_post_meta( get_the_ID(), 'text_color', true ); ?>
															<?php $background_color = get_post_meta( get_the_ID(), 'background_color', true ); ?>
															<?php $background_color_rgb = mega_hex2rgb( $background_color ); ?>
															<?php $opacity = .8; ?>
															<?php $background_color_rgba = "rgba(" . $background_color_rgb[0] . ", " . $background_color_rgb[1] . ", " . $background_color_rgb[2] . ", " . $opacity . ")"; ?>
															
															<div class="posts-content-wrapper">
															
																<div class="posts-content">
																	
																	<?php $containers = vc_sorted_list_parse_value( $meta_data ); ?>
																	<?php foreach ( $containers as $key => $container_data ) { ?>
																	
																		<?php $container = $container_data[0]; ?>
																		
																		<?php // Meta data animation ?>
																		<?php $delay = ( $key - 1 ) * .05; ?>
																		
																		<?php if ( $container === 'title' ) { ?>
																		<header class="entry-header <?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>animated-item<?php } ?>" <?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>style="--delay: <?php echo esc_attr( $delay ); ?>s;"<?php } ?>>
																			<h2 style="<?php if ( ! empty( $text_color ) ) { ?>color: <?php echo esc_attr( $text_color ); ?>; --title-color: <?php echo esc_attr( $text_color ); ?>; <?php } else if ( ! empty( $title_color ) ) { ?>color: <?php echo esc_attr( $title_color ); ?>; --title-color: <?php echo esc_attr( $title_color ); ?>; <?php } ?><?php if ( ! empty( $title_color_on_hover ) ) { ?>--title-color-on-hover: <?php echo esc_attr( $title_color_on_hover ); ?>; <?php } ?><?php if ( ! empty( $title_color_on_active ) ) { ?>--title-color-on-active: <?php echo esc_attr( $title_color_on_active ); ?>; <?php } ?><?php if ( ! empty( $title_font_size ) ) { ?>font-size: <?php if ( strpos( $title_font_size, 'rem' ) !== false ) { ?>calc(1.44vw + <?php echo esc_attr( $title_font_size ); ?>);<?php } else { echo esc_attr( $title_font_size ); ?>px;<?php } ?> <?php } ?><?php if ( ! empty( $title_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $title_text_transform ); ?>; <?php } ?><?php if ( ! empty( $title_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $title_font_weight ); ?>; <?php } ?><?php if ( ! empty( $title_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $title_letter_spacing ); ?><?php if ( strpos( $title_letter_spacing, 'em' ) == false ) { ?>px<?php } ?>; <?php } ?><?php if ( ! empty( $title_font_style ) ) { ?>font-style: <?php echo esc_attr( $title_font_style ); ?>; <?php } ?><?php if ( $title_font_family == 'primary' ) { ?>font-family: inherit; <?php } ?>"><span><?php the_title(); ?></span></h2>
																		</header><!-- .entry-header -->
																		<?php } ?>
																		
																		<?php if ( $container == 'excerpt' ) { ?>
																		<?php if ( has_excerpt() ) { ?>
																		<div class="entry-excerpt <?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>animated-item<?php } ?>" style="<?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>--delay: <?php echo esc_attr( $delay ); ?>s;<?php } ?> <?php if ( ! empty( $excerpt_color ) ) { ?>color: <?php echo esc_attr( $excerpt_color ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_size ) ) { ?>font-size: <?php echo esc_attr( $meta_data_font_size ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $meta_data_text_transform ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $meta_data_font_weight ); ?>; <?php } ?><?php if ( ! empty( $meta_data_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $meta_data_letter_spacing ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_font_style ) ) { ?>font-style: <?php echo esc_attr( $meta_data_font_style ); ?>; <?php } ?>">
																			<?php the_excerpt(); ?>
																		</div>
																		<?php } ?>
																		<?php } ?>
																		
																		<?php if ( $container == 'categories' ) { ?>
																		<div class="entry-meta <?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>animated-item<?php } ?>" style="<?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>--delay: <?php echo esc_attr( $delay ); ?>s;<?php } ?> <?php if ( ! empty( $meta_data_color ) ) { ?>color: <?php echo esc_attr( $meta_data_color ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_size ) ) { ?>font-size: <?php echo esc_attr( $meta_data_font_size ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $meta_data_text_transform ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $meta_data_font_weight ); ?>; <?php } ?><?php if ( ! empty( $meta_data_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $meta_data_letter_spacing ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_font_style ) ) { ?>font-style: <?php echo esc_attr( $meta_data_font_style ); ?>; <?php } ?>">
																			<span class="entry-category"><?php echo esc_html( mega_custom_taxonomies_terms_links() ); ?></span>
																		</div>
																		<?php } ?>
																		
																		<?php if ( $container == 'date' ) { ?>
																		<div class="entry-meta <?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>animated-item<?php } ?>" style="<?php if ( $meta_data_animation != '' && $meta_data_animation != '0' ) { ?>--delay: <?php echo esc_attr( $delay ); ?>s;<?php } ?> <?php if ( ! empty( $meta_data_color ) ) { ?>color: <?php echo esc_attr( $meta_data_color ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_size ) ) { ?>font-size: <?php echo esc_attr( $meta_data_font_size ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_text_transform ) ) { ?>text-transform: <?php echo esc_attr( $meta_data_text_transform ); ?>; <?php } ?><?php if ( ! empty( $meta_data_font_weight ) ) { ?>font-weight: <?php echo esc_attr( $meta_data_font_weight ); ?>; <?php } ?><?php if ( ! empty( $meta_data_letter_spacing ) ) { ?>letter-spacing: <?php echo esc_attr( $meta_data_letter_spacing ); ?>px; <?php } ?><?php if ( ! empty( $meta_data_font_style ) ) { ?>font-style: <?php echo esc_attr( $meta_data_font_style ); ?>; <?php } ?>">
																			<span class="entry-date"><?php echo esc_html( get_the_date() ); ?></span>
																		</div>
																		<?php } ?>
																		
																	<?php } ?>
																
																</div>
															</div>
															
															<?php if ( ! empty( $show_overlay_on_hover ) ) { ?>
															<div class="overlay" style="<?php if ( $overlay_mix_blend_mode != '' ) { ?>mix-blend-mode: <?php echo esc_attr( $overlay_mix_blend_mode ); ?>;<?php } ?><?php if ( ! empty( $background_color ) || ! empty( $overlay_background_color ) ) { ?>background-color: <?php if ( ! empty( $background_color ) ) { echo esc_attr( $background_color_rgba ); } else { echo esc_attr( $overlay_background_color ); } ?>;<?php } ?>"></div>
															<?php } ?>
															
															<?php if ( $lazyload != '' && $lazyload != '0' ) { ?>
																<?php echo $thumbnail_lazy; ?>
																<span class="loaderbg"></span>
																
																<?php // Portfolio Gallery ?>
																<?php if ( ! empty( $gallery_attachments ) ) { ?>
																	<?php foreach ( $gallery_attachments as $gallery_attachment_id ) { ?>
																		<?php if ( $gallery_attachment_id > 0 ) { ?>
																			<?php $gallery_post_thumbnail = wpb_getImageBySize( array( 'attach_id' => $gallery_attachment_id, 'thumb_size' => $img_size, 'class' => 'gallery-attachment' ) ); ?>
																			<?php $gallery_thumbnail = $gallery_post_thumbnail['thumbnail']; ?>
																		
																			<?php $gallery_thumbnail_lazy = preg_replace( '/(<[^>]+) srcset=".*?"/i', '\1', $gallery_thumbnail ); ?>
																			<?php $gallery_thumbnail_lazy = preg_replace( '/(<[^>]+) sizes=".*?"/i', '\1', $gallery_thumbnail_lazy ); ?>
																			<?php $gallery_thumbnail_lazy = str_replace( 'src=', 'data-src=', $gallery_thumbnail_lazy ); ?>
																			<?php $gallery_thumbnail_lazy = str_replace( '/>', 'src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7">', $gallery_thumbnail_lazy ); ?>
																			<?php if ( in_array( $img_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full', ) ) ) { ?>
																				<?php $gallery_image_attributes = wp_get_attachment_image_src( get_post_thumbnail_id( $gallery_attachment_id ), $img_size ); ?>
																				<?php $gallery_width = $image_attributes[1]; ?>
																				<?php $gallery_height = $image_attributes[2]; ?>
																			<?php } else { ?>
																				<?php $gallery_size = str_replace( 'x', ',', $img_size ); ?>
																				<?php $gallery_width = explode( ',', $gallery_size ); ?>
																				<?php $gallery_width = $width[0]; ?>
																				<?php $gallery_height = substr( $gallery_size, strpos( $gallery_size, "," ) + 1 ); ?>
																			<?php } ?>
																			
																			<?php echo $gallery_thumbnail_lazy; ?>
																		<?php } ?>
																	<?php } ?>
																<?php } ?>

															<?php } else { ?>
																<?php echo $thumbnail; ?>
																<?php // Portfolio Gallery ?>
																<?php if ( ! empty( $gallery_attachments ) ) { ?>
																	<?php foreach ( $gallery_attachments as $gallery_attachment_id ) { ?>
																		<?php if ( $gallery_attachment_id > 0 ) { ?>
																			<?php $gallery_post_thumbnail = wpb_getImageBySize( array( 'attach_id' => $gallery_attachment_id, 'thumb_size' => $img_size, 'class' => 'gallery-attachment' ) ); ?>
																			<?php $gallery_thumbnail = $gallery_post_thumbnail['thumbnail']; ?>
																			<?php echo $gallery_thumbnail; ?>
																		<?php } ?>
																	<?php } ?>
																<?php } ?>
															<?php } ?>
														</div>
													</div>
												</div>
											</div>
										<?php } ?>
									
								</a><!-- .content-wrapper -->
							</div><!-- .content-wrapper-helper -->
						</article>
							
					<?php } ?>
				<?php endwhile; ?>
				
			<?php endif; ?>
		
		</div><!-- .mt-posts-container -->
		
		<?php if ( $pagination == 'infinite_scroll' || $pagination == 'infinite_scroll_with_button' ) { ?>
			<?php if ( $wp_query->max_num_pages > 1 ) { ?>
				<div class="load-more-wrapper">
					<span class="loader-wrapper">
						<svg class="circular" viewBox="25 25 50 50"><circle class="path" cx="50" cy="50" r="20" fill="none" stroke-width="6" stroke-miterlimit="10"></circle></svg>
					</span>
					<?php if ( $pagination == 'infinite_scroll_with_button' ) { ?>
					<button class="vc_general vc_btn3 load-more"><?php esc_html_e( 'Load more', 'mega' ); ?></button>
					<?php } ?>
				</div>
			<?php } ?>
		<?php } ?>
		
		<?php if ( $pagination == 'default' || $pagination == 'infinite_scroll' || $pagination == 'infinite_scroll_with_button' ) { ?>
			<?php mega_pagination_content_nav( 'nav-pagination' ); ?>
		<?php } ?>
		
		<?php wp_reset_postdata(); ?>
	
	</div><!-- .mt-posts-container-wrapper -->
	
    <?php $wp_query = null; $wp_query = $temp;
    $content = ob_get_contents();
    ob_end_clean();
    return $content;
}
add_shortcode( 'mt_vc_posts', 'mt_vc_posts' );

vc_map( array(
   'name' => esc_html__( 'Posts MT', 'mega' ),
   'base' => 'mt_vc_posts',
   'description' => esc_html__( 'Portfolio and default post types', 'mega' ),
   'class' => 'mt-vc-posts',
   'icon' => 'icon-wpb-application-icon-large',
   'category' => esc_html__( 'Content', 'mega' ),
   'weight' => 0,
   'params' => array(
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Data source', 'mega' ),
		  'param_name' => 'data_source',
		  'value' => array( esc_html__( 'Portfolio', 'mega' ) => 'portfolio', esc_html__( 'Post', 'mega' ) => 'post' ),
		  'admin_label' => true,
		  'description' => esc_html__( 'Select content type.', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Items count', 'mega' ),
		  'param_name' => 'number',
		  'value' => 15,
		  'description' => esc_html__( 'Set max limit for items or enter -1 to display all (limited to 1000).', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Layout type', 'mega' ),
		  'param_name' => 'layout',
		  'value' => array( esc_html__( 'Masonry', 'mega' ) => 'masonry', esc_html__( 'Justified', 'mega' ) => 'justified', esc_html__( 'cellsByRow', 'mega' ) => 'cellsbyrow' , esc_html__( 'fitRows', 'mega' ) => 'fitrows' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Row width', 'mega' ),
		  'param_name' => 'row_width',
		  'value' => '',
		  'description' => esc_html__( 'Enter row width in viewport width: 20', 'mega' ),
		  'dependency' => array(
			'element' => 'layout',
			'value' => array( 'justified' ),
		  ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Columns count', 'mega' ),
		  'param_name' => 'columns',
		  'value' => array( 1, 2, 3, 4 ),
		  'std' => 3,
		  'edit_field_class' => 'vc_col-sm-6',
		  'dependency' => array(
			'element' => 'layout',
			'value' => array( 'masonry', 'cellsbyrow', 'fitrows' ),
		  ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Margin between items', 'mega' ),
		  'param_name' => 'margin',
		  'value' => array( '0px', '1px', '5px', '10px', '20px', '30px' ),
		  'std' => '30px',
		  'edit_field_class' => 'vc_col-sm-6',
		  'dependency' => array(
			'element' => 'layout',
			'value' => array( 'masonry', 'justified', 'fitrows' ),
		  ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Image size', 'mega' ),
		  'param_name' => 'img_size',
		  'value' => '',
		  'description' => esc_html__( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "large" size.', 'mega' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Lazy-loading', 'mega' ),
		  'param_name' => 'lazyload',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Pagination', 'mega' ),
		  'param_name' => 'pagination',
		  'value' => array( esc_html__( 'None', 'mega' ) => 'none', esc_html__( 'Default', 'mega' ) => 'default', esc_html__( 'Infinite scroll', 'mega' ) => 'infinite_scroll', esc_html__( 'Infinite scroll with button', 'mega' ) => 'infinite_scroll_with_button' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'First page items count', 'mega' ),
		  'param_name' => 'first_page_number',
		  'value' => '',
		  'description' => esc_html__( 'Enter items count for the first page or leave it empty to use value from items count textfield.', 'mega' ),
		  'dependency' => array(
			'element' => 'pagination',
			'value_not_equal_to' => 'none',
		  ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Animation', 'mega' ),
		  'param_name' => 'animation',
		  'value' => array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Animation type', 'mega' ),
		  'param_name' => 'animation_type',
		  'value' => array( esc_html__( 'FadeInUp', 'mega' ) => 'fadeinup', esc_html__( 'FadeIn', 'mega' ) => 'fadein' ),
		  'description' => esc_html__( 'Select type of animation for element to be animated when it "enters" the browsers viewport.', 'mega' ),
		  'dependency' => array(
		      'element' => 'animation',
		      'not_empty' => true,
		  ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Delayed animation', 'mega' ),
		  'param_name' => 'delayed_animation',
		  'description' => esc_html__( 'Select animation if you want items to be animated when they enter into the browsers viewport.', 'mega' ),
		  'value' => array( esc_html__( 'Yes', 'mega' ) => true ),
		  'dependency' => array(
		      'element' => 'animation',
		      'not_empty' => true,
		  ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Show filter', 'mega' ),
		  'param_name' => 'filter',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Center filter', 'mega' ),
		  'param_name' => 'filter_align',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		  'dependency' => array(
		      'element' => 'filter',
		      'not_empty' => true,
		  ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Custom URL target', 'mega' ),
		  'param_name' => 'custom_url_target',
		  'value' => array( esc_html__( 'Self', 'mega' ) => 'self', esc_html__( 'Blank', 'mega' ) => 'blank' ),
		  'description' => esc_html__( 'Specify where to open the linked document (blank opens the linked document in a new window or tab and self opens the linked document in the same frame as it was clicked (this is default)).', 'mega' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Disable links', 'mega' ),
		  'param_name' => 'disable_links',
		  'value' => array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
			'type' => 'el_id',
			'heading' => esc_html__( 'Element ID', 'mega' ),
			'param_name' => 'el_id',
			'description' => sprintf( esc_html__( 'Enter element ID (Note: make sure it is unique and valid according to %sw3c specification%s).', 'mega' ), '<a href="https://www.w3schools.com/tags/att_global_id.asp" target="_blank">', '</a>' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Extra class name', 'mega' ),
		  'param_name' => 'css_class',
		  'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'mega' ),
		),
		// Data Settings
		array(
		  'type' => 'sorted_list',
		  'heading' => esc_html__( 'Meta data', 'mega' ),
		  'param_name' => 'meta_data',
		  'value' => 'image,title',
		  'options' => array(
			array( 'image', esc_html__( 'Thumbnail', 'mega' ) ),
			array( 'title', esc_html__( 'Title', 'mega' ) ),
			array( 'excerpt', esc_html__( 'Excerpt', 'mega' ) ),
			array( 'categories', esc_html__( 'Categories', 'mega' ) ),
			array( 'date', esc_html__( 'Date', 'mega' ) ),
			array( 'link', esc_html__( 'Read more link', 'mega' ) ),
		  ),
		  'description' => esc_html__( 'Control items look. Enable blocks and place them in desired order. Note: This setting can be overrriden on post to post basis.', 'mega' ),
		  'group' => esc_html__( 'Data Settings', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Read more link text', 'mega' ),
		  'param_name' => 'link_text',
		  'value' => 'Read more',
		  'group' => esc_html__( 'Data Settings', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Order by', 'mega' ),
		  'param_name' => 'orderby',
		  'value' => array( esc_html__( 'Date', 'mega' ) => 'date', esc_html__( 'Title', 'mega' ) => 'title', esc_html__( 'Random', 'mega' ) => 'rand' ),
		  'group' => esc_html__( 'Data Settings', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Order way', 'mega' ),
		  'param_name' => 'order',
		  'value' => array( esc_html__( 'Descending', 'mega' ) => 'DESC', esc_html__( 'Ascending', 'mega' ) => 'ASC' ),
		  'group' => esc_html__( 'Data Settings', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Categories', 'mega' ),
		  'param_name' => 'category',
		  'description' => esc_html__( 'If you want to narrow output, enter category slugs here. Note: Only listed categories will be included. Divide categories with commas.', 'mega' ),
		  'group' => esc_html__( 'Data Settings', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Exclude categories IDs', 'mega' ),
		  'param_name' => 'category_not_in',
		  'description' => esc_html__( 'Fill this field with categories IDs separated by commas (,) to exclude them from query.', 'mega' ),
		  'group' => esc_html__( 'Data Settings', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Items IDs', 'mega' ),
		  'param_name' => 'post_in',
		  'description' => esc_html__( 'Fill this field with items IDs separated by commas (,) to retrieve only them.', 'mega' ),
		  'group' => esc_html__( 'Data Settings', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Exclude items IDs', 'mega' ),
		  'param_name' => 'post_not_in',
		  'description' => esc_html__( 'Fill this field with items IDs separated by commas (,) to exclude them from query.', 'mega' ),
		  'group' => esc_html__( 'Data Settings', 'mega' ),
		),
		// Item Design
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Template', 'mega' ),
		  'param_name' => 'template',
		  'value' => array( esc_html__( 'Title visible', 'mega' ) => 'title_visible', esc_html__( 'Title visible 2', 'mega' ) => 'title_visible2', esc_html__( 'Title hidden', 'mega' ) => 'title_hidden', esc_html__( 'Title hidden 2', 'mega' ) => 'title_hidden2' ),
		  'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Title underline on hover', 'mega' ),
		  'param_name' => 'title_underline_on_hover',
		  'description' => '',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		  'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Show overlay on hover', 'mega' ),
			'param_name' => 'show_overlay_on_hover',
			'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Overlay mix blend mode', 'mega' ),
		  'param_name' => 'overlay_mix_blend_mode',
		  'value' => array(
			esc_html__( 'None', 'mega' ) => 'none',
			esc_html__( 'Multiply', 'mega' ) => 'multiply',
			esc_html__( 'Screen', 'mega' ) => 'screen',
			esc_html__( 'Overlay', 'mega' ) => 'overlay',
			esc_html__( 'Darken', 'mega' ) => 'darken',
			esc_html__( 'Lighten', 'mega' ) => 'lighten',
			esc_html__( 'Color dodge', 'mega' ) => 'color-dodge',
			esc_html__( 'Color burn', 'mega' ) => 'color-burn',
			esc_html__( 'Difference', 'mega' ) => 'difference',
			esc_html__( 'Exclusion', 'mega' ) => 'exclusion',
			esc_html__( 'Hue', 'mega' ) => 'hue',
			esc_html__( 'Saturation', 'mega' ) => 'saturation',
			esc_html__( 'Color', 'mega' ) => 'color',
			esc_html__( 'Luminosity', 'mega' ) => 'luminosity',
		  ),
		  'dependency' => array(
		      'element' => 'show_overlay_on_hover',
		      'not_empty' => true,
			),
		  'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Meta data mix blend mode difference', 'mega' ),
			'param_name' => 'meta_data_mix_blend_mode_difference',
			'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Overlay background color', 'mega' ),
			'param_name' => 'overlay_background_color',
			'value' => 'rgba(0,0,0,0.8)',
			'group' => esc_html__( 'Item Design', 'mega' ),
			'dependency' => array(
		      'element' => 'show_overlay_on_hover',
		      'not_empty' => true,
			),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Overlay background color palette from an image', 'mega' ),
		  'param_name' => 'overlay_background_color_palette',
		  'group' => esc_html__( 'Item Design', 'mega' ),
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		  'dependency' => array(
		      'element' => 'show_overlay_on_hover',
		      'not_empty' => true,
		  ),
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Title color', 'mega' ),
			'param_name' => 'title_color',
			'value' => '',
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Title color on hover', 'mega' ),
			'param_name' => 'title_color_on_hover',
			'value' => '',
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Title color on active', 'mega' ),
			'param_name' => 'title_color_on_active',
			'value' => '',
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Meta data color', 'mega' ),
			'param_name' => 'meta_data_color',
			'value' => '',
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Excerpt color', 'mega' ),
			'param_name' => 'excerpt_color',
			'value' => '',
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Meta data align', 'mega' ),
		  'param_name' => 'meta_data_align',
		  'value' => array( esc_html__( 'Center', 'mega' ) => 'center', esc_html__( 'Left', 'mega' ) => 'left' ),
		  'dependency' => array(
			'element' => 'template',
			'value' => array( 'title_visible', 'title_visible2' ),
		  ),
		  'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Meta data position', 'mega' ),
		  'param_name' => 'meta_data_position',
		  'value' => array( esc_html__( 'Center', 'mega' ) => 'center', esc_html__( 'Top Left', 'mega' ) => 'top_left' ),
		  'dependency' => array(
			'element' => 'template',
			'value' => array( 'title_hidden', 'title_hidden2' ),
		  ),
		  'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Meta data animation', 'mega' ),
		  'param_name' => 'meta_data_animation',
		  'value' => array( esc_html__( 'None', 'mega' ) => 'none', esc_html__( 'FadeIn', 'mega' ) => 'fadein', esc_html__( 'FadeInUp', 'mega' ) => 'fadeinup', esc_html__( 'FadeInFlip', 'mega' ) => 'fadeinflip' ),
		  'dependency' => array(
			'element' => 'template',
			'value' => array( 'title_hidden', 'title_hidden2' ),
		  ),
		  'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Hover scale effect', 'mega' ),
		  'param_name' => 'hover_scale_effect',
		  'value' => array( esc_html__( 'None', 'mega' ) => 'none', esc_html__( 'Scale', 'mega' ) => 'scale', esc_html__( 'Scale 2', 'mega' ) => 'scale2', esc_html__( 'Scale 3', 'mega' ) => 'scale3' ),
		  'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Click scale effect', 'mega' ),
		  'param_name' => 'click_scale_effect',
		  'value' => array( esc_html__( 'None', 'mega' ) => 'none', esc_html__( 'Scale', 'mega' ) => 'scale', esc_html__( 'Scale 2', 'mega' ) => 'scale2' ),
		  'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Hover opacity effect', 'mega' ),
		  'param_name' => 'hover_opacity_effect',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		  'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Click opacity effect', 'mega' ),
		  'param_name' => 'click_opacity_effect',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		  'group' => esc_html__( 'Item Design', 'mega' ),
		),
		// Typography
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Title font size', 'mega' ),
		  'param_name' => 'title_font_size',
		  'value' => '',
		  'description' => esc_html__( 'Enter items title font size in pixels or depending of screen width in rem: 16 or 1rem.', 'mega' ),
		  'group' => esc_html__( 'Typography', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Title text transform', 'mega' ),
		  'param_name' => 'title_text_transform',
		  'value' => array( esc_html__( 'None', 'mega' ) => 'none', esc_html__( 'Uppercase', 'mega' ) => 'uppercase' ),
		  'group' => esc_html__( 'Typography', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Title font weight', 'mega' ),
		  'param_name' => 'title_font_weight',
		  'value' => array(
			 esc_html__( 'Thin 100', 'mega' ) => 100,
			 esc_html__( 'Extra Light 200', 'mega' ) => 200,
			 esc_html__( 'Light 300', 'mega' ) => 300,
			 esc_html__( 'Regular 400', 'mega' ) => 400,
			 esc_html__( 'Medium 500', 'mega' ) => 500,
			 esc_html__( 'Semi Bold 600', 'mega' ) => 600,
			 esc_html__( 'Bold 700', 'mega' ) => 700,
			 esc_html__( 'Extra Bold 800', 'mega' ) => 800,
			 esc_html__( 'Black 900', 'mega' ) => 900,
		  ),
		  'std' => 700,
		  'group' => esc_html__( 'Typography', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Title letter spacing', 'mega' ),
		  'param_name' => 'title_letter_spacing',
		  'value' => '',
		  'description' => esc_html__( 'Enter items title letter spacing in pixels: 2.', 'mega' ),
		  'group' => esc_html__( 'Typography', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Title font style', 'mega' ),
		  'param_name' => 'title_font_style',
		  'value' => array( esc_html__( 'Normal', 'mega' ) => 'normal', esc_html__( 'Italic', 'mega' ) => 'italic' ),
		  'group' => esc_html__( 'Typography', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Title font family', 'mega' ),
		  'param_name' => 'title_font_family',
		  'value' => array( esc_html__( 'Secondary', 'mega' ) => 'secondary', esc_html__( 'Primary', 'mega' ) => 'primary' ),
		  'group' => esc_html__( 'Typography', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Meta data font size', 'mega' ),
		  'param_name' => 'meta_data_font_size',
		  'value' => '',
		  'description' => esc_html__( 'Enter items meta data font size in pixels: 16.', 'mega' ),
		  'group' => esc_html__( 'Typography', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Meta data text transform', 'mega' ),
		  'param_name' => 'meta_data_text_transform',
		  'value' => array( esc_html__( 'None', 'mega' ) => 'none', esc_html__( 'Uppercase', 'mega' ) => 'uppercase' ),
		  'group' => esc_html__( 'Typography', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Meta data font weight', 'mega' ),
		  'param_name' => 'meta_data_font_weight',
		  'value' => array(
			 esc_html__( 'Thin 100', 'mega' ) => 100,
			 esc_html__( 'Extra Light 200', 'mega' ) => 200,
			 esc_html__( 'Light 300', 'mega' ) => 300,
			 esc_html__( 'Regular 400', 'mega' ) => 400,
			 esc_html__( 'Medium 500', 'mega' ) => 500,
			 esc_html__( 'Semi Bold 600', 'mega' ) => 600,
			 esc_html__( 'Bold 700', 'mega' ) => 700,
			 esc_html__( 'Extra Bold 800', 'mega' ) => 800,
			 esc_html__( 'Black 900', 'mega' ) => 900,
		  ),
		  'std' => 400,
		  'group' => esc_html__( 'Typography', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Meta data letter spacing', 'mega' ),
		  'param_name' => 'meta_data_letter_spacing',
		  'value' => '',
		  'description' => esc_html__( 'Enter items meta data letter spacing in pixels: 2.', 'mega' ),
		  'group' => esc_html__( 'Typography', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Meta data font style', 'mega' ),
		  'param_name' => 'meta_data_font_style',
		  'value' => array( esc_html__( 'Normal', 'mega' ) => 'normal', esc_html__( 'Italic', 'mega' ) => 'italic' ),
		  'group' => esc_html__( 'Typography', 'mega' ),
		),
   ),
) );

// Image Gallery MT
function mega_mt_vc_gallery( $atts, $content = null ) {
	wp_enqueue_script( 'isotope-pkgd' );
	wp_enqueue_script( 'mega-gallery' );

    extract( shortcode_atts( array(
		'include' => '',
		'number' => '',
		'img_size' => 'large',
		'lazyload' => '',
		'max_width' => '',
		'layout' => '',
		'row_width' => '20',
		'columns' => '',
		'margin' => '',
		'onclick' => 'lightbox',
		'onimageclick' => 'next',
		'custom_links' => '',
		'custom_url_target' => '',
		'animation' => '',
		'animation_type' => 'fadeinup',
		'delayed_animation' => '',
		'show_captions' => '',
		'randomize' => '',
		'el_id' => '',
		'css_class' => '',
		'lightbox_background_color' => '',
		'lightbox_buttons_color' => '',
		'lightbox_buttons_background_color' => '',
		'lightbox_buttons_background_color_hover' => '',
		'lightbox_buttons_background_color_active' => '',
		'lightbox_open_close_animation_type' => '',
		'lightbox_transition_effect_between_slides' => '',
		'show_overlay_on_hover' => '',
		'overlay_background_color' => '',
		'hover_scale_effect' => '',
		'click_scale_effect' => '',
		'hover_opacity_effect' => '',
		'click_opacity_effect' => '',
    ), $atts ) );
	
	if ( ! $lazyload ) {
		wp_enqueue_script( 'imagesloaded' );
	}
	
	// Lazy-loading
	if ( $lazyload != '' && $lazyload != '0' ) {
		wp_enqueue_script( 'lazysizes' );
		$lazyload_class = 'lazyload-enabled';
	} else {
		$lazyload_class = 'lazyload-disabled';
	}
	
	// Layout type
	if ( $layout == 'justified' ) {
		$layout_class = 'layout-justified';
	} else if ( $layout == 'cellsbyrow' ) {
		$layout_class = 'layout-cellsbyrow';
	} else if ( $layout == 'fitrows' ) {
		$layout_class = 'layout-fitrows';
	} else {
		$layout_class = 'layout-masonry';
	}
	
	// Columns count
	if ( $columns == 2 ) {
		$columns_class = 'col-2';
	} else if ( $columns == 3 ) {
		$columns_class = 'col-3';
	} else if ( $columns == 4 ) {
		$columns_class = 'col-4';
	} else if ( $columns == 5 ) {
		$columns_class = 'col5';
	} else if ( $columns == 6 ) {
		$columns_class = 'col6';
	} else if ( $columns == 7 ) {
		$columns_class = 'col7';
	} else if ( $columns == 8 ) {
		$columns_class = 'col8';
	} else if ( $columns == 1 ) {
		$columns_class = 'col-1';
	} else {
		$columns_class = '';
	}
	
	if ( $layout == 'justified' ) {
		$columns_class = '';
	}
	
	// Margin between items
	if ( $margin == '0px' ) {
		$margin_class = 'margin-0px';
	} else if ( $margin == '1px' ) {
		$margin_class = 'margin-1px';
	} else if ( $margin == '5px' ) {
		$margin_class = 'margin-5px';
	} else if ( $margin == '10px' ) {
		$margin_class = 'margin-10px';
	} else if ( $margin == '15px' ) {
		$margin_class = 'margin-15px';
	} else if ( $margin == '20px' ) {
		$margin_class = 'margin-20px';
	} else {
		$margin_class = 'margin-30px';
	}
	
	// On click action
	$lightgallery_class = '';
	$onimageclick_data = '';
	if ( $onclick == 'lightbox' ) {
		wp_enqueue_script( 'lightgallery' );
		$lightgallery_class = 'lightgallery-enabled';
		$onimageclick_data = "data-lightgallery-onimageclick='{$onimageclick}'";
	}
	
	if ( 'custom_link' === $onclick ) {
		$custom_links = vc_value_from_safe( $custom_links );
		$custom_links = explode( ',', $custom_links );
	}
	
	// Animation
	if ( $animation != '' && $animation != '0' ) {
		wp_enqueue_script( 'waypoints' );
		$animation_class = 'mt-animate_when_almost_visible-enabled';
		if ( $delayed_animation != '' && $delayed_animation != '0' ) {
			$delayed_animation_class = 'mt-animate_when_almost_visible-delayed-enabled';
		} else {
			$delayed_animation_class = 'mt-animate_when_almost_visible-delayed-disabled';
		}
	} else {
		$animation_class = 'mt-animate_when_almost_visible-disabled';
		$delayed_animation_class = 'animation-for-every-item-in-viewport-disabled';
	}
	
	if ( '' === $include ) {
		$include = '-1,-2,-3';
	}

	$include = explode( ',', $include );
	
	// Randomize images
	if ( ! empty( $randomize ) ) {
		shuffle( $include );
	}
	
	$i = - 1;
	
	$output = '';
	
	// Lightbox background color
	$lightbox_background_color_data = '';
	$lightbox_open_close_animation_type_data = '';
	$lightbox_transition_effect_between_slides_data = '';
	if ( ! empty( $lightbox_background_color ) ) {
		$lightbox_background_color_data = "data-lightgallery-bg-color='{$lightbox_background_color}'";
	}
	
	// Lightbox open/close animation type
	if ( ! empty( $lightbox_open_close_animation_type ) ) {
		$lightbox_open_close_animation_type_data = "data-lightgallery-open-close-animation-type='{$lightbox_open_close_animation_type}'";
	}
	
	// Lightbox transition effect between slides
	if ( ! empty( $lightbox_transition_effect_between_slides ) ) {
		$lightbox_transition_effect_between_slides_data = "data-lightgallery-transition-effect-between-slides='{$lightbox_transition_effect_between_slides}'";
	}
	
	// Lightbox buttons color
	$lightbox_buttons_color_data = '';
	if ( ! empty( $lightbox_buttons_color ) ) {
		$lightbox_buttons_color_data = "data-lightgallery-buttons-color='{$lightbox_buttons_color}'";
	}
	
	// Lightbox buttons background color
	$lightbox_buttons_background_color_data = '';
	if ( ! empty( $lightbox_buttons_background_color ) ) {
		$lightbox_buttons_background_color_data = "data-lightgallery-buttons-bg-color='{$lightbox_buttons_background_color}'";
	}
	
	// Lightbox buttons background color hover
	$lightbox_buttons_background_color_hover_data = '';
	if ( ! empty( $lightbox_buttons_background_color_hover ) ) {
		$lightbox_buttons_background_color_hover_data = "data-lightgallery-buttons-bg-color-hover='{$lightbox_buttons_background_color_hover}'";
	}
	
	// Lightbox buttons background color active
	$lightbox_buttons_background_color_active_data = '';
	if ( ! empty( $lightbox_buttons_background_color_active ) ) {
		$lightbox_buttons_background_color_active_data = "data-lightgallery-buttons-bg-color-active='{$lightbox_buttons_background_color_active}'";
	}
	
	// Hover scale effect
	if ( $hover_scale_effect == 'scale' ) {
		$hover_scale_effect_class = 'hover-scale-effect-scale';
	} else if ( $hover_scale_effect == 'scale2' ) {
		$hover_scale_effect_class = 'hover-scale-effect-scale2';
	} else if ( $hover_scale_effect == 'scale3' ) {
		$hover_scale_effect_class = 'hover-scale-effect-scale3';
	} else {
		$hover_scale_effect_class = 'hover-scale-effect-none';
	}
	
	// Click scale effect
	if ( $click_scale_effect == 'scale' ) {
		$click_scale_effect_class = 'click-scale-effect-scale';
	} else {
		$click_scale_effect_class = 'click-scale-effect-none';
	}
	
	// Hover opacity effect
	if ( $hover_opacity_effect != '' && $hover_opacity_effect != '0' ) {
		$hover_opacity_effect_class = 'hover-opacity-effect-enabled';
	} else {
		$hover_opacity_effect_class = 'hover-opacity-effect-disabled';
	}
	
	// Click opacity effect
	if ( $click_opacity_effect != '' && $click_opacity_effect != '0' ) {
		$click_opacity_effect_class = 'click-opacity-effect-enabled';
	} else {
		$click_opacity_effect_class = 'click-opacity-effect-disabled';
	}
	
	// Max width
	if ( ! empty( $max_width ) ) {
		$style = 'style="max-width: '. $max_width .'px;"';
	} else {
		$style = '';
	}
	
	// Element ID
	if ( ! empty( $el_id ) ) {
		$id = 'id="mt-gallery-container-wrapper-'. esc_attr( $el_id ) .'"';
	} else {
		$id = '';
	}
	
	$output .= '<div '. $id .' class="mt-gallery-container-wrapper '. esc_attr( $lazyload_class ) .' '. esc_attr( $layout_class ) .' '. esc_attr( $columns_class ) .' '. esc_attr( $margin_class ) .' '. esc_attr( $lightgallery_class ) .' '. esc_attr( $animation_class ) .' '. esc_attr( $animation_type ) .' '. esc_attr( $delayed_animation_class ) .' '. esc_attr( $css_class ) .' '. esc_attr( $hover_scale_effect_class ) .' '. esc_attr( $click_scale_effect_class ) .' '. esc_attr( $hover_opacity_effect_class ) .' '. esc_attr( $click_opacity_effect_class ) .' clearfix" '. $onimageclick_data .' '. $lightbox_background_color_data .' '. $lightbox_buttons_color_data .' '. $lightbox_buttons_background_color_data .' '. $lightbox_buttons_background_color_hover_data .' '. $lightbox_buttons_background_color_active_data .' '. $lightbox_open_close_animation_type_data .' '. $lightbox_transition_effect_between_slides_data .'>';
	
		if ( ! $lazyload ) {
		$output .= '<div class="loader-lg">';
			$output .= '<svg class="circular" viewBox="25 25 50 50">';
				$output .= '<circle class="path" cx="50" cy="50" r="20" fill="none" stroke-width="6" stroke-miterlimit="10"/>';
			$output .= '</svg>';
		$output .= '</div>';
		}
		
		$output .= '<div class="mt-gallery-container clearfix" '. $style .'>';
		
			$output .= '<span class="grid-sizer"></span>';
			$output .= '<span class="gutter-sizer"></span>';

			$i = 0;
			foreach ( $include as $attach_id ) {
				
				if ( $attach_id > 0 ) {
					if ( $lazyload != '' && $lazyload != '0' ) {
						$lazyload = 'lazyload';
					} else {
						$lazyload = '';
					}
					$post_thumbnail = wpb_getImageBySize( array( 'attach_id' => $attach_id, 'thumb_size' => $img_size, 'class' => 'attachment '. $lazyload ) );
				}

				$thumbnail = $post_thumbnail['thumbnail'];
				
				if ( $thumbnail ) {
					// Check file type
					$type = '';
					$type = get_post_mime_type( $attach_id );
					$mime_type = explode('/', $type);
					if ( ! isset($mime_type['1'])) {
					   $mime_type['1'] = null;
					}
					$type = $mime_type['1'];
					
					// Remove title tag
					$thumbnail = preg_replace( '/(<[^>]+) title=".*?"/i', '\1', $thumbnail );
				
					if ( $lazyload != '' && $lazyload != '0' ) {
						//$thumbnail_lazy = preg_replace( '/(<[^>]+) sizes=".*?"/i', '\1', $thumbnail );
						$thumbnail_lazy = preg_replace( '/(<[^>]+) width=".*?"/i', '\1', $thumbnail );
						$thumbnail_lazy = preg_replace( '/(<[^>]+) height=".*?"/i', '\1', $thumbnail_lazy );
						$thumbnail_lazy = preg_replace( '/(<[^>]+) loading=".*?"/i', '\1', $thumbnail_lazy );
						if ( strpos( $thumbnail_lazy, 'srcset=' ) !== false ) {
							$thumbnail_lazy = preg_replace( '/(<[^>]+) src=".*?"/i', '\1', $thumbnail_lazy );
							$thumbnail_lazy = str_replace( 'srcset=', 'data-srcset=', $thumbnail_lazy );
						} else {
							$thumbnail_lazy = str_replace( 'src=', 'data-src=', $thumbnail_lazy );
						}
						//$thumbnail_lazy = str_replace( '/>', 'src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7"/>', $thumbnail_lazy );
					}
					if ( in_array( $img_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full', ) ) ) {
						$thumbnail_src = wp_get_attachment_image_src( $attach_id, $img_size );
						$width = $thumbnail_src[1];
						$height = $thumbnail_src[2];
					} else {
						$size = str_replace( 'x', ',', $img_size );
						$width = explode( ',', $size );
						$width = $width[0];
						$height = substr( $size, strpos( $size, "," ) + 1 );
					}
					
					$gallery_image_src_full = wp_get_attachment_image_src( $attach_id, 'full' );
					$gallery_image_src_full_width = $gallery_image_src_full[1];
					$gallery_image_src_full_height = $gallery_image_src_full[2];
					$attachment = get_post( $attach_id );
					$attachment_title = apply_filters( 'the_title', $attachment->post_title );
					$attachment_caption = apply_filters( 'the_title', $attachment->post_excerpt );
				}
				
				if ( $layout == 'justified' ) {
					$output .= '<div class="mt-gallery-item isotope-item" style="--w: '. esc_attr( $width ) .'; --row-width: '. esc_attr( $row_width ) .'vw; --h: '. esc_attr( $height ) .';">';
				} else {
					$output .= '<div class="mt-gallery-item isotope-item">';
				}
				$output .= '<div class="mt-gallery-item-helper" style="max-width: '. esc_attr( $width ) .'px;">';
				$output .= '<div class="content-wrapper-helper">';
				if ( $onclick == 'lightbox' ) {
					if ( ! empty( $show_captions ) ) {
					$output .= '<a class="content-wrapper" data-caption="'. $attachment_caption .'" data-src="'. esc_url( $gallery_image_src_full[0] ).'" data-width="'. esc_attr( $gallery_image_src_full_width ) .'" data-height="'. esc_attr( $gallery_image_src_full_height ) .'" style="max-width: '. esc_attr( $width ) .'px;">';
					} else {
					$output .= '<a class="content-wrapper" data-src="'. esc_url( $gallery_image_src_full[0] ).'" data-width="'. esc_attr( $gallery_image_src_full_width ) .'" data-height="'. esc_attr( $gallery_image_src_full_height ) .'" style="max-width: '. esc_attr( $width ) .'px;">';
					}
				} else if ( $onclick == 'custom_links' ) {
					if ( ! empty( $custom_links [ $i ] ) ) {
						if ( $custom_url_target == 'blank' ) {
							$output .= '<a class="content-wrapper" href="'. esc_url( $custom_links [ $i ] ).'" target="_blank" style="max-width: '. esc_attr( $width ) .'px;">';
						} else {
							$output .= '<a class="content-wrapper" href="'. esc_url( $custom_links [ $i ] ).'" style="max-width: '. esc_attr( $width ) .'px;">';
						}
					}
				} else {
					$output .= '<div class="content-wrapper" style="max-width: '. esc_attr( $width ) .'px;">';
				}
				$output .= '<div class="thumbnail-wrapper-1">';
					$output .= '<div class="thumbnail-wrapper-2">';
						$output .= '<div class="thumbnail-wrapper-helper">';
						if ( $lazyload != '' && $lazyload != '0' ) {
							if ( ! empty( $width ) ) {
							$output .= '<div class="thumbnail-wrapper lazy" style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';">';
								if ( ! empty( $show_overlay_on_hover ) ) {
								if ( ! empty( $overlay_background_color ) ) {
								$output .= '<div class="overlay" style="background-color:'. esc_attr( $overlay_background_color ) .'"></div>';
								} else {
								$output .= '<div class="overlay"></div>';
								}
								}
								$output .= $thumbnail_lazy;
								$output .= '<span class="loaderbg"></span>';
							$output .= '</div>';
							}
						} else {
							$output .= '<div class="thumbnail-wrapper">';
								if ( ! empty( $show_overlay_on_hover ) ) {
								if ( ! empty( $overlay_background_color ) ) {
								$output .= '<div class="overlay" style="background-color:'. esc_attr( $overlay_background_color ) .'"></div>';
								} else {
								$output .= '<div class="overlay"></div>';
								}
								}
								$output .= $thumbnail;
							$output .= '</div>';
						}
						$output .= '</div>';
					$output .= '</div>';
				$output .= '</div>';
				if ( $onclick == 'none' ) {
				$output .= '</div>';
				} else {
				$output .= '</a>';
				}
				$output .= '</div>';
				if ( ! empty( $show_captions ) && $columns == 1 ) {
					if ( ! empty( $attachment_caption ) ) {
						$output .= '<p class="caption">'. $attachment_caption .'</p>';
					}
				}
				$output .= '</div>';
				$output .= '</div>';
				
				// Items count
				if ( ++$i == $number ) {
					break;
				}
			}
		
		$output .= '</div><!-- .mt-gallery-container -->';
	$output .= '</div><!-- .mt-gallery-container-wrapper -->';

return $output;
}
add_shortcode( 'mt_vc_gallery', 'mega_mt_vc_gallery' );

vc_map( array(
	'name' => esc_html__( 'Image Gallery MT', 'mega' ),
	'base' => 'mt_vc_gallery',
	'description' => esc_html__( 'Responsive image gallery', 'mega' ),
	'class' => 'mt-vc-gallery',
	'icon' => 'vc_icon-vc-media-grid',
	'category' => esc_html__( 'Content', 'mega' ),
	'weight' => 0,
	'params' => array(
		array(
			'type' => 'attach_images',
			'heading' => esc_html__( 'Images', 'mega' ),
			'param_name' => 'include',
			'value' => '',
			'description' => esc_html__( 'Select images from media library.', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Items count', 'mega' ),
		  'param_name' => 'number',
		  'value' => '',
		  'description' => esc_html__( 'Set max limit for items or leave empty to display all.', 'mega' ),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Image size', 'mega' ),
			'param_name' => 'img_size',
			'description' => esc_html__( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "large" size.', 'mega' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Lazy-loading', 'mega' ),
		  'param_name' => 'lazyload',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Max width', 'mega' ),
		  'param_name' => 'max_width',
		  'value' => '',
		  'description' => esc_html__( 'Enter images max width in pixels: 784', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Layout type', 'mega' ),
		  'param_name' => 'layout',
		  'value' => array( esc_html__( 'Masonry', 'mega' ) => 'masonry', esc_html__( 'Justified', 'mega' ) => 'justified', esc_html__( 'cellsByRow', 'mega' ) => 'cellsbyrow' , esc_html__( 'fitRows', 'mega' ) => 'fitrows' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Row width', 'mega' ),
		  'param_name' => 'row_width',
		  'value' => '',
		  'description' => esc_html__( 'Enter row width in viewport width: 20', 'mega' ),
		  'dependency' => array(
			'element' => 'layout',
			'value' => array( 'justified' ),
		  ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Columns count', 'mega' ),
		  'param_name' => 'columns',
		  'value' => array( 1, 2, 3, 4 ),
		  'std' => 3,
		  'edit_field_class' => 'vc_col-sm-6',
		  'dependency' => array(
			'element' => 'layout',
			'value' => array( 'masonry', 'cellsbyrow' ),
		  ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Margin between items', 'mega' ),
		  'param_name' => 'margin',
		  'value' => array( '0px', '1px', '5px', '10px', '15px', '20px', '30px' ),
		  'std' => '30px',
		  'edit_field_class' => 'vc_col-sm-6',
		  'dependency' => array(
			'element' => 'layout',
			'value' => array( 'masonry', 'justified' ),
		  ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'On click action', 'mega' ),
		  'param_name' => 'onclick',
		  'value' => array( esc_html__( 'None', 'mega' ) => 'none', esc_html__( 'Open custom links', 'mega' ) => 'custom_link', esc_html__( 'Open lightbox', 'mega' ) => 'lightbox' ),
		  'std' => 'lightbox',
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'On image click action', 'mega' ),
		  'param_name' => 'onimageclick',
		  'value' => array( esc_html__( 'Next', 'mega' ) => 'next', esc_html__( 'Zoom', 'mega' ) => 'zoom', esc_html__( 'Do nothing', 'mega' ) => 'false' ),
		  'dependency' => array(
		      'element' => 'onclick',
			  'value' => array( 'lightbox' ),
		  ),
		),
		array(
			'type' => 'exploded_textarea_safe',
			'heading' => esc_html__( 'Custom links', 'mega' ),
			'param_name' => 'custom_links',
			'description' => esc_html__( 'Enter links for each image (Note: divide links with linebreaks (Enter)).', 'mega' ),
			'dependency' => array(
				'element' => 'onclick',
				'value' => array( 'custom_link' ),
			),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Custom URL target', 'mega' ),
		  'param_name' => 'custom_url_target',
		  'value' => array( esc_html__( 'Self', 'mega' ) => 'self', esc_html__( 'Blank', 'mega' ) => 'blank' ),
		  'description' => esc_html__( 'Specify where to open the linked document (blank opens the linked document in a new window or tab and self opens the linked document in the same frame as it was clicked (this is default)).', 'mega' ),
		  'dependency' => array(
			'element' => 'onclick',
			'value' => array( 'custom_link' ),
		  ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Animation', 'mega' ),
		  'param_name' => 'animation',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Animation type', 'mega' ),
		  'param_name' => 'animation_type',
		  'value' => array( esc_html__( 'FadeInUp', 'mega' ) => 'fadeinup', esc_html__( 'FadeIn', 'mega' ) => 'fadein' ),
		  'description' => esc_html__( 'Select type of animation for element to be animated when it "enters" the browsers viewport.', 'mega' ),
		  'dependency' => array(
		      'element' => 'animation',
		      'not_empty' => true,
		  ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Delayed animation', 'mega' ),
		  'param_name' => 'delayed_animation',
		  'description' => esc_html__( 'Select animation if you want items to be animated when they enter into the browsers viewport.', 'mega' ),
		  'value' => array( esc_html__( 'Yes', 'mega' ) => true ),
		  'dependency' => array(
		      'element' => 'animation',
		      'not_empty' => true,
		  ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Show captions', 'mega' ),
		  'param_name' => 'show_captions',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Randomize images', 'mega' ),
			'param_name' => 'randomize',
			'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
			'type' => 'el_id',
			'heading' => esc_html__( 'Element ID', 'mega' ),
			'param_name' => 'el_id',
			'description' => sprintf( esc_html__( 'Enter element ID (Note: make sure it is unique and valid according to %sw3c specification%s).', 'mega' ), '<a href="https://www.w3schools.com/tags/att_global_id.asp" target="_blank">', '</a>' ),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Extra class name', 'mega' ),
			'param_name' => 'css_class',
			'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'mega' ),
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Lightbox background color', 'mega' ),
			'param_name' => 'lightbox_background_color',
			'value' => 'rgba(0,0,0,0.87)',
			'dependency' => array(
				'element' => 'onclick',
				'value' => array( 'lightbox' ),
			),
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Lightbox buttons color', 'mega' ),
			'param_name' => 'lightbox_buttons_color',
			'value' => '#ffffff',
			'dependency' => array(
				'element' => 'onclick',
				'value' => array( 'lightbox' ),
			),
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Lightbox buttons background color', 'mega' ),
			'param_name' => 'lightbox_buttons_background_color',
			'value' => 'rgba(0,0,0,0.37)',
			'dependency' => array(
				'element' => 'onclick',
				'value' => array( 'lightbox' ),
			),
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Lightbox buttons background color hover', 'mega' ),
			'param_name' => 'lightbox_buttons_background_color_hover',
			'value' => 'rgba(0,0,0,0.46)',
			'dependency' => array(
				'element' => 'onclick',
				'value' => array( 'lightbox' ),
			),
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Lightbox buttons background color active', 'mega' ),
			'param_name' => 'lightbox_buttons_background_color_active',
			'value' => 'rgba(0,0,0,0.46)',
			'dependency' => array(
				'element' => 'onclick',
				'value' => array( 'lightbox' ),
			),
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Lightbox open/close animation type', 'mega' ),
			'param_name' => 'lightbox_open_close_animation_type',
			'value' => array( esc_html__( 'Zoom', 'mega' ) => 'zoom', esc_html__( 'Fade', 'mega' ) => 'fade', esc_html__( 'Zoom-in-out', 'mega' ) => 'zoom-in-out' ),
			'dependency' => array(
				'element' => 'onclick',
				'value' => array( 'lightbox' ),
			),
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Lightbox transition effect between slides', 'mega' ),
			'param_name' => 'lightbox_transition_effect_between_slides',
			'value' => array( esc_html__( 'Fade', 'mega' ) => 'fade', esc_html__( 'Slide', 'mega' ) => 'slide', esc_html__( 'Zoom-in-out', 'mega' ) => 'zoom-in-out' ),
			'dependency' => array(
				'element' => 'onclick',
				'value' => array( 'lightbox' ),
			),
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Show overlay on hover', 'mega' ),
			'param_name' => 'show_overlay_on_hover',
			'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
			'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Overlay background color', 'mega' ),
			'param_name' => 'overlay_background_color',
			'value' => 'rgba(0,0,0,0.8)',
			'group' => esc_html__( 'Item Design', 'mega' ),
			'dependency' => array(
		      'element' => 'show_overlay_on_hover',
		      'not_empty' => true,
			),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Hover scale effect', 'mega' ),
		  'param_name' => 'hover_scale_effect',
		  'value' => array( esc_html__( 'None', 'mega' ) => 'none', esc_html__( 'Scale', 'mega' ) => 'scale', esc_html__( 'Scale 2', 'mega' ) => 'scale2', esc_html__( 'Scale 3', 'mega' ) => 'scale3' ),
		  'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Click scale effect', 'mega' ),
		  'param_name' => 'click_scale_effect',
		  'value' => array( esc_html__( 'None', 'mega' ) => 'none', esc_html__( 'Scale', 'mega' ) => 'scale' ),
		  'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Hover opacity effect', 'mega' ),
		  'param_name' => 'hover_opacity_effect',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		  'group' => esc_html__( 'Item Design', 'mega' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Click opacity effect', 'mega' ),
		  'param_name' => 'click_opacity_effect',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		  'group' => esc_html__( 'Item Design', 'mega' ),
		),
	),
) );

VcShortcodeAutoloader::getInstance()->includeClass( 'WPBakeryShortCode_Vc_Basic_Grid' );

/**
 * Class WPBakeryShortCode_mt_vc_gallery
 */
class WPBakeryShortCode_mt_vc_gallery extends WPBakeryShortCode_Vc_Basic_Grid {

	/**
	 * @param $param
	 * @param $value
	 * @return string
	 */
	public function singleParamHtmlHolder( $param, $value ) {
		$output = '';
		$param_name = isset( $param['param_name'] ) ? $param['param_name'] : '';
		$type = isset( $param['type'] ) ? $param['type'] : '';
		$class = isset( $param['class'] ) ? $param['class'] : '';

		if ( isset( $param['holder'] ) && 'hidden' !== $param['holder'] ) {
			$output .= '<' . $param['holder'] . ' class="wpb_vc_param_value ' . $param_name . ' ' . $type . ' ' . $class . '" name="' . $param_name . '">' . $value . '</' . $param['holder'] . '>';
		}

		if ( 'include' === $param_name ) {
			$images_ids = empty( $value ) ? array() : explode( ',', trim( $value ) );
			$output .= '<ul class="attachment-thumbnails' . ( empty( $images_ids ) ? ' image-exists' : '' ) . '" data-name="' . $param_name . '">';
			foreach ( $images_ids as $image ) {
				$img = wpb_getImageBySize( array(
					'attach_id' => (int) $image,
					'thumb_size' => 'thumbnail',
				) );
				$output .= ( $img ? '<li>' . $img['thumbnail'] . '</li>' : '<li><img width="150" height="150" src="' . esc_url( vc_asset_url( 'vc/blank.gif' ) ) . '" class="attachment-thumbnail" alt="" title="" /></li>' );
			}
			$output .= '</ul>';
			$output .= '<a href="#" class="column_edit_trigger' . ( ! empty( $images_ids ) ? ' image-exists' : '' ) . '">' . esc_html__( 'Add images', 'js_composer' ) . '</a>';

		}

		return $output;
	}
}

// Posts Slider MT
function mt_vc_posts_slider( $atts, $content = null ) {
    extract( shortcode_atts( array(
		'img_size' => 'large',
		'items' => '3',
		'items_on_small_screens' => '3',
		'navigation' => '',
		'slide_by' => 'by_page',
		'navigation_style' => '1',
		'dots' => '',
		'margin' => '',
		'style' => '1',
		'fade' => '',
		'number' => 6,
		'meta_data' => '',
		'category' => '',
		'post_in' => '',
		'post_not_in' => '',
		'orderby' => 'date',
		'order' => 'DESC',
		'target_for_url' => '',
		'lazyload' => '',
		'css_class' => '',
    ), $atts ) );
	
	if ( $items == 1 ) {
		wp_enqueue_script( 'slick' );
		wp_enqueue_script( 'slick-init' );
	} else {
		wp_enqueue_script( 'owl-carousel' );
		wp_enqueue_script( 'owl-carousel-init' );
	}
	
	if ($dots!= '' && $dots!= '0'){
		$dots = 'true';
	} else {
		$dots = 'false';
	}
	
	if ($margin!= '' && $margin!= '0'){
		$margin = '0';
	} else {
		$margin = '30';
	}
	
	$no_found_rows = true;
	
	if ( get_query_var('paged') ) { $paged = get_query_var('paged'); } else if ( get_query_var('page') ) {$paged = get_query_var('page'); } else {$paged = 1; }
	
	global $wp_query, $post;
    $temp = $wp_query;
    $wp_query= null;
	
	$args = array();
	
	$not_in = array();
	if ( $post_not_in != '' ) {
		$post_not_in = str_ireplace( ' ', '', $post_not_in );
		$not_in = explode(',', $post_not_in);
	}
	
	if ( $post_in != '' ) {
		$post_in = str_ireplace( ' ', '', $post_in );
		$args['post__in'] = explode( ',', $post_in );
	}
	if ( $post_in == '' || $post_not_in != '' ) {
		$args['post__not_in'] = $not_in;
	}
	
	if ( $orderby != NULL ) {
		$args['orderby'] = $orderby;
	}
	$args['order'] = $order;
	
	$args['post_type'] = 'portfolio';
	$args['portfolio-category'] = $category;
	$args['posts_per_page'] = $number;
	$args['paged'] = $paged;
	$args['no_found_rows'] = $no_found_rows;
	$args['post_status'] = 'publish';
	$wp_query = new WP_Query($args);
	ob_start();
	?>
	
	<?php if ( $lazyload != '' && $lazyload != '0' ) {
		$lazyload = 'lazyload-enabled';
	} else {
		$lazyload = 'lazyload-disabled';
	}
	?>

<?php if ( $items == 1 ) { ?>

	<div class="mt-slick-slider-container-wrapper <?php echo esc_attr( $css_class ); ?>">
	<?php if ( $style == '2' ) { ?>
		<div class="browser-bar"><div class="browser-buttons"><span class="browser-button"></span><span class="browser-button"></span><span class="browser-button"></span></div></div>
	<?php } ?>
	
	<div class="mt-slick-slider-container portfolio-carousel-alternative nav-<?php echo esc_attr( $navigation ); ?> nav-style-<?php echo esc_attr( $navigation_style ); ?> slide-by-<?php echo esc_attr( $slide_by ); ?> margin-<?php echo esc_attr( $margin ); ?> portfolio-carousel-alternative-style-<?php echo esc_attr( $style ); ?> <?php echo esc_attr( $fade ); ?> <?php echo esc_attr( $lazyload ); ?>" data-items="<?php echo esc_attr( $items ); ?>" data-items-on-small-screens="<?php echo esc_attr( $items_on_small_screens ); ?>" data-nav="<?php echo esc_attr( $navigation ); ?>" data-dots="<?php echo esc_attr( $dots ); ?>" data-margin="<?php echo esc_attr( $margin ); ?>">

<?php } else { ?>

<div class="mt-owl-carousel-container-wrapper">
<div class="mt-owl-carousel-container portfolio-carousel owl-mt-theme margin-<?php echo esc_attr( $margin ); ?> <?php echo esc_attr( $lazyload ); ?> <?php echo esc_attr( $css_class ); ?>" data-items="<?php echo esc_attr( $items ); ?>" data-items-on-small-screens="<?php echo esc_attr( $items_on_small_screens ); ?>" data-dots="<?php echo esc_attr( $dots ); ?>" data-margin="<?php echo esc_attr( $margin ); ?>">

<?php } ?>

<?php if ( $wp_query->have_posts() ) : ?>
		
	<?php while ( $wp_query->have_posts() ) : $wp_query->the_post(); ?>
				
		<?php
		$post_id = $wp_query->post->ID;
		$thumbnail = '';
						
		$post_thumbnail = $p_img_large = '';

		$post_thumbnail = wpb_getImageBySize(array( 'post_id' => $post_id, 'thumb_size' => $img_size ));
		$thumbnail = $post_thumbnail['thumbnail'];
		$p_img_large = $post_thumbnail['p_img_large'];
		?>
		
		<?php // Remove title tag ?>
		<?php $thumbnail = preg_replace( '/(<[^>]+) title=".*?"/i', '\1', $thumbnail ); ?>
		
		<?php if ( $lazyload != '' && $lazyload != '0' ) { ?>
			<?php $thumbnail_lazy = preg_replace('/(<[^>]+) srcset=".*?"/i', '\1', $thumbnail); ?>
			<?php $thumbnail_lazy = preg_replace('/(<[^>]+) sizes=".*?"/i', '\1', $thumbnail_lazy); ?>
			<?php $thumbnail_lazy = str_replace('src=', 'data-src=', $thumbnail_lazy); ?>
			<?php $thumbnail_lazy = str_replace('/>', 'src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7">', $thumbnail_lazy); ?>
			<?php if ( in_array( $img_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full', ) ) ) { ?>
				<?php $image_attributes = wp_get_attachment_image_src( get_post_thumbnail_id($post_id), $img_size ); ?>
				<?php $width = $image_attributes[1]; ?>
				<?php $height = $image_attributes[2]; ?>
			<?php } else { ?>
				<?php $size = str_replace('x', ',', $img_size); ?>
				<?php $width = explode(',', $size); ?>
				<?php $width = $width[0]; ?>
				<?php $height = substr($size, strpos($size, ",") + 1); ?>
			<?php } ?>
		<?php } ?>
					
		<?php $custom_url = get_post_meta( get_the_ID(), 'custom_url', true ); ?>
		
		<?php if ( $style == '2' ) { ?>
		
				<?php
				$classes = array(
					'clearfix',
				);
				?>
				<article id="post-<?php the_ID(); ?>" <?php post_class( $classes ); ?>>
					<?php if ( $thumbnail ) { ?>
						<?php $text_color = get_post_meta( get_the_ID(), 'text_color', true ); ?>
						<?php $background_color = get_post_meta( get_the_ID(), 'background_color', true ); ?>
						<?php $background_color_rgb = mega_hex2rgb( $background_color ); ?>
						<?php $opacity = .8; ?>
						<?php $background_color_rgba = "rgba(" . $background_color_rgb[0] . ", " . $background_color_rgb[1] . ", " . $background_color_rgb[2] . ", " . $opacity . ")"; ?>
							<div class="content-wrapper">
								<div class="post-thumbnail clearfix <?php if ( $lazyload != '' && $lazyload != '0' ) echo 'lazy'?>" <?php if ( $lazyload != '' && $lazyload != '0' ) { echo 'style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';"'; }?>>
								<?php if ( $lazyload != '' && $lazyload != '0' ) { ?>
									<?php echo $thumbnail_lazy; ?>
									<span class="loaderbg"></span>
								<?php } else { ?>
									<?php echo $thumbnail; ?>
								<?php } ?>
								
								<div class="posts-content-wrapper">
									<div class="posts-content clearfix">
										<header class="entry-header">
											<h2><?php the_title(); ?></h2>
										</header><!-- .entry-header -->
										<?php if ( $meta_data == 'Categories' ) { ?>
											<div class="entry-category"><?php echo esc_html( mega_custom_taxonomies_terms_links() ); ?></div><!-- .entry-category -->
										<?php } else if ( $meta_data == 'Excerpt' ) { ?>
											<div class="entry-excerpt"><?php the_excerpt(); ?></div>
										<?php } else if ( $meta_data == 'Both' ) { ?>
											<div class="entry-excerpt"><?php the_excerpt(); ?></div>
											<div class="entry-category"><?php echo esc_html( mega_custom_taxonomies_terms_links() ); ?></div><!-- .entry-category -->
										<?php } ?>
										<a class="wpb_button_a" href="<?php if ( ! empty( $custom_url ) ) echo esc_url( $custom_url ); else the_permalink(); ?>" <?php if ( ! empty( $custom_url ) && $target_for_url == 'blank' ) echo 'target="_blank"'?>><?php esc_html_e("View demo", 'mega'); ?></a>
									</div>
								</div>
								
								</div><!-- .post-thumbnail -->
							</div><!-- .content-wrapper -->
					<?php } ?>
				</article>
				
			<?php } else { ?>
			
				<?php
				$classes = array(
					'clearfix',
				);
				?>
				<article <?php post_class( $classes ); ?>>
						<?php if ( $thumbnail ) { ?>
							<?php $text_color = get_post_meta( get_the_ID(), 'text_color', true ); ?>
							<?php $background_color = get_post_meta( get_the_ID(), 'background_color', true ); ?>
							<?php $background_color_rgb = mega_hex2rgb( $background_color ); ?>
							<?php $opacity = .8; ?>
							<?php $background_color_rgba = "rgba(" . $background_color_rgb[0] . ", " . $background_color_rgb[1] . ", " . $background_color_rgb[2] . ", " . $opacity . ")"; ?>
							<?php if ( ! empty( $custom_url ) ) { ?>
								<?php if ( ! empty( $custom_url ) && $target_for_url == 'blank' ) { ?>
									<a class="content-wrapper" href="<?php echo esc_url( $custom_url ); ?>" target="_blank">
								<?php } else { ?>
									<a class="content-wrapper" href="<?php echo esc_url( $custom_url ); ?>">
								<?php } ?>
							<?php } else { ?>
								<a class="content-wrapper" href="<?php echo the_permalink(); ?>">
							<?php } ?>
									<div class="post-thumbnail clearfix <?php if ( $lazyload != '' && $lazyload != '0' ) echo 'lazy'?>" <?php if ( $lazyload != '' && $lazyload != '0' ) { echo 'style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';"'; }?>>
									<?php if ( $lazyload != '' && $lazyload != '0' ) { ?>
										<?php echo $thumbnail_lazy; ?>
										<span class="loaderbg"></span>
									<?php } else { ?>
										<?php echo $thumbnail; ?>
									<?php } ?>
									<div class="posts-content-wrapper">
										<div class="overlay"></div>
										<div class="posts-content">
												<header class="entry-header">
													<h2><?php the_title(); ?></h2>
												</header><!-- .entry-header -->
												<?php if ( $meta_data == 'categories' ) { ?>
													<div class="entry-category" style="color: <?php echo esc_attr( $text_color ); ?>;"><?php echo esc_html( mega_custom_taxonomies_terms_links() ); ?></div><!-- .entry-category -->
												<?php } else if ( $meta_data == 'excerpt' ) { ?>
													<div class="entry-excerpt" style="color: <?php echo esc_attr( $text_color ); ?>;"><?php the_excerpt(); ?></div>
												<?php } else if ( $meta_data == 'both' ) { ?>
													<div class="entry-excerpt"><?php the_excerpt(); ?></div>
													<div class="entry-category"><?php echo esc_html( mega_custom_taxonomies_terms_links() ); ?></div><!-- .entry-category -->
												<?php } ?>
												<i></i>
										</div>
									</div>
									</div><!-- .post-thumbnail -->
								</a><!-- .content-wrapper -->
						<?php } ?>
				</article>
			
			<?php } ?>
		
	<?php endwhile; ?>
				
<?php endif; ?>
		
<?php wp_reset_postdata(); ?>
	
</div>
</div>
	
<?php $wp_query = null; $wp_query = $temp;
$content = ob_get_contents();
ob_end_clean();
return $content;
}
add_shortcode( 'mt_vc_posts_slider', 'mt_vc_posts_slider' );

vc_map( array(
	'name' => esc_html__( 'Posts Slider MT', 'mega' ),
	'base' => 'mt_vc_posts_slider',
	'description' => esc_html__( 'Animated posts slider', 'mega' ),
	'class' => 'mt-vc-portfolio-slider',
	'icon' => 'icon-wpb-images-carousel',
	'category' => esc_html__( 'Content', 'mega' ),
	'weight' => 0,
	'params' => array(
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Image size', 'mega' ),
		  'param_name' => 'img_size',
		  'description' => esc_html__( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height).', 'mega' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Items number', 'mega' ),
			'param_name' => 'items',
			'value' => array( 3, 1, 2, 4, 5, 6 ),
			'description' => esc_html__( 'The number of items you want to see on the screen.', 'mega' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Items number on small screens', 'mega' ),
			'param_name' => 'items_on_small_screens',
			'value' => array( 3, 1, 2, 4 ),
			'description' => esc_html__( 'The number of items on small screens you want to see on the screen.', 'mega' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Navigation', 'mega' ),
		  'param_name' => 'navigation',
		  'description' => esc_html__( 'Show next/prev buttons.', 'mega' ),
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Slide by', 'mega' ),
			'param_name' => 'slide_by',
			'value' => array( esc_html__( 'By page', 'mega' ) => 'by_page', 1 ),
			'description' => esc_html__( 'Navigation slide by x.', 'mega' ),
			'dependency' => array(
				'element' => 'navigation',
				'not_empty' => true,
			),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Navigation style', 'mega' ),
			'param_name' => 'navigation_style',
			'value' => array( 1, 2 ),
			'description' => esc_html__( 'Select style for navigation.', 'mega' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Dots', 'mega' ),
		  'param_name' => 'dots',
		  'description' => esc_html__( 'Show dots navigation.', 'mega' ),
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Disable margin', 'mega' ),
		  'param_name' => 'margin',
		  'description' => esc_html__( 'Disable margin.', 'mega' ),
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Style', 'mega' ),
		  'param_name' => 'style',
		  'value' => array( 1, 2 ),
		  'description' => esc_html__( 'Select style for gallery items.', 'mega' ),
		),
		array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Enable fade', 'mega' ),
			'param_name' => 'fade',
			'description' => esc_html__( 'If selected, fade animation will be enabled. Works only with one item.', 'mega' ),
			'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Portfolio items count', 'mega' ),
		  'param_name' => 'number',
		  'value' => 6,
		  'description' => esc_html__( 'Enter portfolio items count.', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Meta Data', 'mega' ),
		  'param_name' => 'meta_data',
		  'value' => array( esc_html__( 'None', 'mega' ) => 'none', esc_html__( 'Excerpt', 'mega' ) => 'excerpt', esc_html__( 'Categories', 'mega' ) => 'categories', esc_html__( 'Both', 'mega' ) => 'both' ),
		  'description' => esc_html__( 'Select what information to display for each portfolio item just under their title.', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Categories', 'mega' ),
		  'param_name' => 'category',
		  'description' => esc_html__( 'If you want to narrow output, enter category slugs here. Note: Only listed categories will be included. Divide categories with commas.', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Portfolio items IDs', 'mega' ),
		  'param_name' => 'post_in',
		  'description' => esc_html__( 'Fill this field with portfolio items IDs separated by commas (,) to retrieve only them.', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Exclude portfolio items IDs', 'mega' ),
		  'param_name' => 'post_not_in',
		  'description' => esc_html__( 'Fill this field with portfolio items IDs separated by commas (,) to exclude them from query.', 'mega' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Order by', 'mega' ),
		  'param_name' => 'orderby',
		  'value' => array( esc_html__( 'Date', 'mega' ) => 'date', esc_html__( 'ID', 'mega' ) => 'ID', esc_html__( 'Title', 'mega' ) => 'title', esc_html__( 'Random', 'mega' ) => 'rand' ),
		  'description' => sprintf( esc_html__( 'Select how to sort retrieved posts. More at %s.', 'mega' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Order way', 'mega' ),
		  'param_name' => 'order',
		  'value' => array( esc_html__( 'Descending', 'mega' ) => 'DESC', esc_html__( 'Ascending', 'mega' ) => 'ASC' ),
		  'description' => sprintf( esc_html__( 'Designates the ascending or descending order. More at %s.', 'mega' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Target for URL', 'mega' ),
		  'param_name' => 'target_for_url',
		  'value' => array( esc_html__( 'Self', 'mega' ) => 'self', esc_html__( 'Blank', 'mega' ) => 'blank' ),
		  'description' => sprintf( esc_html__( 'Select how to sort retrieved posts. More at %s.', 'mega' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Enable lazyload', 'mega' ),
		  'param_name' => 'lazyload',
		  'description' => esc_html__( 'Select lazyload if you want portfolio image to be loaded when it enters into the browsers viewport.', 'mega' ),
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Extra class name', 'mega' ),
			'param_name' => 'css_class',
			'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'mega' ),
		),
	),
) );

// Image Slider MT
function mt_vc_image_slider( $atts, $content = null ) {
    extract( shortcode_atts( array(
		'include' => '',
		'number' => '',
		'img_size' => 'large',
		'lazyload' => '',
		'effect' => 'slide',
		'loop' => '',
		'autoplay' => '',
		'autoplay_delay' => '3000',
		'disable_on_interaction' => '',
		'pause_on_mouse_enter' => '',
		'slides_per_view' => '1',
		'navigation' => '',
		'navigation_style' => '1',
		'slides_per_group' => '1',
		'on_click' => '',
		'pagination' => '',
		'space_between' => '0',
		'show_captions' => '',
		'randomize' => '',
		'css_animation' => '',
		'el_id' => '',
		'css_class' => '',
    ), $atts ) );
	
	//if ( !$lazyload ) {
		//wp_enqueue_script( 'imagesloaded' );
	//}
	
	// Lazy-loading
	if ( $lazyload != '' && $lazyload != '0' ) {
		$lazyload_class = 'lazyload-enabled';
	} else {
		$lazyload_class = 'lazyload-disabled';
	}
	
	// Infinite loop
	if ( $loop != '' && $loop != '0' ) {
		$loop = 'true';
	} else {
		$loop = 'false';
	}
	
	// Autoplay
	if ( $autoplay != '' && $autoplay != '0' ) {
		$autoplay = 'true';
	} else {
		$autoplay = 'false';
	}
	
	// Disable on interaction
	if ( $disable_on_interaction != '' && $disable_on_interaction != '0' ) {
		$disable_on_interaction = 'true';
	} else {
		$disable_on_interaction = 'false';
	}
	
	// Pause on mouse enter
	if ( $pause_on_mouse_enter != '' && $pause_on_mouse_enter != '0' ) {
		$pause_on_mouse_enter = 'true';
	} else {
		$pause_on_mouse_enter = 'false';
	}
	
	// Navigation
	if ( $navigation != '' && $navigation != '0' ) {
		$navigation = 'true';
	} else {
		$navigation = 'false';
	}
	
	// On click action
	if ( $on_click != '' && $on_click != '0' ) {
		$on_click = 'true';
	} else {
		$on_click = 'false';
	}
	
	// Pagination
	if ( $pagination != '' && $pagination != '0' ) {
		$pagination = 'true';
	} else {
		$pagination = 'false';
	}
	
	// Space between
	if ( $space_between == '30px' ) {
		$space_between = '30';
	} else {
		$space_between = '0';
	}
	
	if ( '' === $include ) {
		$include = '-1,-2,-3';
	}

	$include = explode( ',', $include );

	// Randomize images
	if ( ! empty( $randomize ) ) {
		shuffle( $include );
	}

	$i = - 1;

	// Animation
	if ( $css_animation != '' ) {
		wp_enqueue_script( 'waypoints' );
		$CSSAnimation = ' wpb_animate_when_almost_visible wpb_'. $css_animation;
	} else {
		$CSSAnimation = 'no-animation';
	}

	$output = '';
	
	// Element ID
	if ( ! empty( $el_id ) ) {
		$id = 'id="swiper-'. esc_attr( $el_id ) .'"';
	} else {
		$id = '';
	}

	$output .= '<div '. $id .' class="swiper '. esc_attr( $lazyload_class ) .' nav-style-'. esc_attr( $navigation_style ) .' on-click-'. esc_attr( $on_click ) .' '. esc_attr( $CSSAnimation ) .' '. esc_attr( $css_class ) .'" data-effect="'. esc_attr( $effect ) .'" data-loop="'. esc_attr( $loop ) .'" data-autoplay="'. esc_attr( $autoplay ) .'" data-autoplay-delay="'. esc_attr( $autoplay_delay ) .'" data-disable-on-interaction="'. esc_attr( $disable_on_interaction ) .'" data-pause-on-mouse-enter="'. esc_attr( $pause_on_mouse_enter ) .'" data-slides-per-view="'. esc_attr( $slides_per_view ) .'" data-navigation="'. esc_attr( $navigation ) .'" data-slides-per-group="'. esc_attr( $slides_per_group ) .'" data-on-click="'. esc_attr( $on_click ) .'" data-pagination="'. esc_attr( $pagination ) .'" data-space-between="'. esc_attr( $space_between ) .'">';
		$output .= '<div class="swiper-wrapper">';

		$i = 0;
		foreach ( $include as $attach_id ) {
			
			if ( $attach_id > 0 ) {
				if ( $lazyload != '' && $lazyload != '0' ) {
					$lazyclass = 'swiper-lazy';
				} else {
					$lazyclass = '';
				}
				$post_thumbnail = wpb_getImageBySize( array( 'attach_id' => $attach_id, 'thumb_size' => $img_size, 'class' => 'attachment '. $lazyclass ) );
			}

			$thumbnail = $post_thumbnail['thumbnail'];
			
			if ( $thumbnail ) {
				// Remove title tag
				$thumbnail = preg_replace( '/(<[^>]+) title=".*?"/i', '\1', $thumbnail );
			
				if ( $lazyload != '' && $lazyload != '0' ) {
					$thumbnail = preg_replace( '/(<[^>]+) sizes=".*?"/i', '\1', $thumbnail );
					$thumbnail = preg_replace( '/(<[^>]+) loading=".*?"/i', '\1', $thumbnail );
					$thumbnail = preg_replace( '/(<[^>]+) width=".*?"/i', '\1', $thumbnail );
					$thumbnail = preg_replace( '/(<[^>]+) height=".*?"/i', '\1', $thumbnail );
					
					if ( in_array( $img_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full', ) ) ) {
						$thumbnail_lazy = preg_replace( '/(<[^>]+) src=".*?"/i', '\1', $thumbnail );
						$thumbnail_lazy = str_replace('/>', 'data-src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7">', $thumbnail_lazy);
						$thumbnail_lazy = str_replace( 'srcset=', 'data-srcset=', $thumbnail_lazy );
						
						$thumbnail_src = wp_get_attachment_image_src( $attach_id, $img_size );
						$width = $thumbnail_src[1];
						$height = $thumbnail_src[2];
					} else {
						$thumbnail_lazy = str_replace( 'src=', 'data-srcset=', $thumbnail );
						$thumbnail_lazy = str_replace('/>', 'data-src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7">', $thumbnail_lazy);
						
						$size = str_replace( 'x', ',', $img_size );
						$width = explode( ',', $size );
						$width = $width[0];
						$height = substr( $size, strpos( $size, "," ) + 1 );
					}
				}
			
				$attachment = get_post( $attach_id );
				$attachment_caption = apply_filters( 'the_title', $attachment->post_excerpt );
			}
				
			$output .= '<div class="swiper-slide">';
				if ( $lazyload != '' && $lazyload != '0' ) {
						$output .= '<div class="image-wrapper" style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';">';
							$output .= $thumbnail_lazy;
							$output .= '<span class="swiper-lazy-loader"></span>';
						$output .= '</div>';
				} else {
					$output .= '<div class="image-wrapper">';
						$output .= $thumbnail;
					$output .= '</div>';
				}
				if ( ! empty( $show_captions ) ) {
					$output .= '<span class="caption">';
						$output .= $attachment_caption;
					$output .= '</span>';
				}
			$output .= '</div>';
			
			// Items count
			if ( ++$i == $number ) {
				break;
			}
		}

		$output .= '</div>';
		
		if ( $navigation == 'true' ) {
			$output .= '<div class="swiper-button-nav swiper-button-prev"><svg viewBox="0 0 8 15"><polyline fill="none" stroke-miterlimit="10" points="7.3,14.7 2.5,8 7.3,1.2"></polyline></svg></div>';
			$output .= '<div class="swiper-button-nav swiper-button-next"><svg viewBox="0 0 8 15"><polyline fill="none" stroke-miterlimit="10" points="1.6,1.2 6.5,7.9 1.6,14.7"></polyline></svg></div>';
		}
		
	$output .= '</div>';

	return $output;
}
add_shortcode( 'mt_vc_image_slider', 'mt_vc_image_slider' );

vc_map( array(
	'name' => esc_html__( 'Image Slider MT', 'mega' ),
	'base' => 'mt_vc_image_slider',
	'description' => esc_html__( 'Animated images slider', 'mega' ),
	'class' => 'mt-vc-image-slider',
	'icon' => 'icon-wpb-images-carousel',
	'category' => esc_html__( 'Content', 'mega' ),
	'weight' => 0,
	'params' => array(
		array(
			'type' => 'attach_images',
			'heading' => esc_html__( 'Images', 'mega' ),
			'param_name' => 'include',
			'value' => '',
			'description' => esc_html__( 'Select images from media library.', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Items count', 'mega' ),
		  'param_name' => 'number',
		  'value' => '',
		  'description' => esc_html__( 'Set max limit for items or leave empty to display all.', 'mega' ),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Image size', 'mega' ),
			'param_name' => 'img_size',
			'value' => 'large',
			'description' => esc_html__( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "large" size.', 'mega' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Lazy-loading', 'mega' ),
		  'param_name' => 'lazyload',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Effect', 'mega' ),
		  'param_name' => 'effect',
		  'value' => array( esc_html__( 'Slide', 'mega' ) => 'slide', esc_html__( 'Fade', 'mega' ) => 'fade' ),
		),
		array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Infinite loop', 'mega' ),
			'param_name' => 'loop',
			'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Autoplay', 'mega' ),
			'param_name' => 'autoplay',
			'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Autoplay delay', 'mega' ),
			'param_name' => 'autoplay_delay',
			'description' => esc_html__( 'Autoplay delay in milliseconds. Default 3000.', 'mega' ),
			'value' => '3000',
			'dependency' => array(
				'element' => 'autoplay',
				'not_empty' => true,
			),
		),
		array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Disable on interaction', 'mega' ),
			'param_name' => 'disable_on_interaction',
			'description' => esc_html__( 'Autoplay will not be restarted every time after interaction.', 'mega' ),
			'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
			'dependency' => array(
				'element' => 'autoplay',
				'not_empty' => true,
			),
		),
		array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Pause on mouse enter', 'mega' ),
			'param_name' => 'pause_on_mouse_enter',
			'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
			'dependency' => array(
				'element' => 'autoplay',
				'not_empty' => true,
			),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Slides per view', 'mega' ),
			'param_name' => 'slides_per_view',
			'value' => array( '1', '2', '3', '4' ),
			'edit_field_class' => 'vc_col-sm-6',
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Navigation', 'mega' ),
		  'param_name' => 'navigation',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Navigation style', 'mega' ),
			'param_name' => 'navigation_style',
			'value' => array( '1', '2' ),
			'dependency' => array(
				'element' => 'navigation',
				'not_empty' => true,
			),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Slides per group', 'mega' ),
			'param_name' => 'slides_per_group',
			'value' => array( '1', '2', '3', '4' ),
			'dependency' => array(
				'element' => 'navigation',
				'not_empty' => true,
			),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'On click action', 'mega' ),
		  'param_name' => 'on_click',
		  'value' => array( esc_html__( 'None', 'mega' ) => 'none', esc_html__( 'Next slide', 'mega' ) => 'next_slide' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Pagination', 'mega' ),
		  'param_name' => 'pagination',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'dropdown',
		  'heading' => esc_html__( 'Space between', 'mega' ),
		  'param_name' => 'space_between',
		  'value' => array( '0', '30px' ),
		  'std' => '0',
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Show captions', 'mega' ),
		  'param_name' => 'show_captions',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Randomize images', 'mega' ),
			'param_name' => 'randomize',
			'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		$add_css_animation = array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Animation', 'mega' ),
			'param_name' => 'css_animation',
			'value' => array(
				esc_html__( 'None', 'mega' ) => '',
				esc_html__( 'Bottom to top', 'mega' ) => 'bottom-to-top',
				esc_html__( 'Left to right', 'mega' ) => 'left-to-right',
				esc_html__( 'Right to left', 'mega' ) => 'right-to-left',
			),
			'description' => esc_html__( 'Select type of animation for element to be animated when it "enters" the browsers viewport.', 'mega' ),
		),
		array(
			'type' => 'el_id',
			'heading' => esc_html__( 'Element ID', 'mega' ),
			'param_name' => 'el_id',
			'description' => sprintf( esc_html__( 'Enter element ID (Note: make sure it is unique and valid according to %sw3c specification%s).', 'mega' ), '<a href="https://www.w3schools.com/tags/att_global_id.asp" target="_blank">', '</a>' ),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Extra class name', 'mega' ),
			'param_name' => 'css_class',
			'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'mega' ),
		),
	),
) );

VcShortcodeAutoloader::getInstance()->includeClass( 'WPBakeryShortCode_Vc_Basic_Grid' );

/**
 * Class WPBakeryShortCode_mt_vc_image_slider
 */
class WPBakeryShortCode_mt_vc_image_slider extends WPBakeryShortCode_Vc_Basic_Grid {

	/**
	 * @param $param
	 * @param $value
	 * @return string
	 */
	public function singleParamHtmlHolder( $param, $value ) {
		$output = '';
		$param_name = isset( $param['param_name'] ) ? $param['param_name'] : '';
		$type = isset( $param['type'] ) ? $param['type'] : '';
		$class = isset( $param['class'] ) ? $param['class'] : '';

		if ( isset( $param['holder'] ) && 'hidden' !== $param['holder'] ) {
			$output .= '<' . $param['holder'] . ' class="wpb_vc_param_value ' . $param_name . ' ' . $type . ' ' . $class . '" name="' . $param_name . '">' . $value . '</' . $param['holder'] . '>';
		}

		if ( 'include' === $param_name ) {
			$images_ids = empty( $value ) ? array() : explode( ',', trim( $value ) );
			$output .= '<ul class="attachment-thumbnails' . ( empty( $images_ids ) ? ' image-exists' : '' ) . '" data-name="' . $param_name . '">';
			foreach ( $images_ids as $image ) {
				$img = wpb_getImageBySize( array(
					'attach_id' => (int) $image,
					'thumb_size' => 'thumbnail',
				) );
				$output .= ( $img ? '<li>' . $img['thumbnail'] . '</li>' : '<li><img width="150" height="150" src="' . esc_url( vc_asset_url( 'vc/blank.gif' ) ) . '" class="attachment-thumbnail" alt="" title="" /></li>' );
			}
			$output .= '</ul>';
			$output .= '<a href="#" class="column_edit_trigger' . ( ! empty( $images_ids ) ? ' image-exists' : '' ) . '">' . esc_html__( 'Add images', 'js_composer' ) . '</a>';

		}

		return $output;
	}
}

// Testimonials
class WPBakeryShortCode_VC_Tta_Testimonials extends WPBakeryShortCodesContainer {
	protected $controls_css_settings = 'out-tc vc_controls-content-widget';
	protected $controls_list = array( 'add', 'edit', 'clone', 'delete' );
	protected $template_vars = array();

	public $layout = 'accordion';
	protected $content;

	public $activeClass = 'vc_active';
	/**
	 * @var WPBakeryShortCode_VC_Tta_Testimonials_Section
	 */
	protected $sectionClass;

	public $nonDraggableClass = 'vc-non-draggable-container';

	public function getFileName() {
		return 'vc_tta_global_testimonials';
	}

	public function containerContentClass() {
		return 'vc_container_for_children vc_clearfix';
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 */
	public function resetVariables( $atts, $content ) {
		$this->atts = $atts;
		$this->content = $content;
		$this->template_vars = array();
	}

	public function setGlobalTtaInfo() {
		$sectionClass = visual_composer()->getShortCode( 'vc_tta_section_testimonials' )->shortcodeClass();
		$this->sectionClass = $sectionClass;

		/** @var $sectionClass WPBakeryShortCode_VC_Tta_Testimonials_Section */
		if ( is_object( $sectionClass ) ) {
			VcShortcodeAutoloader::getInstance()->includeClass( 'WPBakeryShortCode_VC_Tta_Testimonials_Section' );
			WPBakeryShortCode_VC_Tta_Testimonials_Section::$tta_base_shortcode = $this;
			WPBakeryShortCode_VC_Tta_Testimonials_Section::$self_count = 0;
			WPBakeryShortCode_VC_Tta_Testimonials_Section::$section_info = array();

			return true;
		}

		return false;
	}

	/**
	 * Override default getColumnControls to make it "simple"(blue), as single element has
	 *
	 * @param string $controls
	 * @param string $extended_css
	 *
	 * @return string
	 */
	public function getColumnControls( $controls = 'full', $extended_css = '' ) {
		// we don't need containers bottom-controls for tabs
		if ( 'bottom-controls' === $extended_css ) {
			return '';
		}
		$column_controls = $this->getColumnControlsModular();

		return $output = $column_controls;
	}

	public function getTtaContainerClasses() {
		$classes = array();
		$classes[] = 'vc_tta-container';

		return implode( ' ', apply_filters( 'vc_tta_container_classes', array_filter( $classes ), $this->getAtts() ) );
	}

	public function getTtaGeneralClasses() {
		$classes = array();
		$classes[] = 'vc_general';
		$classes[] = 'vc_tta';
		$classes[] = 'vc_tta-' . $this->layout;
		$classes[] = $this->getTemplateVariable( 'color' );
		$classes[] = $this->getTemplateVariable( 'style' );
		$classes[] = $this->getTemplateVariable( 'shape' );
		$classes[] = $this->getTemplateVariable( 'spacing' );
		$classes[] = $this->getTemplateVariable( 'gap' );
		$classes[] = $this->getTemplateVariable( 'c_align' );
		$classes[] = $this->getTemplateVariable( 'no_fill' );
		if ( isset( $this->atts['collapsible_all'] ) && 'true' === $this->atts['collapsible_all'] ) {
			$classes[] = 'vc_tta-o-all-clickable';
		}

		$pagination = isset( $this->atts['pagination_style'] ) ? trim( $this->atts['pagination_style'] ) : false;
		if ( $pagination && 'none' !== $pagination && strlen( $pagination ) > 0 ) {
			$classes[] = 'vc_tta-has-pagination';
		}

		/**
		 * @since 4.6.2
		 */
		if ( isset( $this->atts['el_class'] ) ) {
			$classes[] = $this->atts['el_class'];
		}

		return implode( ' ', apply_filters( 'vc_tta_accordion_general_classes', array_filter( $classes ), $this->getAtts() ) );
	}

	public function getTtaPaginationClasses() {
		$classes = array();
		$classes[] = 'vc_general';
		$classes[] = 'vc_pagination';

		if ( isset( $this->atts['pagination_style'] ) && strlen( $this->atts['pagination_style'] ) > 0 ) {
			$chunks = explode( '-', $this->atts['pagination_style'] );
			$classes[] = 'vc_pagination-style-' . $chunks[0];
			$classes[] = 'vc_pagination-shape-' . $chunks[1];
		}

		if ( isset( $this->atts['pagination_color'] ) && strlen( $this->atts['pagination_color'] ) > 0 ) {
			$classes[] = 'vc_pagination-color-' . $this->atts['pagination_color'];
		}

		return implode( ' ', $classes );
	}

	public function getWrapperAttributes() {
		$attributes = array();
		$attributes[] = 'class="' . esc_attr( $this->getTtaContainerClasses() ) . '"';
		$attributes[] = 'data-vc-action="' . ( 'true' === $this->atts['collapsible_all'] ? 'collapseAll' : 'collapse' ) . '"';

		$autoplay = isset( $this->atts['autoplay'] ) ? trim( $this->atts['autoplay'] ) : false;
		if ( $autoplay && 'none' !== $autoplay && intval( $autoplay ) > 0 ) {
			$attributes[] = 'data-vc-tta-autoplay="' . esc_attr(
				json_encode(
					array(
							'delay' => intval( $autoplay ) * 1000,
						)
				)
			) . '"';
		}

		return implode( ' ', $attributes );
	}

	public function getTemplateVariable( $string ) {
		if ( isset( $this->template_vars[ $string ] ) ) {
			return $this->template_vars[ $string ];
		} elseif ( method_exists( $this, 'getParam' . vc_studly( $string ) ) ) {
			$this->template_vars[ $string ] = $this->{'getParam' . vc_studly( $string )}( $this->atts, $this->content );

			return $this->template_vars[ $string ];
		}

		return '';
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamColor( $atts, $content ) {
		if ( isset( $atts['color'] ) && strlen( $atts['color'] ) > 0 ) {
			return 'vc_tta-color-' . $atts['color'];
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamStyle( $atts, $content ) {
		if ( isset( $atts['style'] ) && strlen( $atts['style'] ) > 0 ) {
			return 'vc_tta-style-' . $atts['style'];
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamTitle( $atts, $content ) {
		if ( isset( $atts['title'] ) && strlen( $atts['title'] ) > 0 ) {
			return '<h2>' . $atts['title'] . '</h2>';
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamContent( $atts, $content ) {
		$panelsContent = wpb_js_remove_wpautop( $content );
		if ( isset( $atts['c_icon'] ) && strlen( $atts['c_icon'] ) > 0 ) {
			$isPageEditable = vc_is_page_editable();
			if ( ! $isPageEditable ) {
				$panelsContent = str_replace( '{{{ control-icon }}}',
					'<i class="vc_tta-controls-icon vc_tta-controls-icon-' . $atts['c_icon'] . '"></i>',
					$panelsContent
				);
			} else {
				$panelsContent = str_replace( '{{{ control-icon }}}',
					'<i class="vc_tta-controls-icon" data-vc-tta-controls-icon="' . $atts['c_icon'] . '"></i>',
					$panelsContent
				);
			}
		} else {
			$panelsContent = str_replace( '{{{ control-icon }}}',
				'',
			$panelsContent );
		}

		return $panelsContent;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamShape( $atts, $content ) {
		if ( isset( $atts['shape'] ) && strlen( $atts['shape'] ) > 0 ) {
			return 'vc_tta-shape-' . $atts['shape'];
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string
	 */
	public function getParamSpacing( $atts, $content ) {
		if ( isset( $atts['spacing'] ) && strlen( $atts['spacing'] ) > 0 ) {
			return 'vc_tta-spacing-' . $atts['spacing'];
		}

		// In case if no spacing set we need to append extra class
		return 'vc_tta-o-shape-group';
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamGap( $atts, $content ) {
		if ( isset( $atts['gap'] ) && strlen( $atts['gap'] ) > 0 ) {
			return 'vc_tta-gap-' . $atts['gap'];
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamNoFill( $atts, $content ) {
		if ( isset( $atts['no_fill'] ) && 'true' === $atts['no_fill'] ) {
			return 'vc_tta-o-no-fill';
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamCAlign( $atts, $content ) {
		if ( isset( $atts['c_align'] ) && strlen( $atts['c_align'] ) > 0 ) {
			return 'vc_tta-controls-align-' . $atts['c_align'];
		}

		return null;
	}

	/**
	 * Accordion doesn't have pagination
	 *
	 * @param $atts
	 * @param $content
	 *
	 * @return null
	 */
	public function getParamPaginationTop( $atts, $content ) {
		return null;
	}

	/**
	 * Accordion doesn't have pagination
	 *
	 * @param $atts
	 * @param $content
	 *
	 * @return null
	 */
	public function getParamPaginationBottom( $atts, $content ) {
		return null;
	}

	/**
	 * Get currently active section (from $atts)
	 *
	 * @param $atts
	 * @param bool $strict_bounds If true, check for min/max bounds
	 *
	 * @return int nth position (one-based) of active section
	 */
	function getActiveSection( $atts, $strict_bounds = false ) {
		$active_section = intval( $atts['active_section'] );

		if ( $strict_bounds ) {
			VcShortcodeAutoloader::getInstance()->includeClass( 'WPBakeryShortCode_VC_Tta_Testimonials_Section' );
			if ( $active_section < 1 ) {
				$active_section = 1;
			} elseif ( $active_section > WPBakeryShortCode_VC_Tta_Testimonials_Section::$self_count ) {
				$active_section = WPBakeryShortCode_VC_Tta_Testimonials_Section::$self_count;
			}
		}

		return $active_section;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string
	 */
	public function getParamPaginationList( $atts, $content ) {
		if ( empty( $atts['pagination_style'] ) ) {
			return null;
		}
		$isPageEditabe = vc_is_page_editable();

		$sectionClass = $this->sectionClass;

		$html = array();
		$html[] = '<ul class="' . $this->getTtaPaginationClasses() . '">';

		if ( ! $isPageEditabe ) {
			VcShortcodeAutoloader::getInstance()->includeClass( 'WPBakeryShortCode_VC_Tta_Testimonials_Section' );
			foreach ( WPBakeryShortCode_VC_Tta_Testimonials_Section::$section_info as $nth => $section ) {
				$strict_bounds = ( 'vc_tta_tabs' === $this->shortcode );
				$active_section = $this->getActiveSection( $atts, $strict_bounds );

				$classes = array( 'vc_pagination-item' );
				if ( ( $nth + 1 ) === $active_section ) {
					$classes[] = $this->activeClass;
				}

				$a_html = '<a href="#' . $section['tab_id'] . '" class="vc_pagination-trigger" data-vc-tabs data-vc-container=".vc_tta"></a>';
				$html[] = '<li class="' . implode( ' ', $classes ) . '" data-vc-tab>' . $a_html . '</li>';
			}
		}

		$html[] = '</ul>';

		return implode( '', $html );
	}

	public function enqueueTtaScript() {		
		wp_enqueue_script( 'vc_accordion_script' );
		if ( ! vc_is_page_editable() ) {
			wp_enqueue_script( 'vc_tta_autoplay_script' );
		}
	}

	/**
	 * Override default outputTitle (also Icon). To remove anything, also Icon.
	 *
	 * @param $title - just for strict standards
	 *
	 * @return string
	 */
	protected function outputTitle( $title ) {
		return '';
	}
	/**
	 * Check is allowed to add another element inside current element.
	 *
	 * @since 4.8
	 *
	 * @return bool
	 */
	public function getAddAllowed() {
		return vc_user_access_check_shortcode_all( 'vc_tta_section_testimonials' );
	}
}

VcShortcodeAutoloader::getInstance()->includeClass( 'WPBakeryShortCode_VC_Tta_Testimonials' );
class WPBakeryShortCode_VC_Tta_Testimonials_Section extends WPBakeryShortCode_VC_Tta_Testimonials {
	protected $controls_css_settings = 'tc vc_control-container';
	protected $controls_list = array( 'add', 'edit', 'clone', 'delete' );
	protected $backened_editor_prepend_controls = false;
	/**
	 * @var WPBakeryShortCode_VC_Tta_Testimonials
	 */
	public static $tta_base_shortcode;
	public static $self_count = 0;
	public static $section_info = array();

	public function getFileName() {
		if ( isset( self::$tta_base_shortcode ) && 'vc_tta_pageable' === self::$tta_base_shortcode->getShortcode() ) {
			return 'vc_tta_pageable_section';
		} else {
			return 'vc_tta_section_testimonials';
		}
	}

	public function containerContentClass() {
		return 'wpb_column_container vc_container_for_children vc_clearfix';
	}

	public function getElementClasses() {
		$classes = array();
		$classes[] = 'vc_tta-panel';
		$isActive = ! vc_is_page_editable() && $this->getTemplateVariable( 'section-is-active' );

		if ( $isActive ) {
			$classes[] = $this->activeClass;
		}

		/**
		 * @since 4.6.2
		 */
		if ( isset( $this->atts['el_class'] ) ) {
			$classes[] = $this->atts['el_class'];
		}

		return implode( ' ', array_filter( $classes ) );
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string
	 */
	public function getParamContent( $atts, $content ) {
		return wpb_js_remove_wpautop( $content );
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamTabId( $atts, $content ) {
		if ( isset( $atts['tab_id'] ) && strlen( $atts['tab_id'] ) > 0 ) {
			return $atts['tab_id'];
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamTitle( $atts, $content ) {
		if ( isset( $atts['title'] ) && strlen( $atts['title'] ) > 0 ) {
			return $atts['title'];
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamIcon( $atts, $content ) {
		if ( ! empty( $atts['add_icon'] ) && 'true' === $atts['add_icon'] ) {
			$iconClass = '';
			if ( isset( $atts[ 'i_icon_' . $atts['i_type'] ] ) ) {
				$iconClass = $atts[ 'i_icon_' . $atts['i_type'] ];
			}
			vc_icon_element_fonts_enqueue( $atts['i_type'] );

			return '<i class="vc_tta-icon ' . esc_attr( $iconClass ) . '"></i>';
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamIconLeft( $atts, $content ) {
		if ( 'left' === $atts['i_position'] ) {
			return $this->getParamIcon( $atts, $content );
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamIconRight( $atts, $content ) {
		if ( 'right' === $atts['i_position'] ) {
			return $this->getParamIcon( $atts, $content );
		}

		return null;
	}

	/**
	 * Section param active
	 */
	public function getParamSectionIsActive( $atts, $content ) {
		if ( is_object( self::$tta_base_shortcode ) ) {
			if ( isset( self::$tta_base_shortcode->atts['active_section'] ) && strlen( self::$tta_base_shortcode->atts['active_section'] ) > 0 ) {
				$active = (int) self::$tta_base_shortcode->atts['active_section'];
				if ( $active === self::$self_count ) {
					return true;
				}
			}
		}

		return null;
	}

	public function getParamControlIconPosition( $atts, $content ) {
		if ( is_object( self::$tta_base_shortcode ) ) {
			if (
				isset( self::$tta_base_shortcode->atts['c_icon'] ) && strlen( self::$tta_base_shortcode->atts['c_icon'] ) > 0 &&
				isset( self::$tta_base_shortcode->atts['c_position'] ) && strlen( self::$tta_base_shortcode->atts['c_position'] ) > 0
			) {
				$c_position = self::$tta_base_shortcode->atts['c_position'];

				return 'vc_tta-controls-icon-position-' . $c_position;
			}
		}

		return null;
	}

	public function getParamControlIcon( $atts, $content ) {
		if ( is_object( self::$tta_base_shortcode ) ) {
			if ( isset( self::$tta_base_shortcode->atts['c_icon'] ) && strlen( self::$tta_base_shortcode->atts['c_icon'] ) > 0 ) {
				$c_icon = self::$tta_base_shortcode->atts['c_icon'];

				return '<i class="vc_tta-controls-icon vc_tta-controls-icon-' . $c_icon . '"></i>';
			}
		}

		return null;
	}

	public function getParamHeading( $atts, $content ) {
		$isPageEditable = vc_is_page_editable();

		$h4attributes = array();
		$h4classes = array(
			'vc_tta-panel-title',
		);
		if ( $isPageEditable ) {
			$h4attributes[] = 'data-vc-tta-controls-icon-position=""';
		} else {
			$controlIconPosition = $this->getTemplateVariable( 'control-icon-position' );
			if ( $controlIconPosition ) {
				$h4classes[] = $controlIconPosition;
			}
		}
		$h4attributes[] = 'class="' . implode( ' ', $h4classes ) . '"';

		$output = '<h4 ' . implode( ' ', $h4attributes ) . '>'; // close h4

		if ( $isPageEditable ) {
			$output .= '<a href="javascript:;" data-vc-target=""';
			$output .= ' data-vc-tta-controls-icon-wrapper';
			$output .= ' data-vc-use-cache="false"';
		} else {
			$output .= '<a href="#' . esc_attr( $this->getTemplateVariable( 'tab_id' ) ) . '"';
		}

		$output .= ' data-vc-accordion';

		$output .= ' data-vc-container=".vc_tta-container">';
		$output .= $this->getTemplateVariable( 'icon-left' );
		$output .= '<span class="vc_tta-title-text">'
		           . $this->getTemplateVariable( 'title' )
		           . '</span>';
		$output .= $this->getTemplateVariable( 'icon-right' );
		if ( ! $isPageEditable ) {
			$output .= $this->getTemplateVariable( 'control-icon' );
		}

		$output .= '</a>';
		$output .= '</h4>'; // close h4 fix #2229

		return $output;
	}

	/**
	 * Get basic heading
	 *
	 * These are used in Pageable element inside content and are hidden from view
	 *
	 * @param $atts
	 * @param $content
	 *
	 * @return string
	 */
	public function getParamBasicHeading( $atts, $content ) {
		$isPageEditable = vc_is_page_editable();

		if ( $isPageEditable ) {
			$attributes = array(
				'href' => 'javascript:;',
				'data-vc-container' => '.vc_tta-container',
				'data-vc-accordion' => '',
				'data-vc-target' => '',
				'data-vc-tta-controls-icon-wrapper' => '',
				'data-vc-use-cache' => 'false',
			);
		} else {
			$attributes = array(
				'data-vc-container' => '.vc_tta-container',
				'data-vc-accordion' => '',
				'data-vc-target' => esc_attr( '#' . $this->getTemplateVariable( 'tab_id' ) ),
			);
		}

		$output = '
			<span class="vc_tta-panel-title">
				<a ' . vc_convert_atts_to_string( $attributes ) . '></a>
			</span>
		';

		return $output;
	}
	/**
	 * Check is allowed to add another element inside current element.
	 *
	 * @since 4.8
	 *
	 * @return bool
	 */
	public function getAddAllowed() {
		return  vc_user_access()
			->part( 'shortcodes' )
			->checkStateAny( true, 'custom', null )->get();
	}
}

vc_map( array(
  'name' => esc_html__( 'Testimonials MT', 'mega' ),
  'base' => 'vc_tta_testimonials',
  'icon' => 'icon-wpb-ui-accordion',
  'is_container' => true,
  'show_settings_on_create' => true,
  'as_parent' => array(
	'only' => 'vc_tta_section_testimonials',
  ),
  'category' => esc_html__( 'Content', 'mega' ),
  'weight' => 0,
  'params' => array(
	array(
      'type' => 'dropdown',
      'heading' => esc_html__( 'Style', 'mega' ),
      'param_name' => 'style',
	  'value' => array( 1, 2, 3, 4, 5, 6, 7, 8, 9 ),
      'description' => esc_html__( 'Select testimonials style.', 'mega' ),
    ),
	array(
	  'type' => 'checkbox',
	  'heading' => esc_html__( 'Lazy-loading', 'mega' ),
	  'param_name' => 'lazyload',
	  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
	),
	array(
	  'type' => 'dropdown',
	  'heading' => esc_html__( 'Effect', 'mega' ),
	  'param_name' => 'effect',
	  'value' => array( esc_html__( 'Slide', 'mega' ) => 'slide', esc_html__( 'Fade', 'mega' ) => 'fade' ),
	),
	array(
		'type' => 'checkbox',
		'heading' => esc_html__( 'Autoplay', 'mega' ),
		'param_name' => 'autoplay',
		'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
	),
	array(
		'type' => 'textfield',
		'heading' => esc_html__( 'Autoplay delay', 'mega' ),
		'param_name' => 'autoplay_delay',
		'description' => esc_html__( 'Autoplay delay in milliseconds. Default 3000.', 'mega' ),
		'value' => '3000',
		'dependency' => array(
			'element' => 'autoplay',
			'not_empty' => true,
		),
	),
	array(
		'type' => 'checkbox',
		'heading' => esc_html__( 'Disable on interaction', 'mega' ),
		'param_name' => 'disable_on_interaction',
		'description' => esc_html__( 'Autoplay will not be restarted every time after interaction.', 'mega' ),
		'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		'dependency' => array(
			'element' => 'autoplay',
			'not_empty' => true,
		),
	),
	array(
		'type' => 'checkbox',
		'heading' => esc_html__( 'Pause on mouse enter', 'mega' ),
		'param_name' => 'pause_on_mouse_enter',
		'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		'dependency' => array(
			'element' => 'autoplay',
			'not_empty' => true,
		),
	),
	array(
	  'type' => 'checkbox',
	  'heading' => esc_html__( 'Navigation', 'mega' ),
	  'param_name' => 'navigation',
	  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
	),
	array(
		'type' => 'dropdown',
		'heading' => esc_html__( 'Navigation style', 'mega' ),
		'param_name' => 'navigation_style',
		'value' => array( '1', '2' ),
		'dependency' => array(
			'element' => 'navigation',
			'not_empty' => true,
		),
	),
	array(
	  'type' => 'checkbox',
	  'heading' => esc_html__( 'Pagination', 'mega' ),
	  'param_name' => 'pagination',
	  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
	),
	array(
		'type' => 'checkbox',
		'heading' => esc_html__( 'Animation', 'mega' ),
		'param_name' => 'animation',
		'description' => esc_html__( 'Select type of animation for element to be animated when it "enters" the browsers viewport.', 'mega' ),
		'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
	),
	array(
		'type' => 'checkbox',
		'heading' => esc_html__( 'Randomize testimonials', 'mega' ),
		'param_name' => 'randomize',
		'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
	),
    array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Extra class name', 'mega' ),
      'param_name' => 'el_class',
      'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'mega' ),
    ),
  ),
  'js_view' => 'VcBackendTtaAccordionTestimonialsView',
  'custom_markup' => '
  <div class="vc_tta-container" data-vc-action="collapseAll">
	<div class="vc_general vc_tta vc_tta-accordion vc_tta-color-backend-accordion-white vc_tta-style-flat vc_tta-shape-rounded vc_tta-o-shape-group vc_tta-controls-align-left vc_tta-gap-2">
	   <div class="vc_tta-panels vc_clearfix {{container-class}}">
	      {{ content }}
	      <div class="vc_tta-panel vc_tta-section-append">
	         <div class="vc_tta-panel-heading">
	            <h4 class="vc_tta-panel-title vc_tta-controls-icon-position-left">
	               <a href="javascript:;" aria-expanded="false" class="vc_tta-backend-add-control">
	                   <span class="vc_tta-title-text">' . esc_html__( 'Add Section', 'mega' ) . '</span>
	                    <i class="vc_tta-controls-icon vc_tta-controls-icon-plus"></i>
					</a>
	            </h4>
	         </div>
	      </div>
	   </div>
	</div>
  </div>',
  'default_content' => '[vc_tta_section_testimonials title="' . sprintf( '%s %d', esc_html__( 'Section', 'mega' ), 1 ) . '"][/vc_tta_section_testimonials][vc_tta_section_testimonials title="' . sprintf( '%s %d', esc_html__( 'Section', 'mega' ), 2 ) . '"][/vc_tta_section_testimonials]',
) );

vc_map( array(
	'name' => esc_html__( 'Section MT', 'mega' ),
	'base' => 'vc_tta_section_testimonials',
	'icon' => 'icon-wpb-ui-tta-section',
	'allowed_container_element' => 'vc_column_text',
	'is_container' => true,
	'show_settings_on_create' => false,
	'as_child' => array(
		'only' => 'vc_tta_testimonials',
	),
	'as_parent' => array(
		'only' => 'vc_column_text',
	),
	'category' => esc_html__( 'Content', 'mega' ),
	'weight' => 0,
	'description' => esc_html__( 'Section for Tabs, Tours, Accordions.', 'mega' ),
	'params' => array(
		 array(
		  'type' => 'attach_image',
		  'heading' => esc_html__( 'Image', 'mega' ),
		  'param_name' => 'image',
		  'value' => '',
		  'description' => esc_html__( 'Select image from media library.', 'mega' ),
		),
		 array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Image size', 'mega' ),
		  'param_name' => 'img_size',
		  'description' => esc_html__( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "thumbnail" size.', 'mega' ),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Image width SVG', 'mega' ),
			'param_name' => 'img_width_svg',
			'description' => esc_html__( 'Enter image width in pixels (200) in case of using SVG.', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Name', 'mega' ),
		  'param_name' => 'name',
		  'description' => esc_html__( 'Enter person name.', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Title', 'mega' ),
		  'param_name' => 'title',
		  'description' => esc_html__( 'Enter person title.', 'mega' ),
		),
	  ),
	'js_view' => 'VcBackendTtaSectionView',
	'custom_markup' => '
		<div class="vc_tta-panel-heading">
		    <h4 class="vc_tta-panel-title vc_tta-controls-icon-position-left"><a href="javascript:;" data-vc-target="[data-model-id=\'{{ model_id }}\']" data-vc-accordion data-vc-container=".vc_tta-container"><span class="vc_tta-title-text">{{ section_title }}</span><i class="vc_tta-controls-icon vc_tta-controls-icon-plus"></i></a></h4>
		</div>
		<div class="vc_tta-panel-body">
			
			
			<div class="vc_controls">
				<div class="vc_controls-tc vc_control-container">
					<a class="vc_control-btn vc_element-name vc_element-move">
						<span class="vc_btn-content" title="Drag to move Section"><i class="vc-composer-icon vc-c-icon-dragndrop"></i>Section</span>
					</a>
					<a class="vc_control-btn vc_control-btn-prepend vc_edit" href="#" title="Prepend to Section"><span class="vc_btn-content"><i class="vc-composer-icon vc-c-icon-add"></i></span></a>
					<a class="vc_control-btn vc_control-btn-edit" href="#" title="Edit Section"><span class="vc_btn-content"><i class="vc-composer-icon vc-c-icon-mode_edit"></i></span></a>
					<a class="vc_control-btn vc_control-btn-clone" href="#" title="Clone Section"><span class="vc_btn-content"><i class="vc-composer-icon vc-c-icon-content_copy"></i></span></a>
					<a class="vc_control-btn vc_control-btn-delete" href="#" title="Delete Section"><span class="vc_btn-content"><i class="vc-composer-icon vc-c-icon-delete_empty"></i></span></a>
				</div>
			</div>
			
			
			<div class="wpb_column_container vc_container_for_children vc_clearfix vc_empty-container ui-droppable ui-sortable">
			{{ content }}
			</div>
		</div>',
	'default_content' => '',
) );

function mega_vc_tta_section_testimonials( $atts, $content = null ) {
	 extract(shortcode_atts(array(
		'image' => '',
		'img_size' => 'full',
		'img_width_svg' => '',
		'name' => '',
		'title' => '',
	), $atts));

global $mega_atts;

$img_id = preg_replace('/[^\d]/', '', $image);
$img = wpb_getImageBySize(array( 'attach_id' => $img_id, 'thumb_size' => $img_size ));
if ( $img == NULL ) $img['thumbnail'] = '';

if ( ! empty( $img['thumbnail'] ) ) {
	
	// Check file type
	$type = '';
	$type = get_post_mime_type( $img_id );
	$mime_type = explode( '/', $type );
	if ( ! isset( $mime_type['1'] ) ) {
	   $mime_type['1'] = null;
	}
	$type = $mime_type['1'];

	if ( ( array_key_exists( 'lazyload', $mega_atts ) ) && $mega_atts['lazyload'] != '' && $mega_atts['lazyload'] != '0' ) {
		$thumbnail_lazy = preg_replace( '/(<[^>]+) srcset=".*?"/i', '\1', $img['thumbnail'] );
		$thumbnail_lazy = preg_replace( '/(<[^>]+) sizes=".*?"/i', '\1', $thumbnail_lazy );
		$thumbnail_lazy = str_replace( 'src=', 'data-src=', $thumbnail_lazy );
		$thumbnail_lazy = str_replace( '/>', 'src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7">', $thumbnail_lazy );
		if ( in_array( $img_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full', ) ) ) {
			$image_src = wp_get_attachment_image_src( $img_id, $img_size );
			$width = $image_src[1];
			$height = $image_src[2];
		} else {
			$size = str_replace( 'x', ',', $img_size );
			$width = explode( ',', $size );
			$width = $width[0];
			$height = substr( $size, strpos( $size, "," ) + 1 );
		}
	}

	$image_src_full = wp_get_attachment_image_src( $img_id, 'full' );
	$attachment = get_post( $img_id );
	$attachment_title = apply_filters( 'the_title', $attachment->post_title );
	$attachment_caption = apply_filters( 'the_title', $attachment->post_excerpt );
	
}

$output = '';
$output .= '<div class="swiper-slide mt-testimonial">';

	
	if ( $mega_atts['style'] == '2' ) {
		
	
	$output .= '<div class="testimonial-content-name-title-wrapper">';
	
	$testimonials_image_data = wp_get_attachment_image_src( $img_id, $img_size );
	if ( ! empty( $img_width_svg ) ) {
		$output .= '<div class="testimonial-image-wrapper clearfix" style="max-width: '. esc_attr( $img_width_svg ) .'px;">';
	} else {
		$output .= '<div class="testimonial-image-wrapper clearfix" style="max-width: '. esc_attr( $testimonials_image_data[1] ) .'px;">';
	}
		if ( ! empty( $img_width_svg ) ) {
			if ( ! empty( $attachment_title ) ) {
				$output .= '<img class="svg-image" src="'. esc_url( $testimonials_image_data[0] ) .'" alt="'. esc_attr( $attachment_title ) .'" style="max-width: '. esc_attr( $img_width_svg ) .'px;" />';
			} else {
				$output .= '<img class="svg-image" src="'. esc_url( $testimonials_image_data[0] ) .'" style="max-width: '. esc_attr( $img_width_svg ) .'px;" />';
			}
		} else {
			$output .= '<img width="'. esc_attr( $testimonials_image_data[1] ) .'" height="'. esc_attr( $testimonials_image_data[2] ) .'" alt="'. esc_attr( $attachment_title ) .'" src="'. esc_url( $testimonials_image_data[0] ) .'" style="max-width: '. esc_attr( $testimonials_image_data[1] ) .'px;" />';
		}
	$output .= '</div>';
	
	
		$output .= '<div class="testimonial-wrapper">';
			$output .= ($content=='' || $content==' ') ? esc_html__("Empty section. Edit page to add content here.", 'mega') : "\n\t\t\t\t" . wpb_js_remove_wpautop($content);
        
		
				$output .= '<div class="testimonial-name-title-wrapper">';
					$output .= '<span class="testimonial-name">' . esc_html( $name ) . '</span>,';
					$output .= ' <span class="testimonial-title">' . esc_html( $title ) . '</span>';
				$output .= ' </div>';
		$output .= '</div>';		
	$output .= ' </div>';
	
	} else if ( $mega_atts['style'] == '3' ) {
		
		
		$output .= '<div class="testimonial-wrapper">';
			$output .= ($content=='' || $content==' ') ? esc_html__("Empty section. Edit page to add content here.", 'mega') : "\n\t\t\t\t" . wpb_js_remove_wpautop($content);
        $output .= '</div>';
		
        $output .= '<div class="testimonial-image-wrapper clearfix">';
		
		    $output .= $img['thumbnail'];
				$output .= '<div class="testimonial-name-title-wrapper">';
					$output .= '<span class="testimonial-name">' . esc_html( $name ) . '</span><br>';
					$output .= ' <span class="testimonial-title">' . esc_html( $title ) . '</span>';
				$output .= ' </div>';
		$output .= '</div>';
	
	
	} else if ( $mega_atts['style'] == '4' ) {
		
		$output .= '<div class="testimonial-content-name-title-wrapper">';
	
		if ( ! empty( $img['thumbnail'] ) ) {
		$output .= '<div class="testimonial-image-wrapper clearfix">';
			$testimonials_image_data = wp_get_attachment_image_src( $img_id, $img_size );
			if ($mega_atts['lazyload']!= '' && $mega_atts['lazyload']!= '0') {
				$output .= '<div class="thumbnail-wrapper lazy" style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';">';
					$output .= $thumbnail_lazy;
					$output .= '<span class="loaderbg"></span>';
				$output .= '</div>';
			} else {
				$output .= '<img width="'. esc_attr( $testimonials_image_data[1] ) .'" height="'. esc_attr( $testimonials_image_data[2] ) .'" alt="'. esc_attr( $attachment_title ) .'" src="'. esc_url( $testimonials_image_data[0] ) .'">';
			}
		$output .= '</div>';
		}
		
		
			$output .= '<div class="testimonial-wrapper">';
				$output .= ($content=='' || $content==' ') ? esc_html__("Empty section. Edit page to add content here.", 'mega') : "\n\t\t\t\t" . wpb_js_remove_wpautop($content);
			
			
					$output .= '<div class="testimonial-name-title-wrapper">';
						$output .= '<span class="testimonial-name">' . esc_html( $name ) . '</span>,';
						$output .= ' <span class="testimonial-title">' . esc_html( $title ) . '</span>';
					$output .= ' </div>';
			$output .= '</div>';		
		$output .= ' </div>';
		
	} else if ( $mega_atts['style'] == '5' ) {
		
		$output .= '<div class="testimonial-content-name-title-wrapper">';
		
			$output .= '<div class="testimonial-wrapper">';
				$output .= ($content=='' || $content==' ') ? esc_html__("Empty section. Edit page to add content here.", 'mega') : "\n\t\t\t\t" . wpb_js_remove_wpautop($content);
			$output .= '</div>';
		
			$output .= '<div class="testimonial-image-name-title-wrapper clearfix">';
				$output .= '<div class="testimonial-image-wrapper clearfix">';
					$output .= $img['thumbnail'];
				$output .= '</div>';
				
				$output .= '<div class="testimonial-name-title-wrapper">';
					$output .= '<span class="testimonial-name">' . esc_html( $name ) . '</span>';
					$output .= ' <span class="testimonial-title">' . esc_html( $title ) . '</span>';
				$output .= ' </div>';
			$output .= ' </div>';
				
		$output .= ' </div>';
		
	} else if ( $mega_atts['style'] == '6' ) {
		
		$output .= '<div class="testimonial-content-name-title-wrapper">';
	
		if ( ! empty( $img['thumbnail'] ) ) {
		$output .= '<div class="testimonial-image-wrapper clearfix">';
			$testimonials_image_data = wp_get_attachment_image_src( $img_id, $img_size );
			if ($mega_atts['lazyload']!= '' && $mega_atts['lazyload']!= '0') {
				$output .= '<div class="thumbnail-wrapper lazy" style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';">';
					$output .= $thumbnail_lazy;
					$output .= '<span class="loaderbg"></span>';
				$output .= '</div>';
			} else {
				$output .= $img['thumbnail'];
			}
		$output .= '</div>';
		}
		
		
			$output .= '<div class="testimonial-wrapper">';
				$output .= ($content=='' || $content==' ') ? esc_html__("Empty section. Edit page to add content here.", 'mega') : "\n\t\t\t\t" . wpb_js_remove_wpautop($content);
			
			
					$output .= '<div class="testimonial-name-title-wrapper">';
						$output .= '<span class="testimonial-name">' . esc_html( $name ) . '</span><br>';
						$output .= ' <span class="testimonial-title">' . esc_html( $title ) . '</span>';
					$output .= ' </div>';
			$output .= '</div>';		
		$output .= ' </div>';
		
		
	} else if ( $mega_atts['style'] == '7' ) {
		
		
		$output .= '<div class="testimonial-wrapper">';
			$output .= ($content=='' || $content==' ') ? esc_html__("Empty section. Edit page to add content here.", 'mega') : "\n\t\t\t\t" . wpb_js_remove_wpautop($content);
        $output .= '</div>';
	
	} else if ( $mega_atts['style'] == '8' ) {
	
		$output .= '<div class="testimonial-content-name-title-wrapper">';
	
		if ( ! empty( $img['thumbnail'] ) ) {
		$output .= '<div class="testimonial-image-wrapper clearfix">';
			if ($mega_atts['lazyload']!= '' && $mega_atts['lazyload']!= '0') {
				$output .= '<div class="thumbnail-wrapper lazy" style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';">';
					$output .= $thumbnail_lazy;
					$output .= '<span class="loaderbg"></span>';
				$output .= '</div>';
			} else {
				$output .= $img['thumbnail'];
			}
		$output .= '</div>';
		}
		
		
			$output .= '<div class="testimonial-wrapper">';
				$output .= '<div class="testimonial-name-title-content-wrapper">';
					$output .= '<div class="testimonial-name-title-wrapper">';
						$output .= '<span class="testimonial-name">' . esc_html( $name ) . '</span>,';
						$output .= ' <span class="testimonial-title">' . esc_html( $title ) . '</span>';
					$output .= ' </div>';
				
					$output .= ($content=='' || $content==' ') ? esc_html__("Empty section. Edit page to add content here.", 'mega') : "\n\t\t\t\t" . wpb_js_remove_wpautop($content);
				$output .= '</div>';
			$output .= '</div>';
		$output .= ' </div>';
	
	
	} else if ( $mega_atts['style'] == '9' ) {
	
		$output .= '<div class="testimonial-wrapper-helper">';
			$output .= '<div class="testimonial-wrapper">';
				$output .= ($content=='' || $content==' ') ? esc_html__("Empty section. Edit page to add content here.", 'mega') : "\n\t\t\t\t" . wpb_js_remove_wpautop($content);
			$output .= '</div>';
				
			$output .= '<div class="testimonial-image-wrapper clearfix">';
		
				$output .= $img['thumbnail'];
					$output .= '<div class="testimonial-name-title-wrapper">';
						$output .= '<div class="testimonial-name">' . esc_html( $name ) . '</div>';
						$output .= ' <span class="testimonial-title">' . esc_html( $title ) . '</span>';
					$output .= ' </div>';
			$output .= '</div>';
		$output .= '</div>';
	
	} else {
	
		$output .= '<div class="testimonial-wrapper">';
			$output .= ($content=='' || $content==' ') ? esc_html__("Empty section. Edit page to add content here.", 'mega') : "\n\t\t\t\t" . wpb_js_remove_wpautop($content);
        $output .= '</div>';
		
        $output .= '<div class="testimonial-image-wrapper clearfix">';
		
		    $output .= $img['thumbnail'];
				$output .= '<div class="testimonial-name-title-wrapper">';
					$output .= '<span class="testimonial-name">' . esc_html( $name ) . '</span>,';
					$output .= ' <span class="testimonial-title">' . esc_html( $title ) . '</span>';
				$output .= ' </div>';
		$output .= '</div>';
	
	}
		
    $output .= '</div>';

	return $output;
}
add_shortcode( 'vc_tta_section_testimonials', 'mega_vc_tta_section_testimonials' );

// Team Slider
class WPBakeryShortCode_VC_Tta_Team_Slider extends WPBakeryShortCodesContainer {
	protected $controls_css_settings = 'out-tc vc_controls-content-widget';
	protected $controls_list = array( 'add', 'edit', 'clone', 'delete' );
	protected $template_vars = array();

	public $layout = 'accordion';
	protected $content;

	public $activeClass = 'vc_active';
	/**
	 * @var WPBakeryShortCode_VC_Tta_Team_Slider_Section
	 */
	protected $sectionClass;

	public $nonDraggableClass = 'vc-non-draggable-container';

	public function getFileName() {
		return 'vc_tta_global_team_slider';
	}

	public function containerContentClass() {
		return 'vc_container_for_children vc_clearfix';
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 */
	public function resetVariables( $atts, $content ) {
		$this->atts = $atts;
		$this->content = $content;
		$this->template_vars = array();
	}

	public function setGlobalTtaInfo() {
		$sectionClass = visual_composer()->getShortCode( 'vc_tta_section_team_slider' )->shortcodeClass();
		$this->sectionClass = $sectionClass;

		/** @var $sectionClass WPBakeryShortCode_VC_Tta_Team_Slider_Section */
		if ( is_object( $sectionClass ) ) {
			VcShortcodeAutoloader::getInstance()->includeClass( 'WPBakeryShortCode_VC_Tta_Team_Slider_Section' );
			WPBakeryShortCode_VC_Tta_Team_Slider_Section::$tta_base_shortcode = $this;
			WPBakeryShortCode_VC_Tta_Team_Slider_Section::$self_count = 0;
			WPBakeryShortCode_VC_Tta_Team_Slider_Section::$section_info = array();

			return true;
		}

		return false;
	}

	/**
	 * Override default getColumnControls to make it "simple"(blue), as single element has
	 *
	 * @param string $controls
	 * @param string $extended_css
	 *
	 * @return string
	 */
	public function getColumnControls( $controls = 'full', $extended_css = '' ) {
		// we don't need containers bottom-controls for tabs
		if ( 'bottom-controls' === $extended_css ) {
			return '';
		}
		$column_controls = $this->getColumnControlsModular();

		return $output = $column_controls;
	}

	public function getTtaContainerClasses() {
		$classes = array();
		$classes[] = 'vc_tta-container';

		return implode( ' ', apply_filters( 'vc_tta_container_classes', array_filter( $classes ), $this->getAtts() ) );
	}

	public function getTtaGeneralClasses() {
		$classes = array();
		$classes[] = 'vc_general';
		$classes[] = 'vc_tta';
		$classes[] = 'vc_tta-' . $this->layout;
		$classes[] = $this->getTemplateVariable( 'color' );
		$classes[] = $this->getTemplateVariable( 'style' );
		$classes[] = $this->getTemplateVariable( 'shape' );
		$classes[] = $this->getTemplateVariable( 'spacing' );
		$classes[] = $this->getTemplateVariable( 'gap' );
		$classes[] = $this->getTemplateVariable( 'c_align' );
		$classes[] = $this->getTemplateVariable( 'no_fill' );
		if ( isset( $this->atts['collapsible_all'] ) && 'true' === $this->atts['collapsible_all'] ) {
			$classes[] = 'vc_tta-o-all-clickable';
		}

		$pagination = isset( $this->atts['pagination_style'] ) ? trim( $this->atts['pagination_style'] ) : false;
		if ( $pagination && 'none' !== $pagination && strlen( $pagination ) > 0 ) {
			$classes[] = 'vc_tta-has-pagination';
		}

		/**
		 * @since 4.6.2
		 */
		if ( isset( $this->atts['el_class'] ) ) {
			$classes[] = $this->atts['el_class'];
		}

		return implode( ' ', apply_filters( 'vc_tta_accordion_general_classes', array_filter( $classes ), $this->getAtts() ) );
	}

	public function getTtaPaginationClasses() {
		$classes = array();
		$classes[] = 'vc_general';
		$classes[] = 'vc_pagination';

		if ( isset( $this->atts['pagination_style'] ) && strlen( $this->atts['pagination_style'] ) > 0 ) {
			$chunks = explode( '-', $this->atts['pagination_style'] );
			$classes[] = 'vc_pagination-style-' . $chunks[0];
			$classes[] = 'vc_pagination-shape-' . $chunks[1];
		}

		if ( isset( $this->atts['pagination_color'] ) && strlen( $this->atts['pagination_color'] ) > 0 ) {
			$classes[] = 'vc_pagination-color-' . $this->atts['pagination_color'];
		}

		return implode( ' ', $classes );
	}

	public function getWrapperAttributes() {
		$attributes = array();
		$attributes[] = 'class="' . esc_attr( $this->getTtaContainerClasses() ) . '"';
		$attributes[] = 'data-vc-action="' . ( 'true' === $this->atts['collapsible_all'] ? 'collapseAll' : 'collapse' ) . '"';

		$autoplay = isset( $this->atts['autoplay'] ) ? trim( $this->atts['autoplay'] ) : false;
		if ( $autoplay && 'none' !== $autoplay && intval( $autoplay ) > 0 ) {
			$attributes[] = 'data-vc-tta-autoplay="' . esc_attr(
				json_encode(
					array(
							'delay' => intval( $autoplay ) * 1000,
						)
				)
			) . '"';
		}

		return implode( ' ', $attributes );
	}

	public function getTemplateVariable( $string ) {
		if ( isset( $this->template_vars[ $string ] ) ) {
			return $this->template_vars[ $string ];
		} elseif ( method_exists( $this, 'getParam' . vc_studly( $string ) ) ) {
			$this->template_vars[ $string ] = $this->{'getParam' . vc_studly( $string )}( $this->atts, $this->content );

			return $this->template_vars[ $string ];
		}

		return '';
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamColor( $atts, $content ) {
		if ( isset( $atts['color'] ) && strlen( $atts['color'] ) > 0 ) {
			return 'vc_tta-color-' . $atts['color'];
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamStyle( $atts, $content ) {
		if ( isset( $atts['style'] ) && strlen( $atts['style'] ) > 0 ) {
			return 'vc_tta-style-' . $atts['style'];
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamTitle( $atts, $content ) {
		if ( isset( $atts['title'] ) && strlen( $atts['title'] ) > 0 ) {
			return '<h2>' . $atts['title'] . '</h2>';
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamContent( $atts, $content ) {
		$panelsContent = wpb_js_remove_wpautop( $content );
		if ( isset( $atts['c_icon'] ) && strlen( $atts['c_icon'] ) > 0 ) {
			$isPageEditable = vc_is_page_editable();
			if ( ! $isPageEditable ) {
				$panelsContent = str_replace( '{{{ control-icon }}}',
					'<i class="vc_tta-controls-icon vc_tta-controls-icon-' . $atts['c_icon'] . '"></i>',
					$panelsContent
				);
			} else {
				$panelsContent = str_replace( '{{{ control-icon }}}',
					'<i class="vc_tta-controls-icon" data-vc-tta-controls-icon="' . $atts['c_icon'] . '"></i>',
					$panelsContent
				);
			}
		} else {
			$panelsContent = str_replace( '{{{ control-icon }}}',
				'',
			$panelsContent );
		}

		return $panelsContent;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamShape( $atts, $content ) {
		if ( isset( $atts['shape'] ) && strlen( $atts['shape'] ) > 0 ) {
			return 'vc_tta-shape-' . $atts['shape'];
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string
	 */
	public function getParamSpacing( $atts, $content ) {
		if ( isset( $atts['spacing'] ) && strlen( $atts['spacing'] ) > 0 ) {
			return 'vc_tta-spacing-' . $atts['spacing'];
		}

		// In case if no spacing set we need to append extra class
		return 'vc_tta-o-shape-group';
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamGap( $atts, $content ) {
		if ( isset( $atts['gap'] ) && strlen( $atts['gap'] ) > 0 ) {
			return 'vc_tta-gap-' . $atts['gap'];
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamNoFill( $atts, $content ) {
		if ( isset( $atts['no_fill'] ) && 'true' === $atts['no_fill'] ) {
			return 'vc_tta-o-no-fill';
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamCAlign( $atts, $content ) {
		if ( isset( $atts['c_align'] ) && strlen( $atts['c_align'] ) > 0 ) {
			return 'vc_tta-controls-align-' . $atts['c_align'];
		}

		return null;
	}

	/**
	 * Accordion doesn't have pagination
	 *
	 * @param $atts
	 * @param $content
	 *
	 * @return null
	 */
	public function getParamPaginationTop( $atts, $content ) {
		return null;
	}

	/**
	 * Accordion doesn't have pagination
	 *
	 * @param $atts
	 * @param $content
	 *
	 * @return null
	 */
	public function getParamPaginationBottom( $atts, $content ) {
		return null;
	}

	/**
	 * Get currently active section (from $atts)
	 *
	 * @param $atts
	 * @param bool $strict_bounds If true, check for min/max bounds
	 *
	 * @return int nth position (one-based) of active section
	 */
	function getActiveSection( $atts, $strict_bounds = false ) {
		$active_section = intval( $atts['active_section'] );

		if ( $strict_bounds ) {
			VcShortcodeAutoloader::getInstance()->includeClass( 'WPBakeryShortCode_VC_Tta_Team_Slider_Section' );
			if ( $active_section < 1 ) {
				$active_section = 1;
			} elseif ( $active_section > WPBakeryShortCode_VC_Tta_Team_Slider_Section::$self_count ) {
				$active_section = WPBakeryShortCode_VC_Tta_Team_Slider_Section::$self_count;
			}
		}

		return $active_section;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string
	 */
	public function getParamPaginationList( $atts, $content ) {
		if ( empty( $atts['pagination_style'] ) ) {
			return null;
		}
		$isPageEditabe = vc_is_page_editable();

		$sectionClass = $this->sectionClass;

		$html = array();
		$html[] = '<ul class="' . $this->getTtaPaginationClasses() . '">';

		if ( ! $isPageEditabe ) {
			VcShortcodeAutoloader::getInstance()->includeClass( 'WPBakeryShortCode_VC_Tta_Team_Slider_Section' );
			foreach ( WPBakeryShortCode_VC_Tta_Team_Slider_Section::$section_info as $nth => $section ) {
				$strict_bounds = ( 'vc_tta_tabs' === $this->shortcode );
				$active_section = $this->getActiveSection( $atts, $strict_bounds );

				$classes = array( 'vc_pagination-item' );
				if ( ( $nth + 1 ) === $active_section ) {
					$classes[] = $this->activeClass;
				}

				$a_html = '<a href="#' . $section['tab_id'] . '" class="vc_pagination-trigger" data-vc-tabs data-vc-container=".vc_tta"></a>';
				$html[] = '<li class="' . implode( ' ', $classes ) . '" data-vc-tab>' . $a_html . '</li>';
			}
		}

		$html[] = '</ul>';

		return implode( '', $html );
	}

	public function enqueueTtaScript() {		
		wp_enqueue_script( 'vc_accordion_script' );
		if ( ! vc_is_page_editable() ) {
			wp_enqueue_script( 'vc_tta_autoplay_script' );
		}
	}

	/**
	 * Override default outputTitle (also Icon). To remove anything, also Icon.
	 *
	 * @param $title - just for strict standards
	 *
	 * @return string
	 */
	protected function outputTitle( $title ) {
		return '';
	}
	/**
	 * Check is allowed to add another element inside current element.
	 *
	 * @since 4.8
	 *
	 * @return bool
	 */
	public function getAddAllowed() {
		return vc_user_access_check_shortcode_all( 'vc_tta_section_team_slider' );
	}
}

VcShortcodeAutoloader::getInstance()->includeClass( 'WPBakeryShortCode_VC_Tta_Team_Slider' );
class WPBakeryShortCode_VC_Tta_Team_Slider_Section extends WPBakeryShortCode_VC_Tta_Team_Slider {
	protected $controls_css_settings = 'tc vc_control-container';
	protected $controls_list = array( 'add', 'edit', 'clone', 'delete' );
	protected $backened_editor_prepend_controls = false;
	/**
	 * @var WPBakeryShortCode_VC_Tta_Team_Slider
	 */
	public static $tta_base_shortcode;
	public static $self_count = 0;
	public static $section_info = array();

	public function getFileName() {
		if ( isset( self::$tta_base_shortcode ) && 'vc_tta_pageable' === self::$tta_base_shortcode->getShortcode() ) {
			return 'vc_tta_pageable_section';
		} else {
			return 'vc_tta_section_team_slider';
		}
	}

	public function containerContentClass() {
		return 'wpb_column_container vc_container_for_children vc_clearfix';
	}

	public function getElementClasses() {
		$classes = array();
		$classes[] = 'vc_tta-panel';
		$isActive = ! vc_is_page_editable() && $this->getTemplateVariable( 'section-is-active' );

		if ( $isActive ) {
			$classes[] = $this->activeClass;
		}

		/**
		 * @since 4.6.2
		 */
		if ( isset( $this->atts['el_class'] ) ) {
			$classes[] = $this->atts['el_class'];
		}

		return implode( ' ', array_filter( $classes ) );
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string
	 */
	public function getParamContent( $atts, $content ) {
		return wpb_js_remove_wpautop( $content );
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamTabId( $atts, $content ) {
		if ( isset( $atts['tab_id'] ) && strlen( $atts['tab_id'] ) > 0 ) {
			return $atts['tab_id'];
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamTitle( $atts, $content ) {
		if ( isset( $atts['title'] ) && strlen( $atts['title'] ) > 0 ) {
			return $atts['title'];
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamIcon( $atts, $content ) {
		if ( ! empty( $atts['add_icon'] ) && 'true' === $atts['add_icon'] ) {
			$iconClass = '';
			if ( isset( $atts[ 'i_icon_' . $atts['i_type'] ] ) ) {
				$iconClass = $atts[ 'i_icon_' . $atts['i_type'] ];
			}
			vc_icon_element_fonts_enqueue( $atts['i_type'] );

			return '<i class="vc_tta-icon ' . esc_attr( $iconClass ) . '"></i>';
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamIconLeft( $atts, $content ) {
		if ( 'left' === $atts['i_position'] ) {
			return $this->getParamIcon( $atts, $content );
		}

		return null;
	}

	/**
	 * @param $atts
	 * @param $content
	 *
	 * @return string|null
	 */
	public function getParamIconRight( $atts, $content ) {
		if ( 'right' === $atts['i_position'] ) {
			return $this->getParamIcon( $atts, $content );
		}

		return null;
	}

	/**
	 * Section param active
	 */
	public function getParamSectionIsActive( $atts, $content ) {
		if ( is_object( self::$tta_base_shortcode ) ) {
			if ( isset( self::$tta_base_shortcode->atts['active_section'] ) && strlen( self::$tta_base_shortcode->atts['active_section'] ) > 0 ) {
				$active = (int) self::$tta_base_shortcode->atts['active_section'];
				if ( $active === self::$self_count ) {
					return true;
				}
			}
		}

		return null;
	}

	public function getParamControlIconPosition( $atts, $content ) {
		if ( is_object( self::$tta_base_shortcode ) ) {
			if (
				isset( self::$tta_base_shortcode->atts['c_icon'] ) && strlen( self::$tta_base_shortcode->atts['c_icon'] ) > 0 &&
				isset( self::$tta_base_shortcode->atts['c_position'] ) && strlen( self::$tta_base_shortcode->atts['c_position'] ) > 0
			) {
				$c_position = self::$tta_base_shortcode->atts['c_position'];

				return 'vc_tta-controls-icon-position-' . $c_position;
			}
		}

		return null;
	}

	public function getParamControlIcon( $atts, $content ) {
		if ( is_object( self::$tta_base_shortcode ) ) {
			if ( isset( self::$tta_base_shortcode->atts['c_icon'] ) && strlen( self::$tta_base_shortcode->atts['c_icon'] ) > 0 ) {
				$c_icon = self::$tta_base_shortcode->atts['c_icon'];

				return '<i class="vc_tta-controls-icon vc_tta-controls-icon-' . $c_icon . '"></i>';
			}
		}

		return null;
	}

	public function getParamHeading( $atts, $content ) {
		$isPageEditable = vc_is_page_editable();

		$h4attributes = array();
		$h4classes = array(
			'vc_tta-panel-title',
		);
		if ( $isPageEditable ) {
			$h4attributes[] = 'data-vc-tta-controls-icon-position=""';
		} else {
			$controlIconPosition = $this->getTemplateVariable( 'control-icon-position' );
			if ( $controlIconPosition ) {
				$h4classes[] = $controlIconPosition;
			}
		}
		$h4attributes[] = 'class="' . implode( ' ', $h4classes ) . '"';

		$output = '<h4 ' . implode( ' ', $h4attributes ) . '>'; // close h4

		if ( $isPageEditable ) {
			$output .= '<a href="javascript:;" data-vc-target=""';
			$output .= ' data-vc-tta-controls-icon-wrapper';
			$output .= ' data-vc-use-cache="false"';
		} else {
			$output .= '<a href="#' . esc_attr( $this->getTemplateVariable( 'tab_id' ) ) . '"';
		}

		$output .= ' data-vc-accordion';

		$output .= ' data-vc-container=".vc_tta-container">';
		$output .= $this->getTemplateVariable( 'icon-left' );
		$output .= '<span class="vc_tta-title-text">'
		           . $this->getTemplateVariable( 'title' )
		           . '</span>';
		$output .= $this->getTemplateVariable( 'icon-right' );
		if ( ! $isPageEditable ) {
			$output .= $this->getTemplateVariable( 'control-icon' );
		}

		$output .= '</a>';
		$output .= '</h4>'; // close h4 fix #2229

		return $output;
	}

	/**
	 * Get basic heading
	 *
	 * These are used in Pageable element inside content and are hidden from view
	 *
	 * @param $atts
	 * @param $content
	 *
	 * @return string
	 */
	public function getParamBasicHeading( $atts, $content ) {
		$isPageEditable = vc_is_page_editable();

		if ( $isPageEditable ) {
			$attributes = array(
				'href' => 'javascript:;',
				'data-vc-container' => '.vc_tta-container',
				'data-vc-accordion' => '',
				'data-vc-target' => '',
				'data-vc-tta-controls-icon-wrapper' => '',
				'data-vc-use-cache' => 'false',
			);
		} else {
			$attributes = array(
				'data-vc-container' => '.vc_tta-container',
				'data-vc-accordion' => '',
				'data-vc-target' => esc_attr( '#' . $this->getTemplateVariable( 'tab_id' ) ),
			);
		}

		$output = '
			<span class="vc_tta-panel-title">
				<a ' . vc_convert_atts_to_string( $attributes ) . '></a>
			</span>
		';

		return $output;
	}
	/**
	 * Check is allowed to add another element inside current element.
	 *
	 * @since 4.8
	 *
	 * @return bool
	 */
	public function getAddAllowed() {
		return  vc_user_access()
			->part( 'shortcodes' )
			->checkStateAny( true, 'custom', null )->get();
	}
}

vc_map( array(
  'name' => esc_html__( 'Team Slider MT', 'mega' ),
  'base' => 'vc_tta_team_slider',
  'icon' => 'icon-wpb-ui-accordion',
  'is_container' => true,
  'show_settings_on_create' => true,
  'as_parent' => array(
	'only' => 'vc_tta_section_team_slider',
  ),
  'category' => esc_html__( 'Content', 'mega' ),
  'weight' => 0,
  'params' => array(
	array(
		'type' => 'checkbox',
		'heading' => esc_html__( 'Enable lazyload', 'mega' ),
		'param_name' => 'lazyload',
		'description' => esc_html__( 'Select lazyload if you want image to be loaded when it enters into the browsers viewport.', 'mega' ),
		'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
	),
    array(
      'type' => 'textfield',
      'heading' => esc_html__( "Extra class name", 'mega' ),
      'param_name' => 'el_class',
      'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'mega' ),
    ),
  ),
  'js_view' => 'VcBackendTtaAccordionTeamSliderView',
  'custom_markup' => '
  <div class="vc_tta-container" data-vc-action="collapseAll">
	<div class="vc_general vc_tta vc_tta-accordion vc_tta-color-backend-accordion-white vc_tta-style-flat vc_tta-shape-rounded vc_tta-o-shape-group vc_tta-controls-align-left vc_tta-gap-2">
	   <div class="vc_tta-panels vc_clearfix {{container-class}}">
	      {{ content }}
	      <div class="vc_tta-panel vc_tta-section-append">
	         <div class="vc_tta-panel-heading">
	            <h4 class="vc_tta-panel-title vc_tta-controls-icon-position-left">
	               <a href="javascript:;" aria-expanded="false" class="vc_tta-backend-add-control">
	                   <span class="vc_tta-title-text">' . esc_html__( 'Add Section', 'mega' ) . '</span>
	                    <i class="vc_tta-controls-icon vc_tta-controls-icon-plus"></i>
					</a>
	            </h4>
	         </div>
	      </div>
	   </div>
	</div>
  </div>',
  'default_content' => '[vc_tta_section_team_slider title="' . sprintf( '%s %d', esc_html__( 'Section', 'mega' ), 1 ) . '"][/vc_tta_section_team_slider][vc_tta_section_team_slider title="' . sprintf( '%s %d', esc_html__( 'Section', 'mega' ), 2 ) . '"][/vc_tta_section_team_slider]',
) );

vc_map( array(
	'name' => esc_html__( 'Section MT', 'mega' ),
	'base' => 'vc_tta_section_team_slider',
	'icon' => 'icon-wpb-ui-tta-section',
	'allowed_container_element' => 'vc_column_text',
	'is_container' => true,
	'show_settings_on_create' => false,
	'as_child' => array(
		'only' => 'vc_tta_team_slider',
	),
	'as_parent' => array(
		'only' => 'vc_column_text',
	),
	'category' => esc_html__( 'Content', 'mega' ),
	'weight' => 0,
	'description' => esc_html__( 'Section for Tabs, Tours, Accordions.', 'mega' ),
	'params' => array(
		 array(
		  'type' => 'attach_image',
		  'heading' => esc_html__( 'Image', 'mega' ),
		  'param_name' => 'image',
		  'value' => '',
		  'description' => esc_html__( 'Select image from media library.', 'mega' ),
		),
		 array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Image size', 'mega' ),
		  'param_name' => 'img_size',
		  'description' => esc_html__( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "thumbnail" size.', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Name', 'mega' ),
		  'param_name' => 'name',
		  'description' => esc_html__( 'Enter person name.', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Title', 'mega' ),
		  'param_name' => 'title',
		  'description' => esc_html__( 'Enter person title.', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Twitter Address (URL)', 'mega' ),
		  'param_name' => 'twitter',
		  'description' => esc_html__( 'Twitter Address (URL)', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Facebook Address (URL)', 'mega' ),
		  'param_name' => 'facebook',
		  'description' => esc_html__( 'Facebook Address (URL)', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Dribbble Address (URL)', 'mega' ),
		  'param_name' => 'dribbble',
		  'description' => esc_html__( 'Dribbble Address (URL)', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'LinkedIn Address (URL)', 'mega' ),
		  'param_name' => 'linkedin',
		  'description' => esc_html__( 'LinkedIn Address (URL)', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Pinterest Address (URL)', 'mega' ),
		  'param_name' => 'pinterest',
		  'description' => esc_html__( 'Pinterest Address (URL)', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Instagram Address (URL)', 'mega' ),
		  'param_name' => 'instagram',
		  'description' => esc_html__( 'Instagram Address (URL)', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Flickr Address (URL)', 'mega' ),
		  'param_name' => 'flickr',
		  'description' => esc_html__( 'Flickr Address (URL)', 'mega' ),
		),
		array(
		  'type' => 'textfield',
		  'heading' => esc_html__( 'Tumblr Address (URL)', 'mega' ),
		  'param_name' => 'tumblr',
		  'description' => esc_html__( 'Tumblr Address (URL)', 'mega' ),
		),
	  ),
	'js_view' => 'VcBackendTtaSectionView',
	'custom_markup' => '
		<div class="vc_tta-panel-heading">
		    <h4 class="vc_tta-panel-title vc_tta-controls-icon-position-left"><a href="javascript:;" data-vc-target="[data-model-id=\'{{ model_id }}\']" data-vc-accordion data-vc-container=".vc_tta-container"><span class="vc_tta-title-text">{{ section_title }}</span><i class="vc_tta-controls-icon vc_tta-controls-icon-plus"></i></a></h4>
		</div>
		<div class="vc_tta-panel-body">
			
			
			<div class="vc_controls">
				<div class="vc_controls-tc vc_control-container">
					<a class="vc_control-btn vc_element-name vc_element-move">
						<span class="vc_btn-content" title="Drag to move Section"><i class="vc-composer-icon vc-c-icon-dragndrop"></i>Section</span>
					</a>
					<a class="vc_control-btn vc_control-btn-prepend vc_edit" href="#" title="Prepend to Section"><span class="vc_btn-content"><i class="vc-composer-icon vc-c-icon-add"></i></span></a>
					<a class="vc_control-btn vc_control-btn-edit" href="#" title="Edit Section"><span class="vc_btn-content"><i class="vc-composer-icon vc-c-icon-mode_edit"></i></span></a>
					<a class="vc_control-btn vc_control-btn-clone" href="#" title="Clone Section"><span class="vc_btn-content"><i class="vc-composer-icon vc-c-icon-content_copy"></i></span></a>
					<a class="vc_control-btn vc_control-btn-delete" href="#" title="Delete Section"><span class="vc_btn-content"><i class="vc-composer-icon vc-c-icon-delete_empty"></i></span></a>
				</div>
			</div>
			
			
			<div class="wpb_column_container vc_container_for_children vc_clearfix vc_empty-container ui-droppable ui-sortable">
			{{ content }}
			</div>
		</div>',
	'default_content' => '',
) );

function mega_vc_tta_section_team_slider( $atts, $content = null ) {
	 extract( shortcode_atts( array(
		'image' => '',
		'img_size' => 'full',
		'name' => '',
		'title' => '',
		'twitter' => '',
		'facebook' => '',
		'dribbble' => '',
		'linkedin' => '',
		'pinterest' => '',
		'instagram' => '',
		'flickr' => '',
		'tumblr' => '',
	), $atts ) );

global $mega_atts;

$img_id = preg_replace('/[^\d]/', '', $image);
$img = wpb_getImageBySize(array( 'attach_id' => $img_id, 'thumb_size' => $img_size ));
if ( $img == NULL ) $img['thumbnail'] = '';

if ( ! empty( $img['thumbnail'] ) ) {
	if ($mega_atts['lazyload']!= '' && $mega_atts['lazyload']!= '0') {
		$thumbnail_lazy = preg_replace('/(<[^>]+) srcset=".*?"/i', '\1', $img['thumbnail']);
		$thumbnail_lazy = preg_replace('/(<[^>]+) sizes=".*?"/i', '\1', $thumbnail_lazy);
		$thumbnail_lazy = str_replace('src=', 'data-src=', $thumbnail_lazy);
		$thumbnail_lazy = str_replace('/>', 'src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7">', $thumbnail_lazy);
		if ( in_array( $img_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full', ) ) ) {
			$image_src = wp_get_attachment_image_src( $img_id, $img_size );
			$width = $image_src[1];
			$height = $image_src[2];
		} else {
			$size = str_replace('x', ',', $img_size);
			$width = explode(',', $size);
			$width = $width[0];
			$height = substr($size, strpos($size, ",") + 1);
		}
	}
}

$output = '';
$output .= '<div class="mt-team-slider-person-wrapper">';
$output .= '<div class="mt-team-slider-person clearfix">';
		
		$output .= '<div class="team-slider-person-wrapper">';
			
			$output .= '<div class="team-slider-person-name-title-wrapper">';
				$output .= '<div class="team-slider-person-name"><h3>' . esc_html( $name ) . '</h3></div>';
				$output .= ' <span class="team-slider-person-title">' . esc_html( $title ) . '</span>';
			$output .= ' </div>';
			
			$output .= ($content=='' || $content==' ') ? esc_html__("Empty section. Edit page to add content here.", 'mega') : "\n\t\t\t\t" . wpb_js_remove_wpautop($content);
		
			$output .= '<ul class="clearfix">';
				
				if ( ! empty( $twitter ) ) {
					$output .= '<li><a class="social twitter" href="' . esc_url( $twitter ) . '" target="_blank">';
						$output .= '<span class="social-icon"></span>';
					$output .= '</a></li>';
				}
				
				if ( ! empty( $facebook ) ) {
					$output .= '<li><a class="social facebook" href="' . esc_url( $facebook ) . '" target="_blank">';
						$output .= '<span class="social-icon"></span>';
					$output .= '</a></li>';
				}
				
				if ( ! empty( $dribbble ) ) {
					$output .= '<li><a class="social dribbble" href="' . esc_url( $dribbble ) . '" target="_blank">';
						$output .= '<span class="social-icon"></span>';
					$output .= '</a></li>';
				}
									
				if ( ! empty( $linkedin ) ) {
					$output .= '<li><a class="social linkedin" href="' . esc_url( $linkedin ) . '" target="_blank">';
						$output .= '<span class="social-icon"></span>';
					$output .= '</a></li>';
				}
								
				if ( ! empty( $pinterest ) ) {
					$output .= '<li><a class="social pinterest" href="' . esc_url( $pinterest ) . '" target="_blank">';
						$output .= '<span class="social-icon"></span>';
					$output .= '</a></li>';
				}
								
				if ( ! empty( $instagram ) ) {
					$output .= '<li><a class="social instagram" href="' . esc_url( $instagram ) . '" target="_blank">';
						$output .= '<span class="social-icon"></span>';
					$output .= '</a></li>';
				}
								
				if ( ! empty( $flickr ) ) {
					$output .= '<li><a class="social flickr" href="' . esc_url( $flickr ) . '" target="_blank">';
						$output .= '<span class="social-icon"></span>';
					$output .= '</a></li>';
				}
								
				if ( ! empty( $tumblr ) ) {
					$output .= '<li><a class="social tumblr" href="' . esc_url( $tumblr ) . '" target="_blank">';
						$output .= '<span class="social-icon"></span>';
					$output .= '</a></li>';
				}
								
			$output .= '</ul>';

		$output .= '</div>';
	   
		$output .= '<div class="team-slider-person-image-wrapper clearfix">';
		$output .= '<div class="team-slider-person-image clearfix">';
		
			if ( ! empty( $img['thumbnail'] ) ) {
				if ($mega_atts['lazyload']!= '' && $mega_atts['lazyload']!= '0') {
					$output .= '<div class="thumbnail-wrapper lazy" style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';">';
						$output .= $thumbnail_lazy;
						$output .= '<span class="loaderbg"></span>';
					$output .= '</div>';
				} else {
					$output .= $img['thumbnail'];
				}
			}
		$output .= '</div>';
		$output .= '</div>';
		
    $output .= '</div>';
	$output .= '</div>';

	return $output;
}
add_shortcode( 'vc_tta_section_team_slider', 'mega_vc_tta_section_team_slider' );

// Icon Box MT
function mt_vc_icon_box( $atts, $content = null ) {
	 extract( shortcode_atts( array(
		'image' => '',
		'name' => '',
		'img_size' => 'thumbnail',
		'id' => '',
		'title' => '',
		'content' => $content,
		'icon_name' => '',
		'icon_color' => '',
		'style' => '1',
		'custom_link' => '',
		'button_title' => '',
		'css_animation' => '',
		'svg_animation' => '',
		'css_class' => '',
	), $atts ) );
	
	$img_id = preg_replace('/[^\d]/', '', $image);
	$img = wpb_getImageBySize(array( 'attach_id' => $img_id, 'thumb_size' => $img_size ));
	if ( $img == NULL ) $img['thumbnail'] = '';
	
	if ( ! empty( $img['thumbnail'] ) ) {
		// Check file type
		$type = '';
		$type =  get_post_mime_type( $img_id );
		$mime_type = explode('/', $type);
		if ( ! isset($mime_type['1'])) {
		   $mime_type['1'] = null;
		}
		$type = $mime_type['1'];
		
		// Get image URL
		$src = wp_get_attachment_image_src( $img_id, 'full', false );
	}
		
	if ( $css_animation != '' ) {
        wp_enqueue_script( 'waypoints' );
		if ( $svg_animation != '' ) {
			$svg_animation_class = 'svg-animation-enabled';
			wp_enqueue_script( 'vivus' );
		} else {
			$svg_animation_class = 'svg-animation-disabled';
		}
		if ( $type = 'svg+xml' ) {
			$CSSAnimation = 'mt_animate_when_almost_visible mt_'.$css_animation;
		} else {
			$CSSAnimation = ' wpb_animate_when_almost_visible wpb_'.$css_animation;
		}
    } else {
		$CSSAnimation = 'no-animation';
		$svg_animation_class = 'svg-animation-disabled';
	}
	
	if ( $style == '1' ) {
		$style_class = 'marketing-tour-1';
	} else if ( $style == '2' ) {
		$style_class = 'marketing-tour-2';
	} else if ( $style == '3' ) {
		$style_class = 'marketing-tour-3';
	} else if ( $style == '4' ) {
		$style_class = 'marketing-tour-4';
	} else if ( $style == '5' ) {
		$style_class = 'marketing-tour-5';
	} else if ( $style == '6' ) {
		$style_class = 'marketing-tour-6';
	} else if ( $style == '7' ) {
		$style_class = 'marketing-tour-7';
	} else if ( $style == '8' ) {
		$style_class = 'marketing-tour-8';
	} else if ( $style == '9' ) {
		$style_class = 'marketing-tour-9';
	} else if ( $style == '10' ) {
		$style_class = 'marketing-tour-10';
	} else if ( $style == '11' ) {
		$style_class = 'marketing-tour-11';
	} else {
		$style_class = 'marketing-tour-12';
	}
	
	$output = '';
	if ( $style == '10' ) {
		$output .= '<a class="marketing-tour-wrapper clearfix '. esc_attr( $CSSAnimation ) .' '. esc_attr( $svg_animation_class ) .' '. esc_attr( $style_class ) .' '. esc_attr( $css_class ) .'" href="'. esc_url( $custom_link ).'">';
		$output .='<div>';
		
			$output .= '<span class="marketing-tour">';
				if ( ! empty( $icon_name ) ) {
					if ( $icon_color == NULL ) {
						$output .= '<span class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon"></span>';
					} else {
						$output .= '<span class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon" style="color: '. esc_attr( $icon_color ) .';"></span>';
					}
				}
				
			$output .= '</span>';
			
			if ( ! empty( $title ) ) {
				$output .= '<h3>'. esc_html( $title ) .'</h3>';
			}
			
			$output .='<div class="marketing-tour-content-wpb-button-wrapper">';
				if ( ! empty( $content ) ) {
					$output .= '<div class="marketing-tour-content">' . wpb_js_remove_wpautop($content, true) . '</div>';
				}
				
				if ( ! empty( $custom_link ) ) {
				$output .='<div class="vc_btn3-container special-button-2 vc_btn3-left">';
					$output .='<span class="wpb_button_a"><span>'. esc_html( $button_title ) .'</span></span>';
				$output .='</div>';
				}
			$output .='</div><!-- .marketing-tour-content-wpb-button-wrapper -->';
		$output .='</div>';
		$output .= '</a><!-- .marketing-tour-wrapper -->';
	
	
	
	} else if ( $style == '11' ) {
	
		
		$output .= '<div class="marketing-tour-wrapper clearfix '. esc_attr( $CSSAnimation ) .' '. esc_attr( $svg_animation_class ) .' '. esc_attr( $style_class ) .' '. esc_attr( $css_class ) .'">';
		
		$output .= '<div class="marketing-tour-title-wrapper">';
			$output .= '<span class="marketing-tour">';
				if ( ! empty( $icon_name ) ) {
					if ( $icon_color == NULL ) {
						$output .= '<span class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon"></span>';
					} else {
						$output .= '<span class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon" style="color: '. esc_attr( $icon_color ) .';"></span>';
					}
				} else {
					if ( $type == 'svg+xml' ) {
						$output .= '<object id="marketing-tour-icon-animated-' . esc_attr( $id ) . '" class="svg-icon" type="image/svg+xml" data="'. esc_url( $src[0] ) .'"></object>';
					} else {
						$output .= $img['thumbnail'];
					}
				}
				
			$output .= '</span>';
		
			if ( ! empty( $title ) ) {
				$output .= '<h3>'. esc_html( $title ) .'</h3>';
			}
		$output .= '</div>';
		
		if ( ! empty( $content ) ) {
			$output .= '<div class="marketing-tour-content">' . wpb_js_remove_wpautop($content, true) . '</div>';
		}
		$output .= '</div><!-- .marketing-tour-wrapper -->';
	
	
	} else if ( $style == '12' ) {
		
		
		$output .= '<div class="marketing-tour-wrapper clearfix '. esc_attr( $CSSAnimation ) .' '. esc_attr( $svg_animation_class ) .' '. esc_attr( $style_class ) .' '. esc_attr( $css_class ) .'">';
		
		$output .= '<div class="marketing-tour-title-wrapper">';
		
			if ( ! empty( $title ) ) {
				$output .= '<h2>'. esc_html( $title ) .'</h2>';
			}
		
			$output .= '<span class="marketing-tour">';
				if ( ! empty( $icon_name ) ) {
					if ( $icon_color == NULL ) {
						$output .= '<div class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon"></div>';
					} else {
						$output .= '<div class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon" style="color: '. esc_attr( $icon_color ) .';"></div>';
					}
				} else {
					if ( ! empty( $img['thumbnail'] ) ) {
						if ( $type == 'svg+xml' ) {
							$output .= '<object id="marketing-tour-icon-animated-' . esc_attr( $id ) . '" class="svg-icon" type="image/svg+xml" data="'. esc_url( $src[0] ) .'"></object>';
						} else {
							$output .= $img['thumbnail'];
						}
					}
				}
				
			$output .= '</span>';
		$output .= '</div>';
		
		if ( ! empty( $content ) ) {
			$output .= '<div class="marketing-tour-content">' . wpb_js_remove_wpautop($content, true) . '</div>';
		}
		$output .= '</div><!-- .marketing-tour-wrapper -->';
	
	
	} else {
		$output .= '<div class="marketing-tour-wrapper clearfix '. esc_attr( $CSSAnimation ) .' '. esc_attr( $svg_animation_class ) .' '. esc_attr( $style_class ) .' '. esc_attr( $css_class ) .'">';
		if ( $style == '8' ) {
		$output .= '<div class="marketing-tour-content-wrapper">';
		}
		
		$output .= '<span class="marketing-tour">';
			if ( ! empty( $icon_name ) ) {
				if ( $icon_color == NULL ) {
					$output .= '<span class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon"></span>';
				} else {
					$output .= '<span class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon" style="color: '. esc_attr( $icon_color ) .';"></span>';
				}
			} else {
				if ( ! empty( $img['thumbnail'] ) ) {
					if ( $type == 'svg+xml' ) {
						if ( ! empty( $id ) ) {
							$id = 'id="marketing-tour-icon-animated-'. esc_attr( $id ) .'"';
						}
						$output .= '<img'. esc_attr( $id ) .' class="svg-icon style-svg" src="'. esc_url( $src[0] ) .'"/>';
					} else {
						$output .= $img['thumbnail'];
					}
				}
			}
			
			if ( ! empty( $title ) ) {
				$output .= '<h3>'. esc_html( $title ) .'</h3>';
			}
			
		$output .= '</span>';
		
		if ( ! empty( $content ) ) {
			$output .= '<div class="marketing-tour-content">' . wpb_js_remove_wpautop($content, true) . '</div>';
		}
		
		if ( $style == '8' ) {
		$output .= '</div><!-- .marketing-tour-content-wrapper -->';
		}
		
		if ( ! empty( $custom_link ) ) {
		$output .='<div class="wpb-button-wrapper clearfix">';
			$output .='<a class="wpb_button_a" href="'. esc_url( $custom_link ).'"><span>'. esc_html( $button_title ) .'</span></a>';
		$output .='</div>';
		}
		$output .= '</div><!-- .marketing-tour-wrapper -->';
	}

	return $output;
}
add_shortcode( 'mt_vc_icon_box', 'mt_vc_icon_box' );

vc_map( array(
  'name' => esc_html__( 'Icon Box MT', 'mega' ),
  'base' => 'mt_vc_icon_box',
  'icon' => 'icon-wpb-vc-mt',
  'category' => esc_html__( 'Content', 'mega' ),
  'weight' => 0,
  'params' => array(
     array(
      'type' => 'attach_image',
      'heading' => esc_html__( 'Image', 'mega' ),
      'param_name' => 'image',
      'value' => '',
      'description' => esc_html__( 'Select image from media library.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Image size', 'mega' ),
      'param_name' => 'img_size',
      'description' => esc_html__( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "thumbnail" size.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Id', 'mega' ),
      'param_name' => 'id',
      'description' => esc_html__( 'Enter id.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Title', 'mega' ),
      'param_name' => 'title',
      'description' => esc_html__( 'Enter title.', 'mega' ),
    ),
    array(
      'type' => 'textarea_html',
      'holder' => 'div',
      'heading' => esc_html__( 'Text', 'mega' ),
      'param_name' => 'content',
      'value' => esc_html__( 'I am text block. Click edit button to change this text.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Icon name', 'mega' ),
      'param_name' => 'icon_name',
      'description' => sprintf( esc_html__( 'If you wish to use font icons, then use this field to add an icon name. You will need to install WordPress Icons - SVG plugin first. More at %s.', 'mega' ), '<a href="https://wordpress.org/plugins/svg-vector-icon-plugin/" target="_blank">WordPress Icons - SVG</a>' ),
    ),
	array(
	  'type' => 'colorpicker',
	  'heading' => esc_html__( 'Icon color', 'mega' ),
	  'param_name' => 'icon_color',
	  'value' => NULL,
	  'description' => esc_html__( 'Choose a value for icon color.', 'mega' ),
	),
	array(
      'type' => 'dropdown',
      'heading' => esc_html__( 'Style', 'mega' ),
      'param_name' => 'style',
	  'value' => array( 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 ),
      'description' => esc_html__( 'Select marketing tour style.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Custom link', 'mega' ),
      'param_name' => 'custom_link',
      'description' => esc_html__( 'Enter link for marketing tour.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Button title', 'mega' ),
      'param_name' => 'button_title',
      'description' => esc_html__( 'Enter button title for marketing tour.', 'mega' ),
    ),
	$add_css_animation = array(
		'type' => 'dropdown',
		'heading' => esc_html__( 'CSS Animation', 'mega' ),
		'param_name' => 'css_animation',
		'value' => array(
			esc_html__( 'No', 'mega' ) => '',
			esc_html__( 'Bottom to top', 'mega' ) => 'bottom-to-top',
		),
		'description' => esc_html__( 'Select type of animation if you want this element to be animated when it enters into the browsers viewport. Note: Works only in modern browsers.', 'mega' ),
	),
	array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Enable SVG animation', 'mega' ),
		  'param_name' => 'svg_animation',
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Extra class name', 'mega' ),
      'param_name' => 'css_class',
      'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'mega' ),
    ),
  ),
) );

// Content Slider MT
function mt_vc_content_carousel( $atts, $content = null ) {
	 extract( shortcode_atts( array(
			'items' => '3',
			'items_on_small_screens' => '3',
			'navigation' => '',
			'slide_by' => 'by_page',
			'navigation_style' => '1',
			'dots' => '',
			'center' => '',
			'animation' => '',
			'fade' => '',
			'loop' => '',
			'margin' => '',
			'linked' => '',
			'el_class' => '',
		), $atts ) );
	
	if ( $items == 1 ) {
		wp_enqueue_script( 'slick' );
		wp_enqueue_script( 'slick-init' );
	} else {
		wp_enqueue_script('mt-owl-carousel-container');
	}
	
	if ($linked!= '' && $linked!= '0'){
		wp_enqueue_script('owl-linked');
		wp_localize_script( 'mega-init', 'megaCarousel', array( 'el_class' => $el_class ) );
	}
	
	if ($navigation!= '' && $navigation!= '0'){
		$navigation = 'true';
	} else {
		$navigation = 'false';
	}
	
	if ($dots!= '' && $dots!= '0'){
		$dots = 'true';
	} else {
		$dots = 'false';
	}
	
	if ($center!= '' && $center!= '0'){
		$center = 'true';
	} else {
		$center = 'false';
	}
	
	if ($animation!= '' && $animation!= '0') {
		wp_enqueue_script( 'waypoints' );
		$animation = 'mt-animate_when_almost_visible-enabled';
	} else {
		$animation = 'mt-animate_when_almost_visible-disabled';
	}
	
	if ($fade!= '' && $fade!= '0'){
		$fade = 'true';
	} else {
		$fade = 'false';
	}
	
	if ($loop!= '' && $loop!= '0'){
		$loop = 'false';
	} else {
		$loop = 'true';
	}
	
	if ($linked!= '' && $linked!= '0'){
		$linked = 'true';
	} else {
		$linked = 'false';
	}
	
	$output = '';
	
	if ( $items == 1 ) {

	$output .= '<div class="mt-slick-slider-container-wrapper '. esc_attr( $css_class ) .'">';
	$output .= '<div class="mt-slick-slider-container nav-'. esc_attr( $navigation ) .' nav-style-'. esc_attr( $navigation_style ) .' slide-by-'. esc_attr( $slide_by ) .' margin-'. esc_attr( $margin ) .' '. esc_attr( $fade ) .' '. esc_attr( $CSSAnimation ) .' '. esc_attr( $lazyload ) .'" data-items="'. esc_attr( $items ) .'" data-items-on-small-screens="'. esc_attr( $items_on_small_screens ) .'" data-nav="'. esc_attr( $navigation ) .'" data-dots="'. esc_attr( $dots ) .'" data-margin="'. esc_attr( $margin ) .'">';

	} else {
		
		$output .= '<div class="mt-owl-carousel-container-wrapper">';
		$output .= '<div class="mt-owl-carousel-container owl-mt-theme nav-'. esc_attr( $navigation ) .' nav-style-'. esc_attr( $navigation_style ) .' center-'. esc_attr( $center ) .' '. esc_attr( $animation ) .' fade-'. esc_attr( $fade ) .' loop-'. esc_attr( $loop ) .' linked-'. esc_attr( $linked ) .' '. esc_attr( $el_class ) .'" data-items="'. esc_attr( $items ) .'" data-items-on-small-screens="'. esc_attr( $items_on_small_screens ) .'" data-nav="'. esc_attr( $navigation ) .'" data-dots="'. esc_attr( $dots ) .'" data-center="'. esc_attr( $center ) .'">';
			
	}
		
		$output .= wpb_js_remove_wpautop($content);
	$output .= '</div>';
	$output .= '</div>';

	return $output;
}
add_shortcode( 'mt_vc_content_carousel', 'mt_vc_content_carousel' );

vc_map( array(
    'name' => esc_html__( 'Content Slider MT', 'mega' ),
    'base' => 'mt_vc_content_carousel',
    'as_parent' => array( 'only' => 'mt_vc_testimonial, mt_vc_person, vc_column_text, product_page' ), // Use only|except attributes to limit child shortcodes (separate multiple values with comma)
    'content_element' => true,
    'show_settings_on_create' => true,
    'is_container' => true,
    'params' => array(
        // add params same as with any other content element
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Items number', 'mega' ),
			'param_name' => 'items',
			'value' => array( 3, 1, 2, 4 ),
			'description' => esc_html__( 'The number of items you want to see on the screen.', 'mega' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Items number on small screens', 'mega' ),
			'param_name' => 'items_on_small_screens',
			'value' => array( 3, 1, 2, 4 ),
			'description' => esc_html__( 'The number of items on small screens you want to see on the screen.', 'mega' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Navigation', 'mega' ),
		  'param_name' => 'navigation',
		  'description' => esc_html__( 'Show next/prev buttons.', 'mega' ),
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Slide by', 'mega' ),
			'param_name' => 'slide_by',
			'value' => array( esc_html__( 'By page', 'mega' ) => 'by_page', 1 ),
			'description' => esc_html__( 'Navigation slide by x.', 'mega' ),
			'dependency' => array(
				'element' => 'navigation',
				'not_empty' => true,
			),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Navigation style', 'mega' ),
			'param_name' => 'navigation_style',
			'value' => array( 1, 2 ),
			'description' => esc_html__( 'Select style for navigation.', 'mega' ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Dots', 'mega' ),
		  'param_name' => 'dots',
		  'description' => esc_html__( 'Show dots navigation.', 'mega' ),
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Center', 'mega' ),
		  'param_name' => 'center',
		  'description' => esc_html__( 'Center item.', 'mega' ),
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Enable animation', 'mega' ),
		  'param_name' => 'animation',
		  'description' => esc_html__( 'Select animation if you want active carousel item to be animated when it enters into the browsers viewport.', 'mega' ),
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Enable linked', 'mega' ),
		  'param_name' => 'linked',
		  'description' => esc_html__( 'Select linked if you want carousel to be synced with another one. Note: extra class name "linked-carousel" must be entered for the second carousel.', 'mega' ),
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Enable fade', 'mega' ),
		  'param_name' => 'fade',
		  'description' => esc_html__( 'Select fade if you want carousel to be fade.', 'mega' ),
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
		array(
		  'type' => 'checkbox',
		  'heading' => esc_html__( 'Disable loop', 'mega' ),
		  'param_name' => 'loop',
		  'description' => esc_html__( 'Inifnity loop. Duplicate last and first items to get loop illusion.', 'mega' ),
		  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
		),
        array(
            'type' => 'textfield',
            'heading' => esc_html__( 'Extra class name', 'mega' ),
            'param_name' => 'el_class',
            'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'mega' ),
        ),
    ),
    'js_view' => 'VcColumnView'
) );

// Testimonial MT
function mt_vc_testimonial( $atts, $content = null ) {
	 extract( shortcode_atts( array(
		'image' => '',
		'img_size' => 'thumbnail',
		'content' => $content,
		'name' => '',
		'title' => '',
		'style' => '1',
		'css_class' => '',
	), $atts ) );
	
	$img_id = preg_replace('/[^\d]/', '', $image);
	$img = wpb_getImageBySize(array( 'attach_id' => $img_id, 'thumb_size' => $img_size ));
	if ( $img == NULL ) $img['thumbnail'] = '';
	
	if ( $style == '2' ) {
		$testimonial_single_style_class = 'testimonial-single-style-2';
	} else  if ( $style == '3' ) {
		$testimonial_single_style_class = 'testimonial-single-style-3';
	} else {
		$testimonial_single_style_class = 'testimonial-single-style-1';
	}
	
	$output = '';
	
	if ( $style == '2' ) {
	
		$output .= '<div class="testimonial-single-wrapper '. esc_attr( $testimonial_single_style_class ) .' '. esc_attr( $css_class ) .'">';
			$output .= '<div class="testimonial-single">';
				$output .= '<div class="testimonial-single-content">' . wpb_js_remove_wpautop($content, true) . '</div>';
					$output .= '<div class="testimonial-single-name-title-wrapper">';
					if ( !empty( $name ) ) {
					$output .= '<span class="testimonial-single-name">' . esc_html( $name ) . '</span>';
					}
					if ( !empty( $title ) ) {
					$output .= ',';
					$output .= ' <span class="testimonial-single-title">' . esc_html( $title ) . '</span>';
					}
				$output .= '</div><!-- .testimonial-single-name-title-wrapper -->';
					if ( !empty( $img ) ) {
						$output .= '<div class="testimonial-single-image-wrapper clearfix">';
						   $output .= $img['thumbnail'];
						$output .= ' </div><!-- .testimonial-single-image-wrapper -->';
					}
			$output .= '</div><!-- .testimonial-single -->';
		$output .= '</div>';
	
	} else {
		
		$output .= '<div class="testimonial-single-wrapper '. esc_attr( $testimonial_single_style_class ) .' '. esc_attr( $css_class ) .'">';
			$output .= '<div class="testimonial-single">';
				$output .= '<div class="testimonial-single-name-title-wrapper">';
					if ( !empty( $name ) ) {
					$output .= '<span class="testimonial-single-name">' . esc_html( $name ) . '</span>';
					}
					if ( !empty( $title ) ) {
					$output .= ',';
					$output .= ' <span class="testimonial-single-title">' . esc_html( $title ) . '</span>';
					}
				$output .= '</div><!-- .testimonial-single-name-title-wrapper -->';
				$output .= '<div class="testimonial-single-content">' . wpb_js_remove_wpautop($content, true) . '</div>';
					if ( !empty( $img ) ) {
						$output .= '<div class="testimonial-single-image-wrapper clearfix">';
						   $output .= $img['thumbnail'];
						$output .= ' </div><!-- .testimonial-single-image-wrapper -->';
					}
			$output .= '</div><!-- .testimonial-single -->';
		$output .= '</div>';
		
	}

	return $output;
}
add_shortcode( 'mt_vc_testimonial', 'mt_vc_testimonial' );

vc_map( array(
  'name' => esc_html__( 'Testimonial MT', 'mega' ),
  'base' => 'mt_vc_testimonial',
  'content_element' => true,
  'icon' => 'icon-wpb-vc-mt',
  'category' => esc_html__( 'Content', 'mega' ),
  'weight' => 0,
  'params' => array(
     array(
      'type' => 'attach_image',
      'heading' => esc_html__( 'Image', 'mega' ),
      'param_name' => 'image',
      'value' => '',
      'description' => esc_html__( 'Select image from media library.', 'mega' ),
    ),
	 array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Image size', 'mega' ),
      'param_name' => 'img_size',
      'description' => esc_html__( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "thumbnail" size.', 'mega' ),
    ),
    array(
      'type' => 'textarea_html',
      'holder' => 'div',
      'heading' => esc_html__( 'Text', 'mega' ),
      'param_name' => 'content',
      'value' => esc_html__( 'I am text block. Click edit button to change this text.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Name', 'mega' ),
      'param_name' => 'name',
      'description' => esc_html__( 'Enter person name.', 'mega' ),
    ),
    array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Title', 'mega' ),
      'param_name' => 'title',
      'description' => esc_html__( 'Enter person title.', 'mega' ),
    ),
	array(
		'type' => 'dropdown',
		'heading' => esc_html__( 'Testimonial style', 'mega' ),
		'param_name' => 'style',
		'value' => array( 1, 2, 3 ),
		'description' => esc_html__( 'Select style for testimonial.', 'mega' ),
	),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Extra class name', 'mega' ),
      'param_name' => 'css_class',
      'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'mega' ),
    ),
  ),
) );

// Person MT
function mt_vc_person( $atts, $content = null ) {
	 extract( shortcode_atts( array(
		'image' => '',
		'name' => '',
		'img_size' => 'thumbnail',
		'style' => '1',
		'title' => '',
		'content' => $content,
		'person_url' => '',
		'facebook' => '',
		'twitter' => '',
		'linkedin' => '',
		'dribbble' => '',
		'pinterest' => '',
		'instagram' => '',
		'flickr' => '',
		'tumblr' => '',
		'lazyload' => '',
		'css_class' => '',
	), $atts ) );
		
	$img_id = preg_replace('/[^\d]/', '', $image);
	$img = wpb_getImageBySize(array( 'attach_id' => $img_id, 'thumb_size' => $img_size ));
	if ( $img == NULL ) $img['thumbnail'] = '';
	
	if ($lazyload!= '' && $lazyload!= '0' && ! empty( $img['thumbnail'] ) ) {
		$thumbnail_lazy = preg_replace('/(<[^>]+) srcset=".*?"/i', '\1', $img['thumbnail']);
		$thumbnail_lazy = preg_replace('/(<[^>]+) sizes=".*?"/i', '\1', $thumbnail_lazy);
		$thumbnail_lazy = str_replace('src=', 'data-src=', $thumbnail_lazy);
		$thumbnail_lazy = str_replace('/>', 'src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7">', $thumbnail_lazy);
		if ( in_array( $img_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full', ) ) ) {
			$image_src = wp_get_attachment_image_src( $img_id, $img_size );
			$width = $image_src[1];
			$height = $image_src[2];
		} else {
			$size = str_replace('x', ',', $img_size);
			$width = explode(',', $size);
			$width = $width[0];
			$height = substr($size, strpos($size, ",") + 1);
		}
	}
	
	if ( $style == '2' ) {
		$person_style_class = 'person-style-2';
	} else  if ( $style == '3' ) {
		$person_style_class = 'person-style-3';
	} else  if ( $style == '4' ) {
		$person_style_class = 'person-style-4';
	} else  if ( $style == '5' ) {
		$person_style_class = 'person-style-5';
	} else  if ( $style == '6' ) {
		$person_style_class = 'person-style-6';
	} else  if ( $style == '7' ) {
		$person_style_class = 'person-style-7';
	} else {
		$person_style_class = 'person-style-1';
	}
	
	$output = '';
	
	if ( $style == '2' ) {
	
		if ( !empty( $person_url ) ) {
		$output .= '<a href="'. esc_url( $person_url ) .'" target="_blank" class="person '. esc_attr( $person_style_class ) .' '. esc_attr( $css_class ) .'">';
		} else {
		$output .= '<div class="person '. esc_attr( $person_style_class ) .' '. esc_attr( $css_class ) .'">';
		}
		if ( !empty( $img ) ) {
		$output .= '<div class="person-img-wrapper clearfix">';
			if ($lazyload!= '' && $lazyload!= '0' && ! empty( $img['thumbnail'] ) ) {
				$output .= '<div class="thumbnail-wrapper lazy" style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';">';
					$output .= $thumbnail_lazy;
					$output .= '<span class="loaderbg"></span>';
				$output .= '</div>';
			} else {
				$output .= $img['thumbnail'];
			}
		$output .= '</div>';
		}
			$output .= '<div class="person-desc-wrapper">';
			$output .= '<div>';
			$output .= '<div class="person-desc">';
				$output .= '<div class="person-author clearfix">';
					if ( ! empty( $content ) ) {
					$output .= '<div class="person-content">' . wpb_js_remove_wpautop($content, true) . '</div>';
					}
					if ( ! empty( $name ) ) {
					$output .= '<div class="person-author-wrapper"><h3 class="person-name">' . esc_html( $name ) . '</h3>, ';
					}
					if ( ! empty( $title ) ) {
					$output .= '<span class="person-title">' . esc_html( $title ) . '</span></div>';
					}
				$output .= '</div>';
				
				$output .= '<ul class="clearfix">';
						
					if ( ! empty( $twitter ) ) {
						$output .= '<li><a class="social twitter" href="' . esc_url( $twitter ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $facebook ) ) {
						$output .= '<li><a class="social facebook" href="' . esc_url( $facebook ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
						
					if ( ! empty( $linkedin ) ) {
						$output .= '<li><a class="social linkedin" href="' . esc_url( $linkedin ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
						
					if ( ! empty( $dribbble ) ) {
						$output .= '<li><a class="social dribbble" href="' . esc_url( $dribbble ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $pinterest ) ) {
						$output .= '<li><a class="social pinterest" href="' . esc_url( $pinterest ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $instagram ) ) {
						$output .= '<li><a class="social instagram" href="' . esc_url( $instagram ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $flickr ) ) {
						$output .= '<li><a class="social flickr" href="' . esc_url( $flickr ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $tumblr ) ) {
						$output .= '<li><a class="social tumblr" href="' . esc_url( $tumblr ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
				$output .= '</ul>';
			$output .= '</div>';
			$output .= '</div>';
			$output .= '</div>';
		if ( !empty( $person_url ) ) {
		$output .= '</a>';
		} else {
		$output .= '</div>';
		}
		
	} else if ( $style == '3' ) {
		
		$output .= '<div class="person '. esc_attr( $person_style_class ) .' '. esc_attr( $css_class ) .'">';
		if ( !empty( $img ) ) {
		$output .= '<div class="person-img-wrapper clearfix">';
			if ($lazyload!= '' && $lazyload!= '0' && ! empty( $img['thumbnail'] ) ) {
				$output .= '<div class="thumbnail-wrapper lazy" style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';">';
					$output .= $thumbnail_lazy;
					$output .= '<span class="loaderbg"></span>';
				$output .= '</div>';
			} else {
				$output .= $img['thumbnail'];
			}
		$output .= '</div>';
		}
			$output .= '<div class="person-desc-wrapper">';
			$output .= '<div class="person-desc">';
				$output .= '<div class="person-author clearfix">';
					if ( ! empty( $name ) ) {
					$output .= '<div class="person-author-wrapper"><h3 class="person-name">' . esc_html( $name ) . '</h3>';
					}
					if ( ! empty( $title ) ) {
					$output .= '<span class="person-title">' . esc_html( $title ) . '</span></div>';
					}
				$output .= '</div>';
				if ( ! empty( $content ) ) {
				$output .= '<div class="person-content">' . wpb_js_remove_wpautop($content, true) . '</div>';
				}
				
				$output .= '<ul class="clearfix">';
				
				if ( ! empty( $twitter ) ) {
					$output .= '<li><a class="social twitter" href="' . esc_url( $twitter ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $facebook ) ) {
					$output .= '<li><a class="social facebook" href="' . esc_url( $facebook ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
						
				if ( ! empty( $linkedin ) ) {
					$output .= '<li><a class="social linkedin" href="' . esc_url( $linkedin ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
						
				if ( ! empty( $dribbble ) ) {
					$output .= '<li><a class="social dribbble" href="' . esc_url( $dribbble ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $pinterest ) ) {
					$output .= '<li><a class="social pinterest" href="' . esc_url( $pinterest ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $instagram ) ) {
					$output .= '<li><a class="social instagram" href="' . esc_url( $instagram ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $flickr ) ) {
					$output .= '<li><a class="social flickr" href="' . esc_url( $flickr ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $tumblr ) ) {
					$output .= '<li><a class="social tumblr" href="' . esc_url( $tumblr ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
			$output .= '</ul>';
			$output .= '</div>';
			$output .= '</div>';
		$output .= '</div>';
	
	} else if ( $style == '4' ) {
		
		$output .= '<div class="person '. esc_attr( $person_style_class ) .' '. esc_attr( $css_class ) .'">';
		if ( !empty( $img ) ) {
		$output .= '<div class="person-img-wrapper clearfix">';
			if ($lazyload!= '' && $lazyload!= '0' && ! empty( $img['thumbnail'] ) ) {
				$output .= '<div class="thumbnail-wrapper lazy" style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';">';
					$output .= $thumbnail_lazy;
					$output .= '<span class="loaderbg"></span>';
				$output .= '</div>';
			} else {
				$output .= $img['thumbnail'];
			}
		$output .= '</div>';
		}
			$output .= '<div class="person-desc-wrapper">';
			$output .= '<div>';
			$output .= '<div class="person-desc-bg"></div>';
			$output .= '<div class="person-desc">';
				$output .= '<div class="person-author clearfix">';
					if ( ! empty( $title ) ) {
					$output .= '<span class="person-title">' . esc_html( $title ) . '</span></div>';
					}
					if ( ! empty( $name ) ) {
					$output .= '<div class="person-author-wrapper"><h3 class="person-name">' . esc_html( $name ) . '</h3>';
					}
				$output .= '</div>';
				
				$output .= '<ul class="clearfix">';
				
					if ( ! empty( $twitter ) ) {
						$output .= '<li><a class="social twitter" href="' . esc_url( $twitter ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $facebook ) ) {
						$output .= '<li><a class="social facebook" href="' . esc_url( $facebook ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
						
					if ( ! empty( $linkedin ) ) {
						$output .= '<li><a class="social linkedin" href="' . esc_url( $linkedin ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
						
					if ( ! empty( $dribbble ) ) {
						$output .= '<li><a class="social dribbble" href="' . esc_url( $dribbble ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $pinterest ) ) {
						$output .= '<li><a class="social pinterest" href="' . esc_url( $pinterest ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $instagram ) ) {
						$output .= '<li><a class="social instagram" href="' . esc_url( $instagram ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $flickr ) ) {
						$output .= '<li><a class="social flickr" href="' . esc_url( $flickr ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $tumblr ) ) {
						$output .= '<li><a class="social tumblr" href="' . esc_url( $tumblr ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
				$output .= '</ul>';
			$output .= '</div>';
			$output .= '</div>';
			$output .= '</div>';
		$output .= '</div>';
		
	} else if ( $style == '5' ) {
		
		$output .= '<div class="person '. esc_attr( $person_style_class ) .' '. esc_attr( $css_class ) .'">';
		if ( !empty( $img ) ) {
		$output .= '<div class="person-img-wrapper clearfix">';
			if ($lazyload!= '' && $lazyload!= '0' && ! empty( $img['thumbnail'] ) ) {
				$output .= '<div class="thumbnail-wrapper lazy" style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';">';
					$output .= $thumbnail_lazy;
					$output .= '<span class="loaderbg"></span>';
				$output .= '</div>';
			} else {
				$output .= $img['thumbnail'];
			}
		$output .= '</div>';
		}
			$output .= '<div class="person-desc-wrapper">';
			$output .= '<div class="person-desc">';
				$output .= '<div class="person-author clearfix">';
					if ( ! empty( $title ) ) {
					$output .= '<span class="person-title">' . esc_html( $title ) . '</span></div>';
					}
					if ( ! empty( $name ) ) {
					$output .= '<div class="person-author-wrapper"><h3 class="person-name">' . esc_html( $name ) . '</h3></div>';
					}
				$output .= '</div>';
				if ( ! empty( $content ) ) {
				$output .= '<div class="person-content">' . wpb_js_remove_wpautop($content, true) . '</div>';
				}
				
				$output .= '<ul class="clearfix">';
				
					if ( ! empty( $twitter ) ) {
						$output .= '<li><a class="social twitter" href="' . esc_url( $twitter ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $facebook ) ) {
						$output .= '<li><a class="social facebook" href="' . esc_url( $facebook ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
						
					if ( ! empty( $linkedin ) ) {
						$output .= '<li><a class="social linkedin" href="' . esc_url( $linkedin ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
						
					if ( ! empty( $dribbble ) ) {
						$output .= '<li><a class="social dribbble" href="' . esc_url( $dribbble ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $pinterest ) ) {
						$output .= '<li><a class="social pinterest" href="' . esc_url( $pinterest ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $instagram ) ) {
						$output .= '<li><a class="social instagram" href="' . esc_url( $instagram ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $flickr ) ) {
						$output .= '<li><a class="social flickr" href="' . esc_url( $flickr ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $tumblr ) ) {
						$output .= '<li><a class="social tumblr" href="' . esc_url( $tumblr ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
				$output .= '</ul>';
			$output .= '</div>';
			$output .= '</div>';
		$output .= '</div>';
		
	} else if ( $style == '6' ) {
		
		if ( !empty( $person_url ) ) {
		$output .= '<a href="'. esc_url( $person_url ) .'" target="_blank" class="person '. esc_attr( $person_style_class ) .' '. esc_attr( $css_class ) .'">';
		} else {
		$output .= '<div class="person '. esc_attr( $person_style_class ) .' '. esc_attr( $css_class ) .'">';
		}
		if ( !empty( $img ) ) {
		$output .= '<div class="person-img-wrapper clearfix">';
			if ( $lazyload != '' && $lazyload != '0' && ! empty( $img['thumbnail'] ) ) {
				$output .= '<div class="thumbnail-wrapper lazy" style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';">';
					$output .= $thumbnail_lazy;
					$output .= '<span class="loaderbg"></span>';
				$output .= '</div>';
			} else {
				$output .= $img['thumbnail'];
			}
		$output .= '</div>';
		}
			$output .= '<div class="person-desc-wrapper">';
			$output .= '<div class="person-desc">';
				$output .= '<div class="person-author clearfix">';
					if ( ! empty( $name ) ) {
					$output .= '<div class="person-author-wrapper"><h3 class="person-name">' . esc_html( $name ) . '</h3>';
					}
					if ( ! empty( $title ) ) {
					$output .= '<span class="person-title">' . esc_html( $title ) . '</span></div>';
					}
				$output .= '</div>';
				if ( ! empty( $content ) ) {
				$output .= '<div class="person-content">' . wpb_js_remove_wpautop($content, true) . '</div>';
				}
				
				$output .= '<ul class="clearfix">';
				
				if ( ! empty( $twitter ) ) {
					$output .= '<li><a class="social twitter" href="' . esc_url( $twitter ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $facebook ) ) {
					$output .= '<li><a class="social facebook" href="' . esc_url( $facebook ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
						
				if ( ! empty( $linkedin ) ) {
					$output .= '<li><a class="social linkedin" href="' . esc_url( $linkedin ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
						
				if ( ! empty( $dribbble ) ) {
					$output .= '<li><a class="social dribbble" href="' . esc_url( $dribbble ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $pinterest ) ) {
					$output .= '<li><a class="social pinterest" href="' . esc_url( $pinterest ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $instagram ) ) {
					$output .= '<li><a class="social instagram" href="' . esc_url( $instagram ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $flickr ) ) {
					$output .= '<li><a class="social flickr" href="' . esc_url( $flickr ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $tumblr ) ) {
					$output .= '<li><a class="social tumblr" href="' . esc_url( $tumblr ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
			$output .= '</ul>';
			$output .= '</div>';
			$output .= '</div>';
		if ( !empty( $person_url ) ) {
		$output .= '</a>';
		} else {
		$output .= '</div>';
		}
		
	} else if ( $style == '7' ) {
	
		if ( !empty( $person_url ) ) {
		$output .= '<a href="'. esc_url( $person_url ) .'" target="_blank" class="person '. esc_attr( $person_style_class ) .' '. esc_attr( $css_class ) .'">';
		} else {
		$output .= '<div class="person '. esc_attr( $person_style_class ) .' '. esc_attr( $css_class ) .'">';
		}
		if ( !empty( $img ) ) {
		$output .= '<div class="person-img-wrapper clearfix">';
			if ($lazyload!= '' && $lazyload!= '0' && ! empty( $img['thumbnail'] ) ) {
				$output .= '<div class="thumbnail-wrapper lazy" style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';">';
					$output .= $thumbnail_lazy;
					$output .= '<span class="loaderbg"></span>';
				$output .= '</div>';
			} else {
				$output .= $img['thumbnail'];
			}
		$output .= '</div>';
		}
			$output .= '<div class="person-desc-wrapper">';
			$output .= '<div>';
			$output .= '<div class="person-desc">';
				$output .= '<div class="person-author clearfix">';
					if ( ! empty( $title ) ) {
					$output .= '<span class="person-title">' . esc_html( $title ) . '</span></div>';
					}
					if ( ! empty( $name ) ) {
					$output .= '<div class="person-author-wrapper"><h3 class="person-name">' . esc_html( $name ) . '</h3>';
					}
					if ( ! empty( $content ) ) {
					$output .= '<div class="person-content">' . wpb_js_remove_wpautop($content, true) . '</div>';
					}
				$output .= '</div>';
				
				$output .= '<ul class="clearfix">';
						
					if ( ! empty( $twitter ) ) {
						$output .= '<li><a class="social twitter" href="' . esc_url( $twitter ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $facebook ) ) {
						$output .= '<li><a class="social facebook" href="' . esc_url( $facebook ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
						
					if ( ! empty( $linkedin ) ) {
						$output .= '<li><a class="social linkedin" href="' . esc_url( $linkedin ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
						
					if ( ! empty( $dribbble ) ) {
						$output .= '<li><a class="social dribbble" href="' . esc_url( $dribbble ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $pinterest ) ) {
						$output .= '<li><a class="social pinterest" href="' . esc_url( $pinterest ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $instagram ) ) {
						$output .= '<li><a class="social instagram" href="' . esc_url( $instagram ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $flickr ) ) {
						$output .= '<li><a class="social flickr" href="' . esc_url( $flickr ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
					if ( ! empty( $tumblr ) ) {
						$output .= '<li><a class="social tumblr" href="' . esc_url( $tumblr ) . '" target="_blank">
							<span class="social-icon"></span>
						</a></li>';
					}
					
				$output .= '</ul>';
			$output .= '</div>';
			$output .= '</div>';
			$output .= '</div>';
		if ( !empty( $person_url ) ) {
		$output .= '</a>';
		} else {
		$output .= '</div>';
		}
	
	} else {
	
		$output .= '<div class="person '. esc_attr( $person_style_class ) .' '. esc_attr( $css_class ) .'">';
		if ( !empty( $img ) ) {
		$output .= '<div class="person-img-wrapper clearfix">';
			if ($lazyload!= '' && $lazyload!= '0' && ! empty( $img['thumbnail'] ) ) {
				$output .= '<div class="thumbnail-wrapper lazy" style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';">';
					$output .= $thumbnail_lazy;
					$output .= '<span class="loaderbg"></span>';
				$output .= '</div>';
			} else {
				$output .= $img['thumbnail'];
			}
			
			$output .= '<div class="person-bg"></div>';
			
			$output .= '<div class="person-view-wrapper">';
			$output .= '<div class="person-view-content">';
			$output .= '<div class="person-view-animate">';
			$output .= '<ul class="clearfix">';
				
				if ( ! empty( $twitter ) ) {
					$output .= '<li><a class="social twitter" href="' . esc_url( $twitter ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $facebook ) ) {
					$output .= '<li><a class="social facebook" href="' . esc_url( $facebook ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
						
				if ( ! empty( $linkedin ) ) {
					$output .= '<li><a class="social linkedin" href="' . esc_url( $linkedin ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
						
				if ( ! empty( $dribbble ) ) {
					$output .= '<li><a class="social dribbble" href="' . esc_url( $dribbble ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $pinterest ) ) {
					$output .= '<li><a class="social pinterest" href="' . esc_url( $pinterest ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $instagram ) ) {
					$output .= '<li><a class="social instagram" href="' . esc_url( $instagram ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $flickr ) ) {
					$output .= '<li><a class="social flickr" href="' . esc_url( $flickr ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
				if ( ! empty( $tumblr ) ) {
					$output .= '<li><a class="social tumblr" href="' . esc_url( $tumblr ) . '" target="_blank">
						<span class="social-icon"></span>
					</a></li>';
				}
					
			$output .= '</ul>';
			$output .= '</div>';
			$output .= '</div>';
			$output .= '</div>';
		$output .= '</div>';
		}
			$output .= '<div class="person-desc-wrapper">';
			$output .= '<div>';
			$output .= '<div class="person-desc-bg"></div>';
			$output .= '<div class="person-desc">';
				$output .= '<div class="person-author clearfix">';
					if ( ! empty( $title ) ) {
					$output .= '<span class="person-title">' . esc_html( $title ) . '</span></div>';
					}
					if ( ! empty( $name ) ) {
					$output .= '<div class="person-author-wrapper"><h3 class="person-name">' . esc_html( $name ) . '</h3>';
					}
				$output .= '</div>';
				if ( ! empty( $content ) ) {
				$output .= '<div class="person-content">' . wpb_js_remove_wpautop($content, true) . '</div>';
				}
				
			$output .= '</div>';
			$output .= '</div>';
			$output .= '</div>';
		$output .= '</div>';
	
	}

	return $output;
}
add_shortcode( 'mt_vc_person', 'mt_vc_person' );

vc_map( array(
  'name' => esc_html__( 'Person MT', 'mega' ),
  'base' => 'mt_vc_person',
  'icon' => 'icon-wpb-vc-mt',
  'category' => esc_html__( 'Content', 'mega' ),
  'weight' => 0,
  'params' => array(
     array(
      'type' => 'attach_image',
      'heading' => esc_html__( 'Image', 'mega' ),
      'param_name' => 'image',
      'value' => '',
      'description' => esc_html__( 'Select image from media library.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Image size', 'mega' ),
      'param_name' => 'img_size',
      'description' => esc_html__( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "thumbnail" size.', 'mega' ),
    ),
	array(
		'type' => 'dropdown',
		'heading' => esc_html__( 'Person style', 'mega' ),
		'param_name' => 'style',
		'value' => array( 1, 2, 3, 4, 5, 6, 7 ),
		'description' => esc_html__( 'Select style for person.', 'mega' ),
	),
    array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Name', 'mega' ),
      'param_name' => 'name',
      'description' => esc_html__( 'Enter person name.', 'mega' ),
    ),
    array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Title', 'mega' ),
      'param_name' => 'title',
      'description' => esc_html__( 'Enter person title.', 'mega' ),
    ),
    array(
      'type' => 'textarea_html',
      'holder' => 'div',
      'heading' => esc_html__( 'Text', 'mega' ),
      'param_name' => 'content',
      'value' => esc_html__( 'I am text block. Click edit button to change this text.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Person URL', 'mega' ),
      'param_name' => 'person_url',
      'description' => esc_html__( 'Enter person URL.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Twitter Address (URL)', 'mega' ),
      'param_name' => 'twitter',
      'description' => esc_html__( 'Twitter Address (URL)', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Facebook Address (URL)', 'mega' ),
      'param_name' => 'facebook',
      'description' => esc_html__( 'Facebook Address (URL)', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'LinkedIn Address (URL)', 'mega' ),
      'param_name' => 'linkedin',
      'description' => esc_html__( 'LinkedIn Address (URL)', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Dribbble Address (URL)', 'mega' ),
      'param_name' => 'dribbble',
      'description' => esc_html__( 'Dribbble Address (URL)', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Pinterest Address (URL)', 'mega' ),
      'param_name' => 'pinterest',
      'description' => esc_html__( 'Pinterest Address (URL)', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Instagram Address (URL)', 'mega' ),
      'param_name' => 'instagram',
      'description' => esc_html__( 'Instagram Address (URL)', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Flickr Address (URL)', 'mega' ),
      'param_name' => 'flickr',
      'description' => esc_html__( 'Flickr Address (URL)', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Tumblr Address (URL)', 'mega' ),
      'param_name' => 'tumblr',
      'description' => esc_html__( 'Tumblr Address (URL)', 'mega' ),
    ),
	array(
		'type' => 'checkbox',
		'heading' => esc_html__( 'Enable lazyload', 'mega' ),
		'param_name' => 'lazyload',
		'description' => esc_html__( 'Select lazyload if you want image to be loaded when it enters into the browsers viewport.', 'mega' ),
		'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
	),
	array(
	  'type' => 'textfield',
	  'heading' => esc_html__( 'Extra class name', 'mega' ),
	  'param_name' => 'css_class',
	  'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'mega' ),
	),
  ),
) );

//Your "container" content element should extend WPBakeryShortCodesContainer class to inherit all required functionality
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_VC_Content_Carousel extends WPBakeryShortCodesContainer {
    }
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_Testimonial extends WPBakeryShortCode {
    }
}

if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_Person extends WPBakeryShortCode {
    }
}

// Counting MT
function mt_vc_counting( $atts, $content = null ) {
	wp_enqueue_script( 'waypoints' );
	wp_enqueue_script( 'countUp' );

	 extract( shortcode_atts( array(
		'number' => '',
		'caption' => '',
		'id' => '',
		'image' => '',
		'img_size' => 'full',
		'icon_name' => '',
		'icon_color' => '',
		'units' => '',
		'style' => '',
		'animation' => '',
	), $atts ) );
	
	$img_id = preg_replace( '/[^\d]/', '', $image );
	$img = wpb_getImageBySize(array( 'attach_id' => $img_id, 'thumb_size' => $img_size ));
	
	if ( !empty( $units ) ) {
		$units = '<span class="count-value">' . esc_html( $units ) . '</span>';
	}
	
	if ( $style == '2' ) {
		$style_class = 'counting-style-2';
	} else if ( $style == '3' ) {
		$style_class = 'counting-style-3';
	} else if ( $style == '4' ) {
		$style_class = 'counting-style-4';
	} else if ( $style == '5' ) {
		$style_class = 'counting-style-5';
	} else if ( $style == '6' ) {
		$style_class = 'counting-style-6';
	} else {
		$style_class = 'counting-style-1';
	}
	
	if ($animation!= '' && $animation!= '0') {
		wp_enqueue_script( 'waypoints' );
		$animation = 'mt-animate_when_almost_visible-enabled';
	} else {
		$animation = 'mt-animate_when_almost_visible-disabled';
	}
	
	$output = '';
	
	if ( $style == '2' ) {
	
		$output .= '<div class="count-wrapper '. esc_attr( $style_class ) .' '.esc_attr( $animation ) .'" data-count="count-'. esc_attr( $id ) .'" data-end="' . esc_attr( $number ) .'">';
			$output .= '<div class="count-caption-wrapper">';
				if ( ! empty( $icon_name ) ) {
					if ( $icon_color == NULL ) {
						$output .= '<div class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon"></div>';
					} else {
						$output .= '<div class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon" style="color: '. esc_attr( $icon_color ) .';"></div>';
					}
				} else {
						$output .= $img['thumbnail'];
				}
				$output .= '<span class="count-caption">' . esc_html( $caption ) . '</span>';
			$output .= '</div>';
			
			$output .= '<span class="count-value" id="count-' . esc_attr( $id ) . '">0</span>'. $units;
		$output .= '</div>';
		
	} else if ( $style == '3' ) {
		
		$output .= '<div class="count-wrapper '. esc_attr( $style_class ) .' '. esc_attr( $animation ) .'" data-count="count-'. esc_attr( $id ) .'" data-end="' . esc_attr( $number ) .'">';
			if ( ! empty( $icon_name ) ) {
				if ( $icon_color == NULL ) {
					$output .= '<div class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon"></div>';
				} else {
					$output .= '<div class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon" style="color: '. esc_attr( $icon_color ) .';"></div>';
				}
			} else {
					$output .= $img['thumbnail'];
			}
			$output .= '<span class="count-value" id="count-' . esc_attr( $id ) . '">0</span>'. $units;
			
			if ( ! empty( $caption ) ) {
			$output .= '<span class="count-caption">' . esc_html( $caption ) . '</span>';
			}
			
		$output .= '</div>';
		
	} else if ( $style == '4' ) {
		
		$output .= '<div class="count-wrapper clearfix '. esc_attr( $style_class ) .' '. esc_attr( $animation ) .'" data-count="count-'. esc_attr( $id ) .'" data-end="' . esc_attr( $number ) .'">';
			if ( ! empty( $icon_name ) ) {
				if ( $icon_color == NULL ) {
					$output .= '<div class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon"></div>';
				} else {
					$output .= '<div class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon" style="color: '. esc_attr( $icon_color ) .';"></div>';
				}
			} else {
					$output .= $img['thumbnail'];
			}
			$output .= '<span class="count-value" id="count-' . esc_attr( $id ) . '">0</span>'. $units;
			$output .= '<span class="count-caption">' . esc_html( $caption ) . '</span>';
		$output .= '</div>';
		
	} else if ( $style == '5' ) {
		
		$output .= '<div class="count-wrapper '. esc_attr( $style_class ) .' '. esc_attr( $animation ) .' clearfix" data-count="count-'. esc_attr( $id ) .'" data-end="' . esc_attr( $number ) .'">';
			if ( ! empty( $icon_name ) ) {
				if ( $icon_color == NULL ) {
					$output .= '<div class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon"></div>';
				} else {
					$output .= '<div class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon" style="color: '. esc_attr( $icon_color ) .';"></div>';
				}
			} else {
					$output .= $img['thumbnail'];
			}
			$output .= '<span class="count-value" id="count-' . esc_attr( $id ) . '">0</span>'. $units;
			$output .= '<span class="count-caption">' . esc_html( $caption ) . '</span>';
		$output .= '</div>';
		
	} else if ( $style == '6' ) {
	
		$output .= '<div class="count-wrapper '. esc_attr( $style_class ) .' '. esc_attr( $animation ) .'" data-count="count-'. esc_attr( $id ) .'" data-end="' . esc_attr( $number ) .'">';
				if ( ! empty( $icon_name ) ) {
					if ( $icon_color == NULL ) {
						$output .= '<div class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon"></div>';
					} else {
						$output .= '<div class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon" style="color: '. esc_attr( $icon_color ) .';"></div>';
					}
				} else {
						$output .= $img['thumbnail'];
				}
			
			$output .= '<div class="count-caption-wrapper">';
				$output .= '<span class="count-caption">' . esc_html( $caption ) . '</span>';
				$output .= '<span class="count-value" id="count-' . esc_attr( $id ) . '">0</span>'. $units;
			$output .= '</div>';
		$output .= '</div>';
	
	} else {
		
		$output .= '<div class="count-wrapper '. esc_attr( $style_class ) .' '. esc_attr( $animation ) .'" data-count="count-'. esc_attr( $id ) .'" data-end="' . esc_attr( $number ) .'">';
			if ( ! empty( $icon_name ) ) {
				if ( $icon_color == NULL ) {
					$output .= '<div class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon"></div>';
				} else {
					$output .= '<div class="icon-'. esc_attr( $icon_name ) .' custom-pack-icon" style="color: '. esc_attr( $icon_color ) .';"></div>';
				}
			} else {
					$output .= $img['thumbnail'];
			}
			$output .= '<span class="count-caption">' . esc_html( $caption ) . '</span>';
			$output .= '<span class="count-value" id="count-' . $id . '">0</span>'. $units;
		$output .= '</div>';
		
	}

	return $output;
}
add_shortcode( 'mt_vc_counting', 'mt_vc_counting' );

vc_map( array(
  'name' => esc_html__( 'Counting MT', 'mega' ),
  'base' => 'mt_vc_counting',
  'icon' => 'icon-wpb-vc-mt',
  'category' => esc_html__( 'Content', 'mega' ),
  'weight' => 0,
  'params' => array(
     array(
      'type' => 'attach_image',
      'heading' => esc_html__( 'Image', 'mega' ),
      'param_name' => 'image',
      'value' => '',
      'description' => esc_html__( 'Select image from media library.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Image size', 'mega' ),
      'param_name' => 'img_size',
      'description' => esc_html__( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "thumbnail" size.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Icon name', 'mega' ),
      'param_name' => 'icon_name',
      'description' => sprintf( esc_html__( 'If you wish to use font icons, then use this field to add an icon name. You will need to install WordPress Icons - SVG plugin first. More at %s.', 'mega' ), '<a href="https://wordpress.org/plugins/svg-vector-icon-plugin/" target="_blank">WordPress Icons - SVG</a>' ),
    ),
	array(
		'type' => 'colorpicker',
		'heading' => esc_html__( 'Icon color', 'mega' ),
		'param_name' => 'icon_color',
		'value' => NULL,
		'description' => esc_html__( 'Choose a value for icon color.', 'mega' ),
	),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Number', 'mega' ),
      'param_name' => 'number',
      'description' => esc_html__( 'Enter number.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Caption', 'mega' ),
      'param_name' => 'caption',
      'description' => esc_html__( 'Enter number.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Id', 'mega' ),
      'param_name' => 'id',
      'description' => esc_html__( 'Enter id.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Units', 'mega' ),
      'param_name' => 'units',
      'description' => esc_html__( 'Enter measurement units (if needed) Eg. %, px, points, etc.', 'mega' ),
    ),
	array(
	  'type' => 'dropdown',
	  'heading' => esc_html__( 'Counting style', 'mega' ),
	  'param_name' => 'style',
	  'value' => array( 1, 2, 3, 4, 5, 6 ),
	  'description' => esc_html__( 'Select style for counting.', 'mega' ),
	),
	array(
	  'type' => 'checkbox',
	  'heading' => esc_html__( 'Enable animation', 'mega' ),
	  'param_name' => 'animation',
	  'description' => esc_html__( 'Select animation if you want portfolio to be animated when it enters into the browsers viewport.', 'mega' ),
	  'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
	),
  ),
) );

// Lightbox Video MT
function mt_vc_lightbox_video( $atts, $content = null ) {
	 extract( shortcode_atts( array(
		'image' => '',
		'img_size' => 'thumbnail',
		'max_width' => '',
		'url' => '',
		'text' => '',
		'style' => '',
		'css_animation' => '',
		'lazyload' => '',
		'css_class' => '',
	), $atts ) );
	
	wp_enqueue_script( 'lightgallery' );
	
	if ( $style == '2' ) {
		$style_class = 'lightbox-video-style-2';
	} else if ( $style == '3' ) {
		$style_class = 'lightbox-video-style-3';
	} else if ( $style == '4' ) {
		$style_class = 'lightbox-video-style-4';
	} else {
		$style_class = 'lightbox-video-style-1';
	}
	
	$img_id = preg_replace( '/[^\d]/', '', $image );
	$img = wpb_getImageBySize( array( 'attach_id' => $img_id, 'thumb_size' => $img_size ) );
	
	if ( $lazyload != '' && $lazyload != '0' && ! empty( $img['thumbnail'] ) ) {
		$img_lazy = preg_replace( '/(<[^>]+) srcset=".*?"/i', '\1', $img['thumbnail'] );
		$img_lazy = preg_replace( '/(<[^>]+) sizes=".*?"/i', '\1', $img_lazy );
		$img_lazy = str_replace( 'src=', 'data-src=', $img_lazy );
		$img_lazy = str_replace( '/>', 'src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7">', $img_lazy );
		if ( in_array( $img_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full', ) ) ) {
			$img_attr = wp_get_attachment_image_src( $img_id, $img_size );
			$width = $img_attr[1];
			$height = $img_attr[2];
		} else {
			$size = str_replace( 'x', ',', $img_size );
			$width = explode( ',', $size );
			$width = $width[0];
			$height = substr( $size, strpos( $size, "," ) + 1 );
		}
	}
	
	if ( !empty( $img ) ) {
		$image_class = 'image-enabled';
	} else {
		$image_class = 'image-disabled';
	}
	
	if ( $css_animation != '' ) {
        wp_enqueue_script( 'waypoints' );
		$CSSAnimation = ' wpb_animate_when_almost_visible wpb_'.$css_animation;
    } else {
		$CSSAnimation = 'no-animation';
	}
	
	$output = '';
	
	if ( $style == '4' ) {
	
		$output .= '<div class="vc_btn3-container  special-button no-margin vc_btn3-center">';
			$output .= '<a href="'. esc_url( $url ) .'" class="vc_general vc_btn3 vc_btn3-size-md vc_btn3-shape-rounded vc_btn3-style-modern vc_btn3-color-grey play-button">';
				$output .= '<span>'. esc_html( $text ) .'</span>';
			$output .= '</a>';
		$output .= '</div>';
	
	} else {
		
		if ( !empty( $max_width ) ) {
			$output .= '<div class="lightbox-video-wrapper clearfix '. esc_attr( $CSSAnimation ) .' '.  esc_attr( $style_class ) .' '.  esc_attr( $image_class ) .' '. esc_attr( $css_class ) .'" style="max-width: '. esc_attr( $max_width ) .';">';
		} else {
			$output .= '<div class="lightbox-video-wrapper clearfix '. esc_attr( $CSSAnimation ) .' '.  esc_attr( $style_class ) .' '.  esc_attr( $image_class ) .' '. esc_attr( $css_class ) .'">';
		}
			if ($lazyload!= '' && $lazyload!= '0' && ! empty( $img['thumbnail'] ) ) {
				$output .= '<div class="lightbox-video lazy" style="--aspect-ratio: '. esc_attr( ( $width / $height ) ) .';">';
			} else {
				$output .= '<div class="lightbox-video">';
			}
					$output .= '<a data-lightgallery="gallery" href="'. esc_url( $url ) .'" class="play-button"><i></i></a>';
					if ( !empty( $text ) ) {
						$output .= '<div class="lightbox-video-text">'. esc_html( $text ) .'</div>';
					}
					if ( !empty( $img ) ) {
						
						if ($lazyload!= '' && $lazyload!= '0' && ! empty( $img['thumbnail'] ) ) {
							$output .= $img_lazy;
							$output .= '<span class="loaderbg"></span>';
						} else {
							$output .= $img['thumbnail'];
						}
						$output .= '<div class="lightbox-video-overlay"></div>';
					}
			$output .= '</div>';
		$output .= '</div>';
		
	}

	return $output;
}
add_shortcode( 'mt_vc_lightbox_video', 'mt_vc_lightbox_video' );

vc_map( array(
  'name' => esc_html__( 'Lightbox Video MT', 'mega' ),
  'base' => 'mt_vc_lightbox_video',
  'icon' => 'icon-wpb-vc-mt',
  'category' => esc_html__( 'Content', 'mega' ),
  'weight' => 0,
  'params' => array(
     array(
      'type' => 'attach_image',
      'heading' => esc_html__( 'Image', 'mega' ),
      'param_name' => 'image',
      'value' => '',
      'description' => esc_html__( 'Select image from media library.', 'mega' ),
    ),
	 array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Image size', 'mega' ),
      'param_name' => 'img_size',
      'description' => esc_html__( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "thumbnail" size.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Max width', 'mega' ),
      'param_name' => 'max_width',
      'description' => esc_html__( 'Enter max width in pixels. Example: 600px.', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Video URL', 'mega' ),
      'param_name' => 'url',
      'description' => esc_html__( 'Enter link to video', 'mega' ),
    ),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Text', 'mega' ),
      'param_name' => 'text',
      'description' => esc_html__( 'Enter text', 'mega' ),
    ),
	array(
	  'type' => 'dropdown',
	  'heading' => esc_html__( 'Lightbox Video style', 'mega' ),
	  'param_name' => 'style',
	  'value' => array( 1, 2, 3, 4 ),
	  'description' => esc_html__( 'Select style for lightbox video.', 'mega' ),
	),
	$add_css_animation = array(
		'type' => 'dropdown',
		'heading' => esc_html__( 'CSS Animation', 'mega' ),
		'param_name' => 'css_animation',
		'value' => array(
			esc_html__( 'No', 'mega' ) => '',
			esc_html__( 'Bottom to top', 'mega' ) => 'bottom-to-top',
			esc_html__( 'Left to right', 'mega' ) => 'left-to-right',
			esc_html__( 'Right to left', 'mega' ) => 'right-to-left',
		),
		'description' => esc_html__( 'Select type of animation if you want this element to be animated when it enters into the browsers viewport. Note: Works only in modern browsers.', 'mega' ),
	),
	array(
		'type' => 'checkbox',
		'heading' => esc_html__( 'Enable lazyload', 'mega' ),
		'param_name' => 'lazyload',
		'description' => esc_html__( 'Select lazyload if you want image to be loaded when it enters into the browsers viewport.', 'mega' ),
		'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
	),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Extra class name', 'mega' ),
      'param_name' => 'css_class',
      'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'mega' ),
    ),
  ),
) );

// Scroll Down MT
function mt_vc_scroll_down_button( $atts, $content = null ) {
	extract( shortcode_atts( array(
		'text' => '',
		'style' => '',
		'css_class' => '',
	), $atts ) );
		
	if ( !empty( $text ) ) {
		$text_class = 'text-enabled';
	} else {
		$text_class = 'text-disabled';
	}
	
	$output = '';
	
	if ( $style == '2' ) {
		
		$output .= '<div class="mouse '. esc_attr( $css_class ) .'">';
			$output .= '<div><i></i></div>';
			$output .= '<span>'. esc_html( $text ) .'</span>';
			$output .= '<i class="arrow-down"></i>';
		$output .= '</div>';
		
	} else {
		
		$output .= '<div class="scroll-down-button-wrapper '. esc_attr( $text_class ) .'">';
			$output .= '<div class="scroll-down-button clearfix '. esc_attr( $css_class ) .'">';
				if ( !empty( $text ) ) {
					$output .= '<span class="scroll-down-button-text">'. esc_html( $text ) .'</span>';
				}
						$output .= '<i class="scroll-down-button-icon"></i>';
			$output .= '</div><!-- .scroll-down-button -->';
		$output .= '</div><!-- .scroll-down-button-wrapper -->';
		
	}

	return $output;
}
add_shortcode( 'mt_vc_scroll_down_button', 'mt_vc_scroll_down_button' );

vc_map( array(
  'name' => esc_html__( 'Scroll Down MT', 'mega' ),
  'base' => 'mt_vc_scroll_down_button',
  'icon' => 'icon-wpb-vc-mt',
  'category' => esc_html__( 'Content', 'mega' ),
  'weight' => 0,
  'params' => array(
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Text', 'mega' ),
      'param_name' => 'text',
      'description' => esc_html__( 'Enter scroll down button text.', 'mega' ),
    ),
	array(
	  'type' => 'dropdown',
	  'heading' => esc_html__( 'Style', 'mega' ),
	  'param_name' => 'style',
	  'value' => array( 1, 2 ),
	),
	array(
      'type' => 'textfield',
      'heading' => esc_html__( 'Extra class name', 'mega' ),
      'param_name' => 'css_class',
      'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'mega' ),
    ),
  ),
) );

// Single Image
$mega_vc_single_image_attributes = array(
	array(
		'type' => 'checkbox',
		'heading' => esc_html__( 'Enable lazyload', 'mega' ),
		'param_name' => 'lazyload',
		'description' => esc_html__( 'Select lazyload if you want image to be loaded when it enters into the browsers viewport.', 'mega' ),
		'value' => Array( esc_html__( 'Yes', 'mega' ) => true ),
	),
);
vc_add_params( 'vc_single_image', $mega_vc_single_image_attributes );

// Button Color
function add_button_from_customizer_color() {
	$param = WPBMap::getParam( 'vc_btn', 'color' );
	$param['value'][__( 'From Customizer', 'mega' )] = 'from-customizer';
	vc_update_shortcode_param( 'vc_btn', $param );
}
add_action( 'vc_after_init', 'add_button_from_customizer_color' );

// Button Shape
function add_button_from_customizer_shape() {
	$param = WPBMap::getParam( 'vc_btn', 'shape' );
	$param['value'][__( 'Super Round', 'mega' )] = 'superround';
	vc_update_shortcode_param( 'vc_btn', $param );
}
add_action( 'vc_after_init', 'add_button_from_customizer_shape' );

// Image Gallery
add_action( 'vc_after_init', function() {
	$newParamData = array(
		'type' => 'dropdown',
		'heading' => esc_html__( 'Gallery type', 'mega' ),
		'param_name' => 'type',
		'value' => array(
			esc_html__( 'Flex slider fade', 'mega' ) => 'flexslider_fade',
			esc_html__( 'Flex slider slide', 'mega' ) => 'flexslider_slide',
			//esc_html__( 'Nivo slider', 'mega' ) => 'nivo',
			esc_html__( 'Image grid', 'mega' ) => 'image_grid',
		),
		'description' => esc_html__( 'Select gallery type.', 'mega' ),
	); 
	vc_update_shortcode_param( 'vc_gallery', $newParamData );
} );

// Posts Slider
add_action( 'vc_after_init', function() {
	$newParamData = array(
		'type' => 'dropdown',
		'heading' => esc_html__( 'Slider type', 'mega' ),
		'param_name' => 'type',
		'admin_label' => true,
		'value' => array(
			esc_html__( 'Flex slider fade', 'mega' ) => 'flexslider_fade',
			esc_html__( 'Flex slider slide', 'mega' ) => 'flexslider_slide',
			//esc_html__( 'Nivo slider', 'mega' ) => 'nivo',
		),
		'description' => esc_html__( 'Select slider type.', 'mega' ),
	); 
	vc_update_shortcode_param( 'vc_posts_slider', $newParamData );
} );

// Row
vc_remove_param( 'vc_row', 'video_bg' );
vc_remove_param( 'vc_row', 'video_bg_url' );
vc_remove_param( 'vc_row', 'video_bg_parallax' );
vc_remove_param( 'vc_row', 'parallax_speed_video' );
